/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 7571
#define LARGE_STATE_COUNT 523
#define SYMBOL_COUNT 280
#define ALIAS_COUNT 0
#define TOKEN_COUNT 174
#define EXTERNAL_TOKEN_COUNT 29
#define FIELD_COUNT 19
#define MAX_ALIAS_SEQUENCE_LENGTH 8
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 159
#define SUPERTYPE_COUNT 1

enum ts_symbol_identifiers {
  sym_word = 1,
  anon_sym_for = 2,
  anon_sym_select = 3,
  anon_sym_in = 4,
  anon_sym_LPAREN_LPAREN = 5,
  anon_sym_RPAREN_RPAREN = 6,
  anon_sym_SEMI = 7,
  anon_sym_COMMA = 8,
  anon_sym_EQ = 9,
  anon_sym_PLUS_PLUS = 10,
  anon_sym_DASH_DASH = 11,
  anon_sym_PLUS_EQ = 12,
  anon_sym_DASH_EQ = 13,
  anon_sym_STAR_EQ = 14,
  anon_sym_SLASH_EQ = 15,
  anon_sym_PERCENT_EQ = 16,
  anon_sym_STAR_STAR_EQ = 17,
  anon_sym_LT_LT_EQ = 18,
  anon_sym_GT_GT_EQ = 19,
  anon_sym_AMP_EQ = 20,
  anon_sym_CARET_EQ = 21,
  anon_sym_PIPE_EQ = 22,
  anon_sym_PIPE_PIPE = 23,
  anon_sym_DASHo = 24,
  anon_sym_AMP_AMP = 25,
  anon_sym_DASHa = 26,
  anon_sym_PIPE = 27,
  anon_sym_CARET = 28,
  anon_sym_AMP = 29,
  anon_sym_EQ_EQ = 30,
  anon_sym_BANG_EQ = 31,
  anon_sym_LT = 32,
  anon_sym_GT = 33,
  anon_sym_LT_EQ = 34,
  anon_sym_GT_EQ = 35,
  anon_sym_LT_LT = 36,
  anon_sym_GT_GT = 37,
  anon_sym_PLUS = 38,
  anon_sym_DASH = 39,
  anon_sym_STAR = 40,
  anon_sym_SLASH = 41,
  anon_sym_PERCENT = 42,
  anon_sym_STAR_STAR = 43,
  anon_sym_LPAREN = 44,
  anon_sym_RPAREN = 45,
  aux_sym__c_word_token1 = 46,
  anon_sym_while = 47,
  anon_sym_until = 48,
  anon_sym_do = 49,
  anon_sym_done = 50,
  anon_sym_if = 51,
  anon_sym_then = 52,
  anon_sym_fi = 53,
  anon_sym_elif = 54,
  anon_sym_else = 55,
  anon_sym_case = 56,
  anon_sym_esac = 57,
  anon_sym_SEMI_SEMI = 58,
  anon_sym_SEMI_AMP = 59,
  anon_sym_SEMI_SEMI_AMP = 60,
  anon_sym_function = 61,
  anon_sym_LBRACE = 62,
  anon_sym_RBRACE = 63,
  anon_sym_PIPE_AMP = 64,
  anon_sym_BANG = 65,
  anon_sym_LBRACK = 66,
  anon_sym_RBRACK = 67,
  anon_sym_LBRACK_LBRACK = 68,
  anon_sym_RBRACK_RBRACK = 69,
  anon_sym_declare = 70,
  anon_sym_typeset = 71,
  anon_sym_export = 72,
  anon_sym_readonly = 73,
  anon_sym_local = 74,
  anon_sym_unset = 75,
  anon_sym_unsetenv = 76,
  anon_sym_EQ_TILDE = 77,
  anon_sym_AMP_GT = 78,
  anon_sym_AMP_GT_GT = 79,
  anon_sym_LT_AMP = 80,
  anon_sym_GT_AMP = 81,
  anon_sym_GT_PIPE = 82,
  anon_sym_LT_AMP_DASH = 83,
  anon_sym_GT_AMP_DASH = 84,
  anon_sym_LT_LT_DASH = 85,
  aux_sym_heredoc_redirect_token1 = 86,
  anon_sym_LT_LT_LT = 87,
  anon_sym_QMARK = 88,
  anon_sym_COLON = 89,
  anon_sym_PLUS_PLUS2 = 90,
  anon_sym_DASH_DASH2 = 91,
  anon_sym_DASH2 = 92,
  anon_sym_PLUS2 = 93,
  anon_sym_TILDE = 94,
  anon_sym_DOLLAR_LPAREN_LPAREN = 95,
  anon_sym_DOLLAR_LBRACK = 96,
  aux_sym_brace_expression_token1 = 97,
  anon_sym_DOT_DOT = 98,
  anon_sym_RBRACE2 = 99,
  aux_sym_concatenation_token1 = 100,
  anon_sym_DOLLAR = 101,
  sym__special_character = 102,
  anon_sym_DQUOTE = 103,
  sym_string_content = 104,
  sym_raw_string = 105,
  sym_ansi_c_string = 106,
  aux_sym_number_token1 = 107,
  aux_sym_number_token2 = 108,
  anon_sym_POUND = 109,
  anon_sym_DOLLAR_LBRACE = 110,
  anon_sym_RBRACE3 = 111,
  anon_sym_BANG2 = 112,
  anon_sym_AT = 113,
  anon_sym_STAR2 = 114,
  anon_sym_POUND2 = 115,
  anon_sym_EQ2 = 116,
  anon_sym_COLON_EQ = 117,
  anon_sym_DASH3 = 118,
  anon_sym_COLON_DASH = 119,
  anon_sym_PLUS3 = 120,
  anon_sym_COLON_PLUS = 121,
  anon_sym_QMARK2 = 122,
  anon_sym_COLON_QMARK = 123,
  anon_sym_PERCENT_PERCENT = 124,
  aux_sym__expansion_regex_token1 = 125,
  anon_sym_SLASH_SLASH = 126,
  anon_sym_SLASH_POUND = 127,
  anon_sym_SLASH_PERCENT = 128,
  anon_sym_COMMA_COMMA = 129,
  anon_sym_CARET_CARET = 130,
  anon_sym_U = 131,
  anon_sym_u = 132,
  anon_sym_L = 133,
  anon_sym_Q = 134,
  anon_sym_E = 135,
  anon_sym_P = 136,
  anon_sym_A = 137,
  anon_sym_K = 138,
  anon_sym_a = 139,
  anon_sym_k = 140,
  anon_sym_DOLLAR_LPAREN = 141,
  anon_sym_BQUOTE = 142,
  anon_sym_DOLLAR_BQUOTE = 143,
  anon_sym_LT_LPAREN = 144,
  anon_sym_GT_LPAREN = 145,
  sym_comment = 146,
  sym__comment_word = 147,
  aux_sym__simple_variable_name_token1 = 148,
  aux_sym__multiline_variable_name_token1 = 149,
  anon_sym_AT2 = 150,
  anon_sym__ = 151,
  sym_heredoc_start = 152,
  sym_simple_heredoc_body = 153,
  sym__heredoc_body_beginning = 154,
  sym_heredoc_content = 155,
  sym_heredoc_end = 156,
  sym_file_descriptor = 157,
  sym__empty_value = 158,
  sym__concat = 159,
  sym_variable_name = 160,
  sym_test_operator = 161,
  sym_regex = 162,
  sym__regex_no_slash = 163,
  sym__regex_no_space = 164,
  sym__expansion_word = 165,
  sym_extglob_pattern = 166,
  sym__bare_dollar = 167,
  sym__brace_start = 168,
  sym__immediate_double_hash = 169,
  sym__external_expansion_sym_hash = 170,
  sym__external_expansion_sym_bang = 171,
  sym__external_expansion_sym_equal = 172,
  sym___error_recovery = 173,
  sym_program = 174,
  sym__statements = 175,
  aux_sym__terminated_statement = 176,
  sym__statement_not_pipeline = 177,
  sym_redirected_statement = 178,
  sym_for_statement = 179,
  sym_c_style_for_statement = 180,
  sym__for_body = 181,
  sym__c_expression = 182,
  sym__c_expression_not_assignment = 183,
  sym__c_variable_assignment = 184,
  sym__c_unary_expression = 185,
  sym__c_binary_expression = 186,
  sym__c_postfix_expression = 187,
  sym__c_parenthesized_expression = 188,
  sym_while_statement = 189,
  sym_do_group = 190,
  sym_if_statement = 191,
  sym_elif_clause = 192,
  sym_else_clause = 193,
  sym_case_statement = 194,
  sym_case_item = 195,
  sym_last_case_item = 196,
  sym_function_definition = 197,
  sym_compound_statement = 198,
  sym_subshell = 199,
  sym_pipeline = 200,
  sym_list = 201,
  sym_negated_command = 202,
  sym_test_command = 203,
  sym__test_command_binary_expression = 204,
  sym_declaration_command = 205,
  sym_unset_command = 206,
  sym_command = 207,
  sym_command_name = 208,
  sym_variable_assignment = 209,
  sym_variable_assignments = 210,
  sym_subscript = 211,
  sym_file_redirect = 212,
  sym_heredoc_redirect = 213,
  sym__heredoc_pipeline = 214,
  sym__heredoc_expression = 215,
  aux_sym__heredoc_command = 216,
  sym__heredoc_body = 217,
  sym_heredoc_body = 218,
  sym__simple_heredoc_body = 219,
  sym_herestring_redirect = 220,
  sym__expression = 221,
  sym_binary_expression = 222,
  sym_ternary_expression = 223,
  sym_unary_expression = 224,
  sym_postfix_expression = 225,
  sym_parenthesized_expression = 226,
  sym_arithmetic_expansion = 227,
  sym_brace_expression = 228,
  sym__arithmetic_expression = 229,
  sym__arithmetic_literal = 230,
  sym__arithmetic_binary_expression = 231,
  sym__arithmetic_ternary_expression = 232,
  sym__arithmetic_unary_expression = 233,
  sym__arithmetic_postfix_expression = 234,
  sym__arithmetic_parenthesized_expression = 235,
  sym_concatenation = 236,
  sym_string = 237,
  sym_translated_string = 238,
  sym_array = 239,
  sym_number = 240,
  sym_simple_expansion = 241,
  sym_expansion = 242,
  sym__expansion_body = 243,
  sym__expansion_expression = 244,
  sym__expansion_regex = 245,
  sym__expansion_regex_replacement = 246,
  sym__expansion_regex_removal = 247,
  sym__expansion_max_length = 248,
  sym__expansion_max_length_expression = 249,
  sym__expansion_max_length_binary_expression = 250,
  sym__expansion_operator = 251,
  sym__concatenation_in_expansion = 252,
  sym_command_substitution = 253,
  sym_process_substitution = 254,
  sym__extglob_blob = 255,
  sym__c_terminator = 256,
  aux_sym__statements_repeat1 = 257,
  aux_sym_redirected_statement_repeat1 = 258,
  aux_sym_redirected_statement_repeat2 = 259,
  aux_sym_for_statement_repeat1 = 260,
  aux_sym__for_body_repeat1 = 261,
  aux_sym_if_statement_repeat1 = 262,
  aux_sym_case_statement_repeat1 = 263,
  aux_sym_case_item_repeat1 = 264,
  aux_sym_compound_statement_repeat1 = 265,
  aux_sym_pipeline_repeat1 = 266,
  aux_sym_declaration_command_repeat1 = 267,
  aux_sym_unset_command_repeat1 = 268,
  aux_sym_command_repeat1 = 269,
  aux_sym_command_repeat2 = 270,
  aux_sym_variable_assignments_repeat1 = 271,
  aux_sym_heredoc_body_repeat1 = 272,
  aux_sym__literal_repeat1 = 273,
  aux_sym_arithmetic_expansion_repeat1 = 274,
  aux_sym_concatenation_repeat1 = 275,
  aux_sym_string_repeat1 = 276,
  aux_sym__expansion_body_repeat1 = 277,
  aux_sym__expansion_regex_repeat1 = 278,
  aux_sym__concatenation_in_expansion_repeat1 = 279,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_word] = "word",
  [anon_sym_for] = "for",
  [anon_sym_select] = "select",
  [anon_sym_in] = "in",
  [anon_sym_LPAREN_LPAREN] = "((",
  [anon_sym_RPAREN_RPAREN] = "))",
  [anon_sym_SEMI] = ";",
  [anon_sym_COMMA] = ",",
  [anon_sym_EQ] = "=",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_STAR_STAR_EQ] = "**=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DASHo] = "-o",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_DASHa] = "-a",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_AMP] = "&",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [aux_sym__c_word_token1] = "word",
  [anon_sym_while] = "while",
  [anon_sym_until] = "until",
  [anon_sym_do] = "do",
  [anon_sym_done] = "done",
  [anon_sym_if] = "if",
  [anon_sym_then] = "then",
  [anon_sym_fi] = "fi",
  [anon_sym_elif] = "elif",
  [anon_sym_else] = "else",
  [anon_sym_case] = "case",
  [anon_sym_esac] = "esac",
  [anon_sym_SEMI_SEMI] = ";;",
  [anon_sym_SEMI_AMP] = ";&",
  [anon_sym_SEMI_SEMI_AMP] = ";;&",
  [anon_sym_function] = "function",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_PIPE_AMP] = "|&",
  [anon_sym_BANG] = "!",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACK_LBRACK] = "[[",
  [anon_sym_RBRACK_RBRACK] = "]]",
  [anon_sym_declare] = "declare",
  [anon_sym_typeset] = "typeset",
  [anon_sym_export] = "export",
  [anon_sym_readonly] = "readonly",
  [anon_sym_local] = "local",
  [anon_sym_unset] = "unset",
  [anon_sym_unsetenv] = "unsetenv",
  [anon_sym_EQ_TILDE] = "=~",
  [anon_sym_AMP_GT] = "&>",
  [anon_sym_AMP_GT_GT] = "&>>",
  [anon_sym_LT_AMP] = "<&",
  [anon_sym_GT_AMP] = ">&",
  [anon_sym_GT_PIPE] = ">|",
  [anon_sym_LT_AMP_DASH] = "<&-",
  [anon_sym_GT_AMP_DASH] = ">&-",
  [anon_sym_LT_LT_DASH] = "<<-",
  [aux_sym_heredoc_redirect_token1] = "heredoc_redirect_token1",
  [anon_sym_LT_LT_LT] = "<<<",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON] = ":",
  [anon_sym_PLUS_PLUS2] = "++",
  [anon_sym_DASH_DASH2] = "--",
  [anon_sym_DASH2] = "-",
  [anon_sym_PLUS2] = "+",
  [anon_sym_TILDE] = "~",
  [anon_sym_DOLLAR_LPAREN_LPAREN] = "$((",
  [anon_sym_DOLLAR_LBRACK] = "$[",
  [aux_sym_brace_expression_token1] = "number",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_RBRACE2] = "}",
  [aux_sym_concatenation_token1] = "``",
  [anon_sym_DOLLAR] = "$",
  [sym__special_character] = "_special_character",
  [anon_sym_DQUOTE] = "\"",
  [sym_string_content] = "string_content",
  [sym_raw_string] = "raw_string",
  [sym_ansi_c_string] = "ansi_c_string",
  [aux_sym_number_token1] = "number_token1",
  [aux_sym_number_token2] = "number_token2",
  [anon_sym_POUND] = "#",
  [anon_sym_DOLLAR_LBRACE] = "${",
  [anon_sym_RBRACE3] = "}",
  [anon_sym_BANG2] = "!",
  [anon_sym_AT] = "@",
  [anon_sym_STAR2] = "*",
  [anon_sym_POUND2] = "#",
  [anon_sym_EQ2] = "=",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_DASH3] = "-",
  [anon_sym_COLON_DASH] = ":-",
  [anon_sym_PLUS3] = "+",
  [anon_sym_COLON_PLUS] = ":+",
  [anon_sym_QMARK2] = "\?",
  [anon_sym_COLON_QMARK] = ":\?",
  [anon_sym_PERCENT_PERCENT] = "%%",
  [aux_sym__expansion_regex_token1] = "regex",
  [anon_sym_SLASH_SLASH] = "//",
  [anon_sym_SLASH_POUND] = "/#",
  [anon_sym_SLASH_PERCENT] = "/%",
  [anon_sym_COMMA_COMMA] = ",,",
  [anon_sym_CARET_CARET] = "^^",
  [anon_sym_U] = "U",
  [anon_sym_u] = "u",
  [anon_sym_L] = "L",
  [anon_sym_Q] = "Q",
  [anon_sym_E] = "E",
  [anon_sym_P] = "P",
  [anon_sym_A] = "A",
  [anon_sym_K] = "K",
  [anon_sym_a] = "a",
  [anon_sym_k] = "k",
  [anon_sym_DOLLAR_LPAREN] = "$(",
  [anon_sym_BQUOTE] = "`",
  [anon_sym_DOLLAR_BQUOTE] = "$`",
  [anon_sym_LT_LPAREN] = "<(",
  [anon_sym_GT_LPAREN] = ">(",
  [sym_comment] = "comment",
  [sym__comment_word] = "word",
  [aux_sym__simple_variable_name_token1] = "variable_name",
  [aux_sym__multiline_variable_name_token1] = "variable_name",
  [anon_sym_AT2] = "special_variable_name",
  [anon_sym__] = "special_variable_name",
  [sym_heredoc_start] = "heredoc_start",
  [sym_simple_heredoc_body] = "heredoc_body",
  [sym__heredoc_body_beginning] = "_heredoc_body_beginning",
  [sym_heredoc_content] = "heredoc_content",
  [sym_heredoc_end] = "heredoc_end",
  [sym_file_descriptor] = "file_descriptor",
  [sym__empty_value] = "_empty_value",
  [sym__concat] = "_concat",
  [sym_variable_name] = "variable_name",
  [sym_test_operator] = "test_operator",
  [sym_regex] = "regex",
  [sym__regex_no_slash] = "regex",
  [sym__regex_no_space] = "regex",
  [sym__expansion_word] = "word",
  [sym_extglob_pattern] = "extglob_pattern",
  [sym__bare_dollar] = "$",
  [sym__brace_start] = "{",
  [sym__immediate_double_hash] = "##",
  [sym__external_expansion_sym_hash] = "#",
  [sym__external_expansion_sym_bang] = "!",
  [sym__external_expansion_sym_equal] = "=",
  [sym___error_recovery] = "__error_recovery",
  [sym_program] = "program",
  [sym__statements] = "_statements",
  [aux_sym__terminated_statement] = "_terminated_statement",
  [sym__statement_not_pipeline] = "_statement_not_pipeline",
  [sym_redirected_statement] = "redirected_statement",
  [sym_for_statement] = "for_statement",
  [sym_c_style_for_statement] = "c_style_for_statement",
  [sym__for_body] = "_for_body",
  [sym__c_expression] = "_c_expression",
  [sym__c_expression_not_assignment] = "_c_expression_not_assignment",
  [sym__c_variable_assignment] = "variable_assignment",
  [sym__c_unary_expression] = "unary_expression",
  [sym__c_binary_expression] = "binary_expression",
  [sym__c_postfix_expression] = "postfix_expression",
  [sym__c_parenthesized_expression] = "parenthesized_expression",
  [sym_while_statement] = "while_statement",
  [sym_do_group] = "do_group",
  [sym_if_statement] = "if_statement",
  [sym_elif_clause] = "elif_clause",
  [sym_else_clause] = "else_clause",
  [sym_case_statement] = "case_statement",
  [sym_case_item] = "case_item",
  [sym_last_case_item] = "case_item",
  [sym_function_definition] = "function_definition",
  [sym_compound_statement] = "compound_statement",
  [sym_subshell] = "subshell",
  [sym_pipeline] = "pipeline",
  [sym_list] = "list",
  [sym_negated_command] = "negated_command",
  [sym_test_command] = "test_command",
  [sym__test_command_binary_expression] = "binary_expression",
  [sym_declaration_command] = "declaration_command",
  [sym_unset_command] = "unset_command",
  [sym_command] = "command",
  [sym_command_name] = "command_name",
  [sym_variable_assignment] = "variable_assignment",
  [sym_variable_assignments] = "variable_assignments",
  [sym_subscript] = "subscript",
  [sym_file_redirect] = "file_redirect",
  [sym_heredoc_redirect] = "heredoc_redirect",
  [sym__heredoc_pipeline] = "pipeline",
  [sym__heredoc_expression] = "_heredoc_expression",
  [aux_sym__heredoc_command] = "_heredoc_command",
  [sym__heredoc_body] = "_heredoc_body",
  [sym_heredoc_body] = "heredoc_body",
  [sym__simple_heredoc_body] = "_simple_heredoc_body",
  [sym_herestring_redirect] = "herestring_redirect",
  [sym__expression] = "_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_postfix_expression] = "postfix_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_arithmetic_expansion] = "arithmetic_expansion",
  [sym_brace_expression] = "brace_expression",
  [sym__arithmetic_expression] = "_arithmetic_expression",
  [sym__arithmetic_literal] = "_arithmetic_literal",
  [sym__arithmetic_binary_expression] = "binary_expression",
  [sym__arithmetic_ternary_expression] = "ternary_expression",
  [sym__arithmetic_unary_expression] = "unary_expression",
  [sym__arithmetic_postfix_expression] = "postfix_expression",
  [sym__arithmetic_parenthesized_expression] = "parenthesized_expression",
  [sym_concatenation] = "concatenation",
  [sym_string] = "string",
  [sym_translated_string] = "translated_string",
  [sym_array] = "array",
  [sym_number] = "number",
  [sym_simple_expansion] = "simple_expansion",
  [sym_expansion] = "expansion",
  [sym__expansion_body] = "_expansion_body",
  [sym__expansion_expression] = "_expansion_expression",
  [sym__expansion_regex] = "_expansion_regex",
  [sym__expansion_regex_replacement] = "_expansion_regex_replacement",
  [sym__expansion_regex_removal] = "_expansion_regex_removal",
  [sym__expansion_max_length] = "_expansion_max_length",
  [sym__expansion_max_length_expression] = "_expansion_max_length_expression",
  [sym__expansion_max_length_binary_expression] = "binary_expression",
  [sym__expansion_operator] = "_expansion_operator",
  [sym__concatenation_in_expansion] = "concatenation",
  [sym_command_substitution] = "command_substitution",
  [sym_process_substitution] = "process_substitution",
  [sym__extglob_blob] = "_extglob_blob",
  [sym__c_terminator] = "_c_terminator",
  [aux_sym__statements_repeat1] = "_statements_repeat1",
  [aux_sym_redirected_statement_repeat1] = "redirected_statement_repeat1",
  [aux_sym_redirected_statement_repeat2] = "redirected_statement_repeat2",
  [aux_sym_for_statement_repeat1] = "for_statement_repeat1",
  [aux_sym__for_body_repeat1] = "_for_body_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_case_statement_repeat1] = "case_statement_repeat1",
  [aux_sym_case_item_repeat1] = "case_item_repeat1",
  [aux_sym_compound_statement_repeat1] = "compound_statement_repeat1",
  [aux_sym_pipeline_repeat1] = "pipeline_repeat1",
  [aux_sym_declaration_command_repeat1] = "declaration_command_repeat1",
  [aux_sym_unset_command_repeat1] = "unset_command_repeat1",
  [aux_sym_command_repeat1] = "command_repeat1",
  [aux_sym_command_repeat2] = "command_repeat2",
  [aux_sym_variable_assignments_repeat1] = "variable_assignments_repeat1",
  [aux_sym_heredoc_body_repeat1] = "heredoc_body_repeat1",
  [aux_sym__literal_repeat1] = "_literal_repeat1",
  [aux_sym_arithmetic_expansion_repeat1] = "arithmetic_expansion_repeat1",
  [aux_sym_concatenation_repeat1] = "concatenation_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym__expansion_body_repeat1] = "_expansion_body_repeat1",
  [aux_sym__expansion_regex_repeat1] = "_expansion_regex_repeat1",
  [aux_sym__concatenation_in_expansion_repeat1] = "_concatenation_in_expansion_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_word] = sym_word,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_select] = anon_sym_select,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_LPAREN_LPAREN] = anon_sym_LPAREN_LPAREN,
  [anon_sym_RPAREN_RPAREN] = anon_sym_RPAREN_RPAREN,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_STAR_STAR_EQ] = anon_sym_STAR_STAR_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DASHo] = anon_sym_DASHo,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_DASHa] = anon_sym_DASHa,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [aux_sym__c_word_token1] = sym_word,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_until] = anon_sym_until,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_done] = anon_sym_done,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_fi] = anon_sym_fi,
  [anon_sym_elif] = anon_sym_elif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_esac] = anon_sym_esac,
  [anon_sym_SEMI_SEMI] = anon_sym_SEMI_SEMI,
  [anon_sym_SEMI_AMP] = anon_sym_SEMI_AMP,
  [anon_sym_SEMI_SEMI_AMP] = anon_sym_SEMI_SEMI_AMP,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_PIPE_AMP] = anon_sym_PIPE_AMP,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACK_LBRACK] = anon_sym_LBRACK_LBRACK,
  [anon_sym_RBRACK_RBRACK] = anon_sym_RBRACK_RBRACK,
  [anon_sym_declare] = anon_sym_declare,
  [anon_sym_typeset] = anon_sym_typeset,
  [anon_sym_export] = anon_sym_export,
  [anon_sym_readonly] = anon_sym_readonly,
  [anon_sym_local] = anon_sym_local,
  [anon_sym_unset] = anon_sym_unset,
  [anon_sym_unsetenv] = anon_sym_unsetenv,
  [anon_sym_EQ_TILDE] = anon_sym_EQ_TILDE,
  [anon_sym_AMP_GT] = anon_sym_AMP_GT,
  [anon_sym_AMP_GT_GT] = anon_sym_AMP_GT_GT,
  [anon_sym_LT_AMP] = anon_sym_LT_AMP,
  [anon_sym_GT_AMP] = anon_sym_GT_AMP,
  [anon_sym_GT_PIPE] = anon_sym_GT_PIPE,
  [anon_sym_LT_AMP_DASH] = anon_sym_LT_AMP_DASH,
  [anon_sym_GT_AMP_DASH] = anon_sym_GT_AMP_DASH,
  [anon_sym_LT_LT_DASH] = anon_sym_LT_LT_DASH,
  [aux_sym_heredoc_redirect_token1] = aux_sym_heredoc_redirect_token1,
  [anon_sym_LT_LT_LT] = anon_sym_LT_LT_LT,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_PLUS_PLUS2] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH2] = anon_sym_DASH_DASH,
  [anon_sym_DASH2] = anon_sym_DASH,
  [anon_sym_PLUS2] = anon_sym_PLUS,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_DOLLAR_LPAREN_LPAREN] = anon_sym_DOLLAR_LPAREN_LPAREN,
  [anon_sym_DOLLAR_LBRACK] = anon_sym_DOLLAR_LBRACK,
  [aux_sym_brace_expression_token1] = sym_number,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_RBRACE2] = anon_sym_RBRACE,
  [aux_sym_concatenation_token1] = aux_sym_concatenation_token1,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [sym__special_character] = sym__special_character,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [sym_string_content] = sym_string_content,
  [sym_raw_string] = sym_raw_string,
  [sym_ansi_c_string] = sym_ansi_c_string,
  [aux_sym_number_token1] = aux_sym_number_token1,
  [aux_sym_number_token2] = aux_sym_number_token2,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_DOLLAR_LBRACE] = anon_sym_DOLLAR_LBRACE,
  [anon_sym_RBRACE3] = anon_sym_RBRACE,
  [anon_sym_BANG2] = anon_sym_BANG,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_STAR2] = anon_sym_STAR,
  [anon_sym_POUND2] = anon_sym_POUND,
  [anon_sym_EQ2] = anon_sym_EQ,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_DASH3] = anon_sym_DASH,
  [anon_sym_COLON_DASH] = anon_sym_COLON_DASH,
  [anon_sym_PLUS3] = anon_sym_PLUS,
  [anon_sym_COLON_PLUS] = anon_sym_COLON_PLUS,
  [anon_sym_QMARK2] = anon_sym_QMARK,
  [anon_sym_COLON_QMARK] = anon_sym_COLON_QMARK,
  [anon_sym_PERCENT_PERCENT] = anon_sym_PERCENT_PERCENT,
  [aux_sym__expansion_regex_token1] = sym_regex,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [anon_sym_SLASH_POUND] = anon_sym_SLASH_POUND,
  [anon_sym_SLASH_PERCENT] = anon_sym_SLASH_PERCENT,
  [anon_sym_COMMA_COMMA] = anon_sym_COMMA_COMMA,
  [anon_sym_CARET_CARET] = anon_sym_CARET_CARET,
  [anon_sym_U] = anon_sym_U,
  [anon_sym_u] = anon_sym_u,
  [anon_sym_L] = anon_sym_L,
  [anon_sym_Q] = anon_sym_Q,
  [anon_sym_E] = anon_sym_E,
  [anon_sym_P] = anon_sym_P,
  [anon_sym_A] = anon_sym_A,
  [anon_sym_K] = anon_sym_K,
  [anon_sym_a] = anon_sym_a,
  [anon_sym_k] = anon_sym_k,
  [anon_sym_DOLLAR_LPAREN] = anon_sym_DOLLAR_LPAREN,
  [anon_sym_BQUOTE] = anon_sym_BQUOTE,
  [anon_sym_DOLLAR_BQUOTE] = anon_sym_DOLLAR_BQUOTE,
  [anon_sym_LT_LPAREN] = anon_sym_LT_LPAREN,
  [anon_sym_GT_LPAREN] = anon_sym_GT_LPAREN,
  [sym_comment] = sym_comment,
  [sym__comment_word] = sym_word,
  [aux_sym__simple_variable_name_token1] = sym_variable_name,
  [aux_sym__multiline_variable_name_token1] = sym_variable_name,
  [anon_sym_AT2] = anon_sym_AT2,
  [anon_sym__] = anon_sym_AT2,
  [sym_heredoc_start] = sym_heredoc_start,
  [sym_simple_heredoc_body] = sym_heredoc_body,
  [sym__heredoc_body_beginning] = sym__heredoc_body_beginning,
  [sym_heredoc_content] = sym_heredoc_content,
  [sym_heredoc_end] = sym_heredoc_end,
  [sym_file_descriptor] = sym_file_descriptor,
  [sym__empty_value] = sym__empty_value,
  [sym__concat] = sym__concat,
  [sym_variable_name] = sym_variable_name,
  [sym_test_operator] = sym_test_operator,
  [sym_regex] = sym_regex,
  [sym__regex_no_slash] = sym_regex,
  [sym__regex_no_space] = sym_regex,
  [sym__expansion_word] = sym_word,
  [sym_extglob_pattern] = sym_extglob_pattern,
  [sym__bare_dollar] = anon_sym_DOLLAR,
  [sym__brace_start] = anon_sym_LBRACE,
  [sym__immediate_double_hash] = sym__immediate_double_hash,
  [sym__external_expansion_sym_hash] = anon_sym_POUND,
  [sym__external_expansion_sym_bang] = anon_sym_BANG,
  [sym__external_expansion_sym_equal] = anon_sym_EQ,
  [sym___error_recovery] = sym___error_recovery,
  [sym_program] = sym_program,
  [sym__statements] = sym__statements,
  [aux_sym__terminated_statement] = aux_sym__terminated_statement,
  [sym__statement_not_pipeline] = sym__statement_not_pipeline,
  [sym_redirected_statement] = sym_redirected_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_c_style_for_statement] = sym_c_style_for_statement,
  [sym__for_body] = sym__for_body,
  [sym__c_expression] = sym__c_expression,
  [sym__c_expression_not_assignment] = sym__c_expression_not_assignment,
  [sym__c_variable_assignment] = sym_variable_assignment,
  [sym__c_unary_expression] = sym_unary_expression,
  [sym__c_binary_expression] = sym_binary_expression,
  [sym__c_postfix_expression] = sym_postfix_expression,
  [sym__c_parenthesized_expression] = sym_parenthesized_expression,
  [sym_while_statement] = sym_while_statement,
  [sym_do_group] = sym_do_group,
  [sym_if_statement] = sym_if_statement,
  [sym_elif_clause] = sym_elif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_case_statement] = sym_case_statement,
  [sym_case_item] = sym_case_item,
  [sym_last_case_item] = sym_case_item,
  [sym_function_definition] = sym_function_definition,
  [sym_compound_statement] = sym_compound_statement,
  [sym_subshell] = sym_subshell,
  [sym_pipeline] = sym_pipeline,
  [sym_list] = sym_list,
  [sym_negated_command] = sym_negated_command,
  [sym_test_command] = sym_test_command,
  [sym__test_command_binary_expression] = sym_binary_expression,
  [sym_declaration_command] = sym_declaration_command,
  [sym_unset_command] = sym_unset_command,
  [sym_command] = sym_command,
  [sym_command_name] = sym_command_name,
  [sym_variable_assignment] = sym_variable_assignment,
  [sym_variable_assignments] = sym_variable_assignments,
  [sym_subscript] = sym_subscript,
  [sym_file_redirect] = sym_file_redirect,
  [sym_heredoc_redirect] = sym_heredoc_redirect,
  [sym__heredoc_pipeline] = sym_pipeline,
  [sym__heredoc_expression] = sym__heredoc_expression,
  [aux_sym__heredoc_command] = aux_sym__heredoc_command,
  [sym__heredoc_body] = sym__heredoc_body,
  [sym_heredoc_body] = sym_heredoc_body,
  [sym__simple_heredoc_body] = sym__simple_heredoc_body,
  [sym_herestring_redirect] = sym_herestring_redirect,
  [sym__expression] = sym__expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_postfix_expression] = sym_postfix_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_arithmetic_expansion] = sym_arithmetic_expansion,
  [sym_brace_expression] = sym_brace_expression,
  [sym__arithmetic_expression] = sym__arithmetic_expression,
  [sym__arithmetic_literal] = sym__arithmetic_literal,
  [sym__arithmetic_binary_expression] = sym_binary_expression,
  [sym__arithmetic_ternary_expression] = sym_ternary_expression,
  [sym__arithmetic_unary_expression] = sym_unary_expression,
  [sym__arithmetic_postfix_expression] = sym_postfix_expression,
  [sym__arithmetic_parenthesized_expression] = sym_parenthesized_expression,
  [sym_concatenation] = sym_concatenation,
  [sym_string] = sym_string,
  [sym_translated_string] = sym_translated_string,
  [sym_array] = sym_array,
  [sym_number] = sym_number,
  [sym_simple_expansion] = sym_simple_expansion,
  [sym_expansion] = sym_expansion,
  [sym__expansion_body] = sym__expansion_body,
  [sym__expansion_expression] = sym__expansion_expression,
  [sym__expansion_regex] = sym__expansion_regex,
  [sym__expansion_regex_replacement] = sym__expansion_regex_replacement,
  [sym__expansion_regex_removal] = sym__expansion_regex_removal,
  [sym__expansion_max_length] = sym__expansion_max_length,
  [sym__expansion_max_length_expression] = sym__expansion_max_length_expression,
  [sym__expansion_max_length_binary_expression] = sym_binary_expression,
  [sym__expansion_operator] = sym__expansion_operator,
  [sym__concatenation_in_expansion] = sym_concatenation,
  [sym_command_substitution] = sym_command_substitution,
  [sym_process_substitution] = sym_process_substitution,
  [sym__extglob_blob] = sym__extglob_blob,
  [sym__c_terminator] = sym__c_terminator,
  [aux_sym__statements_repeat1] = aux_sym__statements_repeat1,
  [aux_sym_redirected_statement_repeat1] = aux_sym_redirected_statement_repeat1,
  [aux_sym_redirected_statement_repeat2] = aux_sym_redirected_statement_repeat2,
  [aux_sym_for_statement_repeat1] = aux_sym_for_statement_repeat1,
  [aux_sym__for_body_repeat1] = aux_sym__for_body_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_case_statement_repeat1] = aux_sym_case_statement_repeat1,
  [aux_sym_case_item_repeat1] = aux_sym_case_item_repeat1,
  [aux_sym_compound_statement_repeat1] = aux_sym_compound_statement_repeat1,
  [aux_sym_pipeline_repeat1] = aux_sym_pipeline_repeat1,
  [aux_sym_declaration_command_repeat1] = aux_sym_declaration_command_repeat1,
  [aux_sym_unset_command_repeat1] = aux_sym_unset_command_repeat1,
  [aux_sym_command_repeat1] = aux_sym_command_repeat1,
  [aux_sym_command_repeat2] = aux_sym_command_repeat2,
  [aux_sym_variable_assignments_repeat1] = aux_sym_variable_assignments_repeat1,
  [aux_sym_heredoc_body_repeat1] = aux_sym_heredoc_body_repeat1,
  [aux_sym__literal_repeat1] = aux_sym__literal_repeat1,
  [aux_sym_arithmetic_expansion_repeat1] = aux_sym_arithmetic_expansion_repeat1,
  [aux_sym_concatenation_repeat1] = aux_sym_concatenation_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym__expansion_body_repeat1] = aux_sym__expansion_body_repeat1,
  [aux_sym__expansion_regex_repeat1] = aux_sym__expansion_regex_repeat1,
  [aux_sym__concatenation_in_expansion_repeat1] = aux_sym__concatenation_in_expansion_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_word] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_select] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHo] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHa] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__c_word_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_until] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_done] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fi] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_elif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_esac] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI_SEMI_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_declare] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typeset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_export] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_readonly] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_local] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsetenv] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_AMP_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_AMP_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_heredoc_redirect_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LT_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR_LPAREN_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_brace_expression_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_concatenation_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [sym__special_character] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string] = {
    .visible = true,
    .named = true,
  },
  [sym_ansi_c_string] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_number_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_number_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE3] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH3] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS3] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__expansion_regex_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_L] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Q] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_E] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_P] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_A] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_K] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_a] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_k] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__comment_word] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__simple_variable_name_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__multiline_variable_name_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_AT2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym__] = {
    .visible = true,
    .named = true,
  },
  [sym_heredoc_start] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_heredoc_body] = {
    .visible = true,
    .named = true,
  },
  [sym__heredoc_body_beginning] = {
    .visible = false,
    .named = true,
  },
  [sym_heredoc_content] = {
    .visible = true,
    .named = true,
  },
  [sym_heredoc_end] = {
    .visible = true,
    .named = true,
  },
  [sym_file_descriptor] = {
    .visible = true,
    .named = true,
  },
  [sym__empty_value] = {
    .visible = false,
    .named = true,
  },
  [sym__concat] = {
    .visible = false,
    .named = true,
  },
  [sym_variable_name] = {
    .visible = true,
    .named = true,
  },
  [sym_test_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_regex] = {
    .visible = true,
    .named = true,
  },
  [sym__regex_no_slash] = {
    .visible = true,
    .named = true,
  },
  [sym__regex_no_space] = {
    .visible = true,
    .named = true,
  },
  [sym__expansion_word] = {
    .visible = true,
    .named = true,
  },
  [sym_extglob_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__bare_dollar] = {
    .visible = true,
    .named = false,
  },
  [sym__brace_start] = {
    .visible = true,
    .named = false,
  },
  [sym__immediate_double_hash] = {
    .visible = true,
    .named = false,
  },
  [sym__external_expansion_sym_hash] = {
    .visible = true,
    .named = false,
  },
  [sym__external_expansion_sym_bang] = {
    .visible = true,
    .named = false,
  },
  [sym__external_expansion_sym_equal] = {
    .visible = true,
    .named = false,
  },
  [sym___error_recovery] = {
    .visible = false,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym__statements] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__terminated_statement] = {
    .visible = false,
    .named = false,
  },
  [sym__statement_not_pipeline] = {
    .visible = false,
    .named = true,
  },
  [sym_redirected_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_c_style_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__for_body] = {
    .visible = false,
    .named = true,
  },
  [sym__c_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__c_expression_not_assignment] = {
    .visible = false,
    .named = true,
  },
  [sym__c_variable_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym__c_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__c_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__c_postfix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__c_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_group] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_elif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_case_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_item] = {
    .visible = true,
    .named = true,
  },
  [sym_last_case_item] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_subshell] = {
    .visible = true,
    .named = true,
  },
  [sym_pipeline] = {
    .visible = true,
    .named = true,
  },
  [sym_list] = {
    .visible = true,
    .named = true,
  },
  [sym_negated_command] = {
    .visible = true,
    .named = true,
  },
  [sym_test_command] = {
    .visible = true,
    .named = true,
  },
  [sym__test_command_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration_command] = {
    .visible = true,
    .named = true,
  },
  [sym_unset_command] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript] = {
    .visible = true,
    .named = true,
  },
  [sym_file_redirect] = {
    .visible = true,
    .named = true,
  },
  [sym_heredoc_redirect] = {
    .visible = true,
    .named = true,
  },
  [sym__heredoc_pipeline] = {
    .visible = true,
    .named = true,
  },
  [sym__heredoc_expression] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__heredoc_command] = {
    .visible = false,
    .named = false,
  },
  [sym__heredoc_body] = {
    .visible = false,
    .named = true,
  },
  [sym_heredoc_body] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_heredoc_body] = {
    .visible = false,
    .named = true,
  },
  [sym_herestring_redirect] = {
    .visible = true,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_arithmetic_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_brace_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__arithmetic_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__arithmetic_literal] = {
    .visible = false,
    .named = true,
  },
  [sym__arithmetic_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__arithmetic_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__arithmetic_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__arithmetic_postfix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__arithmetic_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_translated_string] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym__expansion_body] = {
    .visible = false,
    .named = true,
  },
  [sym__expansion_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__expansion_regex] = {
    .visible = false,
    .named = true,
  },
  [sym__expansion_regex_replacement] = {
    .visible = false,
    .named = true,
  },
  [sym__expansion_regex_removal] = {
    .visible = false,
    .named = true,
  },
  [sym__expansion_max_length] = {
    .visible = false,
    .named = true,
  },
  [sym__expansion_max_length_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__expansion_max_length_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__expansion_operator] = {
    .visible = false,
    .named = true,
  },
  [sym__concatenation_in_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_command_substitution] = {
    .visible = true,
    .named = true,
  },
  [sym_process_substitution] = {
    .visible = true,
    .named = true,
  },
  [sym__extglob_blob] = {
    .visible = false,
    .named = true,
  },
  [sym__c_terminator] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__statements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_redirected_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_redirected_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__for_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_item_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pipeline_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declaration_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_unset_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_heredoc_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arithmetic_expansion_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_concatenation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__expansion_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__expansion_regex_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__concatenation_in_expansion_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_argument = 2,
  field_body = 3,
  field_condition = 4,
  field_consequence = 5,
  field_descriptor = 6,
  field_destination = 7,
  field_fallthrough = 8,
  field_index = 9,
  field_initializer = 10,
  field_left = 11,
  field_name = 12,
  field_operator = 13,
  field_redirect = 14,
  field_right = 15,
  field_termination = 16,
  field_update = 17,
  field_value = 18,
  field_variable = 19,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_descriptor] = "descriptor",
  [field_destination] = "destination",
  [field_fallthrough] = "fallthrough",
  [field_index] = "index",
  [field_initializer] = "initializer",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_redirect] = "redirect",
  [field_right] = "right",
  [field_termination] = "termination",
  [field_update] = "update",
  [field_value] = "value",
  [field_variable] = "variable",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [4] = {.index = 2, .length = 1},
  [5] = {.index = 3, .length = 3},
  [6] = {.index = 6, .length = 3},
  [7] = {.index = 9, .length = 1},
  [8] = {.index = 10, .length = 1},
  [9] = {.index = 10, .length = 1},
  [12] = {.index = 11, .length = 1},
  [14] = {.index = 12, .length = 2},
  [15] = {.index = 14, .length = 1},
  [16] = {.index = 15, .length = 1},
  [17] = {.index = 15, .length = 1},
  [18] = {.index = 16, .length = 3},
  [19] = {.index = 19, .length = 2},
  [20] = {.index = 21, .length = 2},
  [21] = {.index = 23, .length = 2},
  [22] = {.index = 23, .length = 2},
  [23] = {.index = 2, .length = 1},
  [24] = {.index = 25, .length = 2},
  [25] = {.index = 25, .length = 2},
  [26] = {.index = 27, .length = 2},
  [27] = {.index = 29, .length = 1},
  [28] = {.index = 30, .length = 2},
  [29] = {.index = 32, .length = 2},
  [30] = {.index = 34, .length = 3},
  [31] = {.index = 37, .length = 1},
  [32] = {.index = 37, .length = 1},
  [33] = {.index = 11, .length = 1},
  [34] = {.index = 38, .length = 2},
  [35] = {.index = 40, .length = 1},
  [36] = {.index = 41, .length = 2},
  [37] = {.index = 41, .length = 2},
  [38] = {.index = 43, .length = 4},
  [39] = {.index = 47, .length = 4},
  [40] = {.index = 51, .length = 2},
  [41] = {.index = 51, .length = 2},
  [42] = {.index = 53, .length = 2},
  [43] = {.index = 55, .length = 3},
  [44] = {.index = 58, .length = 1},
  [45] = {.index = 59, .length = 1},
  [46] = {.index = 59, .length = 1},
  [47] = {.index = 60, .length = 3},
  [49] = {.index = 63, .length = 2},
  [50] = {.index = 65, .length = 2},
  [51] = {.index = 67, .length = 2},
  [52] = {.index = 69, .length = 2},
  [53] = {.index = 69, .length = 2},
  [54] = {.index = 71, .length = 2},
  [55] = {.index = 25, .length = 2},
  [56] = {.index = 73, .length = 4},
  [57] = {.index = 77, .length = 1},
  [58] = {.index = 78, .length = 1},
  [59] = {.index = 79, .length = 1},
  [60] = {.index = 79, .length = 1},
  [61] = {.index = 80, .length = 2},
  [62] = {.index = 63, .length = 2},
  [63] = {.index = 82, .length = 3},
  [64] = {.index = 85, .length = 3},
  [65] = {.index = 88, .length = 3},
  [66] = {.index = 91, .length = 2},
  [67] = {.index = 93, .length = 2},
  [68] = {.index = 95, .length = 4},
  [69] = {.index = 99, .length = 2},
  [70] = {.index = 101, .length = 2},
  [71] = {.index = 103, .length = 2},
  [72] = {.index = 105, .length = 2},
  [73] = {.index = 107, .length = 2},
  [74] = {.index = 109, .length = 2},
  [75] = {.index = 111, .length = 3},
  [76] = {.index = 114, .length = 3},
  [77] = {.index = 117, .length = 2},
  [78] = {.index = 119, .length = 2},
  [79] = {.index = 121, .length = 2},
  [80] = {.index = 123, .length = 2},
  [81] = {.index = 117, .length = 2},
  [82] = {.index = 119, .length = 2},
  [83] = {.index = 121, .length = 2},
  [84] = {.index = 125, .length = 3},
  [85] = {.index = 67, .length = 2},
  [86] = {.index = 128, .length = 3},
  [87] = {.index = 128, .length = 3},
  [88] = {.index = 63, .length = 2},
  [89] = {.index = 131, .length = 2},
  [90] = {.index = 133, .length = 3},
  [91] = {.index = 136, .length = 3},
  [92] = {.index = 139, .length = 4},
  [93] = {.index = 143, .length = 2},
  [94] = {.index = 145, .length = 1},
  [95] = {.index = 146, .length = 1},
  [96] = {.index = 147, .length = 3},
  [97] = {.index = 150, .length = 3},
  [98] = {.index = 153, .length = 3},
  [99] = {.index = 156, .length = 3},
  [100] = {.index = 159, .length = 3},
  [101] = {.index = 162, .length = 3},
  [102] = {.index = 165, .length = 3},
  [103] = {.index = 168, .length = 2},
  [104] = {.index = 170, .length = 2},
  [105] = {.index = 172, .length = 3},
  [106] = {.index = 175, .length = 3},
  [107] = {.index = 178, .length = 2},
  [108] = {.index = 180, .length = 2},
  [109] = {.index = 182, .length = 2},
  [110] = {.index = 178, .length = 2},
  [111] = {.index = 180, .length = 2},
  [112] = {.index = 182, .length = 2},
  [113] = {.index = 168, .length = 2},
  [114] = {.index = 170, .length = 2},
  [115] = {.index = 172, .length = 3},
  [116] = {.index = 175, .length = 3},
  [117] = {.index = 184, .length = 3},
  [118] = {.index = 184, .length = 3},
  [119] = {.index = 67, .length = 2},
  [120] = {.index = 187, .length = 3},
  [121] = {.index = 131, .length = 2},
  [122] = {.index = 190, .length = 3},
  [123] = {.index = 193, .length = 4},
  [124] = {.index = 197, .length = 3},
  [125] = {.index = 200, .length = 2},
  [126] = {.index = 202, .length = 2},
  [127] = {.index = 204, .length = 3},
  [128] = {.index = 207, .length = 4},
  [129] = {.index = 211, .length = 4},
  [130] = {.index = 215, .length = 4},
  [131] = {.index = 219, .length = 4},
  [132] = {.index = 223, .length = 4},
  [133] = {.index = 227, .length = 4},
  [134] = {.index = 231, .length = 3},
  [135] = {.index = 234, .length = 3},
  [136] = {.index = 237, .length = 2},
  [137] = {.index = 239, .length = 2},
  [138] = {.index = 241, .length = 3},
  [139] = {.index = 244, .length = 3},
  [140] = {.index = 237, .length = 2},
  [141] = {.index = 239, .length = 2},
  [142] = {.index = 241, .length = 3},
  [143] = {.index = 244, .length = 3},
  [144] = {.index = 231, .length = 3},
  [145] = {.index = 234, .length = 3},
  [146] = {.index = 247, .length = 3},
  [147] = {.index = 250, .length = 3},
  [148] = {.index = 250, .length = 3},
  [149] = {.index = 253, .length = 4},
  [150] = {.index = 257, .length = 5},
  [151] = {.index = 262, .length = 5},
  [152] = {.index = 267, .length = 5},
  [153] = {.index = 272, .length = 3},
  [154] = {.index = 275, .length = 3},
  [155] = {.index = 272, .length = 3},
  [156] = {.index = 275, .length = 3},
  [157] = {.index = 278, .length = 3},
  [158] = {.index = 281, .length = 6},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_redirect, 0},
  [2] =
    {field_descriptor, 0},
  [3] =
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [6] =
    {field_alternative, 0, .inherited = true},
    {field_condition, 0, .inherited = true},
    {field_consequence, 0, .inherited = true},
  [9] =
    {field_operator, 0, .inherited = true},
  [10] =
    {field_destination, 1},
  [11] =
    {field_operator, 0},
  [12] =
    {field_body, 0},
    {field_redirect, 1},
  [14] =
    {field_body, 0},
  [15] =
    {field_argument, 0},
  [16] =
    {field_argument, 1, .inherited = true},
    {field_name, 0},
    {field_redirect, 1, .inherited = true},
  [19] =
    {field_name, 1},
    {field_redirect, 0, .inherited = true},
  [21] =
    {field_redirect, 0, .inherited = true},
    {field_redirect, 1, .inherited = true},
  [23] =
    {field_descriptor, 0},
    {field_destination, 2},
  [25] =
    {field_name, 0},
    {field_value, 2},
  [27] =
    {field_name, 0, .inherited = true},
    {field_value, 0, .inherited = true},
  [29] =
    {field_operator, 1},
  [30] =
    {field_body, 2},
    {field_condition, 1},
  [32] =
    {field_body, 2},
    {field_name, 1},
  [34] =
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [37] =
    {field_operator, 1, .inherited = true},
  [38] =
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
  [40] =
    {field_redirect, 1},
  [41] =
    {field_argument, 0},
    {field_argument, 1},
  [43] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
    {field_redirect, 0, .inherited = true},
    {field_redirect, 1, .inherited = true},
  [47] =
    {field_argument, 2, .inherited = true},
    {field_name, 1},
    {field_redirect, 0, .inherited = true},
    {field_redirect, 2, .inherited = true},
  [51] =
    {field_index, 2},
    {field_name, 0},
  [53] =
    {field_body, 3},
    {field_variable, 1},
  [55] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [58] =
    {field_condition, 1},
  [59] =
    {field_value, 1},
  [60] =
    {field_body, 2},
    {field_name, 1},
    {field_redirect, 3},
  [63] =
    {field_operator, 0},
    {field_operator, 1},
  [65] =
    {field_operator, 0},
    {field_operator, 1, .inherited = true},
  [67] =
    {field_operator, 0},
    {field_operator, 2},
  [69] =
    {field_operator, 0},
    {field_operator, 2, .inherited = true},
  [71] =
    {field_body, 3},
    {field_name, 0},
  [73] =
    {field_body, 4},
    {field_condition, 2, .inherited = true},
    {field_initializer, 2, .inherited = true},
    {field_update, 2, .inherited = true},
  [77] =
    {field_initializer, 0},
  [78] =
    {field_update, 2},
  [79] =
    {field_value, 0},
  [80] =
    {field_body, 4},
    {field_name, 1},
  [82] =
    {field_operator, 0},
    {field_operator, 1},
    {field_operator, 2, .inherited = true},
  [85] =
    {field_operator, 0},
    {field_operator, 1, .inherited = true},
    {field_operator, 2},
  [88] =
    {field_body, 3},
    {field_name, 0},
    {field_redirect, 4},
  [91] =
    {field_operator, 0},
    {field_right, 1},
  [93] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [95] =
    {field_body, 5},
    {field_condition, 2, .inherited = true},
    {field_initializer, 2, .inherited = true},
    {field_update, 2, .inherited = true},
  [99] =
    {field_condition, 2},
    {field_initializer, 0},
  [101] =
    {field_initializer, 0},
    {field_update, 3},
  [103] =
    {field_initializer, 0},
    {field_initializer, 1},
  [105] =
    {field_condition, 1},
    {field_update, 3},
  [107] =
    {field_condition, 1},
    {field_condition, 2},
  [109] =
    {field_update, 2},
    {field_update, 3},
  [111] =
    {field_body, 5},
    {field_value, 3},
    {field_variable, 1},
  [114] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [117] =
    {field_termination, 2},
    {field_value, 0},
  [119] =
    {field_fallthrough, 2},
    {field_value, 0},
  [121] =
    {field_value, 0},
    {field_value, 1, .inherited = true},
  [123] =
    {field_value, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [125] =
    {field_body, 4},
    {field_name, 1},
    {field_redirect, 5},
  [128] =
    {field_operator, 0},
    {field_operator, 1},
    {field_operator, 3},
  [131] =
    {field_operator, 0},
    {field_operator, 3},
  [133] =
    {field_operator, 0},
    {field_operator, 2},
    {field_operator, 3, .inherited = true},
  [136] =
    {field_operator, 0},
    {field_operator, 1},
    {field_operator, 3, .inherited = true},
  [139] =
    {field_operator, 0},
    {field_operator, 1, .inherited = true},
    {field_operator, 2},
    {field_operator, 3, .inherited = true},
  [143] =
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
  [145] =
    {field_argument, 2, .inherited = true},
  [146] =
    {field_redirect, 2},
  [147] =
    {field_condition, 2},
    {field_initializer, 0},
    {field_update, 4},
  [150] =
    {field_condition, 2},
    {field_condition, 3},
    {field_initializer, 0},
  [153] =
    {field_initializer, 0},
    {field_update, 3},
    {field_update, 4},
  [156] =
    {field_condition, 3},
    {field_initializer, 0},
    {field_initializer, 1},
  [159] =
    {field_initializer, 0},
    {field_initializer, 1},
    {field_update, 4},
  [162] =
    {field_condition, 1},
    {field_update, 3},
    {field_update, 4},
  [165] =
    {field_condition, 1},
    {field_condition, 2},
    {field_update, 4},
  [168] =
    {field_termination, 3},
    {field_value, 0},
  [170] =
    {field_fallthrough, 3},
    {field_value, 0},
  [172] =
    {field_termination, 3},
    {field_value, 0},
    {field_value, 1, .inherited = true},
  [175] =
    {field_fallthrough, 3},
    {field_value, 0},
    {field_value, 1, .inherited = true},
  [178] =
    {field_termination, 3},
    {field_value, 1},
  [180] =
    {field_fallthrough, 3},
    {field_value, 1},
  [182] =
    {field_value, 1},
    {field_value, 2, .inherited = true},
  [184] =
    {field_operator, 0},
    {field_operator, 2},
    {field_operator, 4},
  [187] =
    {field_operator, 0},
    {field_operator, 1},
    {field_operator, 4},
  [190] =
    {field_operator, 0},
    {field_operator, 2},
    {field_operator, 4, .inherited = true},
  [193] =
    {field_operator, 0},
    {field_operator, 1, .inherited = true},
    {field_operator, 2},
    {field_operator, 4, .inherited = true},
  [197] =
    {field_descriptor, 0},
    {field_operator, 3, .inherited = true},
    {field_right, 3, .inherited = true},
  [200] =
    {field_argument, 3, .inherited = true},
    {field_descriptor, 0},
  [202] =
    {field_descriptor, 0},
    {field_redirect, 3},
  [204] =
    {field_operator, 3, .inherited = true},
    {field_redirect, 2},
    {field_right, 3, .inherited = true},
  [207] =
    {field_condition, 2},
    {field_initializer, 0},
    {field_update, 4},
    {field_update, 5},
  [211] =
    {field_condition, 2},
    {field_condition, 3},
    {field_initializer, 0},
    {field_update, 5},
  [215] =
    {field_condition, 3},
    {field_initializer, 0},
    {field_initializer, 1},
    {field_update, 5},
  [219] =
    {field_condition, 3},
    {field_condition, 4},
    {field_initializer, 0},
    {field_initializer, 1},
  [223] =
    {field_initializer, 0},
    {field_initializer, 1},
    {field_update, 4},
    {field_update, 5},
  [227] =
    {field_condition, 1},
    {field_condition, 2},
    {field_update, 4},
    {field_update, 5},
  [231] =
    {field_termination, 4},
    {field_value, 0},
    {field_value, 1, .inherited = true},
  [234] =
    {field_fallthrough, 4},
    {field_value, 0},
    {field_value, 1, .inherited = true},
  [237] =
    {field_termination, 4},
    {field_value, 1},
  [239] =
    {field_fallthrough, 4},
    {field_value, 1},
  [241] =
    {field_termination, 4},
    {field_value, 1},
    {field_value, 2, .inherited = true},
  [244] =
    {field_fallthrough, 4},
    {field_value, 1},
    {field_value, 2, .inherited = true},
  [247] =
    {field_operator, 0},
    {field_operator, 2},
    {field_operator, 5},
  [250] =
    {field_operator, 0},
    {field_operator, 3},
    {field_operator, 5},
  [253] =
    {field_descriptor, 0},
    {field_operator, 4, .inherited = true},
    {field_redirect, 3},
    {field_right, 4, .inherited = true},
  [257] =
    {field_condition, 2},
    {field_condition, 3},
    {field_initializer, 0},
    {field_update, 5},
    {field_update, 6},
  [262] =
    {field_condition, 3},
    {field_initializer, 0},
    {field_initializer, 1},
    {field_update, 5},
    {field_update, 6},
  [267] =
    {field_condition, 3},
    {field_condition, 4},
    {field_initializer, 0},
    {field_initializer, 1},
    {field_update, 6},
  [272] =
    {field_termination, 5},
    {field_value, 1},
    {field_value, 2, .inherited = true},
  [275] =
    {field_fallthrough, 5},
    {field_value, 1},
    {field_value, 2, .inherited = true},
  [278] =
    {field_operator, 0},
    {field_operator, 3},
    {field_operator, 6},
  [281] =
    {field_condition, 3},
    {field_condition, 4},
    {field_initializer, 0},
    {field_initializer, 1},
    {field_update, 6},
    {field_update, 7},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_word,
  },
  [9] = {
    [1] = sym_word,
  },
  [10] = {
    [1] = sym_word,
  },
  [11] = {
    [1] = anon_sym_AT2,
  },
  [13] = {
    [0] = anon_sym_AT2,
  },
  [16] = {
    [0] = sym_word,
  },
  [22] = {
    [2] = sym_word,
  },
  [23] = {
    [2] = sym_word,
  },
  [25] = {
    [2] = sym_word,
  },
  [32] = {
    [0] = anon_sym_AT2,
  },
  [33] = {
    [1] = anon_sym_AT2,
  },
  [36] = {
    [1] = sym_word,
  },
  [40] = {
    [2] = sym_word,
  },
  [45] = {
    [1] = sym_word,
  },
  [48] = {
    [0] = sym_regex,
  },
  [53] = {
    [1] = anon_sym_AT2,
  },
  [55] = {
    [0] = sym_variable_name,
  },
  [59] = {
    [0] = sym_word,
  },
  [62] = {
    [2] = sym_word,
  },
  [77] = {
    [0] = sym_word,
  },
  [78] = {
    [0] = sym_word,
  },
  [79] = {
    [0] = sym_word,
  },
  [85] = {
    [3] = sym_word,
  },
  [86] = {
    [2] = sym_word,
  },
  [88] = {
    [3] = sym_word,
  },
  [103] = {
    [0] = sym_word,
  },
  [104] = {
    [0] = sym_word,
  },
  [105] = {
    [0] = sym_word,
  },
  [106] = {
    [0] = sym_word,
  },
  [107] = {
    [1] = sym_word,
  },
  [108] = {
    [1] = sym_word,
  },
  [109] = {
    [1] = sym_word,
  },
  [117] = {
    [3] = sym_word,
  },
  [119] = {
    [4] = sym_word,
  },
  [120] = {
    [3] = sym_word,
  },
  [121] = {
    [4] = sym_word,
  },
  [134] = {
    [0] = sym_word,
  },
  [135] = {
    [0] = sym_word,
  },
  [136] = {
    [1] = sym_word,
  },
  [137] = {
    [1] = sym_word,
  },
  [138] = {
    [1] = sym_word,
  },
  [139] = {
    [1] = sym_word,
  },
  [146] = {
    [4] = sym_word,
  },
  [147] = {
    [4] = sym_word,
  },
  [153] = {
    [1] = sym_word,
  },
  [154] = {
    [1] = sym_word,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  aux_sym__literal_repeat1, 2,
    aux_sym__literal_repeat1,
    sym_word,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 5,
  [6] = 5,
  [7] = 5,
  [8] = 5,
  [9] = 5,
  [10] = 5,
  [11] = 5,
  [12] = 5,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 14,
  [17] = 14,
  [18] = 15,
  [19] = 14,
  [20] = 15,
  [21] = 15,
  [22] = 13,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 50,
  [52] = 52,
  [53] = 50,
  [54] = 52,
  [55] = 52,
  [56] = 52,
  [57] = 52,
  [58] = 50,
  [59] = 52,
  [60] = 52,
  [61] = 52,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 26,
  [68] = 26,
  [69] = 64,
  [70] = 70,
  [71] = 66,
  [72] = 70,
  [73] = 73,
  [74] = 64,
  [75] = 66,
  [76] = 70,
  [77] = 73,
  [78] = 64,
  [79] = 66,
  [80] = 70,
  [81] = 73,
  [82] = 64,
  [83] = 73,
  [84] = 66,
  [85] = 70,
  [86] = 64,
  [87] = 66,
  [88] = 70,
  [89] = 73,
  [90] = 64,
  [91] = 91,
  [92] = 66,
  [93] = 70,
  [94] = 73,
  [95] = 64,
  [96] = 62,
  [97] = 66,
  [98] = 70,
  [99] = 73,
  [100] = 64,
  [101] = 66,
  [102] = 102,
  [103] = 102,
  [104] = 104,
  [105] = 105,
  [106] = 63,
  [107] = 65,
  [108] = 102,
  [109] = 62,
  [110] = 104,
  [111] = 105,
  [112] = 63,
  [113] = 65,
  [114] = 102,
  [115] = 62,
  [116] = 104,
  [117] = 105,
  [118] = 63,
  [119] = 65,
  [120] = 102,
  [121] = 62,
  [122] = 104,
  [123] = 105,
  [124] = 63,
  [125] = 102,
  [126] = 62,
  [127] = 104,
  [128] = 105,
  [129] = 63,
  [130] = 102,
  [131] = 62,
  [132] = 104,
  [133] = 105,
  [134] = 63,
  [135] = 102,
  [136] = 62,
  [137] = 104,
  [138] = 105,
  [139] = 63,
  [140] = 62,
  [141] = 104,
  [142] = 105,
  [143] = 63,
  [144] = 62,
  [145] = 104,
  [146] = 105,
  [147] = 63,
  [148] = 62,
  [149] = 104,
  [150] = 105,
  [151] = 63,
  [152] = 62,
  [153] = 104,
  [154] = 105,
  [155] = 63,
  [156] = 62,
  [157] = 104,
  [158] = 105,
  [159] = 63,
  [160] = 62,
  [161] = 104,
  [162] = 105,
  [163] = 63,
  [164] = 62,
  [165] = 104,
  [166] = 105,
  [167] = 63,
  [168] = 62,
  [169] = 104,
  [170] = 105,
  [171] = 63,
  [172] = 62,
  [173] = 104,
  [174] = 105,
  [175] = 63,
  [176] = 62,
  [177] = 104,
  [178] = 105,
  [179] = 63,
  [180] = 62,
  [181] = 104,
  [182] = 105,
  [183] = 63,
  [184] = 62,
  [185] = 104,
  [186] = 105,
  [187] = 63,
  [188] = 62,
  [189] = 104,
  [190] = 105,
  [191] = 63,
  [192] = 62,
  [193] = 104,
  [194] = 105,
  [195] = 63,
  [196] = 62,
  [197] = 104,
  [198] = 105,
  [199] = 63,
  [200] = 62,
  [201] = 104,
  [202] = 105,
  [203] = 63,
  [204] = 62,
  [205] = 104,
  [206] = 105,
  [207] = 63,
  [208] = 62,
  [209] = 104,
  [210] = 105,
  [211] = 63,
  [212] = 62,
  [213] = 104,
  [214] = 105,
  [215] = 63,
  [216] = 62,
  [217] = 104,
  [218] = 105,
  [219] = 63,
  [220] = 62,
  [221] = 104,
  [222] = 105,
  [223] = 63,
  [224] = 62,
  [225] = 104,
  [226] = 105,
  [227] = 63,
  [228] = 62,
  [229] = 104,
  [230] = 105,
  [231] = 63,
  [232] = 62,
  [233] = 104,
  [234] = 105,
  [235] = 63,
  [236] = 62,
  [237] = 104,
  [238] = 105,
  [239] = 63,
  [240] = 62,
  [241] = 104,
  [242] = 105,
  [243] = 63,
  [244] = 62,
  [245] = 104,
  [246] = 105,
  [247] = 63,
  [248] = 62,
  [249] = 104,
  [250] = 105,
  [251] = 63,
  [252] = 62,
  [253] = 104,
  [254] = 105,
  [255] = 63,
  [256] = 62,
  [257] = 104,
  [258] = 105,
  [259] = 63,
  [260] = 62,
  [261] = 104,
  [262] = 105,
  [263] = 63,
  [264] = 62,
  [265] = 104,
  [266] = 105,
  [267] = 63,
  [268] = 62,
  [269] = 104,
  [270] = 105,
  [271] = 63,
  [272] = 62,
  [273] = 104,
  [274] = 105,
  [275] = 63,
  [276] = 62,
  [277] = 104,
  [278] = 105,
  [279] = 63,
  [280] = 62,
  [281] = 104,
  [282] = 105,
  [283] = 63,
  [284] = 62,
  [285] = 104,
  [286] = 105,
  [287] = 63,
  [288] = 62,
  [289] = 104,
  [290] = 105,
  [291] = 63,
  [292] = 62,
  [293] = 104,
  [294] = 105,
  [295] = 63,
  [296] = 62,
  [297] = 104,
  [298] = 105,
  [299] = 63,
  [300] = 62,
  [301] = 104,
  [302] = 105,
  [303] = 63,
  [304] = 62,
  [305] = 104,
  [306] = 105,
  [307] = 63,
  [308] = 62,
  [309] = 104,
  [310] = 105,
  [311] = 63,
  [312] = 62,
  [313] = 104,
  [314] = 105,
  [315] = 63,
  [316] = 62,
  [317] = 104,
  [318] = 105,
  [319] = 63,
  [320] = 62,
  [321] = 104,
  [322] = 105,
  [323] = 63,
  [324] = 62,
  [325] = 104,
  [326] = 105,
  [327] = 63,
  [328] = 62,
  [329] = 104,
  [330] = 105,
  [331] = 63,
  [332] = 62,
  [333] = 104,
  [334] = 105,
  [335] = 63,
  [336] = 62,
  [337] = 104,
  [338] = 105,
  [339] = 63,
  [340] = 62,
  [341] = 104,
  [342] = 105,
  [343] = 63,
  [344] = 62,
  [345] = 104,
  [346] = 105,
  [347] = 63,
  [348] = 62,
  [349] = 104,
  [350] = 105,
  [351] = 63,
  [352] = 62,
  [353] = 104,
  [354] = 105,
  [355] = 63,
  [356] = 62,
  [357] = 104,
  [358] = 105,
  [359] = 63,
  [360] = 62,
  [361] = 104,
  [362] = 105,
  [363] = 63,
  [364] = 62,
  [365] = 104,
  [366] = 105,
  [367] = 62,
  [368] = 104,
  [369] = 105,
  [370] = 62,
  [371] = 104,
  [372] = 105,
  [373] = 62,
  [374] = 104,
  [375] = 105,
  [376] = 62,
  [377] = 104,
  [378] = 105,
  [379] = 62,
  [380] = 104,
  [381] = 105,
  [382] = 62,
  [383] = 104,
  [384] = 105,
  [385] = 62,
  [386] = 104,
  [387] = 105,
  [388] = 62,
  [389] = 104,
  [390] = 105,
  [391] = 62,
  [392] = 104,
  [393] = 105,
  [394] = 62,
  [395] = 104,
  [396] = 105,
  [397] = 62,
  [398] = 104,
  [399] = 105,
  [400] = 62,
  [401] = 104,
  [402] = 105,
  [403] = 62,
  [404] = 104,
  [405] = 105,
  [406] = 62,
  [407] = 104,
  [408] = 105,
  [409] = 409,
  [410] = 410,
  [411] = 104,
  [412] = 105,
  [413] = 73,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 416,
  [420] = 416,
  [421] = 416,
  [422] = 418,
  [423] = 418,
  [424] = 418,
  [425] = 418,
  [426] = 414,
  [427] = 414,
  [428] = 414,
  [429] = 429,
  [430] = 430,
  [431] = 430,
  [432] = 432,
  [433] = 433,
  [434] = 433,
  [435] = 430,
  [436] = 433,
  [437] = 430,
  [438] = 433,
  [439] = 430,
  [440] = 433,
  [441] = 430,
  [442] = 430,
  [443] = 433,
  [444] = 433,
  [445] = 430,
  [446] = 433,
  [447] = 447,
  [448] = 447,
  [449] = 447,
  [450] = 447,
  [451] = 451,
  [452] = 451,
  [453] = 451,
  [454] = 447,
  [455] = 451,
  [456] = 447,
  [457] = 451,
  [458] = 451,
  [459] = 459,
  [460] = 460,
  [461] = 459,
  [462] = 460,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 466,
  [493] = 463,
  [494] = 464,
  [495] = 468,
  [496] = 467,
  [497] = 465,
  [498] = 473,
  [499] = 480,
  [500] = 469,
  [501] = 481,
  [502] = 482,
  [503] = 483,
  [504] = 484,
  [505] = 471,
  [506] = 477,
  [507] = 478,
  [508] = 486,
  [509] = 472,
  [510] = 487,
  [511] = 479,
  [512] = 474,
  [513] = 485,
  [514] = 475,
  [515] = 476,
  [516] = 470,
  [517] = 489,
  [518] = 488,
  [519] = 491,
  [520] = 490,
  [521] = 521,
  [522] = 521,
  [523] = 523,
  [524] = 524,
  [525] = 523,
  [526] = 524,
  [527] = 527,
  [528] = 524,
  [529] = 529,
  [530] = 523,
  [531] = 531,
  [532] = 524,
  [533] = 523,
  [534] = 534,
  [535] = 529,
  [536] = 460,
  [537] = 459,
  [538] = 524,
  [539] = 539,
  [540] = 523,
  [541] = 541,
  [542] = 523,
  [543] = 527,
  [544] = 524,
  [545] = 531,
  [546] = 460,
  [547] = 459,
  [548] = 531,
  [549] = 459,
  [550] = 541,
  [551] = 529,
  [552] = 527,
  [553] = 531,
  [554] = 534,
  [555] = 527,
  [556] = 529,
  [557] = 539,
  [558] = 460,
  [559] = 541,
  [560] = 460,
  [561] = 527,
  [562] = 531,
  [563] = 534,
  [564] = 459,
  [565] = 534,
  [566] = 539,
  [567] = 459,
  [568] = 541,
  [569] = 569,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 539,
  [574] = 460,
  [575] = 460,
  [576] = 459,
  [577] = 527,
  [578] = 529,
  [579] = 531,
  [580] = 580,
  [581] = 524,
  [582] = 460,
  [583] = 459,
  [584] = 460,
  [585] = 459,
  [586] = 586,
  [587] = 587,
  [588] = 588,
  [589] = 539,
  [590] = 580,
  [591] = 591,
  [592] = 569,
  [593] = 571,
  [594] = 572,
  [595] = 569,
  [596] = 571,
  [597] = 572,
  [598] = 598,
  [599] = 599,
  [600] = 534,
  [601] = 539,
  [602] = 460,
  [603] = 541,
  [604] = 459,
  [605] = 523,
  [606] = 599,
  [607] = 534,
  [608] = 608,
  [609] = 569,
  [610] = 608,
  [611] = 588,
  [612] = 586,
  [613] = 587,
  [614] = 591,
  [615] = 571,
  [616] = 572,
  [617] = 569,
  [618] = 608,
  [619] = 523,
  [620] = 571,
  [621] = 572,
  [622] = 572,
  [623] = 569,
  [624] = 608,
  [625] = 459,
  [626] = 608,
  [627] = 460,
  [628] = 459,
  [629] = 571,
  [630] = 460,
  [631] = 608,
  [632] = 459,
  [633] = 569,
  [634] = 608,
  [635] = 571,
  [636] = 598,
  [637] = 608,
  [638] = 572,
  [639] = 524,
  [640] = 586,
  [641] = 587,
  [642] = 460,
  [643] = 531,
  [644] = 598,
  [645] = 569,
  [646] = 571,
  [647] = 572,
  [648] = 588,
  [649] = 586,
  [650] = 459,
  [651] = 587,
  [652] = 586,
  [653] = 587,
  [654] = 586,
  [655] = 587,
  [656] = 598,
  [657] = 591,
  [658] = 460,
  [659] = 571,
  [660] = 569,
  [661] = 571,
  [662] = 572,
  [663] = 588,
  [664] = 586,
  [665] = 587,
  [666] = 572,
  [667] = 460,
  [668] = 459,
  [669] = 460,
  [670] = 459,
  [671] = 460,
  [672] = 459,
  [673] = 569,
  [674] = 460,
  [675] = 459,
  [676] = 569,
  [677] = 571,
  [678] = 572,
  [679] = 527,
  [680] = 529,
  [681] = 591,
  [682] = 570,
  [683] = 586,
  [684] = 586,
  [685] = 587,
  [686] = 587,
  [687] = 687,
  [688] = 688,
  [689] = 688,
  [690] = 569,
  [691] = 580,
  [692] = 460,
  [693] = 459,
  [694] = 687,
  [695] = 527,
  [696] = 688,
  [697] = 687,
  [698] = 569,
  [699] = 529,
  [700] = 460,
  [701] = 459,
  [702] = 531,
  [703] = 586,
  [704] = 688,
  [705] = 591,
  [706] = 687,
  [707] = 572,
  [708] = 688,
  [709] = 587,
  [710] = 687,
  [711] = 571,
  [712] = 569,
  [713] = 459,
  [714] = 571,
  [715] = 460,
  [716] = 588,
  [717] = 459,
  [718] = 569,
  [719] = 459,
  [720] = 571,
  [721] = 591,
  [722] = 571,
  [723] = 572,
  [724] = 572,
  [725] = 598,
  [726] = 599,
  [727] = 460,
  [728] = 539,
  [729] = 460,
  [730] = 460,
  [731] = 541,
  [732] = 459,
  [733] = 460,
  [734] = 459,
  [735] = 460,
  [736] = 588,
  [737] = 586,
  [738] = 459,
  [739] = 587,
  [740] = 534,
  [741] = 570,
  [742] = 460,
  [743] = 587,
  [744] = 459,
  [745] = 460,
  [746] = 459,
  [747] = 541,
  [748] = 459,
  [749] = 460,
  [750] = 459,
  [751] = 460,
  [752] = 459,
  [753] = 580,
  [754] = 460,
  [755] = 459,
  [756] = 569,
  [757] = 569,
  [758] = 571,
  [759] = 571,
  [760] = 460,
  [761] = 534,
  [762] = 586,
  [763] = 599,
  [764] = 587,
  [765] = 572,
  [766] = 586,
  [767] = 459,
  [768] = 587,
  [769] = 586,
  [770] = 587,
  [771] = 586,
  [772] = 460,
  [773] = 459,
  [774] = 459,
  [775] = 460,
  [776] = 460,
  [777] = 459,
  [778] = 778,
  [779] = 539,
  [780] = 460,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 459,
  [785] = 785,
  [786] = 572,
  [787] = 460,
  [788] = 586,
  [789] = 586,
  [790] = 587,
  [791] = 587,
  [792] = 460,
  [793] = 793,
  [794] = 571,
  [795] = 569,
  [796] = 796,
  [797] = 571,
  [798] = 572,
  [799] = 459,
  [800] = 800,
  [801] = 569,
  [802] = 466,
  [803] = 463,
  [804] = 464,
  [805] = 465,
  [806] = 460,
  [807] = 460,
  [808] = 459,
  [809] = 459,
  [810] = 810,
  [811] = 475,
  [812] = 477,
  [813] = 466,
  [814] = 785,
  [815] = 463,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 464,
  [820] = 569,
  [821] = 571,
  [822] = 572,
  [823] = 586,
  [824] = 476,
  [825] = 479,
  [826] = 465,
  [827] = 571,
  [828] = 828,
  [829] = 572,
  [830] = 783,
  [831] = 466,
  [832] = 473,
  [833] = 463,
  [834] = 480,
  [835] = 464,
  [836] = 469,
  [837] = 481,
  [838] = 838,
  [839] = 839,
  [840] = 465,
  [841] = 482,
  [842] = 569,
  [843] = 591,
  [844] = 571,
  [845] = 587,
  [846] = 782,
  [847] = 483,
  [848] = 484,
  [849] = 796,
  [850] = 572,
  [851] = 598,
  [852] = 478,
  [853] = 486,
  [854] = 569,
  [855] = 793,
  [856] = 856,
  [857] = 470,
  [858] = 487,
  [859] = 485,
  [860] = 800,
  [861] = 472,
  [862] = 474,
  [863] = 588,
  [864] = 586,
  [865] = 781,
  [866] = 587,
  [867] = 471,
  [868] = 793,
  [869] = 587,
  [870] = 569,
  [871] = 571,
  [872] = 572,
  [873] = 782,
  [874] = 460,
  [875] = 459,
  [876] = 588,
  [877] = 465,
  [878] = 810,
  [879] = 838,
  [880] = 880,
  [881] = 817,
  [882] = 818,
  [883] = 466,
  [884] = 800,
  [885] = 591,
  [886] = 463,
  [887] = 488,
  [888] = 478,
  [889] = 486,
  [890] = 470,
  [891] = 487,
  [892] = 485,
  [893] = 472,
  [894] = 474,
  [895] = 464,
  [896] = 478,
  [897] = 486,
  [898] = 470,
  [899] = 487,
  [900] = 460,
  [901] = 459,
  [902] = 485,
  [903] = 475,
  [904] = 477,
  [905] = 472,
  [906] = 474,
  [907] = 466,
  [908] = 476,
  [909] = 479,
  [910] = 463,
  [911] = 464,
  [912] = 465,
  [913] = 475,
  [914] = 477,
  [915] = 473,
  [916] = 480,
  [917] = 469,
  [918] = 481,
  [919] = 471,
  [920] = 476,
  [921] = 479,
  [922] = 482,
  [923] = 483,
  [924] = 586,
  [925] = 460,
  [926] = 459,
  [927] = 473,
  [928] = 480,
  [929] = 469,
  [930] = 481,
  [931] = 465,
  [932] = 471,
  [933] = 598,
  [934] = 482,
  [935] = 483,
  [936] = 484,
  [937] = 880,
  [938] = 880,
  [939] = 782,
  [940] = 460,
  [941] = 459,
  [942] = 880,
  [943] = 943,
  [944] = 781,
  [945] = 466,
  [946] = 569,
  [947] = 571,
  [948] = 572,
  [949] = 880,
  [950] = 463,
  [951] = 828,
  [952] = 839,
  [953] = 785,
  [954] = 783,
  [955] = 796,
  [956] = 781,
  [957] = 783,
  [958] = 793,
  [959] = 856,
  [960] = 816,
  [961] = 880,
  [962] = 800,
  [963] = 796,
  [964] = 569,
  [965] = 571,
  [966] = 586,
  [967] = 587,
  [968] = 464,
  [969] = 785,
  [970] = 880,
  [971] = 572,
  [972] = 460,
  [973] = 459,
  [974] = 880,
  [975] = 586,
  [976] = 587,
  [977] = 484,
  [978] = 472,
  [979] = 459,
  [980] = 460,
  [981] = 459,
  [982] = 463,
  [983] = 470,
  [984] = 491,
  [985] = 466,
  [986] = 463,
  [987] = 464,
  [988] = 466,
  [989] = 463,
  [990] = 464,
  [991] = 465,
  [992] = 465,
  [993] = 785,
  [994] = 464,
  [995] = 488,
  [996] = 478,
  [997] = 486,
  [998] = 569,
  [999] = 571,
  [1000] = 572,
  [1001] = 586,
  [1002] = 460,
  [1003] = 587,
  [1004] = 459,
  [1005] = 488,
  [1006] = 460,
  [1007] = 459,
  [1008] = 810,
  [1009] = 838,
  [1010] = 478,
  [1011] = 486,
  [1012] = 470,
  [1013] = 487,
  [1014] = 485,
  [1015] = 1015,
  [1016] = 817,
  [1017] = 472,
  [1018] = 474,
  [1019] = 818,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 460,
  [1023] = 459,
  [1024] = 475,
  [1025] = 477,
  [1026] = 856,
  [1027] = 1027,
  [1028] = 816,
  [1029] = 1029,
  [1030] = 476,
  [1031] = 479,
  [1032] = 783,
  [1033] = 473,
  [1034] = 480,
  [1035] = 469,
  [1036] = 481,
  [1037] = 471,
  [1038] = 482,
  [1039] = 483,
  [1040] = 484,
  [1041] = 487,
  [1042] = 472,
  [1043] = 469,
  [1044] = 481,
  [1045] = 1045,
  [1046] = 474,
  [1047] = 1047,
  [1048] = 482,
  [1049] = 485,
  [1050] = 483,
  [1051] = 484,
  [1052] = 487,
  [1053] = 856,
  [1054] = 475,
  [1055] = 816,
  [1056] = 1056,
  [1057] = 460,
  [1058] = 459,
  [1059] = 460,
  [1060] = 1047,
  [1061] = 459,
  [1062] = 460,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 459,
  [1066] = 476,
  [1067] = 479,
  [1068] = 473,
  [1069] = 477,
  [1070] = 480,
  [1071] = 1071,
  [1072] = 474,
  [1073] = 471,
  [1074] = 782,
  [1075] = 466,
  [1076] = 463,
  [1077] = 469,
  [1078] = 481,
  [1079] = 482,
  [1080] = 483,
  [1081] = 484,
  [1082] = 485,
  [1083] = 1083,
  [1084] = 471,
  [1085] = 476,
  [1086] = 479,
  [1087] = 470,
  [1088] = 473,
  [1089] = 943,
  [1090] = 477,
  [1091] = 480,
  [1092] = 800,
  [1093] = 475,
  [1094] = 828,
  [1095] = 839,
  [1096] = 1096,
  [1097] = 1047,
  [1098] = 793,
  [1099] = 810,
  [1100] = 838,
  [1101] = 817,
  [1102] = 818,
  [1103] = 460,
  [1104] = 459,
  [1105] = 810,
  [1106] = 838,
  [1107] = 817,
  [1108] = 818,
  [1109] = 478,
  [1110] = 486,
  [1111] = 586,
  [1112] = 465,
  [1113] = 587,
  [1114] = 466,
  [1115] = 463,
  [1116] = 464,
  [1117] = 828,
  [1118] = 839,
  [1119] = 465,
  [1120] = 466,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1121,
  [1124] = 1122,
  [1125] = 796,
  [1126] = 781,
  [1127] = 783,
  [1128] = 782,
  [1129] = 465,
  [1130] = 800,
  [1131] = 460,
  [1132] = 586,
  [1133] = 587,
  [1134] = 459,
  [1135] = 460,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 481,
  [1139] = 488,
  [1140] = 482,
  [1141] = 483,
  [1142] = 484,
  [1143] = 470,
  [1144] = 482,
  [1145] = 483,
  [1146] = 484,
  [1147] = 465,
  [1148] = 475,
  [1149] = 478,
  [1150] = 1150,
  [1151] = 473,
  [1152] = 477,
  [1153] = 1153,
  [1154] = 486,
  [1155] = 478,
  [1156] = 469,
  [1157] = 471,
  [1158] = 1020,
  [1159] = 488,
  [1160] = 487,
  [1161] = 466,
  [1162] = 463,
  [1163] = 491,
  [1164] = 478,
  [1165] = 1021,
  [1166] = 464,
  [1167] = 475,
  [1168] = 477,
  [1169] = 465,
  [1170] = 475,
  [1171] = 486,
  [1172] = 486,
  [1173] = 477,
  [1174] = 476,
  [1175] = 485,
  [1176] = 586,
  [1177] = 479,
  [1178] = 480,
  [1179] = 460,
  [1180] = 459,
  [1181] = 943,
  [1182] = 481,
  [1183] = 587,
  [1184] = 487,
  [1185] = 485,
  [1186] = 1186,
  [1187] = 460,
  [1188] = 459,
  [1189] = 472,
  [1190] = 1190,
  [1191] = 466,
  [1192] = 476,
  [1193] = 479,
  [1194] = 463,
  [1195] = 474,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 464,
  [1199] = 1186,
  [1200] = 1020,
  [1201] = 466,
  [1202] = 470,
  [1203] = 463,
  [1204] = 466,
  [1205] = 463,
  [1206] = 1186,
  [1207] = 466,
  [1208] = 476,
  [1209] = 479,
  [1210] = 1021,
  [1211] = 810,
  [1212] = 1212,
  [1213] = 463,
  [1214] = 491,
  [1215] = 1186,
  [1216] = 1045,
  [1217] = 1186,
  [1218] = 1186,
  [1219] = 464,
  [1220] = 1056,
  [1221] = 817,
  [1222] = 464,
  [1223] = 818,
  [1224] = 472,
  [1225] = 465,
  [1226] = 1063,
  [1227] = 1064,
  [1228] = 482,
  [1229] = 483,
  [1230] = 1071,
  [1231] = 484,
  [1232] = 488,
  [1233] = 1121,
  [1234] = 1122,
  [1235] = 1083,
  [1236] = 482,
  [1237] = 943,
  [1238] = 483,
  [1239] = 465,
  [1240] = 1015,
  [1241] = 487,
  [1242] = 474,
  [1243] = 485,
  [1244] = 460,
  [1245] = 1027,
  [1246] = 470,
  [1247] = 484,
  [1248] = 478,
  [1249] = 486,
  [1250] = 459,
  [1251] = 487,
  [1252] = 485,
  [1253] = 473,
  [1254] = 480,
  [1255] = 469,
  [1256] = 481,
  [1257] = 472,
  [1258] = 1029,
  [1259] = 474,
  [1260] = 475,
  [1261] = 473,
  [1262] = 477,
  [1263] = 471,
  [1264] = 1121,
  [1265] = 1122,
  [1266] = 1096,
  [1267] = 460,
  [1268] = 469,
  [1269] = 828,
  [1270] = 839,
  [1271] = 459,
  [1272] = 471,
  [1273] = 470,
  [1274] = 473,
  [1275] = 856,
  [1276] = 816,
  [1277] = 472,
  [1278] = 480,
  [1279] = 810,
  [1280] = 838,
  [1281] = 817,
  [1282] = 818,
  [1283] = 465,
  [1284] = 476,
  [1285] = 479,
  [1286] = 480,
  [1287] = 469,
  [1288] = 481,
  [1289] = 474,
  [1290] = 471,
  [1291] = 838,
  [1292] = 1021,
  [1293] = 473,
  [1294] = 480,
  [1295] = 469,
  [1296] = 470,
  [1297] = 466,
  [1298] = 481,
  [1299] = 471,
  [1300] = 482,
  [1301] = 1015,
  [1302] = 483,
  [1303] = 484,
  [1304] = 486,
  [1305] = 572,
  [1306] = 810,
  [1307] = 838,
  [1308] = 478,
  [1309] = 486,
  [1310] = 469,
  [1311] = 465,
  [1312] = 481,
  [1313] = 487,
  [1314] = 482,
  [1315] = 483,
  [1316] = 484,
  [1317] = 465,
  [1318] = 485,
  [1319] = 475,
  [1320] = 1320,
  [1321] = 478,
  [1322] = 1020,
  [1323] = 1190,
  [1324] = 1137,
  [1325] = 1021,
  [1326] = 466,
  [1327] = 476,
  [1328] = 479,
  [1329] = 486,
  [1330] = 1196,
  [1331] = 473,
  [1332] = 1197,
  [1333] = 477,
  [1334] = 1071,
  [1335] = 482,
  [1336] = 470,
  [1337] = 1337,
  [1338] = 463,
  [1339] = 491,
  [1340] = 470,
  [1341] = 465,
  [1342] = 483,
  [1343] = 487,
  [1344] = 1096,
  [1345] = 464,
  [1346] = 1020,
  [1347] = 1212,
  [1348] = 1021,
  [1349] = 485,
  [1350] = 1056,
  [1351] = 484,
  [1352] = 466,
  [1353] = 466,
  [1354] = 1020,
  [1355] = 1021,
  [1356] = 817,
  [1357] = 818,
  [1358] = 472,
  [1359] = 487,
  [1360] = 1027,
  [1361] = 491,
  [1362] = 1121,
  [1363] = 1122,
  [1364] = 474,
  [1365] = 485,
  [1366] = 1029,
  [1367] = 1063,
  [1368] = 1064,
  [1369] = 1150,
  [1370] = 1015,
  [1371] = 465,
  [1372] = 466,
  [1373] = 810,
  [1374] = 838,
  [1375] = 463,
  [1376] = 1121,
  [1377] = 1122,
  [1378] = 464,
  [1379] = 1020,
  [1380] = 475,
  [1381] = 463,
  [1382] = 1121,
  [1383] = 476,
  [1384] = 471,
  [1385] = 1045,
  [1386] = 1122,
  [1387] = 1029,
  [1388] = 477,
  [1389] = 464,
  [1390] = 571,
  [1391] = 1027,
  [1392] = 472,
  [1393] = 463,
  [1394] = 476,
  [1395] = 1083,
  [1396] = 474,
  [1397] = 488,
  [1398] = 472,
  [1399] = 479,
  [1400] = 473,
  [1401] = 463,
  [1402] = 465,
  [1403] = 480,
  [1404] = 470,
  [1405] = 474,
  [1406] = 475,
  [1407] = 469,
  [1408] = 1153,
  [1409] = 481,
  [1410] = 488,
  [1411] = 1411,
  [1412] = 1071,
  [1413] = 477,
  [1414] = 471,
  [1415] = 480,
  [1416] = 465,
  [1417] = 476,
  [1418] = 466,
  [1419] = 479,
  [1420] = 463,
  [1421] = 464,
  [1422] = 1096,
  [1423] = 488,
  [1424] = 488,
  [1425] = 1411,
  [1426] = 471,
  [1427] = 1427,
  [1428] = 475,
  [1429] = 569,
  [1430] = 464,
  [1431] = 1056,
  [1432] = 472,
  [1433] = 482,
  [1434] = 483,
  [1435] = 484,
  [1436] = 1083,
  [1437] = 1063,
  [1438] = 491,
  [1439] = 477,
  [1440] = 478,
  [1441] = 486,
  [1442] = 474,
  [1443] = 465,
  [1444] = 466,
  [1445] = 1064,
  [1446] = 1121,
  [1447] = 1122,
  [1448] = 1029,
  [1449] = 473,
  [1450] = 817,
  [1451] = 487,
  [1452] = 480,
  [1453] = 469,
  [1454] = 463,
  [1455] = 481,
  [1456] = 818,
  [1457] = 1457,
  [1458] = 485,
  [1459] = 479,
  [1460] = 478,
  [1461] = 464,
  [1462] = 464,
  [1463] = 1027,
  [1464] = 1464,
  [1465] = 491,
  [1466] = 478,
  [1467] = 486,
  [1468] = 1468,
  [1469] = 460,
  [1470] = 459,
  [1471] = 1411,
  [1472] = 472,
  [1473] = 470,
  [1474] = 488,
  [1475] = 487,
  [1476] = 485,
  [1477] = 485,
  [1478] = 487,
  [1479] = 1479,
  [1480] = 1411,
  [1481] = 472,
  [1482] = 474,
  [1483] = 1212,
  [1484] = 488,
  [1485] = 482,
  [1486] = 483,
  [1487] = 484,
  [1488] = 464,
  [1489] = 475,
  [1490] = 475,
  [1491] = 1320,
  [1492] = 472,
  [1493] = 477,
  [1494] = 473,
  [1495] = 477,
  [1496] = 466,
  [1497] = 478,
  [1498] = 486,
  [1499] = 474,
  [1500] = 469,
  [1501] = 1320,
  [1502] = 1027,
  [1503] = 470,
  [1504] = 488,
  [1505] = 478,
  [1506] = 487,
  [1507] = 471,
  [1508] = 1029,
  [1509] = 485,
  [1510] = 466,
  [1511] = 476,
  [1512] = 479,
  [1513] = 463,
  [1514] = 488,
  [1515] = 464,
  [1516] = 472,
  [1517] = 474,
  [1518] = 474,
  [1519] = 1519,
  [1520] = 475,
  [1521] = 485,
  [1522] = 1020,
  [1523] = 465,
  [1524] = 1021,
  [1525] = 478,
  [1526] = 486,
  [1527] = 486,
  [1528] = 470,
  [1529] = 475,
  [1530] = 487,
  [1531] = 485,
  [1532] = 473,
  [1533] = 480,
  [1534] = 472,
  [1535] = 469,
  [1536] = 481,
  [1537] = 474,
  [1538] = 471,
  [1539] = 475,
  [1540] = 477,
  [1541] = 586,
  [1542] = 1457,
  [1543] = 587,
  [1544] = 482,
  [1545] = 483,
  [1546] = 484,
  [1547] = 1150,
  [1548] = 463,
  [1549] = 476,
  [1550] = 479,
  [1551] = 476,
  [1552] = 479,
  [1553] = 475,
  [1554] = 477,
  [1555] = 473,
  [1556] = 469,
  [1557] = 476,
  [1558] = 479,
  [1559] = 473,
  [1560] = 480,
  [1561] = 469,
  [1562] = 481,
  [1563] = 477,
  [1564] = 1519,
  [1565] = 481,
  [1566] = 471,
  [1567] = 482,
  [1568] = 466,
  [1569] = 482,
  [1570] = 483,
  [1571] = 484,
  [1572] = 463,
  [1573] = 483,
  [1574] = 484,
  [1575] = 473,
  [1576] = 480,
  [1577] = 469,
  [1578] = 481,
  [1579] = 471,
  [1580] = 482,
  [1581] = 483,
  [1582] = 484,
  [1583] = 464,
  [1584] = 471,
  [1585] = 1519,
  [1586] = 1212,
  [1587] = 480,
  [1588] = 465,
  [1589] = 1519,
  [1590] = 466,
  [1591] = 463,
  [1592] = 466,
  [1593] = 463,
  [1594] = 1190,
  [1595] = 466,
  [1596] = 474,
  [1597] = 466,
  [1598] = 1137,
  [1599] = 463,
  [1600] = 464,
  [1601] = 1601,
  [1602] = 1602,
  [1603] = 465,
  [1604] = 1604,
  [1605] = 1427,
  [1606] = 1196,
  [1607] = 1197,
  [1608] = 1608,
  [1609] = 1609,
  [1610] = 1020,
  [1611] = 1021,
  [1612] = 1150,
  [1613] = 1153,
  [1614] = 1190,
  [1615] = 1137,
  [1616] = 470,
  [1617] = 478,
  [1618] = 486,
  [1619] = 472,
  [1620] = 487,
  [1621] = 474,
  [1622] = 485,
  [1623] = 465,
  [1624] = 475,
  [1625] = 470,
  [1626] = 466,
  [1627] = 1337,
  [1628] = 1150,
  [1629] = 476,
  [1630] = 479,
  [1631] = 473,
  [1632] = 463,
  [1633] = 477,
  [1634] = 480,
  [1635] = 1153,
  [1636] = 464,
  [1637] = 469,
  [1638] = 481,
  [1639] = 482,
  [1640] = 483,
  [1641] = 484,
  [1642] = 471,
  [1643] = 491,
  [1644] = 1153,
  [1645] = 476,
  [1646] = 491,
  [1647] = 479,
  [1648] = 473,
  [1649] = 1196,
  [1650] = 477,
  [1651] = 480,
  [1652] = 1020,
  [1653] = 1021,
  [1654] = 1197,
  [1655] = 1655,
  [1656] = 469,
  [1657] = 470,
  [1658] = 481,
  [1659] = 471,
  [1660] = 1655,
  [1661] = 478,
  [1662] = 1020,
  [1663] = 1021,
  [1664] = 486,
  [1665] = 1063,
  [1666] = 1064,
  [1667] = 1015,
  [1668] = 810,
  [1669] = 838,
  [1670] = 1670,
  [1671] = 465,
  [1672] = 487,
  [1673] = 1673,
  [1674] = 1096,
  [1675] = 817,
  [1676] = 818,
  [1677] = 1121,
  [1678] = 1122,
  [1679] = 476,
  [1680] = 479,
  [1681] = 1468,
  [1682] = 485,
  [1683] = 480,
  [1684] = 1519,
  [1685] = 1121,
  [1686] = 1122,
  [1687] = 491,
  [1688] = 465,
  [1689] = 465,
  [1690] = 1519,
  [1691] = 796,
  [1692] = 781,
  [1693] = 783,
  [1694] = 470,
  [1695] = 782,
  [1696] = 481,
  [1697] = 465,
  [1698] = 800,
  [1699] = 482,
  [1700] = 483,
  [1701] = 484,
  [1702] = 478,
  [1703] = 486,
  [1704] = 472,
  [1705] = 487,
  [1706] = 1673,
  [1707] = 463,
  [1708] = 1708,
  [1709] = 1479,
  [1710] = 470,
  [1711] = 463,
  [1712] = 475,
  [1713] = 1468,
  [1714] = 477,
  [1715] = 464,
  [1716] = 569,
  [1717] = 476,
  [1718] = 479,
  [1719] = 471,
  [1720] = 1411,
  [1721] = 488,
  [1722] = 1320,
  [1723] = 465,
  [1724] = 470,
  [1725] = 473,
  [1726] = 480,
  [1727] = 469,
  [1728] = 481,
  [1729] = 471,
  [1730] = 482,
  [1731] = 483,
  [1732] = 484,
  [1733] = 472,
  [1734] = 482,
  [1735] = 483,
  [1736] = 484,
  [1737] = 782,
  [1738] = 476,
  [1739] = 478,
  [1740] = 486,
  [1741] = 487,
  [1742] = 1708,
  [1743] = 485,
  [1744] = 800,
  [1745] = 472,
  [1746] = 571,
  [1747] = 474,
  [1748] = 466,
  [1749] = 463,
  [1750] = 465,
  [1751] = 800,
  [1752] = 475,
  [1753] = 466,
  [1754] = 1754,
  [1755] = 473,
  [1756] = 1411,
  [1757] = 463,
  [1758] = 477,
  [1759] = 464,
  [1760] = 1020,
  [1761] = 1021,
  [1762] = 491,
  [1763] = 1673,
  [1764] = 487,
  [1765] = 1150,
  [1766] = 466,
  [1767] = 463,
  [1768] = 469,
  [1769] = 1754,
  [1770] = 1708,
  [1771] = 1427,
  [1772] = 471,
  [1773] = 479,
  [1774] = 476,
  [1775] = 479,
  [1776] = 491,
  [1777] = 470,
  [1778] = 466,
  [1779] = 463,
  [1780] = 480,
  [1781] = 1754,
  [1782] = 478,
  [1783] = 486,
  [1784] = 481,
  [1785] = 1754,
  [1786] = 487,
  [1787] = 1457,
  [1788] = 485,
  [1789] = 1754,
  [1790] = 1027,
  [1791] = 465,
  [1792] = 472,
  [1793] = 1754,
  [1794] = 482,
  [1795] = 483,
  [1796] = 484,
  [1797] = 474,
  [1798] = 1754,
  [1799] = 1020,
  [1800] = 1021,
  [1801] = 1464,
  [1802] = 1153,
  [1803] = 1320,
  [1804] = 475,
  [1805] = 1754,
  [1806] = 473,
  [1807] = 477,
  [1808] = 469,
  [1809] = 1337,
  [1810] = 471,
  [1811] = 488,
  [1812] = 476,
  [1813] = 1604,
  [1814] = 1320,
  [1815] = 479,
  [1816] = 480,
  [1817] = 481,
  [1818] = 1029,
  [1819] = 1411,
  [1820] = 1427,
  [1821] = 482,
  [1822] = 483,
  [1823] = 1608,
  [1824] = 1609,
  [1825] = 1457,
  [1826] = 484,
  [1827] = 488,
  [1828] = 1411,
  [1829] = 491,
  [1830] = 478,
  [1831] = 486,
  [1832] = 480,
  [1833] = 1670,
  [1834] = 1027,
  [1835] = 1468,
  [1836] = 478,
  [1837] = 1673,
  [1838] = 470,
  [1839] = 470,
  [1840] = 478,
  [1841] = 486,
  [1842] = 472,
  [1843] = 488,
  [1844] = 487,
  [1845] = 474,
  [1846] = 487,
  [1847] = 485,
  [1848] = 475,
  [1849] = 466,
  [1850] = 1020,
  [1851] = 1021,
  [1852] = 476,
  [1853] = 479,
  [1854] = 473,
  [1855] = 486,
  [1856] = 477,
  [1857] = 480,
  [1858] = 485,
  [1859] = 474,
  [1860] = 469,
  [1861] = 481,
  [1862] = 482,
  [1863] = 483,
  [1864] = 484,
  [1865] = 572,
  [1866] = 471,
  [1867] = 796,
  [1868] = 488,
  [1869] = 463,
  [1870] = 488,
  [1871] = 472,
  [1872] = 475,
  [1873] = 1873,
  [1874] = 1655,
  [1875] = 1190,
  [1876] = 1137,
  [1877] = 474,
  [1878] = 464,
  [1879] = 781,
  [1880] = 473,
  [1881] = 477,
  [1882] = 783,
  [1883] = 1708,
  [1884] = 1708,
  [1885] = 1337,
  [1886] = 465,
  [1887] = 465,
  [1888] = 491,
  [1889] = 828,
  [1890] = 839,
  [1891] = 469,
  [1892] = 488,
  [1893] = 856,
  [1894] = 816,
  [1895] = 466,
  [1896] = 485,
  [1897] = 1708,
  [1898] = 810,
  [1899] = 838,
  [1900] = 817,
  [1901] = 818,
  [1902] = 465,
  [1903] = 1320,
  [1904] = 481,
  [1905] = 1029,
  [1906] = 1655,
  [1907] = 1907,
  [1908] = 1907,
  [1909] = 1907,
  [1910] = 486,
  [1911] = 1655,
  [1912] = 470,
  [1913] = 1913,
  [1914] = 856,
  [1915] = 1915,
  [1916] = 816,
  [1917] = 1917,
  [1918] = 1918,
  [1919] = 1919,
  [1920] = 1920,
  [1921] = 1921,
  [1922] = 1922,
  [1923] = 478,
  [1924] = 486,
  [1925] = 587,
  [1926] = 1926,
  [1927] = 1927,
  [1928] = 1928,
  [1929] = 1921,
  [1930] = 1020,
  [1931] = 1021,
  [1932] = 1932,
  [1933] = 474,
  [1934] = 466,
  [1935] = 1935,
  [1936] = 472,
  [1937] = 1937,
  [1938] = 1938,
  [1939] = 1907,
  [1940] = 1940,
  [1941] = 1917,
  [1942] = 1942,
  [1943] = 482,
  [1944] = 1944,
  [1945] = 1945,
  [1946] = 1919,
  [1947] = 1913,
  [1948] = 1921,
  [1949] = 1922,
  [1950] = 483,
  [1951] = 484,
  [1952] = 1918,
  [1953] = 487,
  [1954] = 1920,
  [1955] = 1926,
  [1956] = 485,
  [1957] = 1927,
  [1958] = 1928,
  [1959] = 1932,
  [1960] = 1935,
  [1961] = 1944,
  [1962] = 1468,
  [1963] = 1945,
  [1964] = 1913,
  [1965] = 1928,
  [1966] = 1940,
  [1967] = 1919,
  [1968] = 1464,
  [1969] = 475,
  [1970] = 463,
  [1971] = 1673,
  [1972] = 1918,
  [1973] = 1479,
  [1974] = 1920,
  [1975] = 472,
  [1976] = 1942,
  [1977] = 1940,
  [1978] = 1921,
  [1979] = 1468,
  [1980] = 1940,
  [1981] = 473,
  [1982] = 1468,
  [1983] = 1926,
  [1984] = 474,
  [1985] = 477,
  [1986] = 470,
  [1987] = 1150,
  [1988] = 469,
  [1989] = 1942,
  [1990] = 487,
  [1991] = 466,
  [1992] = 463,
  [1993] = 1922,
  [1994] = 474,
  [1995] = 465,
  [1996] = 485,
  [1997] = 471,
  [1998] = 1927,
  [1999] = 1907,
  [2000] = 1915,
  [2001] = 488,
  [2002] = 475,
  [2003] = 476,
  [2004] = 491,
  [2005] = 475,
  [2006] = 479,
  [2007] = 473,
  [2008] = 477,
  [2009] = 469,
  [2010] = 471,
  [2011] = 473,
  [2012] = 1937,
  [2013] = 476,
  [2014] = 479,
  [2015] = 1938,
  [2016] = 1907,
  [2017] = 480,
  [2018] = 1608,
  [2019] = 1609,
  [2020] = 1670,
  [2021] = 477,
  [2022] = 481,
  [2023] = 472,
  [2024] = 480,
  [2025] = 1915,
  [2026] = 488,
  [2027] = 1320,
  [2028] = 469,
  [2029] = 481,
  [2030] = 1604,
  [2031] = 1673,
  [2032] = 1937,
  [2033] = 1938,
  [2034] = 1153,
  [2035] = 1907,
  [2036] = 1655,
  [2037] = 482,
  [2038] = 483,
  [2039] = 484,
  [2040] = 1918,
  [2041] = 1915,
  [2042] = 464,
  [2043] = 1655,
  [2044] = 464,
  [2045] = 1464,
  [2046] = 1937,
  [2047] = 1479,
  [2048] = 1938,
  [2049] = 1907,
  [2050] = 1932,
  [2051] = 471,
  [2052] = 476,
  [2053] = 491,
  [2054] = 479,
  [2055] = 1150,
  [2056] = 1655,
  [2057] = 1907,
  [2058] = 1915,
  [2059] = 480,
  [2060] = 481,
  [2061] = 1907,
  [2062] = 482,
  [2063] = 483,
  [2064] = 1937,
  [2065] = 484,
  [2066] = 1928,
  [2067] = 1919,
  [2068] = 1907,
  [2069] = 478,
  [2070] = 1907,
  [2071] = 1938,
  [2072] = 488,
  [2073] = 1907,
  [2074] = 1907,
  [2075] = 1907,
  [2076] = 491,
  [2077] = 1907,
  [2078] = 465,
  [2079] = 1917,
  [2080] = 1940,
  [2081] = 1907,
  [2082] = 1673,
  [2083] = 1907,
  [2084] = 1907,
  [2085] = 1468,
  [2086] = 1907,
  [2087] = 488,
  [2088] = 1907,
  [2089] = 1932,
  [2090] = 1907,
  [2091] = 1907,
  [2092] = 1907,
  [2093] = 1907,
  [2094] = 1907,
  [2095] = 1907,
  [2096] = 1907,
  [2097] = 1907,
  [2098] = 1907,
  [2099] = 1935,
  [2100] = 1907,
  [2101] = 1907,
  [2102] = 1907,
  [2103] = 1907,
  [2104] = 1907,
  [2105] = 1907,
  [2106] = 1907,
  [2107] = 1907,
  [2108] = 1907,
  [2109] = 1907,
  [2110] = 1320,
  [2111] = 470,
  [2112] = 1320,
  [2113] = 810,
  [2114] = 838,
  [2115] = 1935,
  [2116] = 817,
  [2117] = 818,
  [2118] = 1922,
  [2119] = 1944,
  [2120] = 1945,
  [2121] = 1604,
  [2122] = 491,
  [2123] = 1907,
  [2124] = 1907,
  [2125] = 1608,
  [2126] = 1920,
  [2127] = 491,
  [2128] = 1907,
  [2129] = 1926,
  [2130] = 1907,
  [2131] = 1917,
  [2132] = 1942,
  [2133] = 1920,
  [2134] = 1907,
  [2135] = 1919,
  [2136] = 1907,
  [2137] = 478,
  [2138] = 1944,
  [2139] = 1907,
  [2140] = 1907,
  [2141] = 1907,
  [2142] = 828,
  [2143] = 1907,
  [2144] = 486,
  [2145] = 1945,
  [2146] = 1907,
  [2147] = 1921,
  [2148] = 586,
  [2149] = 488,
  [2150] = 487,
  [2151] = 1907,
  [2152] = 1922,
  [2153] = 1907,
  [2154] = 1926,
  [2155] = 1917,
  [2156] = 1907,
  [2157] = 1913,
  [2158] = 1670,
  [2159] = 1917,
  [2160] = 1921,
  [2161] = 1922,
  [2162] = 1926,
  [2163] = 1927,
  [2164] = 1928,
  [2165] = 1907,
  [2166] = 1932,
  [2167] = 1935,
  [2168] = 1944,
  [2169] = 1945,
  [2170] = 1913,
  [2171] = 1907,
  [2172] = 1940,
  [2173] = 1915,
  [2174] = 1907,
  [2175] = 1942,
  [2176] = 1907,
  [2177] = 839,
  [2178] = 1927,
  [2179] = 485,
  [2180] = 1928,
  [2181] = 1927,
  [2182] = 1907,
  [2183] = 1907,
  [2184] = 1937,
  [2185] = 1938,
  [2186] = 1920,
  [2187] = 1673,
  [2188] = 1932,
  [2189] = 1907,
  [2190] = 1913,
  [2191] = 1935,
  [2192] = 1907,
  [2193] = 1907,
  [2194] = 1907,
  [2195] = 491,
  [2196] = 1907,
  [2197] = 1907,
  [2198] = 1907,
  [2199] = 1907,
  [2200] = 1907,
  [2201] = 1907,
  [2202] = 1907,
  [2203] = 1907,
  [2204] = 1907,
  [2205] = 1907,
  [2206] = 1907,
  [2207] = 1609,
  [2208] = 1907,
  [2209] = 1944,
  [2210] = 1153,
  [2211] = 1907,
  [2212] = 1945,
  [2213] = 1942,
  [2214] = 491,
  [2215] = 1907,
  [2216] = 1907,
  [2217] = 488,
  [2218] = 482,
  [2219] = 470,
  [2220] = 483,
  [2221] = 484,
  [2222] = 486,
  [2223] = 478,
  [2224] = 486,
  [2225] = 472,
  [2226] = 487,
  [2227] = 474,
  [2228] = 1015,
  [2229] = 485,
  [2230] = 475,
  [2231] = 810,
  [2232] = 476,
  [2233] = 479,
  [2234] = 473,
  [2235] = 491,
  [2236] = 477,
  [2237] = 480,
  [2238] = 838,
  [2239] = 469,
  [2240] = 481,
  [2241] = 482,
  [2242] = 483,
  [2243] = 484,
  [2244] = 471,
  [2245] = 487,
  [2246] = 465,
  [2247] = 491,
  [2248] = 485,
  [2249] = 488,
  [2250] = 1096,
  [2251] = 470,
  [2252] = 817,
  [2253] = 1320,
  [2254] = 466,
  [2255] = 463,
  [2256] = 466,
  [2257] = 463,
  [2258] = 475,
  [2259] = 465,
  [2260] = 471,
  [2261] = 473,
  [2262] = 459,
  [2263] = 476,
  [2264] = 464,
  [2265] = 469,
  [2266] = 479,
  [2267] = 480,
  [2268] = 1608,
  [2269] = 1609,
  [2270] = 465,
  [2271] = 481,
  [2272] = 477,
  [2273] = 463,
  [2274] = 472,
  [2275] = 466,
  [2276] = 491,
  [2277] = 465,
  [2278] = 474,
  [2279] = 1320,
  [2280] = 488,
  [2281] = 491,
  [2282] = 1020,
  [2283] = 1021,
  [2284] = 465,
  [2285] = 1604,
  [2286] = 1020,
  [2287] = 1021,
  [2288] = 1063,
  [2289] = 1064,
  [2290] = 1015,
  [2291] = 810,
  [2292] = 838,
  [2293] = 1096,
  [2294] = 817,
  [2295] = 818,
  [2296] = 1121,
  [2297] = 1122,
  [2298] = 491,
  [2299] = 465,
  [2300] = 1121,
  [2301] = 1122,
  [2302] = 478,
  [2303] = 465,
  [2304] = 465,
  [2305] = 460,
  [2306] = 818,
  [2307] = 943,
  [2308] = 465,
  [2309] = 2309,
  [2310] = 466,
  [2311] = 463,
  [2312] = 2312,
  [2313] = 484,
  [2314] = 466,
  [2315] = 463,
  [2316] = 483,
  [2317] = 466,
  [2318] = 476,
  [2319] = 479,
  [2320] = 2320,
  [2321] = 1064,
  [2322] = 2322,
  [2323] = 1027,
  [2324] = 463,
  [2325] = 488,
  [2326] = 2326,
  [2327] = 2327,
  [2328] = 484,
  [2329] = 1029,
  [2330] = 463,
  [2331] = 2331,
  [2332] = 464,
  [2333] = 486,
  [2334] = 2331,
  [2335] = 1021,
  [2336] = 2320,
  [2337] = 2337,
  [2338] = 487,
  [2339] = 477,
  [2340] = 469,
  [2341] = 469,
  [2342] = 2342,
  [2343] = 485,
  [2344] = 2309,
  [2345] = 2327,
  [2346] = 1122,
  [2347] = 480,
  [2348] = 471,
  [2349] = 488,
  [2350] = 465,
  [2351] = 491,
  [2352] = 491,
  [2353] = 474,
  [2354] = 465,
  [2355] = 2342,
  [2356] = 466,
  [2357] = 2342,
  [2358] = 471,
  [2359] = 2327,
  [2360] = 481,
  [2361] = 2309,
  [2362] = 2342,
  [2363] = 2327,
  [2364] = 463,
  [2365] = 464,
  [2366] = 2327,
  [2367] = 1121,
  [2368] = 464,
  [2369] = 465,
  [2370] = 475,
  [2371] = 1122,
  [2372] = 478,
  [2373] = 2327,
  [2374] = 2320,
  [2375] = 2320,
  [2376] = 466,
  [2377] = 2331,
  [2378] = 2331,
  [2379] = 2322,
  [2380] = 1020,
  [2381] = 2309,
  [2382] = 1021,
  [2383] = 2322,
  [2384] = 463,
  [2385] = 2326,
  [2386] = 463,
  [2387] = 1121,
  [2388] = 810,
  [2389] = 2326,
  [2390] = 480,
  [2391] = 838,
  [2392] = 1190,
  [2393] = 1137,
  [2394] = 2322,
  [2395] = 1063,
  [2396] = 466,
  [2397] = 472,
  [2398] = 466,
  [2399] = 1071,
  [2400] = 463,
  [2401] = 473,
  [2402] = 491,
  [2403] = 2309,
  [2404] = 470,
  [2405] = 1083,
  [2406] = 464,
  [2407] = 2312,
  [2408] = 1015,
  [2409] = 488,
  [2410] = 817,
  [2411] = 1020,
  [2412] = 1056,
  [2413] = 1021,
  [2414] = 482,
  [2415] = 483,
  [2416] = 466,
  [2417] = 466,
  [2418] = 2342,
  [2419] = 1096,
  [2420] = 463,
  [2421] = 466,
  [2422] = 465,
  [2423] = 818,
  [2424] = 463,
  [2425] = 465,
  [2426] = 1020,
  [2427] = 481,
  [2428] = 473,
  [2429] = 482,
  [2430] = 2326,
  [2431] = 2342,
  [2432] = 484,
  [2433] = 476,
  [2434] = 479,
  [2435] = 480,
  [2436] = 1027,
  [2437] = 473,
  [2438] = 471,
  [2439] = 484,
  [2440] = 474,
  [2441] = 476,
  [2442] = 2442,
  [2443] = 472,
  [2444] = 473,
  [2445] = 487,
  [2446] = 486,
  [2447] = 480,
  [2448] = 481,
  [2449] = 1196,
  [2450] = 477,
  [2451] = 2312,
  [2452] = 488,
  [2453] = 469,
  [2454] = 475,
  [2455] = 474,
  [2456] = 470,
  [2457] = 473,
  [2458] = 1457,
  [2459] = 483,
  [2460] = 482,
  [2461] = 476,
  [2462] = 470,
  [2463] = 477,
  [2464] = 483,
  [2465] = 465,
  [2466] = 478,
  [2467] = 480,
  [2468] = 486,
  [2469] = 484,
  [2470] = 487,
  [2471] = 479,
  [2472] = 485,
  [2473] = 466,
  [2474] = 466,
  [2475] = 463,
  [2476] = 464,
  [2477] = 472,
  [2478] = 474,
  [2479] = 464,
  [2480] = 1212,
  [2481] = 488,
  [2482] = 475,
  [2483] = 474,
  [2484] = 480,
  [2485] = 471,
  [2486] = 482,
  [2487] = 2487,
  [2488] = 1197,
  [2489] = 482,
  [2490] = 465,
  [2491] = 2491,
  [2492] = 481,
  [2493] = 481,
  [2494] = 475,
  [2495] = 2495,
  [2496] = 1320,
  [2497] = 1150,
  [2498] = 470,
  [2499] = 481,
  [2500] = 470,
  [2501] = 471,
  [2502] = 491,
  [2503] = 463,
  [2504] = 1020,
  [2505] = 469,
  [2506] = 480,
  [2507] = 473,
  [2508] = 2508,
  [2509] = 1153,
  [2510] = 475,
  [2511] = 477,
  [2512] = 2512,
  [2513] = 1137,
  [2514] = 466,
  [2515] = 478,
  [2516] = 478,
  [2517] = 486,
  [2518] = 2518,
  [2519] = 463,
  [2520] = 2520,
  [2521] = 486,
  [2522] = 491,
  [2523] = 473,
  [2524] = 487,
  [2525] = 477,
  [2526] = 1190,
  [2527] = 464,
  [2528] = 466,
  [2529] = 485,
  [2530] = 463,
  [2531] = 465,
  [2532] = 471,
  [2533] = 488,
  [2534] = 482,
  [2535] = 484,
  [2536] = 1020,
  [2537] = 483,
  [2538] = 1021,
  [2539] = 466,
  [2540] = 1021,
  [2541] = 2541,
  [2542] = 478,
  [2543] = 2337,
  [2544] = 1337,
  [2545] = 2545,
  [2546] = 487,
  [2547] = 463,
  [2548] = 472,
  [2549] = 2312,
  [2550] = 485,
  [2551] = 482,
  [2552] = 476,
  [2553] = 483,
  [2554] = 483,
  [2555] = 1020,
  [2556] = 1021,
  [2557] = 2309,
  [2558] = 469,
  [2559] = 481,
  [2560] = 485,
  [2561] = 465,
  [2562] = 479,
  [2563] = 469,
  [2564] = 479,
  [2565] = 2565,
  [2566] = 2566,
  [2567] = 484,
  [2568] = 491,
  [2569] = 1029,
  [2570] = 472,
  [2571] = 471,
  [2572] = 469,
  [2573] = 484,
  [2574] = 483,
  [2575] = 466,
  [2576] = 463,
  [2577] = 464,
  [2578] = 465,
  [2579] = 478,
  [2580] = 486,
  [2581] = 470,
  [2582] = 487,
  [2583] = 485,
  [2584] = 471,
  [2585] = 472,
  [2586] = 474,
  [2587] = 2587,
  [2588] = 2588,
  [2589] = 473,
  [2590] = 480,
  [2591] = 469,
  [2592] = 481,
  [2593] = 471,
  [2594] = 2337,
  [2595] = 2595,
  [2596] = 2596,
  [2597] = 482,
  [2598] = 483,
  [2599] = 484,
  [2600] = 475,
  [2601] = 477,
  [2602] = 2602,
  [2603] = 1608,
  [2604] = 1609,
  [2605] = 1411,
  [2606] = 476,
  [2607] = 479,
  [2608] = 2518,
  [2609] = 1457,
  [2610] = 1427,
  [2611] = 1337,
  [2612] = 473,
  [2613] = 480,
  [2614] = 469,
  [2615] = 481,
  [2616] = 471,
  [2617] = 2617,
  [2618] = 1411,
  [2619] = 2619,
  [2620] = 482,
  [2621] = 483,
  [2622] = 484,
  [2623] = 2623,
  [2624] = 2624,
  [2625] = 2625,
  [2626] = 2545,
  [2627] = 2627,
  [2628] = 2566,
  [2629] = 2629,
  [2630] = 1320,
  [2631] = 2631,
  [2632] = 1027,
  [2633] = 1029,
  [2634] = 1320,
  [2635] = 2512,
  [2636] = 2636,
  [2637] = 2637,
  [2638] = 2638,
  [2639] = 2639,
  [2640] = 2640,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2643,
  [2644] = 2644,
  [2645] = 2541,
  [2646] = 2646,
  [2647] = 2647,
  [2648] = 2648,
  [2649] = 2649,
  [2650] = 2650,
  [2651] = 2442,
  [2652] = 460,
  [2653] = 459,
  [2654] = 1020,
  [2655] = 1021,
  [2656] = 2656,
  [2657] = 2657,
  [2658] = 491,
  [2659] = 2656,
  [2660] = 2657,
  [2661] = 1479,
  [2662] = 482,
  [2663] = 2657,
  [2664] = 475,
  [2665] = 1150,
  [2666] = 491,
  [2667] = 2656,
  [2668] = 2657,
  [2669] = 2656,
  [2670] = 2657,
  [2671] = 2656,
  [2672] = 2656,
  [2673] = 2656,
  [2674] = 2656,
  [2675] = 2656,
  [2676] = 2656,
  [2677] = 1670,
  [2678] = 2656,
  [2679] = 2656,
  [2680] = 2656,
  [2681] = 2656,
  [2682] = 2656,
  [2683] = 2656,
  [2684] = 2656,
  [2685] = 2656,
  [2686] = 1153,
  [2687] = 2656,
  [2688] = 2656,
  [2689] = 2656,
  [2690] = 2656,
  [2691] = 2656,
  [2692] = 2656,
  [2693] = 2656,
  [2694] = 2656,
  [2695] = 2656,
  [2696] = 2656,
  [2697] = 2656,
  [2698] = 2656,
  [2699] = 2656,
  [2700] = 2656,
  [2701] = 2656,
  [2702] = 2656,
  [2703] = 2656,
  [2704] = 2656,
  [2705] = 2656,
  [2706] = 2656,
  [2707] = 2656,
  [2708] = 2656,
  [2709] = 2656,
  [2710] = 2656,
  [2711] = 2656,
  [2712] = 2712,
  [2713] = 2656,
  [2714] = 2656,
  [2715] = 2715,
  [2716] = 2656,
  [2717] = 2656,
  [2718] = 2656,
  [2719] = 2656,
  [2720] = 2656,
  [2721] = 2656,
  [2722] = 2656,
  [2723] = 2656,
  [2724] = 2656,
  [2725] = 2656,
  [2726] = 2656,
  [2727] = 2727,
  [2728] = 2656,
  [2729] = 2729,
  [2730] = 2656,
  [2731] = 2656,
  [2732] = 2656,
  [2733] = 2656,
  [2734] = 2656,
  [2735] = 2656,
  [2736] = 470,
  [2737] = 488,
  [2738] = 476,
  [2739] = 478,
  [2740] = 486,
  [2741] = 479,
  [2742] = 473,
  [2743] = 487,
  [2744] = 485,
  [2745] = 477,
  [2746] = 480,
  [2747] = 472,
  [2748] = 474,
  [2749] = 2508,
  [2750] = 2750,
  [2751] = 2751,
  [2752] = 2752,
  [2753] = 475,
  [2754] = 473,
  [2755] = 477,
  [2756] = 469,
  [2757] = 471,
  [2758] = 476,
  [2759] = 479,
  [2760] = 480,
  [2761] = 481,
  [2762] = 482,
  [2763] = 483,
  [2764] = 484,
  [2765] = 2765,
  [2766] = 2766,
  [2767] = 2767,
  [2768] = 2768,
  [2769] = 2769,
  [2770] = 2770,
  [2771] = 2771,
  [2772] = 2772,
  [2773] = 2773,
  [2774] = 2774,
  [2775] = 2775,
  [2776] = 2776,
  [2777] = 470,
  [2778] = 469,
  [2779] = 478,
  [2780] = 486,
  [2781] = 487,
  [2782] = 485,
  [2783] = 481,
  [2784] = 482,
  [2785] = 483,
  [2786] = 488,
  [2787] = 472,
  [2788] = 474,
  [2789] = 484,
  [2790] = 2657,
  [2791] = 2656,
  [2792] = 491,
  [2793] = 488,
  [2794] = 475,
  [2795] = 473,
  [2796] = 477,
  [2797] = 469,
  [2798] = 471,
  [2799] = 476,
  [2800] = 479,
  [2801] = 480,
  [2802] = 481,
  [2803] = 2656,
  [2804] = 2647,
  [2805] = 2805,
  [2806] = 2806,
  [2807] = 2807,
  [2808] = 469,
  [2809] = 2809,
  [2810] = 2810,
  [2811] = 2805,
  [2812] = 2806,
  [2813] = 481,
  [2814] = 478,
  [2815] = 2566,
  [2816] = 2809,
  [2817] = 2810,
  [2818] = 2805,
  [2819] = 2806,
  [2820] = 2820,
  [2821] = 2809,
  [2822] = 2491,
  [2823] = 2810,
  [2824] = 2805,
  [2825] = 2806,
  [2826] = 2826,
  [2827] = 2809,
  [2828] = 2810,
  [2829] = 2829,
  [2830] = 2809,
  [2831] = 1464,
  [2832] = 471,
  [2833] = 1670,
  [2834] = 486,
  [2835] = 2835,
  [2836] = 2836,
  [2837] = 2837,
  [2838] = 2838,
  [2839] = 1673,
  [2840] = 2636,
  [2841] = 1468,
  [2842] = 2541,
  [2843] = 2646,
  [2844] = 2647,
  [2845] = 2805,
  [2846] = 482,
  [2847] = 2518,
  [2848] = 483,
  [2849] = 484,
  [2850] = 488,
  [2851] = 2641,
  [2852] = 1655,
  [2853] = 2648,
  [2854] = 2642,
  [2855] = 2649,
  [2856] = 475,
  [2857] = 2643,
  [2858] = 2602,
  [2859] = 1320,
  [2860] = 477,
  [2861] = 2644,
  [2862] = 2642,
  [2863] = 2810,
  [2864] = 470,
  [2865] = 487,
  [2866] = 2866,
  [2867] = 2646,
  [2868] = 2650,
  [2869] = 485,
  [2870] = 2637,
  [2871] = 1150,
  [2872] = 2508,
  [2873] = 2750,
  [2874] = 1153,
  [2875] = 2750,
  [2876] = 1673,
  [2877] = 2520,
  [2878] = 2565,
  [2879] = 475,
  [2880] = 2442,
  [2881] = 473,
  [2882] = 477,
  [2883] = 2638,
  [2884] = 2639,
  [2885] = 2806,
  [2886] = 2647,
  [2887] = 2887,
  [2888] = 469,
  [2889] = 2889,
  [2890] = 472,
  [2891] = 476,
  [2892] = 479,
  [2893] = 474,
  [2894] = 2640,
  [2895] = 2640,
  [2896] = 460,
  [2897] = 459,
  [2898] = 491,
  [2899] = 471,
  [2900] = 2641,
  [2901] = 1655,
  [2902] = 2902,
  [2903] = 2648,
  [2904] = 2887,
  [2905] = 2905,
  [2906] = 2906,
  [2907] = 2907,
  [2908] = 2491,
  [2909] = 2636,
  [2910] = 2637,
  [2911] = 2638,
  [2912] = 2639,
  [2913] = 2640,
  [2914] = 2641,
  [2915] = 2642,
  [2916] = 2643,
  [2917] = 2644,
  [2918] = 2646,
  [2919] = 2919,
  [2920] = 2627,
  [2921] = 488,
  [2922] = 2649,
  [2923] = 2650,
  [2924] = 476,
  [2925] = 479,
  [2926] = 480,
  [2927] = 1468,
  [2928] = 2495,
  [2929] = 1608,
  [2930] = 1609,
  [2931] = 2931,
  [2932] = 2932,
  [2933] = 2487,
  [2934] = 481,
  [2935] = 2602,
  [2936] = 460,
  [2937] = 459,
  [2938] = 2649,
  [2939] = 2650,
  [2940] = 460,
  [2941] = 459,
  [2942] = 2810,
  [2943] = 2805,
  [2944] = 2806,
  [2945] = 1604,
  [2946] = 2643,
  [2947] = 2809,
  [2948] = 2948,
  [2949] = 482,
  [2950] = 483,
  [2951] = 2624,
  [2952] = 2625,
  [2953] = 484,
  [2954] = 2627,
  [2955] = 2887,
  [2956] = 2624,
  [2957] = 2625,
  [2958] = 2627,
  [2959] = 2520,
  [2960] = 2565,
  [2961] = 2636,
  [2962] = 2637,
  [2963] = 2638,
  [2964] = 2639,
  [2965] = 2640,
  [2966] = 2641,
  [2967] = 2642,
  [2968] = 2643,
  [2969] = 2644,
  [2970] = 2646,
  [2971] = 2647,
  [2972] = 2648,
  [2973] = 2649,
  [2974] = 2650,
  [2975] = 1320,
  [2976] = 2495,
  [2977] = 2487,
  [2978] = 2978,
  [2979] = 2750,
  [2980] = 2810,
  [2981] = 2809,
  [2982] = 2805,
  [2983] = 2806,
  [2984] = 2984,
  [2985] = 2985,
  [2986] = 2809,
  [2987] = 2948,
  [2988] = 2887,
  [2989] = 2624,
  [2990] = 2625,
  [2991] = 491,
  [2992] = 2627,
  [2993] = 2810,
  [2994] = 2624,
  [2995] = 2948,
  [2996] = 2996,
  [2997] = 2750,
  [2998] = 2805,
  [2999] = 488,
  [3000] = 2512,
  [3001] = 2636,
  [3002] = 2637,
  [3003] = 2638,
  [3004] = 2887,
  [3005] = 2639,
  [3006] = 2806,
  [3007] = 491,
  [3008] = 1479,
  [3009] = 473,
  [3010] = 2809,
  [3011] = 2644,
  [3012] = 2948,
  [3013] = 2625,
  [3014] = 480,
  [3015] = 2887,
  [3016] = 2545,
  [3017] = 2810,
  [3018] = 2648,
  [3019] = 2646,
  [3020] = 3020,
  [3021] = 2766,
  [3022] = 2767,
  [3023] = 3020,
  [3024] = 2712,
  [3025] = 2768,
  [3026] = 3020,
  [3027] = 2715,
  [3028] = 3020,
  [3029] = 2769,
  [3030] = 3020,
  [3031] = 2727,
  [3032] = 2770,
  [3033] = 3020,
  [3034] = 2729,
  [3035] = 2771,
  [3036] = 3020,
  [3037] = 2772,
  [3038] = 3020,
  [3039] = 2773,
  [3040] = 3020,
  [3041] = 2774,
  [3042] = 3020,
  [3043] = 2775,
  [3044] = 3020,
  [3045] = 2776,
  [3046] = 3020,
  [3047] = 2978,
  [3048] = 3020,
  [3049] = 2984,
  [3050] = 3020,
  [3051] = 2985,
  [3052] = 3020,
  [3053] = 2996,
  [3054] = 3020,
  [3055] = 3020,
  [3056] = 2919,
  [3057] = 3020,
  [3058] = 3020,
  [3059] = 2807,
  [3060] = 3020,
  [3061] = 3020,
  [3062] = 459,
  [3063] = 3020,
  [3064] = 2820,
  [3065] = 3020,
  [3066] = 2826,
  [3067] = 3020,
  [3068] = 2829,
  [3069] = 3020,
  [3070] = 2835,
  [3071] = 3020,
  [3072] = 3020,
  [3073] = 465,
  [3074] = 3020,
  [3075] = 475,
  [3076] = 3020,
  [3077] = 2836,
  [3078] = 2837,
  [3079] = 3020,
  [3080] = 1020,
  [3081] = 3020,
  [3082] = 1021,
  [3083] = 3020,
  [3084] = 3020,
  [3085] = 3020,
  [3086] = 3020,
  [3087] = 473,
  [3088] = 3020,
  [3089] = 2776,
  [3090] = 3020,
  [3091] = 473,
  [3092] = 477,
  [3093] = 3020,
  [3094] = 3020,
  [3095] = 480,
  [3096] = 3020,
  [3097] = 2587,
  [3098] = 3020,
  [3099] = 475,
  [3100] = 3020,
  [3101] = 2588,
  [3102] = 3020,
  [3103] = 2907,
  [3104] = 3020,
  [3105] = 2978,
  [3106] = 3020,
  [3107] = 2984,
  [3108] = 3020,
  [3109] = 469,
  [3110] = 3020,
  [3111] = 2866,
  [3112] = 3020,
  [3113] = 2629,
  [3114] = 2985,
  [3115] = 3020,
  [3116] = 3116,
  [3117] = 477,
  [3118] = 3020,
  [3119] = 2996,
  [3120] = 2919,
  [3121] = 3020,
  [3122] = 2807,
  [3123] = 2820,
  [3124] = 3020,
  [3125] = 2826,
  [3126] = 3020,
  [3127] = 2829,
  [3128] = 3020,
  [3129] = 471,
  [3130] = 3020,
  [3131] = 2835,
  [3132] = 3020,
  [3133] = 2836,
  [3134] = 3020,
  [3135] = 2837,
  [3136] = 1320,
  [3137] = 476,
  [3138] = 460,
  [3139] = 459,
  [3140] = 479,
  [3141] = 475,
  [3142] = 460,
  [3143] = 459,
  [3144] = 469,
  [3145] = 480,
  [3146] = 481,
  [3147] = 3020,
  [3148] = 471,
  [3149] = 3149,
  [3150] = 3149,
  [3151] = 491,
  [3152] = 2595,
  [3153] = 2596,
  [3154] = 481,
  [3155] = 3020,
  [3156] = 2765,
  [3157] = 2866,
  [3158] = 3158,
  [3159] = 2629,
  [3160] = 3160,
  [3161] = 3161,
  [3162] = 476,
  [3163] = 3163,
  [3164] = 2902,
  [3165] = 2905,
  [3166] = 3166,
  [3167] = 479,
  [3168] = 3166,
  [3169] = 473,
  [3170] = 2906,
  [3171] = 2838,
  [3172] = 2617,
  [3173] = 2619,
  [3174] = 2750,
  [3175] = 2623,
  [3176] = 2631,
  [3177] = 477,
  [3178] = 480,
  [3179] = 3020,
  [3180] = 3149,
  [3181] = 3158,
  [3182] = 482,
  [3183] = 3160,
  [3184] = 483,
  [3185] = 3161,
  [3186] = 484,
  [3187] = 3163,
  [3188] = 3166,
  [3189] = 476,
  [3190] = 469,
  [3191] = 481,
  [3192] = 482,
  [3193] = 483,
  [3194] = 484,
  [3195] = 2902,
  [3196] = 2905,
  [3197] = 3020,
  [3198] = 471,
  [3199] = 2906,
  [3200] = 2587,
  [3201] = 2838,
  [3202] = 2588,
  [3203] = 2617,
  [3204] = 460,
  [3205] = 459,
  [3206] = 2595,
  [3207] = 2596,
  [3208] = 2619,
  [3209] = 3160,
  [3210] = 2623,
  [3211] = 475,
  [3212] = 3158,
  [3213] = 473,
  [3214] = 3214,
  [3215] = 477,
  [3216] = 469,
  [3217] = 3217,
  [3218] = 471,
  [3219] = 3160,
  [3220] = 476,
  [3221] = 479,
  [3222] = 3161,
  [3223] = 2631,
  [3224] = 480,
  [3225] = 3163,
  [3226] = 3166,
  [3227] = 481,
  [3228] = 460,
  [3229] = 459,
  [3230] = 491,
  [3231] = 479,
  [3232] = 482,
  [3233] = 483,
  [3234] = 484,
  [3235] = 3020,
  [3236] = 482,
  [3237] = 483,
  [3238] = 484,
  [3239] = 488,
  [3240] = 3161,
  [3241] = 460,
  [3242] = 2636,
  [3243] = 2637,
  [3244] = 2638,
  [3245] = 2639,
  [3246] = 2640,
  [3247] = 2641,
  [3248] = 2642,
  [3249] = 2643,
  [3250] = 2644,
  [3251] = 2775,
  [3252] = 2647,
  [3253] = 2648,
  [3254] = 2649,
  [3255] = 2650,
  [3256] = 491,
  [3257] = 3020,
  [3258] = 2624,
  [3259] = 2625,
  [3260] = 2627,
  [3261] = 2907,
  [3262] = 2712,
  [3263] = 2931,
  [3264] = 2932,
  [3265] = 2751,
  [3266] = 2752,
  [3267] = 2715,
  [3268] = 3020,
  [3269] = 2765,
  [3270] = 2766,
  [3271] = 2767,
  [3272] = 2727,
  [3273] = 2768,
  [3274] = 2729,
  [3275] = 2931,
  [3276] = 2769,
  [3277] = 2932,
  [3278] = 2770,
  [3279] = 466,
  [3280] = 3020,
  [3281] = 463,
  [3282] = 2751,
  [3283] = 464,
  [3284] = 2752,
  [3285] = 2771,
  [3286] = 2772,
  [3287] = 2773,
  [3288] = 2774,
  [3289] = 3163,
  [3290] = 460,
  [3291] = 460,
  [3292] = 459,
  [3293] = 481,
  [3294] = 471,
  [3295] = 472,
  [3296] = 487,
  [3297] = 474,
  [3298] = 491,
  [3299] = 3299,
  [3300] = 3300,
  [3301] = 473,
  [3302] = 3299,
  [3303] = 3300,
  [3304] = 3304,
  [3305] = 480,
  [3306] = 3306,
  [3307] = 3307,
  [3308] = 460,
  [3309] = 459,
  [3310] = 3310,
  [3311] = 460,
  [3312] = 476,
  [3313] = 469,
  [3314] = 3307,
  [3315] = 460,
  [3316] = 479,
  [3317] = 460,
  [3318] = 459,
  [3319] = 3306,
  [3320] = 3299,
  [3321] = 459,
  [3322] = 3300,
  [3323] = 3304,
  [3324] = 3306,
  [3325] = 3307,
  [3326] = 3310,
  [3327] = 3299,
  [3328] = 3300,
  [3329] = 477,
  [3330] = 3304,
  [3331] = 3306,
  [3332] = 3307,
  [3333] = 482,
  [3334] = 3310,
  [3335] = 485,
  [3336] = 3304,
  [3337] = 483,
  [3338] = 459,
  [3339] = 460,
  [3340] = 484,
  [3341] = 478,
  [3342] = 486,
  [3343] = 459,
  [3344] = 475,
  [3345] = 459,
  [3346] = 470,
  [3347] = 3310,
  [3348] = 459,
  [3349] = 1121,
  [3350] = 3350,
  [3351] = 818,
  [3352] = 1122,
  [3353] = 459,
  [3354] = 465,
  [3355] = 3350,
  [3356] = 838,
  [3357] = 3357,
  [3358] = 1020,
  [3359] = 464,
  [3360] = 572,
  [3361] = 1015,
  [3362] = 466,
  [3363] = 488,
  [3364] = 810,
  [3365] = 3350,
  [3366] = 3366,
  [3367] = 3350,
  [3368] = 3368,
  [3369] = 1320,
  [3370] = 3370,
  [3371] = 3371,
  [3372] = 463,
  [3373] = 1021,
  [3374] = 1096,
  [3375] = 460,
  [3376] = 817,
  [3377] = 460,
  [3378] = 3378,
  [3379] = 487,
  [3380] = 485,
  [3381] = 3381,
  [3382] = 472,
  [3383] = 474,
  [3384] = 3381,
  [3385] = 3385,
  [3386] = 3386,
  [3387] = 3381,
  [3388] = 3381,
  [3389] = 3381,
  [3390] = 3381,
  [3391] = 3381,
  [3392] = 3381,
  [3393] = 3381,
  [3394] = 3381,
  [3395] = 3381,
  [3396] = 3381,
  [3397] = 3381,
  [3398] = 3381,
  [3399] = 3381,
  [3400] = 3381,
  [3401] = 3381,
  [3402] = 486,
  [3403] = 3403,
  [3404] = 475,
  [3405] = 473,
  [3406] = 477,
  [3407] = 469,
  [3408] = 471,
  [3409] = 476,
  [3410] = 479,
  [3411] = 480,
  [3412] = 481,
  [3413] = 482,
  [3414] = 483,
  [3415] = 484,
  [3416] = 460,
  [3417] = 459,
  [3418] = 478,
  [3419] = 491,
  [3420] = 3381,
  [3421] = 3381,
  [3422] = 470,
  [3423] = 3381,
  [3424] = 3381,
  [3425] = 3381,
  [3426] = 3381,
  [3427] = 1457,
  [3428] = 3428,
  [3429] = 3429,
  [3430] = 3428,
  [3431] = 3429,
  [3432] = 1029,
  [3433] = 460,
  [3434] = 3429,
  [3435] = 3428,
  [3436] = 3429,
  [3437] = 3428,
  [3438] = 3428,
  [3439] = 3429,
  [3440] = 3428,
  [3441] = 3429,
  [3442] = 1320,
  [3443] = 459,
  [3444] = 3444,
  [3445] = 3428,
  [3446] = 3428,
  [3447] = 3429,
  [3448] = 3429,
  [3449] = 1027,
  [3450] = 460,
  [3451] = 1337,
  [3452] = 1411,
  [3453] = 3428,
  [3454] = 488,
  [3455] = 459,
  [3456] = 3429,
  [3457] = 3457,
  [3458] = 3458,
  [3459] = 3459,
  [3460] = 3460,
  [3461] = 3461,
  [3462] = 3462,
  [3463] = 3463,
  [3464] = 3464,
  [3465] = 3465,
  [3466] = 3466,
  [3467] = 3467,
  [3468] = 3460,
  [3469] = 3469,
  [3470] = 3462,
  [3471] = 3471,
  [3472] = 3460,
  [3473] = 3462,
  [3474] = 3462,
  [3475] = 3475,
  [3476] = 3460,
  [3477] = 3462,
  [3478] = 3460,
  [3479] = 3462,
  [3480] = 3460,
  [3481] = 3460,
  [3482] = 3462,
  [3483] = 3460,
  [3484] = 3462,
  [3485] = 3462,
  [3486] = 3460,
  [3487] = 3462,
  [3488] = 572,
  [3489] = 3460,
  [3490] = 3462,
  [3491] = 3491,
  [3492] = 3492,
  [3493] = 3493,
  [3494] = 3494,
  [3495] = 3495,
  [3496] = 3464,
  [3497] = 3497,
  [3498] = 3498,
  [3499] = 3499,
  [3500] = 3500,
  [3501] = 3467,
  [3502] = 3502,
  [3503] = 3503,
  [3504] = 3494,
  [3505] = 3464,
  [3506] = 3467,
  [3507] = 3507,
  [3508] = 3461,
  [3509] = 460,
  [3510] = 3510,
  [3511] = 3457,
  [3512] = 459,
  [3513] = 3513,
  [3514] = 3471,
  [3515] = 3463,
  [3516] = 1670,
  [3517] = 3517,
  [3518] = 3518,
  [3519] = 3465,
  [3520] = 1153,
  [3521] = 3466,
  [3522] = 3510,
  [3523] = 3457,
  [3524] = 3460,
  [3525] = 3513,
  [3526] = 3518,
  [3527] = 3471,
  [3528] = 3517,
  [3529] = 3518,
  [3530] = 3462,
  [3531] = 3510,
  [3532] = 3457,
  [3533] = 3510,
  [3534] = 3457,
  [3535] = 3517,
  [3536] = 3518,
  [3537] = 3469,
  [3538] = 3510,
  [3539] = 3457,
  [3540] = 3517,
  [3541] = 3518,
  [3542] = 3460,
  [3543] = 3510,
  [3544] = 3457,
  [3545] = 3462,
  [3546] = 3510,
  [3547] = 3457,
  [3548] = 3510,
  [3549] = 3457,
  [3550] = 3460,
  [3551] = 3517,
  [3552] = 3462,
  [3553] = 3510,
  [3554] = 3457,
  [3555] = 3510,
  [3556] = 3457,
  [3557] = 3510,
  [3558] = 3457,
  [3559] = 3510,
  [3560] = 3457,
  [3561] = 3460,
  [3562] = 3462,
  [3563] = 3510,
  [3564] = 3460,
  [3565] = 3510,
  [3566] = 3457,
  [3567] = 3510,
  [3568] = 3457,
  [3569] = 3510,
  [3570] = 3457,
  [3571] = 3510,
  [3572] = 3457,
  [3573] = 3510,
  [3574] = 3457,
  [3575] = 3510,
  [3576] = 3457,
  [3577] = 3510,
  [3578] = 3457,
  [3579] = 3500,
  [3580] = 3457,
  [3581] = 3510,
  [3582] = 3457,
  [3583] = 3510,
  [3584] = 3457,
  [3585] = 3510,
  [3586] = 3457,
  [3587] = 3510,
  [3588] = 3457,
  [3589] = 3510,
  [3590] = 3457,
  [3591] = 3510,
  [3592] = 3457,
  [3593] = 3510,
  [3594] = 3457,
  [3595] = 3493,
  [3596] = 3510,
  [3597] = 3457,
  [3598] = 3495,
  [3599] = 3497,
  [3600] = 3498,
  [3601] = 3510,
  [3602] = 3457,
  [3603] = 3500,
  [3604] = 3510,
  [3605] = 3457,
  [3606] = 3458,
  [3607] = 3510,
  [3608] = 3457,
  [3609] = 3459,
  [3610] = 3461,
  [3611] = 3510,
  [3612] = 3457,
  [3613] = 3463,
  [3614] = 3510,
  [3615] = 3457,
  [3616] = 3510,
  [3617] = 3457,
  [3618] = 3510,
  [3619] = 3457,
  [3620] = 3510,
  [3621] = 3457,
  [3622] = 3510,
  [3623] = 3457,
  [3624] = 3510,
  [3625] = 3457,
  [3626] = 3465,
  [3627] = 3466,
  [3628] = 3510,
  [3629] = 3457,
  [3630] = 3510,
  [3631] = 3457,
  [3632] = 3469,
  [3633] = 3475,
  [3634] = 3510,
  [3635] = 3457,
  [3636] = 3510,
  [3637] = 3457,
  [3638] = 3510,
  [3639] = 3457,
  [3640] = 460,
  [3641] = 3510,
  [3642] = 3457,
  [3643] = 459,
  [3644] = 3510,
  [3645] = 3457,
  [3646] = 3510,
  [3647] = 3457,
  [3648] = 3510,
  [3649] = 3457,
  [3650] = 3510,
  [3651] = 3457,
  [3652] = 3510,
  [3653] = 3457,
  [3654] = 3510,
  [3655] = 3457,
  [3656] = 3510,
  [3657] = 3457,
  [3658] = 3510,
  [3659] = 3457,
  [3660] = 3510,
  [3661] = 3457,
  [3662] = 1673,
  [3663] = 3510,
  [3664] = 3457,
  [3665] = 3510,
  [3666] = 3457,
  [3667] = 3458,
  [3668] = 3510,
  [3669] = 3457,
  [3670] = 3510,
  [3671] = 3457,
  [3672] = 3510,
  [3673] = 3457,
  [3674] = 3510,
  [3675] = 3457,
  [3676] = 3510,
  [3677] = 3457,
  [3678] = 3510,
  [3679] = 3457,
  [3680] = 3510,
  [3681] = 3457,
  [3682] = 3510,
  [3683] = 3457,
  [3684] = 3510,
  [3685] = 3457,
  [3686] = 3475,
  [3687] = 460,
  [3688] = 459,
  [3689] = 3689,
  [3690] = 3690,
  [3691] = 1468,
  [3692] = 1479,
  [3693] = 3493,
  [3694] = 3690,
  [3695] = 3495,
  [3696] = 1150,
  [3697] = 3513,
  [3698] = 3460,
  [3699] = 3497,
  [3700] = 3462,
  [3701] = 1655,
  [3702] = 3498,
  [3703] = 491,
  [3704] = 3459,
  [3705] = 3494,
  [3706] = 3690,
  [3707] = 460,
  [3708] = 459,
  [3709] = 3510,
  [3710] = 460,
  [3711] = 3711,
  [3712] = 3712,
  [3713] = 3713,
  [3714] = 3711,
  [3715] = 3715,
  [3716] = 3712,
  [3717] = 3711,
  [3718] = 3718,
  [3719] = 3711,
  [3720] = 3712,
  [3721] = 3711,
  [3722] = 3712,
  [3723] = 3712,
  [3724] = 3711,
  [3725] = 3712,
  [3726] = 3711,
  [3727] = 3712,
  [3728] = 3713,
  [3729] = 3715,
  [3730] = 3730,
  [3731] = 3711,
  [3732] = 3711,
  [3733] = 3712,
  [3734] = 3711,
  [3735] = 3715,
  [3736] = 3718,
  [3737] = 3711,
  [3738] = 3712,
  [3739] = 3712,
  [3740] = 3718,
  [3741] = 3711,
  [3742] = 3711,
  [3743] = 3713,
  [3744] = 3711,
  [3745] = 3712,
  [3746] = 459,
  [3747] = 3715,
  [3748] = 3711,
  [3749] = 3712,
  [3750] = 3715,
  [3751] = 3711,
  [3752] = 3711,
  [3753] = 3711,
  [3754] = 3712,
  [3755] = 3712,
  [3756] = 3711,
  [3757] = 3712,
  [3758] = 3712,
  [3759] = 3718,
  [3760] = 3730,
  [3761] = 3718,
  [3762] = 3712,
  [3763] = 3711,
  [3764] = 3712,
  [3765] = 3712,
  [3766] = 3712,
  [3767] = 3715,
  [3768] = 3718,
  [3769] = 3711,
  [3770] = 3712,
  [3771] = 3711,
  [3772] = 3713,
  [3773] = 3712,
  [3774] = 459,
  [3775] = 460,
  [3776] = 3730,
  [3777] = 460,
  [3778] = 3711,
  [3779] = 3711,
  [3780] = 3712,
  [3781] = 3711,
  [3782] = 460,
  [3783] = 3711,
  [3784] = 3712,
  [3785] = 459,
  [3786] = 3711,
  [3787] = 3712,
  [3788] = 3712,
  [3789] = 3713,
  [3790] = 3713,
  [3791] = 3730,
  [3792] = 3712,
  [3793] = 3711,
  [3794] = 3712,
  [3795] = 3713,
  [3796] = 459,
  [3797] = 3797,
  [3798] = 3798,
  [3799] = 3798,
  [3800] = 3800,
  [3801] = 3797,
  [3802] = 3798,
  [3803] = 3803,
  [3804] = 3797,
  [3805] = 3798,
  [3806] = 3803,
  [3807] = 3798,
  [3808] = 3803,
  [3809] = 3798,
  [3810] = 3803,
  [3811] = 3798,
  [3812] = 3803,
  [3813] = 3798,
  [3814] = 3798,
  [3815] = 3797,
  [3816] = 3798,
  [3817] = 3798,
  [3818] = 3803,
  [3819] = 3798,
  [3820] = 3803,
  [3821] = 3803,
  [3822] = 3798,
  [3823] = 3803,
  [3824] = 3798,
  [3825] = 3803,
  [3826] = 3798,
  [3827] = 3798,
  [3828] = 3798,
  [3829] = 3798,
  [3830] = 3798,
  [3831] = 3797,
  [3832] = 3798,
  [3833] = 3803,
  [3834] = 3797,
  [3835] = 3798,
  [3836] = 3797,
  [3837] = 3803,
  [3838] = 3797,
  [3839] = 3803,
  [3840] = 3797,
  [3841] = 3841,
  [3842] = 3797,
  [3843] = 3803,
  [3844] = 3844,
  [3845] = 3803,
  [3846] = 3797,
  [3847] = 3797,
  [3848] = 3803,
  [3849] = 3803,
  [3850] = 3797,
  [3851] = 3841,
  [3852] = 3803,
  [3853] = 3803,
  [3854] = 3803,
  [3855] = 3855,
  [3856] = 3797,
  [3857] = 3841,
  [3858] = 3844,
  [3859] = 3841,
  [3860] = 3844,
  [3861] = 3841,
  [3862] = 3797,
  [3863] = 3803,
  [3864] = 3844,
  [3865] = 3797,
  [3866] = 3803,
  [3867] = 3797,
  [3868] = 3798,
  [3869] = 3803,
  [3870] = 3803,
  [3871] = 3803,
  [3872] = 3841,
  [3873] = 3844,
  [3874] = 3841,
  [3875] = 3844,
  [3876] = 3841,
  [3877] = 3844,
  [3878] = 3797,
  [3879] = 3797,
  [3880] = 3797,
  [3881] = 3797,
  [3882] = 3797,
  [3883] = 3844,
  [3884] = 3797,
  [3885] = 3841,
  [3886] = 3844,
  [3887] = 3841,
  [3888] = 3844,
  [3889] = 3798,
  [3890] = 3797,
  [3891] = 3798,
  [3892] = 3797,
  [3893] = 3841,
  [3894] = 3844,
  [3895] = 3841,
  [3896] = 3844,
  [3897] = 3841,
  [3898] = 3803,
  [3899] = 3844,
  [3900] = 3803,
  [3901] = 3803,
  [3902] = 3798,
  [3903] = 3803,
  [3904] = 3904,
  [3905] = 3905,
  [3906] = 3798,
  [3907] = 3841,
  [3908] = 3844,
  [3909] = 3797,
  [3910] = 3803,
  [3911] = 3798,
  [3912] = 3803,
  [3913] = 3913,
  [3914] = 3797,
  [3915] = 3803,
  [3916] = 3797,
  [3917] = 3798,
  [3918] = 3803,
  [3919] = 3841,
  [3920] = 3797,
  [3921] = 3844,
  [3922] = 3803,
  [3923] = 3797,
  [3924] = 3797,
  [3925] = 3803,
  [3926] = 3803,
  [3927] = 3803,
  [3928] = 3798,
  [3929] = 3797,
  [3930] = 3841,
  [3931] = 3803,
  [3932] = 3797,
  [3933] = 3844,
  [3934] = 3797,
  [3935] = 3803,
  [3936] = 3797,
  [3937] = 3803,
  [3938] = 3798,
  [3939] = 3797,
  [3940] = 3841,
  [3941] = 3803,
  [3942] = 3844,
  [3943] = 3797,
  [3944] = 3797,
  [3945] = 3803,
  [3946] = 3797,
  [3947] = 3797,
  [3948] = 3798,
  [3949] = 3803,
  [3950] = 3803,
  [3951] = 3797,
  [3952] = 3803,
  [3953] = 3841,
  [3954] = 3954,
  [3955] = 3844,
  [3956] = 3797,
  [3957] = 3797,
  [3958] = 3798,
  [3959] = 3797,
  [3960] = 3798,
  [3961] = 3803,
  [3962] = 3841,
  [3963] = 3803,
  [3964] = 3844,
  [3965] = 3797,
  [3966] = 3797,
  [3967] = 3797,
  [3968] = 3841,
  [3969] = 3803,
  [3970] = 3797,
  [3971] = 3798,
  [3972] = 3844,
  [3973] = 3797,
  [3974] = 3803,
  [3975] = 3844,
  [3976] = 3797,
  [3977] = 3803,
  [3978] = 3803,
  [3979] = 3797,
  [3980] = 3798,
  [3981] = 3803,
  [3982] = 3841,
  [3983] = 3797,
  [3984] = 3844,
  [3985] = 3797,
  [3986] = 3797,
  [3987] = 3797,
  [3988] = 3803,
  [3989] = 3798,
  [3990] = 3803,
  [3991] = 3797,
  [3992] = 3841,
  [3993] = 3844,
  [3994] = 3803,
  [3995] = 3797,
  [3996] = 3798,
  [3997] = 3803,
  [3998] = 3841,
  [3999] = 3803,
  [4000] = 3797,
  [4001] = 3844,
  [4002] = 465,
  [4003] = 3797,
  [4004] = 3797,
  [4005] = 3798,
  [4006] = 3797,
  [4007] = 3803,
  [4008] = 3841,
  [4009] = 3844,
  [4010] = 3797,
  [4011] = 3798,
  [4012] = 3797,
  [4013] = 3841,
  [4014] = 4014,
  [4015] = 3844,
  [4016] = 3798,
  [4017] = 3803,
  [4018] = 3841,
  [4019] = 3797,
  [4020] = 3803,
  [4021] = 3797,
  [4022] = 3844,
  [4023] = 3798,
  [4024] = 3798,
  [4025] = 465,
  [4026] = 3841,
  [4027] = 3797,
  [4028] = 3844,
  [4029] = 3798,
  [4030] = 3797,
  [4031] = 3803,
  [4032] = 3841,
  [4033] = 3797,
  [4034] = 3844,
  [4035] = 3803,
  [4036] = 3797,
  [4037] = 3803,
  [4038] = 3798,
  [4039] = 3803,
  [4040] = 3803,
  [4041] = 3797,
  [4042] = 3803,
  [4043] = 3797,
  [4044] = 3798,
  [4045] = 3803,
  [4046] = 3803,
  [4047] = 3797,
  [4048] = 3798,
  [4049] = 3841,
  [4050] = 3797,
  [4051] = 3797,
  [4052] = 3798,
  [4053] = 3803,
  [4054] = 3803,
  [4055] = 3797,
  [4056] = 3798,
  [4057] = 3797,
  [4058] = 3803,
  [4059] = 3844,
  [4060] = 3803,
  [4061] = 3798,
  [4062] = 3797,
  [4063] = 3798,
  [4064] = 3803,
  [4065] = 3797,
  [4066] = 3803,
  [4067] = 3803,
  [4068] = 3913,
  [4069] = 3855,
  [4070] = 3798,
  [4071] = 3797,
  [4072] = 3803,
  [4073] = 3803,
  [4074] = 3803,
  [4075] = 3797,
  [4076] = 3803,
  [4077] = 3803,
  [4078] = 3797,
  [4079] = 3798,
  [4080] = 3797,
  [4081] = 3803,
  [4082] = 3797,
  [4083] = 3797,
  [4084] = 3798,
  [4085] = 3803,
  [4086] = 3803,
  [4087] = 3797,
  [4088] = 3797,
  [4089] = 3803,
  [4090] = 3841,
  [4091] = 3798,
  [4092] = 3844,
  [4093] = 3798,
  [4094] = 3841,
  [4095] = 3844,
  [4096] = 3798,
  [4097] = 3797,
  [4098] = 3913,
  [4099] = 3855,
  [4100] = 3797,
  [4101] = 3803,
  [4102] = 3803,
  [4103] = 3798,
  [4104] = 3797,
  [4105] = 3841,
  [4106] = 3803,
  [4107] = 3803,
  [4108] = 3797,
  [4109] = 3803,
  [4110] = 3798,
  [4111] = 3844,
  [4112] = 3797,
  [4113] = 3803,
  [4114] = 3803,
  [4115] = 3798,
  [4116] = 3797,
  [4117] = 3798,
  [4118] = 3797,
  [4119] = 3841,
  [4120] = 3798,
  [4121] = 3844,
  [4122] = 3803,
  [4123] = 3798,
  [4124] = 3841,
  [4125] = 3844,
  [4126] = 3913,
  [4127] = 3855,
  [4128] = 3803,
  [4129] = 3798,
  [4130] = 3803,
  [4131] = 3797,
  [4132] = 3841,
  [4133] = 1015,
  [4134] = 465,
  [4135] = 817,
  [4136] = 466,
  [4137] = 463,
  [4138] = 818,
  [4139] = 4139,
  [4140] = 3905,
  [4141] = 4141,
  [4142] = 463,
  [4143] = 464,
  [4144] = 465,
  [4145] = 464,
  [4146] = 3800,
  [4147] = 4147,
  [4148] = 1122,
  [4149] = 4149,
  [4150] = 4014,
  [4151] = 4151,
  [4152] = 4152,
  [4153] = 3904,
  [4154] = 4154,
  [4155] = 465,
  [4156] = 464,
  [4157] = 810,
  [4158] = 838,
  [4159] = 4159,
  [4160] = 460,
  [4161] = 4161,
  [4162] = 466,
  [4163] = 1121,
  [4164] = 459,
  [4165] = 1096,
  [4166] = 464,
  [4167] = 470,
  [4168] = 1096,
  [4169] = 465,
  [4170] = 484,
  [4171] = 471,
  [4172] = 3904,
  [4173] = 475,
  [4174] = 4159,
  [4175] = 1029,
  [4176] = 473,
  [4177] = 477,
  [4178] = 483,
  [4179] = 464,
  [4180] = 4180,
  [4181] = 488,
  [4182] = 4182,
  [4183] = 469,
  [4184] = 2495,
  [4185] = 465,
  [4186] = 4186,
  [4187] = 473,
  [4188] = 471,
  [4189] = 475,
  [4190] = 476,
  [4191] = 479,
  [4192] = 480,
  [4193] = 818,
  [4194] = 466,
  [4195] = 481,
  [4196] = 469,
  [4197] = 474,
  [4198] = 1337,
  [4199] = 478,
  [4200] = 486,
  [4201] = 480,
  [4202] = 3905,
  [4203] = 484,
  [4204] = 463,
  [4205] = 4139,
  [4206] = 481,
  [4207] = 482,
  [4208] = 483,
  [4209] = 484,
  [4210] = 4147,
  [4211] = 3904,
  [4212] = 466,
  [4213] = 1029,
  [4214] = 464,
  [4215] = 2487,
  [4216] = 472,
  [4217] = 4152,
  [4218] = 470,
  [4219] = 482,
  [4220] = 483,
  [4221] = 817,
  [4222] = 463,
  [4223] = 1411,
  [4224] = 480,
  [4225] = 4014,
  [4226] = 474,
  [4227] = 478,
  [4228] = 484,
  [4229] = 486,
  [4230] = 465,
  [4231] = 469,
  [4232] = 471,
  [4233] = 4233,
  [4234] = 1015,
  [4235] = 818,
  [4236] = 1457,
  [4237] = 1122,
  [4238] = 4238,
  [4239] = 466,
  [4240] = 470,
  [4241] = 477,
  [4242] = 476,
  [4243] = 475,
  [4244] = 464,
  [4245] = 1457,
  [4246] = 4141,
  [4247] = 4161,
  [4248] = 477,
  [4249] = 481,
  [4250] = 469,
  [4251] = 817,
  [4252] = 479,
  [4253] = 488,
  [4254] = 1096,
  [4255] = 487,
  [4256] = 810,
  [4257] = 478,
  [4258] = 838,
  [4259] = 479,
  [4260] = 1027,
  [4261] = 477,
  [4262] = 463,
  [4263] = 485,
  [4264] = 485,
  [4265] = 1337,
  [4266] = 471,
  [4267] = 470,
  [4268] = 1015,
  [4269] = 4269,
  [4270] = 478,
  [4271] = 486,
  [4272] = 3800,
  [4273] = 482,
  [4274] = 2520,
  [4275] = 2565,
  [4276] = 487,
  [4277] = 487,
  [4278] = 481,
  [4279] = 4014,
  [4280] = 485,
  [4281] = 1121,
  [4282] = 476,
  [4283] = 479,
  [4284] = 472,
  [4285] = 3904,
  [4286] = 4286,
  [4287] = 4014,
  [4288] = 4288,
  [4289] = 465,
  [4290] = 465,
  [4291] = 1027,
  [4292] = 464,
  [4293] = 4293,
  [4294] = 488,
  [4295] = 482,
  [4296] = 487,
  [4297] = 810,
  [4298] = 483,
  [4299] = 474,
  [4300] = 838,
  [4301] = 486,
  [4302] = 465,
  [4303] = 465,
  [4304] = 473,
  [4305] = 3800,
  [4306] = 485,
  [4307] = 3905,
  [4308] = 473,
  [4309] = 472,
  [4310] = 3905,
  [4311] = 4147,
  [4312] = 475,
  [4313] = 3800,
  [4314] = 480,
  [4315] = 4161,
  [4316] = 474,
  [4317] = 1411,
  [4318] = 488,
  [4319] = 472,
  [4320] = 476,
  [4321] = 4152,
  [4322] = 466,
  [4323] = 463,
  [4324] = 817,
  [4325] = 818,
  [4326] = 466,
  [4327] = 476,
  [4328] = 479,
  [4329] = 817,
  [4330] = 4186,
  [4331] = 463,
  [4332] = 485,
  [4333] = 4152,
  [4334] = 4139,
  [4335] = 4335,
  [4336] = 1337,
  [4337] = 4337,
  [4338] = 478,
  [4339] = 486,
  [4340] = 4161,
  [4341] = 4159,
  [4342] = 818,
  [4343] = 1096,
  [4344] = 466,
  [4345] = 463,
  [4346] = 488,
  [4347] = 1027,
  [4348] = 1457,
  [4349] = 470,
  [4350] = 1029,
  [4351] = 478,
  [4352] = 486,
  [4353] = 1027,
  [4354] = 464,
  [4355] = 470,
  [4356] = 1029,
  [4357] = 487,
  [4358] = 4182,
  [4359] = 485,
  [4360] = 478,
  [4361] = 4180,
  [4362] = 486,
  [4363] = 4152,
  [4364] = 472,
  [4365] = 4141,
  [4366] = 475,
  [4367] = 474,
  [4368] = 1337,
  [4369] = 465,
  [4370] = 466,
  [4371] = 1029,
  [4372] = 487,
  [4373] = 1121,
  [4374] = 463,
  [4375] = 1122,
  [4376] = 488,
  [4377] = 485,
  [4378] = 465,
  [4379] = 4335,
  [4380] = 470,
  [4381] = 473,
  [4382] = 838,
  [4383] = 480,
  [4384] = 477,
  [4385] = 472,
  [4386] = 469,
  [4387] = 4238,
  [4388] = 4269,
  [4389] = 481,
  [4390] = 4233,
  [4391] = 475,
  [4392] = 475,
  [4393] = 477,
  [4394] = 473,
  [4395] = 477,
  [4396] = 491,
  [4397] = 470,
  [4398] = 469,
  [4399] = 475,
  [4400] = 1457,
  [4401] = 487,
  [4402] = 471,
  [4403] = 474,
  [4404] = 4147,
  [4405] = 1457,
  [4406] = 476,
  [4407] = 1411,
  [4408] = 479,
  [4409] = 4141,
  [4410] = 471,
  [4411] = 480,
  [4412] = 4293,
  [4413] = 485,
  [4414] = 1015,
  [4415] = 481,
  [4416] = 472,
  [4417] = 476,
  [4418] = 479,
  [4419] = 1337,
  [4420] = 488,
  [4421] = 465,
  [4422] = 1122,
  [4423] = 472,
  [4424] = 482,
  [4425] = 483,
  [4426] = 484,
  [4427] = 474,
  [4428] = 474,
  [4429] = 1027,
  [4430] = 465,
  [4431] = 466,
  [4432] = 463,
  [4433] = 478,
  [4434] = 476,
  [4435] = 479,
  [4436] = 4159,
  [4437] = 3800,
  [4438] = 4139,
  [4439] = 3904,
  [4440] = 4147,
  [4441] = 1015,
  [4442] = 488,
  [4443] = 473,
  [4444] = 480,
  [4445] = 469,
  [4446] = 481,
  [4447] = 471,
  [4448] = 473,
  [4449] = 480,
  [4450] = 469,
  [4451] = 481,
  [4452] = 4286,
  [4453] = 4147,
  [4454] = 1015,
  [4455] = 4161,
  [4456] = 1096,
  [4457] = 471,
  [4458] = 810,
  [4459] = 838,
  [4460] = 817,
  [4461] = 818,
  [4462] = 482,
  [4463] = 483,
  [4464] = 484,
  [4465] = 491,
  [4466] = 486,
  [4467] = 482,
  [4468] = 483,
  [4469] = 484,
  [4470] = 482,
  [4471] = 483,
  [4472] = 484,
  [4473] = 2587,
  [4474] = 2588,
  [4475] = 4161,
  [4476] = 1096,
  [4477] = 466,
  [4478] = 4288,
  [4479] = 463,
  [4480] = 2595,
  [4481] = 2596,
  [4482] = 465,
  [4483] = 487,
  [4484] = 477,
  [4485] = 4335,
  [4486] = 491,
  [4487] = 810,
  [4488] = 466,
  [4489] = 838,
  [4490] = 463,
  [4491] = 810,
  [4492] = 4159,
  [4493] = 4139,
  [4494] = 4147,
  [4495] = 1015,
  [4496] = 4161,
  [4497] = 1096,
  [4498] = 810,
  [4499] = 838,
  [4500] = 817,
  [4501] = 818,
  [4502] = 1121,
  [4503] = 1122,
  [4504] = 4141,
  [4505] = 491,
  [4506] = 1121,
  [4507] = 4147,
  [4508] = 4508,
  [4509] = 4509,
  [4510] = 478,
  [4511] = 486,
  [4512] = 474,
  [4513] = 491,
  [4514] = 4514,
  [4515] = 1468,
  [4516] = 4180,
  [4517] = 463,
  [4518] = 1153,
  [4519] = 4519,
  [4520] = 4520,
  [4521] = 466,
  [4522] = 4522,
  [4523] = 463,
  [4524] = 4524,
  [4525] = 4525,
  [4526] = 4233,
  [4527] = 463,
  [4528] = 4528,
  [4529] = 4152,
  [4530] = 810,
  [4531] = 4141,
  [4532] = 1468,
  [4533] = 4269,
  [4534] = 4186,
  [4535] = 838,
  [4536] = 4536,
  [4537] = 4288,
  [4538] = 473,
  [4539] = 480,
  [4540] = 469,
  [4541] = 4528,
  [4542] = 481,
  [4543] = 4524,
  [4544] = 4544,
  [4545] = 471,
  [4546] = 4546,
  [4547] = 491,
  [4548] = 4548,
  [4549] = 1479,
  [4550] = 4186,
  [4551] = 4286,
  [4552] = 4544,
  [4553] = 4269,
  [4554] = 4288,
  [4555] = 4293,
  [4556] = 4186,
  [4557] = 1150,
  [4558] = 482,
  [4559] = 483,
  [4560] = 484,
  [4561] = 4288,
  [4562] = 4525,
  [4563] = 4563,
  [4564] = 4564,
  [4565] = 476,
  [4566] = 479,
  [4567] = 4147,
  [4568] = 1015,
  [4569] = 810,
  [4570] = 838,
  [4571] = 4161,
  [4572] = 1096,
  [4573] = 817,
  [4574] = 818,
  [4575] = 4522,
  [4576] = 4576,
  [4577] = 466,
  [4578] = 472,
  [4579] = 1150,
  [4580] = 1479,
  [4581] = 4581,
  [4582] = 463,
  [4583] = 487,
  [4584] = 4180,
  [4585] = 4585,
  [4586] = 4586,
  [4587] = 4238,
  [4588] = 4286,
  [4589] = 4180,
  [4590] = 4238,
  [4591] = 464,
  [4592] = 4293,
  [4593] = 4593,
  [4594] = 4233,
  [4595] = 470,
  [4596] = 488,
  [4597] = 4233,
  [4598] = 1029,
  [4599] = 4286,
  [4600] = 4600,
  [4601] = 4269,
  [4602] = 1121,
  [4603] = 1122,
  [4604] = 1655,
  [4605] = 4159,
  [4606] = 4139,
  [4607] = 1337,
  [4608] = 1673,
  [4609] = 1670,
  [4610] = 1020,
  [4611] = 4611,
  [4612] = 4182,
  [4613] = 4564,
  [4614] = 1021,
  [4615] = 491,
  [4616] = 1153,
  [4617] = 4293,
  [4618] = 465,
  [4619] = 466,
  [4620] = 463,
  [4621] = 1673,
  [4622] = 4593,
  [4623] = 4623,
  [4624] = 4147,
  [4625] = 1015,
  [4626] = 4161,
  [4627] = 1096,
  [4628] = 4576,
  [4629] = 810,
  [4630] = 838,
  [4631] = 817,
  [4632] = 818,
  [4633] = 4161,
  [4634] = 4585,
  [4635] = 1096,
  [4636] = 4147,
  [4637] = 1015,
  [4638] = 4514,
  [4639] = 4509,
  [4640] = 1027,
  [4641] = 817,
  [4642] = 475,
  [4643] = 1670,
  [4644] = 4644,
  [4645] = 4182,
  [4646] = 818,
  [4647] = 477,
  [4648] = 4536,
  [4649] = 463,
  [4650] = 1015,
  [4651] = 810,
  [4652] = 838,
  [4653] = 4161,
  [4654] = 1096,
  [4655] = 817,
  [4656] = 818,
  [4657] = 4586,
  [4658] = 4658,
  [4659] = 485,
  [4660] = 4660,
  [4661] = 465,
  [4662] = 1457,
  [4663] = 4519,
  [4664] = 491,
  [4665] = 4658,
  [4666] = 4238,
  [4667] = 466,
  [4668] = 1655,
  [4669] = 4182,
  [4670] = 466,
  [4671] = 4671,
  [4672] = 466,
  [4673] = 4673,
  [4674] = 4674,
  [4675] = 4675,
  [4676] = 4676,
  [4677] = 472,
  [4678] = 4678,
  [4679] = 4676,
  [4680] = 4680,
  [4681] = 4681,
  [4682] = 4522,
  [4683] = 4683,
  [4684] = 4676,
  [4685] = 4685,
  [4686] = 4676,
  [4687] = 4687,
  [4688] = 474,
  [4689] = 4676,
  [4690] = 4522,
  [4691] = 4676,
  [4692] = 4676,
  [4693] = 4693,
  [4694] = 491,
  [4695] = 4676,
  [4696] = 1670,
  [4697] = 4676,
  [4698] = 4675,
  [4699] = 4676,
  [4700] = 1655,
  [4701] = 4676,
  [4702] = 4702,
  [4703] = 4676,
  [4704] = 4704,
  [4705] = 4705,
  [4706] = 4676,
  [4707] = 4524,
  [4708] = 4708,
  [4709] = 4709,
  [4710] = 4548,
  [4711] = 4676,
  [4712] = 4676,
  [4713] = 4713,
  [4714] = 1150,
  [4715] = 4715,
  [4716] = 4546,
  [4717] = 4509,
  [4718] = 1468,
  [4719] = 4564,
  [4720] = 4720,
  [4721] = 4676,
  [4722] = 4676,
  [4723] = 4702,
  [4724] = 4724,
  [4725] = 4725,
  [4726] = 4726,
  [4727] = 4676,
  [4728] = 4528,
  [4729] = 4676,
  [4730] = 4705,
  [4731] = 4182,
  [4732] = 4732,
  [4733] = 4186,
  [4734] = 4536,
  [4735] = 1670,
  [4736] = 4238,
  [4737] = 4737,
  [4738] = 4676,
  [4739] = 4233,
  [4740] = 475,
  [4741] = 4269,
  [4742] = 4286,
  [4743] = 4522,
  [4744] = 4288,
  [4745] = 473,
  [4746] = 4746,
  [4747] = 477,
  [4748] = 4658,
  [4749] = 4704,
  [4750] = 4750,
  [4751] = 4676,
  [4752] = 4536,
  [4753] = 469,
  [4754] = 4676,
  [4755] = 4676,
  [4756] = 4756,
  [4757] = 4676,
  [4758] = 4758,
  [4759] = 471,
  [4760] = 4676,
  [4761] = 1153,
  [4762] = 4762,
  [4763] = 4658,
  [4764] = 476,
  [4765] = 479,
  [4766] = 4766,
  [4767] = 4528,
  [4768] = 480,
  [4769] = 4576,
  [4770] = 4658,
  [4771] = 4685,
  [4772] = 4683,
  [4773] = 4709,
  [4774] = 4774,
  [4775] = 481,
  [4776] = 4514,
  [4777] = 4777,
  [4778] = 4778,
  [4779] = 4676,
  [4780] = 4780,
  [4781] = 4676,
  [4782] = 4766,
  [4783] = 4778,
  [4784] = 4708,
  [4785] = 4678,
  [4786] = 4777,
  [4787] = 4676,
  [4788] = 4762,
  [4789] = 4724,
  [4790] = 4676,
  [4791] = 4675,
  [4792] = 4792,
  [4793] = 4676,
  [4794] = 4756,
  [4795] = 4795,
  [4796] = 4676,
  [4797] = 4797,
  [4798] = 4798,
  [4799] = 4676,
  [4800] = 4800,
  [4801] = 4801,
  [4802] = 4528,
  [4803] = 4676,
  [4804] = 4676,
  [4805] = 4726,
  [4806] = 4758,
  [4807] = 4676,
  [4808] = 4525,
  [4809] = 4676,
  [4810] = 4676,
  [4811] = 4611,
  [4812] = 4593,
  [4813] = 4576,
  [4814] = 4676,
  [4815] = 4815,
  [4816] = 4676,
  [4817] = 4817,
  [4818] = 4818,
  [4819] = 4792,
  [4820] = 4820,
  [4821] = 4581,
  [4822] = 4676,
  [4823] = 482,
  [4824] = 483,
  [4825] = 484,
  [4826] = 4676,
  [4827] = 4713,
  [4828] = 4725,
  [4829] = 4795,
  [4830] = 4676,
  [4831] = 4818,
  [4832] = 4676,
  [4833] = 4519,
  [4834] = 4676,
  [4835] = 1479,
  [4836] = 4676,
  [4837] = 4837,
  [4838] = 4514,
  [4839] = 4585,
  [4840] = 4774,
  [4841] = 4536,
  [4842] = 4837,
  [4843] = 4732,
  [4844] = 4756,
  [4845] = 4676,
  [4846] = 4544,
  [4847] = 4676,
  [4848] = 1150,
  [4849] = 4780,
  [4850] = 4676,
  [4851] = 4758,
  [4852] = 4852,
  [4853] = 4585,
  [4854] = 4676,
  [4855] = 4676,
  [4856] = 4856,
  [4857] = 4676,
  [4858] = 4858,
  [4859] = 4750,
  [4860] = 1479,
  [4861] = 4746,
  [4862] = 4680,
  [4863] = 4676,
  [4864] = 4676,
  [4865] = 4676,
  [4866] = 466,
  [4867] = 463,
  [4868] = 4676,
  [4869] = 4514,
  [4870] = 4676,
  [4871] = 4585,
  [4872] = 4676,
  [4873] = 4509,
  [4874] = 470,
  [4875] = 4147,
  [4876] = 1015,
  [4877] = 810,
  [4878] = 838,
  [4879] = 4161,
  [4880] = 1096,
  [4881] = 817,
  [4882] = 818,
  [4883] = 4676,
  [4884] = 4676,
  [4885] = 4858,
  [4886] = 1670,
  [4887] = 4593,
  [4888] = 4800,
  [4889] = 4676,
  [4890] = 4676,
  [4891] = 4509,
  [4892] = 4676,
  [4893] = 4687,
  [4894] = 4798,
  [4895] = 4676,
  [4896] = 478,
  [4897] = 4586,
  [4898] = 486,
  [4899] = 4798,
  [4900] = 4676,
  [4901] = 1150,
  [4902] = 4852,
  [4903] = 4676,
  [4904] = 4676,
  [4905] = 4676,
  [4906] = 4906,
  [4907] = 4907,
  [4908] = 4817,
  [4909] = 4676,
  [4910] = 1479,
  [4911] = 4676,
  [4912] = 4681,
  [4913] = 4676,
  [4914] = 4576,
  [4915] = 1153,
  [4916] = 4916,
  [4917] = 487,
  [4918] = 4593,
  [4919] = 4674,
  [4920] = 4856,
  [4921] = 1673,
  [4922] = 4801,
  [4923] = 485,
  [4924] = 4676,
  [4925] = 4676,
  [4926] = 4676,
  [4927] = 4906,
  [4928] = 4797,
  [4929] = 4676,
  [4930] = 4720,
  [4931] = 4676,
  [4932] = 4820,
  [4933] = 4907,
  [4934] = 4737,
  [4935] = 1153,
  [4936] = 4693,
  [4937] = 4815,
  [4938] = 4715,
  [4939] = 4676,
  [4940] = 4676,
  [4941] = 4780,
  [4942] = 4680,
  [4943] = 488,
  [4944] = 4693,
  [4945] = 4581,
  [4946] = 4522,
  [4947] = 4947,
  [4948] = 4715,
  [4949] = 4514,
  [4950] = 4815,
  [4951] = 4856,
  [4952] = 4611,
  [4953] = 4726,
  [4954] = 4792,
  [4955] = 4705,
  [4956] = 4683,
  [4957] = 4546,
  [4958] = 4658,
  [4959] = 4708,
  [4960] = 4702,
  [4961] = 4906,
  [4962] = 4746,
  [4963] = 4720,
  [4964] = 4907,
  [4965] = 4581,
  [4966] = 4737,
  [4967] = 4762,
  [4968] = 4795,
  [4969] = 4778,
  [4970] = 1150,
  [4971] = 4611,
  [4972] = 4774,
  [4973] = 4858,
  [4974] = 4548,
  [4975] = 4678,
  [4976] = 4528,
  [4977] = 4732,
  [4978] = 4797,
  [4979] = 1479,
  [4980] = 4546,
  [4981] = 4852,
  [4982] = 1320,
  [4983] = 4777,
  [4984] = 4750,
  [4985] = 4800,
  [4986] = 4801,
  [4987] = 4817,
  [4988] = 465,
  [4989] = 4576,
  [4990] = 4674,
  [4991] = 4709,
  [4992] = 4581,
  [4993] = 4724,
  [4994] = 4820,
  [4995] = 4685,
  [4996] = 4687,
  [4997] = 4704,
  [4998] = 4713,
  [4999] = 4999,
  [5000] = 465,
  [5001] = 4536,
  [5002] = 4725,
  [5003] = 1153,
  [5004] = 1670,
  [5005] = 4593,
  [5006] = 4546,
  [5007] = 465,
  [5008] = 4611,
  [5009] = 4548,
  [5010] = 4509,
  [5011] = 4585,
  [5012] = 4548,
  [5013] = 4681,
  [5014] = 3800,
  [5015] = 4818,
  [5016] = 4837,
  [5017] = 3904,
  [5018] = 4766,
  [5019] = 465,
  [5020] = 1020,
  [5021] = 1021,
  [5022] = 5022,
  [5023] = 5023,
  [5024] = 5024,
  [5025] = 5025,
  [5026] = 5026,
  [5027] = 5027,
  [5028] = 5028,
  [5029] = 5029,
  [5030] = 5030,
  [5031] = 5031,
  [5032] = 5032,
  [5033] = 5033,
  [5034] = 4147,
  [5035] = 1015,
  [5036] = 4161,
  [5037] = 1096,
  [5038] = 4152,
  [5039] = 466,
  [5040] = 463,
  [5041] = 464,
  [5042] = 5042,
  [5043] = 5043,
  [5044] = 810,
  [5045] = 838,
  [5046] = 465,
  [5047] = 817,
  [5048] = 818,
  [5049] = 4141,
  [5050] = 491,
  [5051] = 5051,
  [5052] = 5052,
  [5053] = 466,
  [5054] = 463,
  [5055] = 465,
  [5056] = 5022,
  [5057] = 4152,
  [5058] = 4141,
  [5059] = 5023,
  [5060] = 5024,
  [5061] = 3800,
  [5062] = 5025,
  [5063] = 5026,
  [5064] = 5027,
  [5065] = 5028,
  [5066] = 5029,
  [5067] = 818,
  [5068] = 466,
  [5069] = 463,
  [5070] = 5022,
  [5071] = 5023,
  [5072] = 464,
  [5073] = 5024,
  [5074] = 5025,
  [5075] = 5026,
  [5076] = 1121,
  [5077] = 1122,
  [5078] = 466,
  [5079] = 463,
  [5080] = 5027,
  [5081] = 5028,
  [5082] = 5029,
  [5083] = 5030,
  [5084] = 5031,
  [5085] = 5032,
  [5086] = 5033,
  [5087] = 5030,
  [5088] = 5031,
  [5089] = 5032,
  [5090] = 5033,
  [5091] = 5091,
  [5092] = 5052,
  [5093] = 465,
  [5094] = 3904,
  [5095] = 5091,
  [5096] = 5091,
  [5097] = 5052,
  [5098] = 4581,
  [5099] = 4546,
  [5100] = 465,
  [5101] = 3904,
  [5102] = 5102,
  [5103] = 466,
  [5104] = 463,
  [5105] = 4159,
  [5106] = 4139,
  [5107] = 4147,
  [5108] = 1015,
  [5109] = 4161,
  [5110] = 1096,
  [5111] = 810,
  [5112] = 838,
  [5113] = 817,
  [5114] = 465,
  [5115] = 5115,
  [5116] = 5116,
  [5117] = 810,
  [5118] = 838,
  [5119] = 5119,
  [5120] = 5120,
  [5121] = 817,
  [5122] = 818,
  [5123] = 1121,
  [5124] = 1122,
  [5125] = 470,
  [5126] = 478,
  [5127] = 486,
  [5128] = 5128,
  [5129] = 487,
  [5130] = 485,
  [5131] = 4182,
  [5132] = 472,
  [5133] = 474,
  [5134] = 1027,
  [5135] = 4159,
  [5136] = 5136,
  [5137] = 1029,
  [5138] = 4147,
  [5139] = 1015,
  [5140] = 4147,
  [5141] = 1015,
  [5142] = 475,
  [5143] = 473,
  [5144] = 477,
  [5145] = 469,
  [5146] = 471,
  [5147] = 4161,
  [5148] = 1096,
  [5149] = 476,
  [5150] = 479,
  [5151] = 5151,
  [5152] = 480,
  [5153] = 481,
  [5154] = 482,
  [5155] = 483,
  [5156] = 484,
  [5157] = 5157,
  [5158] = 466,
  [5159] = 463,
  [5160] = 5160,
  [5161] = 464,
  [5162] = 5162,
  [5163] = 4182,
  [5164] = 4186,
  [5165] = 4238,
  [5166] = 4233,
  [5167] = 4269,
  [5168] = 4286,
  [5169] = 4288,
  [5170] = 5170,
  [5171] = 4269,
  [5172] = 4161,
  [5173] = 4139,
  [5174] = 1096,
  [5175] = 5175,
  [5176] = 470,
  [5177] = 5177,
  [5178] = 478,
  [5179] = 486,
  [5180] = 487,
  [5181] = 466,
  [5182] = 463,
  [5183] = 485,
  [5184] = 5184,
  [5185] = 5185,
  [5186] = 5186,
  [5187] = 1337,
  [5188] = 474,
  [5189] = 5189,
  [5190] = 466,
  [5191] = 5175,
  [5192] = 463,
  [5193] = 488,
  [5194] = 464,
  [5195] = 5195,
  [5196] = 810,
  [5197] = 838,
  [5198] = 5198,
  [5199] = 5175,
  [5200] = 817,
  [5201] = 475,
  [5202] = 818,
  [5203] = 473,
  [5204] = 477,
  [5205] = 5205,
  [5206] = 469,
  [5207] = 471,
  [5208] = 476,
  [5209] = 479,
  [5210] = 480,
  [5211] = 481,
  [5212] = 5175,
  [5213] = 5213,
  [5214] = 482,
  [5215] = 483,
  [5216] = 484,
  [5217] = 465,
  [5218] = 466,
  [5219] = 463,
  [5220] = 464,
  [5221] = 5175,
  [5222] = 4152,
  [5223] = 5223,
  [5224] = 5175,
  [5225] = 1457,
  [5226] = 5226,
  [5227] = 5227,
  [5228] = 5175,
  [5229] = 5229,
  [5230] = 5230,
  [5231] = 5231,
  [5232] = 5232,
  [5233] = 5233,
  [5234] = 5175,
  [5235] = 4141,
  [5236] = 4147,
  [5237] = 1015,
  [5238] = 810,
  [5239] = 838,
  [5240] = 4161,
  [5241] = 1096,
  [5242] = 817,
  [5243] = 818,
  [5244] = 5244,
  [5245] = 472,
  [5246] = 483,
  [5247] = 488,
  [5248] = 5248,
  [5249] = 481,
  [5250] = 5250,
  [5251] = 5251,
  [5252] = 810,
  [5253] = 838,
  [5254] = 5254,
  [5255] = 5255,
  [5256] = 471,
  [5257] = 5257,
  [5258] = 5258,
  [5259] = 5259,
  [5260] = 477,
  [5261] = 1457,
  [5262] = 5262,
  [5263] = 1027,
  [5264] = 5264,
  [5265] = 5265,
  [5266] = 1457,
  [5267] = 5267,
  [5268] = 5268,
  [5269] = 5269,
  [5270] = 817,
  [5271] = 818,
  [5272] = 5272,
  [5273] = 5273,
  [5274] = 5274,
  [5275] = 470,
  [5276] = 1029,
  [5277] = 5277,
  [5278] = 491,
  [5279] = 1337,
  [5280] = 478,
  [5281] = 486,
  [5282] = 5282,
  [5283] = 5283,
  [5284] = 487,
  [5285] = 485,
  [5286] = 475,
  [5287] = 1411,
  [5288] = 5288,
  [5289] = 473,
  [5290] = 477,
  [5291] = 469,
  [5292] = 4286,
  [5293] = 5293,
  [5294] = 471,
  [5295] = 482,
  [5296] = 5296,
  [5297] = 476,
  [5298] = 479,
  [5299] = 1027,
  [5300] = 5300,
  [5301] = 5301,
  [5302] = 480,
  [5303] = 488,
  [5304] = 483,
  [5305] = 472,
  [5306] = 5306,
  [5307] = 481,
  [5308] = 474,
  [5309] = 484,
  [5310] = 4186,
  [5311] = 5311,
  [5312] = 1029,
  [5313] = 5313,
  [5314] = 5314,
  [5315] = 5315,
  [5316] = 5316,
  [5317] = 5317,
  [5318] = 482,
  [5319] = 483,
  [5320] = 484,
  [5321] = 470,
  [5322] = 5322,
  [5323] = 5323,
  [5324] = 5324,
  [5325] = 4288,
  [5326] = 5326,
  [5327] = 478,
  [5328] = 486,
  [5329] = 466,
  [5330] = 469,
  [5331] = 463,
  [5332] = 464,
  [5333] = 5333,
  [5334] = 475,
  [5335] = 5335,
  [5336] = 5336,
  [5337] = 475,
  [5338] = 5338,
  [5339] = 5339,
  [5340] = 477,
  [5341] = 478,
  [5342] = 486,
  [5343] = 487,
  [5344] = 5344,
  [5345] = 476,
  [5346] = 479,
  [5347] = 470,
  [5348] = 4147,
  [5349] = 487,
  [5350] = 1015,
  [5351] = 485,
  [5352] = 472,
  [5353] = 5353,
  [5354] = 5354,
  [5355] = 474,
  [5356] = 5356,
  [5357] = 473,
  [5358] = 480,
  [5359] = 488,
  [5360] = 485,
  [5361] = 5361,
  [5362] = 5362,
  [5363] = 5363,
  [5364] = 5364,
  [5365] = 469,
  [5366] = 5366,
  [5367] = 481,
  [5368] = 5368,
  [5369] = 5369,
  [5370] = 471,
  [5371] = 4238,
  [5372] = 5372,
  [5373] = 4233,
  [5374] = 5374,
  [5375] = 473,
  [5376] = 5376,
  [5377] = 476,
  [5378] = 5378,
  [5379] = 5379,
  [5380] = 5380,
  [5381] = 4182,
  [5382] = 482,
  [5383] = 5383,
  [5384] = 484,
  [5385] = 5385,
  [5386] = 479,
  [5387] = 5387,
  [5388] = 1320,
  [5389] = 5389,
  [5390] = 488,
  [5391] = 472,
  [5392] = 480,
  [5393] = 474,
  [5394] = 1337,
  [5395] = 4161,
  [5396] = 4269,
  [5397] = 1096,
  [5398] = 5398,
  [5399] = 5399,
  [5400] = 5400,
  [5401] = 5401,
  [5402] = 5402,
  [5403] = 5403,
  [5404] = 483,
  [5405] = 1457,
  [5406] = 476,
  [5407] = 1150,
  [5408] = 1670,
  [5409] = 491,
  [5410] = 5410,
  [5411] = 491,
  [5412] = 5412,
  [5413] = 1337,
  [5414] = 465,
  [5415] = 1153,
  [5416] = 5416,
  [5417] = 5417,
  [5418] = 5410,
  [5419] = 478,
  [5420] = 486,
  [5421] = 5417,
  [5422] = 470,
  [5423] = 487,
  [5424] = 471,
  [5425] = 485,
  [5426] = 5410,
  [5427] = 491,
  [5428] = 481,
  [5429] = 472,
  [5430] = 474,
  [5431] = 488,
  [5432] = 5432,
  [5433] = 1479,
  [5434] = 1027,
  [5435] = 5417,
  [5436] = 5410,
  [5437] = 479,
  [5438] = 491,
  [5439] = 484,
  [5440] = 473,
  [5441] = 4581,
  [5442] = 482,
  [5443] = 4546,
  [5444] = 1029,
  [5445] = 5417,
  [5446] = 5410,
  [5447] = 5447,
  [5448] = 475,
  [5449] = 480,
  [5450] = 477,
  [5451] = 5417,
  [5452] = 5452,
  [5453] = 469,
  [5454] = 5454,
  [5455] = 4713,
  [5456] = 4544,
  [5457] = 4141,
  [5458] = 5458,
  [5459] = 4746,
  [5460] = 4815,
  [5461] = 1479,
  [5462] = 463,
  [5463] = 4586,
  [5464] = 1670,
  [5465] = 4674,
  [5466] = 4906,
  [5467] = 4907,
  [5468] = 4681,
  [5469] = 4693,
  [5470] = 4715,
  [5471] = 4705,
  [5472] = 4708,
  [5473] = 4762,
  [5474] = 4519,
  [5475] = 4732,
  [5476] = 4780,
  [5477] = 4800,
  [5478] = 4801,
  [5479] = 4820,
  [5480] = 4725,
  [5481] = 4818,
  [5482] = 1479,
  [5483] = 464,
  [5484] = 4514,
  [5485] = 4585,
  [5486] = 4147,
  [5487] = 4852,
  [5488] = 4680,
  [5489] = 1015,
  [5490] = 5490,
  [5491] = 5458,
  [5492] = 491,
  [5493] = 4536,
  [5494] = 460,
  [5495] = 1468,
  [5496] = 4161,
  [5497] = 4593,
  [5498] = 1096,
  [5499] = 459,
  [5500] = 5458,
  [5501] = 5458,
  [5502] = 1150,
  [5503] = 817,
  [5504] = 1153,
  [5505] = 1153,
  [5506] = 1670,
  [5507] = 1655,
  [5508] = 4658,
  [5509] = 4525,
  [5510] = 5458,
  [5511] = 4528,
  [5512] = 5458,
  [5513] = 818,
  [5514] = 4576,
  [5515] = 4564,
  [5516] = 4581,
  [5517] = 5458,
  [5518] = 4546,
  [5519] = 5458,
  [5520] = 5458,
  [5521] = 1150,
  [5522] = 1673,
  [5523] = 4524,
  [5524] = 810,
  [5525] = 838,
  [5526] = 4522,
  [5527] = 466,
  [5528] = 4509,
  [5529] = 472,
  [5530] = 4797,
  [5531] = 483,
  [5532] = 484,
  [5533] = 4528,
  [5534] = 474,
  [5535] = 4685,
  [5536] = 4720,
  [5537] = 4687,
  [5538] = 4522,
  [5539] = 4750,
  [5540] = 4514,
  [5541] = 481,
  [5542] = 4704,
  [5543] = 1150,
  [5544] = 4737,
  [5545] = 475,
  [5546] = 477,
  [5547] = 4708,
  [5548] = 4778,
  [5549] = 4795,
  [5550] = 4680,
  [5551] = 4762,
  [5552] = 488,
  [5553] = 4705,
  [5554] = 4780,
  [5555] = 470,
  [5556] = 478,
  [5557] = 473,
  [5558] = 1337,
  [5559] = 486,
  [5560] = 4536,
  [5561] = 480,
  [5562] = 4746,
  [5563] = 4658,
  [5564] = 4820,
  [5565] = 4674,
  [5566] = 4801,
  [5567] = 4726,
  [5568] = 4774,
  [5569] = 4792,
  [5570] = 4702,
  [5571] = 469,
  [5572] = 476,
  [5573] = 4732,
  [5574] = 4906,
  [5575] = 4856,
  [5576] = 4585,
  [5577] = 4800,
  [5578] = 4907,
  [5579] = 4593,
  [5580] = 4683,
  [5581] = 1153,
  [5582] = 4713,
  [5583] = 4815,
  [5584] = 4724,
  [5585] = 4858,
  [5586] = 4681,
  [5587] = 4509,
  [5588] = 4693,
  [5589] = 1670,
  [5590] = 4678,
  [5591] = 4709,
  [5592] = 4725,
  [5593] = 4837,
  [5594] = 1479,
  [5595] = 1457,
  [5596] = 1027,
  [5597] = 4766,
  [5598] = 487,
  [5599] = 4777,
  [5600] = 1029,
  [5601] = 4817,
  [5602] = 4818,
  [5603] = 485,
  [5604] = 4852,
  [5605] = 4715,
  [5606] = 471,
  [5607] = 482,
  [5608] = 4576,
  [5609] = 479,
  [5610] = 491,
  [5611] = 1153,
  [5612] = 1479,
  [5613] = 1670,
  [5614] = 1150,
  [5615] = 459,
  [5616] = 5616,
  [5617] = 460,
  [5618] = 5618,
  [5619] = 5619,
  [5620] = 5619,
  [5621] = 5621,
  [5622] = 5619,
  [5623] = 5621,
  [5624] = 5621,
  [5625] = 5621,
  [5626] = 5619,
  [5627] = 5621,
  [5628] = 5619,
  [5629] = 5621,
  [5630] = 5619,
  [5631] = 5621,
  [5632] = 5619,
  [5633] = 5621,
  [5634] = 5619,
  [5635] = 5621,
  [5636] = 5621,
  [5637] = 5619,
  [5638] = 5621,
  [5639] = 5619,
  [5640] = 5621,
  [5641] = 5619,
  [5642] = 5619,
  [5643] = 5621,
  [5644] = 5619,
  [5645] = 5621,
  [5646] = 5619,
  [5647] = 5621,
  [5648] = 5621,
  [5649] = 5619,
  [5650] = 5621,
  [5651] = 5619,
  [5652] = 5621,
  [5653] = 5619,
  [5654] = 5619,
  [5655] = 5619,
  [5656] = 5621,
  [5657] = 5619,
  [5658] = 5621,
  [5659] = 5621,
  [5660] = 5619,
  [5661] = 5619,
  [5662] = 5621,
  [5663] = 5621,
  [5664] = 5619,
  [5665] = 5621,
  [5666] = 5619,
  [5667] = 5621,
  [5668] = 5619,
  [5669] = 5619,
  [5670] = 5621,
  [5671] = 5619,
  [5672] = 5619,
  [5673] = 5621,
  [5674] = 5619,
  [5675] = 5621,
  [5676] = 5621,
  [5677] = 5619,
  [5678] = 5619,
  [5679] = 5621,
  [5680] = 5619,
  [5681] = 5621,
  [5682] = 5619,
  [5683] = 5621,
  [5684] = 5619,
  [5685] = 5621,
  [5686] = 5619,
  [5687] = 5619,
  [5688] = 5621,
  [5689] = 5621,
  [5690] = 5619,
  [5691] = 5621,
  [5692] = 5621,
  [5693] = 5621,
  [5694] = 5619,
  [5695] = 5621,
  [5696] = 5619,
  [5697] = 5619,
  [5698] = 5621,
  [5699] = 5619,
  [5700] = 5621,
  [5701] = 5621,
  [5702] = 5619,
  [5703] = 5621,
  [5704] = 5621,
  [5705] = 5619,
  [5706] = 5619,
  [5707] = 5621,
  [5708] = 5619,
  [5709] = 5621,
  [5710] = 5619,
  [5711] = 5621,
  [5712] = 5621,
  [5713] = 5619,
  [5714] = 5621,
  [5715] = 5619,
  [5716] = 5619,
  [5717] = 5621,
  [5718] = 5621,
  [5719] = 5619,
  [5720] = 5621,
  [5721] = 5619,
  [5722] = 5621,
  [5723] = 5619,
  [5724] = 5621,
  [5725] = 5619,
  [5726] = 5619,
  [5727] = 5619,
  [5728] = 5621,
  [5729] = 5619,
  [5730] = 5621,
  [5731] = 5619,
  [5732] = 5621,
  [5733] = 5619,
  [5734] = 5621,
  [5735] = 5619,
  [5736] = 5621,
  [5737] = 5621,
  [5738] = 5619,
  [5739] = 5621,
  [5740] = 5619,
  [5741] = 5621,
  [5742] = 5619,
  [5743] = 5621,
  [5744] = 5744,
  [5745] = 5621,
  [5746] = 5619,
  [5747] = 5621,
  [5748] = 5619,
  [5749] = 5621,
  [5750] = 5619,
  [5751] = 5621,
  [5752] = 5619,
  [5753] = 5621,
  [5754] = 5619,
  [5755] = 5621,
  [5756] = 5619,
  [5757] = 5619,
  [5758] = 5621,
  [5759] = 5619,
  [5760] = 5621,
  [5761] = 5619,
  [5762] = 5621,
  [5763] = 5621,
  [5764] = 5619,
  [5765] = 5619,
  [5766] = 5621,
  [5767] = 5619,
  [5768] = 5619,
  [5769] = 5621,
  [5770] = 5619,
  [5771] = 5619,
  [5772] = 5621,
  [5773] = 5621,
  [5774] = 5774,
  [5775] = 5774,
  [5776] = 5776,
  [5777] = 5777,
  [5778] = 5778,
  [5779] = 5774,
  [5780] = 5776,
  [5781] = 5777,
  [5782] = 5776,
  [5783] = 5774,
  [5784] = 5774,
  [5785] = 5778,
  [5786] = 5776,
  [5787] = 5774,
  [5788] = 5777,
  [5789] = 5774,
  [5790] = 5774,
  [5791] = 5774,
  [5792] = 5776,
  [5793] = 5777,
  [5794] = 5776,
  [5795] = 5776,
  [5796] = 5776,
  [5797] = 5778,
  [5798] = 5774,
  [5799] = 5777,
  [5800] = 5776,
  [5801] = 5777,
  [5802] = 5774,
  [5803] = 5776,
  [5804] = 5777,
  [5805] = 5776,
  [5806] = 5774,
  [5807] = 5777,
  [5808] = 5774,
  [5809] = 5774,
  [5810] = 5776,
  [5811] = 5776,
  [5812] = 5777,
  [5813] = 5774,
  [5814] = 5776,
  [5815] = 5777,
  [5816] = 5774,
  [5817] = 5774,
  [5818] = 5776,
  [5819] = 5776,
  [5820] = 5777,
  [5821] = 5774,
  [5822] = 5774,
  [5823] = 5776,
  [5824] = 5776,
  [5825] = 5774,
  [5826] = 5777,
  [5827] = 5774,
  [5828] = 5774,
  [5829] = 5776,
  [5830] = 5777,
  [5831] = 5777,
  [5832] = 5774,
  [5833] = 5776,
  [5834] = 5774,
  [5835] = 5776,
  [5836] = 5777,
  [5837] = 5776,
  [5838] = 5776,
  [5839] = 5777,
  [5840] = 5776,
  [5841] = 5777,
  [5842] = 5777,
  [5843] = 5774,
  [5844] = 5774,
  [5845] = 5776,
  [5846] = 5777,
  [5847] = 5774,
  [5848] = 5776,
  [5849] = 5776,
  [5850] = 5777,
  [5851] = 5777,
  [5852] = 5774,
  [5853] = 5776,
  [5854] = 5778,
  [5855] = 5774,
  [5856] = 5774,
  [5857] = 5776,
  [5858] = 5777,
  [5859] = 5777,
  [5860] = 5774,
  [5861] = 5774,
  [5862] = 5774,
  [5863] = 5776,
  [5864] = 5776,
  [5865] = 5776,
  [5866] = 5777,
  [5867] = 5777,
  [5868] = 5774,
  [5869] = 5774,
  [5870] = 5774,
  [5871] = 5776,
  [5872] = 5776,
  [5873] = 5777,
  [5874] = 5776,
  [5875] = 5774,
  [5876] = 5776,
  [5877] = 5777,
  [5878] = 5774,
  [5879] = 5774,
  [5880] = 5777,
  [5881] = 5776,
  [5882] = 5774,
  [5883] = 5777,
  [5884] = 5774,
  [5885] = 5776,
  [5886] = 5776,
  [5887] = 5777,
  [5888] = 5776,
  [5889] = 5774,
  [5890] = 5774,
  [5891] = 5776,
  [5892] = 5774,
  [5893] = 5777,
  [5894] = 5776,
  [5895] = 5777,
  [5896] = 5776,
  [5897] = 5774,
  [5898] = 5776,
  [5899] = 5776,
  [5900] = 5777,
  [5901] = 5777,
  [5902] = 5774,
  [5903] = 5778,
  [5904] = 5774,
  [5905] = 5776,
  [5906] = 5777,
  [5907] = 5774,
  [5908] = 5776,
  [5909] = 5774,
  [5910] = 5774,
  [5911] = 5776,
  [5912] = 5777,
  [5913] = 5776,
  [5914] = 5776,
  [5915] = 5774,
  [5916] = 5776,
  [5917] = 5777,
  [5918] = 5774,
  [5919] = 5774,
  [5920] = 5776,
  [5921] = 5777,
  [5922] = 5774,
  [5923] = 5774,
  [5924] = 5776,
  [5925] = 5777,
  [5926] = 5774,
  [5927] = 5776,
  [5928] = 5777,
  [5929] = 5777,
  [5930] = 5777,
  [5931] = 5774,
  [5932] = 5774,
  [5933] = 5778,
  [5934] = 5776,
  [5935] = 5777,
  [5936] = 5776,
  [5937] = 5774,
  [5938] = 5776,
  [5939] = 5776,
  [5940] = 5777,
  [5941] = 5774,
  [5942] = 5774,
  [5943] = 5774,
  [5944] = 5777,
  [5945] = 5776,
  [5946] = 5776,
  [5947] = 5776,
  [5948] = 5777,
  [5949] = 5777,
  [5950] = 5774,
  [5951] = 5777,
  [5952] = 5776,
  [5953] = 5774,
  [5954] = 5774,
  [5955] = 5776,
  [5956] = 5777,
  [5957] = 5777,
  [5958] = 5776,
  [5959] = 5774,
  [5960] = 5776,
  [5961] = 5776,
  [5962] = 5777,
  [5963] = 5774,
  [5964] = 5778,
  [5965] = 5774,
  [5966] = 5776,
  [5967] = 5776,
  [5968] = 5777,
  [5969] = 5774,
  [5970] = 5777,
  [5971] = 5774,
  [5972] = 5777,
  [5973] = 5777,
  [5974] = 5776,
  [5975] = 5777,
  [5976] = 5777,
  [5977] = 5776,
  [5978] = 5774,
  [5979] = 5776,
  [5980] = 5778,
  [5981] = 5776,
  [5982] = 5774,
  [5983] = 5776,
  [5984] = 5774,
  [5985] = 5777,
  [5986] = 5777,
  [5987] = 5774,
  [5988] = 5777,
  [5989] = 5776,
  [5990] = 5777,
  [5991] = 5776,
  [5992] = 5774,
  [5993] = 5774,
  [5994] = 5777,
  [5995] = 5777,
  [5996] = 5774,
  [5997] = 5776,
  [5998] = 5777,
  [5999] = 5776,
  [6000] = 6000,
  [6001] = 6000,
  [6002] = 6000,
  [6003] = 6000,
  [6004] = 476,
  [6005] = 479,
  [6006] = 6000,
  [6007] = 6000,
  [6008] = 6000,
  [6009] = 6000,
  [6010] = 6010,
  [6011] = 6000,
  [6012] = 6012,
  [6013] = 6013,
  [6014] = 6012,
  [6015] = 6015,
  [6016] = 6016,
  [6017] = 6012,
  [6018] = 6012,
  [6019] = 6016,
  [6020] = 6012,
  [6021] = 6012,
  [6022] = 6012,
  [6023] = 6023,
  [6024] = 6016,
  [6025] = 6012,
  [6026] = 6012,
  [6027] = 6012,
  [6028] = 6016,
  [6029] = 6012,
  [6030] = 6016,
  [6031] = 6031,
  [6032] = 6016,
  [6033] = 6012,
  [6034] = 6012,
  [6035] = 6012,
  [6036] = 6012,
  [6037] = 6012,
  [6038] = 6012,
  [6039] = 6012,
  [6040] = 6012,
  [6041] = 6016,
  [6042] = 6012,
  [6043] = 6012,
  [6044] = 6012,
  [6045] = 6016,
  [6046] = 6012,
  [6047] = 6012,
  [6048] = 6012,
  [6049] = 6012,
  [6050] = 6016,
  [6051] = 6012,
  [6052] = 6052,
  [6053] = 6053,
  [6054] = 6054,
  [6055] = 482,
  [6056] = 483,
  [6057] = 6053,
  [6058] = 6052,
  [6059] = 6052,
  [6060] = 484,
  [6061] = 6052,
  [6062] = 6054,
  [6063] = 6063,
  [6064] = 6053,
  [6065] = 6052,
  [6066] = 6054,
  [6067] = 6054,
  [6068] = 6054,
  [6069] = 6069,
  [6070] = 481,
  [6071] = 6054,
  [6072] = 6054,
  [6073] = 6053,
  [6074] = 6052,
  [6075] = 474,
  [6076] = 1045,
  [6077] = 479,
  [6078] = 6053,
  [6079] = 6053,
  [6080] = 480,
  [6081] = 6053,
  [6082] = 472,
  [6083] = 476,
  [6084] = 6052,
  [6085] = 6085,
  [6086] = 6053,
  [6087] = 6052,
  [6088] = 6054,
  [6089] = 6089,
  [6090] = 465,
  [6091] = 6091,
  [6092] = 6092,
  [6093] = 6093,
  [6094] = 6094,
  [6095] = 6095,
  [6096] = 6096,
  [6097] = 6097,
  [6098] = 464,
  [6099] = 463,
  [6100] = 6100,
  [6101] = 466,
  [6102] = 6096,
  [6103] = 6093,
  [6104] = 6104,
  [6105] = 6096,
  [6106] = 6093,
  [6107] = 6096,
  [6108] = 6093,
  [6109] = 481,
  [6110] = 470,
  [6111] = 481,
  [6112] = 6112,
  [6113] = 475,
  [6114] = 482,
  [6115] = 483,
  [6116] = 484,
  [6117] = 6112,
  [6118] = 482,
  [6119] = 483,
  [6120] = 484,
  [6121] = 488,
  [6122] = 487,
  [6123] = 469,
  [6124] = 481,
  [6125] = 482,
  [6126] = 483,
  [6127] = 484,
  [6128] = 6128,
  [6129] = 480,
  [6130] = 6130,
  [6131] = 471,
  [6132] = 472,
  [6133] = 6112,
  [6134] = 474,
  [6135] = 6135,
  [6136] = 6112,
  [6137] = 478,
  [6138] = 486,
  [6139] = 475,
  [6140] = 477,
  [6141] = 476,
  [6142] = 479,
  [6143] = 473,
  [6144] = 476,
  [6145] = 477,
  [6146] = 480,
  [6147] = 6147,
  [6148] = 480,
  [6149] = 485,
  [6150] = 479,
  [6151] = 6151,
  [6152] = 6152,
  [6153] = 6153,
  [6154] = 6154,
  [6155] = 6154,
  [6156] = 6154,
  [6157] = 6157,
  [6158] = 6154,
  [6159] = 6159,
  [6160] = 6154,
  [6161] = 6161,
  [6162] = 6154,
  [6163] = 6154,
  [6164] = 6154,
  [6165] = 6165,
  [6166] = 6154,
  [6167] = 6154,
  [6168] = 6168,
  [6169] = 6154,
  [6170] = 6154,
  [6171] = 6171,
  [6172] = 6154,
  [6173] = 6173,
  [6174] = 6174,
  [6175] = 6175,
  [6176] = 6176,
  [6177] = 6177,
  [6178] = 6178,
  [6179] = 6154,
  [6180] = 6154,
  [6181] = 6181,
  [6182] = 6154,
  [6183] = 6154,
  [6184] = 6154,
  [6185] = 6154,
  [6186] = 6154,
  [6187] = 6154,
  [6188] = 6188,
  [6189] = 6154,
  [6190] = 6190,
  [6191] = 6191,
  [6192] = 6154,
  [6193] = 6154,
  [6194] = 6176,
  [6195] = 6154,
  [6196] = 6154,
  [6197] = 6197,
  [6198] = 465,
  [6199] = 6199,
  [6200] = 6177,
  [6201] = 6154,
  [6202] = 6154,
  [6203] = 6154,
  [6204] = 6204,
  [6205] = 6205,
  [6206] = 6206,
  [6207] = 6154,
  [6208] = 6208,
  [6209] = 6154,
  [6210] = 6154,
  [6211] = 6154,
  [6212] = 6154,
  [6213] = 6154,
  [6214] = 6154,
  [6215] = 6154,
  [6216] = 6216,
  [6217] = 6154,
  [6218] = 6176,
  [6219] = 6177,
  [6220] = 6154,
  [6221] = 6154,
  [6222] = 6177,
  [6223] = 6223,
  [6224] = 6224,
  [6225] = 473,
  [6226] = 6154,
  [6227] = 6227,
  [6228] = 6154,
  [6229] = 6181,
  [6230] = 6154,
  [6231] = 6154,
  [6232] = 6232,
  [6233] = 491,
  [6234] = 6154,
  [6235] = 6154,
  [6236] = 6154,
  [6237] = 6154,
  [6238] = 6154,
  [6239] = 6239,
  [6240] = 6240,
  [6241] = 6154,
  [6242] = 6242,
  [6243] = 6154,
  [6244] = 6154,
  [6245] = 469,
  [6246] = 6246,
  [6247] = 6181,
  [6248] = 6248,
  [6249] = 6249,
  [6250] = 6154,
  [6251] = 6154,
  [6252] = 6154,
  [6253] = 6253,
  [6254] = 6154,
  [6255] = 6154,
  [6256] = 471,
  [6257] = 6154,
  [6258] = 6154,
  [6259] = 6154,
  [6260] = 6154,
  [6261] = 6176,
  [6262] = 6154,
  [6263] = 6154,
  [6264] = 6154,
  [6265] = 6265,
  [6266] = 6154,
  [6267] = 6267,
  [6268] = 6154,
  [6269] = 6154,
  [6270] = 6181,
  [6271] = 6154,
  [6272] = 6272,
  [6273] = 6154,
  [6274] = 6154,
  [6275] = 6275,
  [6276] = 2495,
  [6277] = 6277,
  [6278] = 6278,
  [6279] = 6279,
  [6280] = 6280,
  [6281] = 6281,
  [6282] = 6282,
  [6283] = 6283,
  [6284] = 6284,
  [6285] = 6285,
  [6286] = 6286,
  [6287] = 6287,
  [6288] = 6288,
  [6289] = 6289,
  [6290] = 6290,
  [6291] = 6287,
  [6292] = 6292,
  [6293] = 6279,
  [6294] = 6294,
  [6295] = 6295,
  [6296] = 6296,
  [6297] = 6288,
  [6298] = 6289,
  [6299] = 6290,
  [6300] = 6300,
  [6301] = 6301,
  [6302] = 6279,
  [6303] = 463,
  [6304] = 483,
  [6305] = 6305,
  [6306] = 2565,
  [6307] = 6307,
  [6308] = 6300,
  [6309] = 6309,
  [6310] = 6310,
  [6311] = 6311,
  [6312] = 6312,
  [6313] = 6313,
  [6314] = 6314,
  [6315] = 6315,
  [6316] = 482,
  [6317] = 6317,
  [6318] = 6318,
  [6319] = 6280,
  [6320] = 6320,
  [6321] = 6279,
  [6322] = 6279,
  [6323] = 6323,
  [6324] = 464,
  [6325] = 484,
  [6326] = 6300,
  [6327] = 6320,
  [6328] = 6285,
  [6329] = 6286,
  [6330] = 6280,
  [6331] = 6301,
  [6332] = 6282,
  [6333] = 6283,
  [6334] = 2520,
  [6335] = 6335,
  [6336] = 6284,
  [6337] = 6285,
  [6338] = 6286,
  [6339] = 6287,
  [6340] = 6288,
  [6341] = 6341,
  [6342] = 6289,
  [6343] = 6290,
  [6344] = 6287,
  [6345] = 6345,
  [6346] = 6300,
  [6347] = 6347,
  [6348] = 6280,
  [6349] = 6349,
  [6350] = 6288,
  [6351] = 6281,
  [6352] = 6281,
  [6353] = 6282,
  [6354] = 6283,
  [6355] = 6284,
  [6356] = 6356,
  [6357] = 6285,
  [6358] = 6286,
  [6359] = 6301,
  [6360] = 6290,
  [6361] = 6361,
  [6362] = 6280,
  [6363] = 6281,
  [6364] = 6320,
  [6365] = 6287,
  [6366] = 6282,
  [6367] = 6288,
  [6368] = 6289,
  [6369] = 6290,
  [6370] = 6282,
  [6371] = 6371,
  [6372] = 6283,
  [6373] = 6301,
  [6374] = 2487,
  [6375] = 6320,
  [6376] = 6283,
  [6377] = 6377,
  [6378] = 6284,
  [6379] = 6379,
  [6380] = 6285,
  [6381] = 6289,
  [6382] = 6382,
  [6383] = 466,
  [6384] = 6286,
  [6385] = 6284,
  [6386] = 6281,
  [6387] = 475,
  [6388] = 485,
  [6389] = 472,
  [6390] = 474,
  [6391] = 482,
  [6392] = 483,
  [6393] = 484,
  [6394] = 488,
  [6395] = 6395,
  [6396] = 2588,
  [6397] = 6397,
  [6398] = 6398,
  [6399] = 2595,
  [6400] = 2596,
  [6401] = 473,
  [6402] = 477,
  [6403] = 469,
  [6404] = 471,
  [6405] = 476,
  [6406] = 479,
  [6407] = 480,
  [6408] = 481,
  [6409] = 6409,
  [6410] = 482,
  [6411] = 483,
  [6412] = 484,
  [6413] = 6413,
  [6414] = 6414,
  [6415] = 487,
  [6416] = 6416,
  [6417] = 6417,
  [6418] = 6418,
  [6419] = 488,
  [6420] = 6420,
  [6421] = 476,
  [6422] = 479,
  [6423] = 6423,
  [6424] = 473,
  [6425] = 480,
  [6426] = 469,
  [6427] = 481,
  [6428] = 471,
  [6429] = 6429,
  [6430] = 482,
  [6431] = 483,
  [6432] = 484,
  [6433] = 6433,
  [6434] = 1673,
  [6435] = 6435,
  [6436] = 2587,
  [6437] = 6437,
  [6438] = 1468,
  [6439] = 6439,
  [6440] = 6440,
  [6441] = 6441,
  [6442] = 6442,
  [6443] = 6443,
  [6444] = 6444,
  [6445] = 470,
  [6446] = 478,
  [6447] = 486,
  [6448] = 6448,
  [6449] = 487,
  [6450] = 6450,
  [6451] = 6450,
  [6452] = 6450,
  [6453] = 6453,
  [6454] = 6450,
  [6455] = 6455,
  [6456] = 6456,
  [6457] = 6457,
  [6458] = 6458,
  [6459] = 6450,
  [6460] = 6457,
  [6461] = 6450,
  [6462] = 6462,
  [6463] = 6457,
  [6464] = 6464,
  [6465] = 6457,
  [6466] = 6466,
  [6467] = 6450,
  [6468] = 6468,
  [6469] = 6457,
  [6470] = 6457,
  [6471] = 6450,
  [6472] = 6472,
  [6473] = 6473,
  [6474] = 6457,
  [6475] = 6475,
  [6476] = 6457,
  [6477] = 6361,
  [6478] = 6478,
  [6479] = 472,
  [6480] = 6457,
  [6481] = 6457,
  [6482] = 6482,
  [6483] = 6450,
  [6484] = 491,
  [6485] = 474,
  [6486] = 6457,
  [6487] = 6450,
  [6488] = 6488,
  [6489] = 6457,
  [6490] = 6490,
  [6491] = 6457,
  [6492] = 491,
  [6493] = 6493,
  [6494] = 6450,
  [6495] = 6457,
  [6496] = 6457,
  [6497] = 6450,
  [6498] = 6498,
  [6499] = 6499,
  [6500] = 6500,
  [6501] = 6501,
  [6502] = 6502,
  [6503] = 6450,
  [6504] = 6504,
  [6505] = 6450,
  [6506] = 6450,
  [6507] = 6450,
  [6508] = 6450,
  [6509] = 6450,
  [6510] = 6361,
  [6511] = 6511,
  [6512] = 6512,
  [6513] = 6513,
  [6514] = 6450,
  [6515] = 6450,
  [6516] = 6450,
  [6517] = 6450,
  [6518] = 6518,
  [6519] = 6450,
  [6520] = 6462,
  [6521] = 6521,
  [6522] = 6450,
  [6523] = 6450,
  [6524] = 2495,
  [6525] = 2487,
  [6526] = 6450,
  [6527] = 6450,
  [6528] = 473,
  [6529] = 6450,
  [6530] = 6450,
  [6531] = 6450,
  [6532] = 6532,
  [6533] = 469,
  [6534] = 6499,
  [6535] = 471,
  [6536] = 6450,
  [6537] = 6504,
  [6538] = 2337,
  [6539] = 6504,
  [6540] = 6450,
  [6541] = 6541,
  [6542] = 6450,
  [6543] = 6543,
  [6544] = 6450,
  [6545] = 6545,
  [6546] = 6546,
  [6547] = 6450,
  [6548] = 6450,
  [6549] = 6450,
  [6550] = 6450,
  [6551] = 6551,
  [6552] = 6450,
  [6553] = 6450,
  [6554] = 6450,
  [6555] = 6462,
  [6556] = 6457,
  [6557] = 6450,
  [6558] = 6450,
  [6559] = 6457,
  [6560] = 6450,
  [6561] = 6561,
  [6562] = 6499,
  [6563] = 6450,
  [6564] = 6450,
  [6565] = 6565,
  [6566] = 6450,
  [6567] = 6567,
  [6568] = 6450,
  [6569] = 473,
  [6570] = 480,
  [6571] = 6571,
  [6572] = 6450,
  [6573] = 6462,
  [6574] = 469,
  [6575] = 6575,
  [6576] = 481,
  [6577] = 471,
  [6578] = 6578,
  [6579] = 6579,
  [6580] = 6580,
  [6581] = 6450,
  [6582] = 6450,
  [6583] = 6462,
  [6584] = 6584,
  [6585] = 6585,
  [6586] = 6450,
  [6587] = 6457,
  [6588] = 6457,
  [6589] = 6589,
  [6590] = 6590,
  [6591] = 482,
  [6592] = 6462,
  [6593] = 483,
  [6594] = 484,
  [6595] = 6457,
  [6596] = 6450,
  [6597] = 6450,
  [6598] = 6450,
  [6599] = 6599,
  [6600] = 6450,
  [6601] = 6450,
  [6602] = 6602,
  [6603] = 6450,
  [6604] = 6462,
  [6605] = 6605,
  [6606] = 6450,
  [6607] = 6457,
  [6608] = 6457,
  [6609] = 6609,
  [6610] = 2520,
  [6611] = 6611,
  [6612] = 6450,
  [6613] = 6450,
  [6614] = 6614,
  [6615] = 6615,
  [6616] = 6450,
  [6617] = 6617,
  [6618] = 6462,
  [6619] = 6619,
  [6620] = 6620,
  [6621] = 6621,
  [6622] = 6622,
  [6623] = 2565,
  [6624] = 6457,
  [6625] = 6450,
  [6626] = 6450,
  [6627] = 6450,
  [6628] = 6439,
  [6629] = 6629,
  [6630] = 6630,
  [6631] = 2588,
  [6632] = 6630,
  [6633] = 6633,
  [6634] = 6633,
  [6635] = 4536,
  [6636] = 6633,
  [6637] = 6633,
  [6638] = 6638,
  [6639] = 6639,
  [6640] = 6640,
  [6641] = 6633,
  [6642] = 485,
  [6643] = 2596,
  [6644] = 6644,
  [6645] = 6645,
  [6646] = 6429,
  [6647] = 4509,
  [6648] = 469,
  [6649] = 4514,
  [6650] = 6633,
  [6651] = 6633,
  [6652] = 6633,
  [6653] = 6653,
  [6654] = 6644,
  [6655] = 6633,
  [6656] = 6633,
  [6657] = 6633,
  [6658] = 6658,
  [6659] = 6429,
  [6660] = 6660,
  [6661] = 6661,
  [6662] = 4585,
  [6663] = 6639,
  [6664] = 6633,
  [6665] = 6665,
  [6666] = 6639,
  [6667] = 6639,
  [6668] = 6639,
  [6669] = 6633,
  [6670] = 6670,
  [6671] = 470,
  [6672] = 6633,
  [6673] = 6633,
  [6674] = 471,
  [6675] = 6633,
  [6676] = 6644,
  [6677] = 6677,
  [6678] = 2512,
  [6679] = 6633,
  [6680] = 6630,
  [6681] = 6633,
  [6682] = 6653,
  [6683] = 6683,
  [6684] = 6653,
  [6685] = 6439,
  [6686] = 6395,
  [6687] = 6639,
  [6688] = 2508,
  [6689] = 6630,
  [6690] = 6653,
  [6691] = 473,
  [6692] = 6395,
  [6693] = 2595,
  [6694] = 6694,
  [6695] = 6633,
  [6696] = 6696,
  [6697] = 6633,
  [6698] = 6644,
  [6699] = 2587,
  [6700] = 6700,
  [6701] = 6633,
  [6702] = 6633,
  [6703] = 6633,
  [6704] = 6704,
  [6705] = 6705,
  [6706] = 6706,
  [6707] = 6707,
  [6708] = 6708,
  [6709] = 6706,
  [6710] = 6710,
  [6711] = 6711,
  [6712] = 6712,
  [6713] = 6713,
  [6714] = 6705,
  [6715] = 6715,
  [6716] = 6716,
  [6717] = 6716,
  [6718] = 6718,
  [6719] = 6710,
  [6720] = 6720,
  [6721] = 6711,
  [6722] = 6716,
  [6723] = 6718,
  [6724] = 6724,
  [6725] = 6705,
  [6726] = 6711,
  [6727] = 6706,
  [6728] = 6710,
  [6729] = 6729,
  [6730] = 6718,
  [6731] = 6706,
  [6732] = 6732,
  [6733] = 6705,
  [6734] = 6734,
  [6735] = 6732,
  [6736] = 6716,
  [6737] = 6710,
  [6738] = 6718,
  [6739] = 6706,
  [6740] = 6711,
  [6741] = 6716,
  [6742] = 6711,
  [6743] = 6732,
  [6744] = 6705,
  [6745] = 6706,
  [6746] = 6710,
  [6747] = 6706,
  [6748] = 6718,
  [6749] = 6749,
  [6750] = 6732,
  [6751] = 6711,
  [6752] = 6716,
  [6753] = 6705,
  [6754] = 6718,
  [6755] = 6710,
  [6756] = 6756,
  [6757] = 6711,
  [6758] = 6705,
  [6759] = 6759,
  [6760] = 6705,
  [6761] = 6706,
  [6762] = 6706,
  [6763] = 6763,
  [6764] = 6710,
  [6765] = 6732,
  [6766] = 6766,
  [6767] = 6767,
  [6768] = 6768,
  [6769] = 6769,
  [6770] = 6716,
  [6771] = 6732,
  [6772] = 6772,
  [6773] = 6710,
  [6774] = 6732,
  [6775] = 6767,
  [6776] = 6776,
  [6777] = 6777,
  [6778] = 6732,
  [6779] = 6779,
  [6780] = 6710,
  [6781] = 6716,
  [6782] = 6718,
  [6783] = 6732,
  [6784] = 6784,
  [6785] = 6785,
  [6786] = 6718,
  [6787] = 6710,
  [6788] = 6716,
  [6789] = 6789,
  [6790] = 6790,
  [6791] = 6711,
  [6792] = 6792,
  [6793] = 6705,
  [6794] = 6710,
  [6795] = 6706,
  [6796] = 6718,
  [6797] = 6716,
  [6798] = 6732,
  [6799] = 6799,
  [6800] = 6732,
  [6801] = 6710,
  [6802] = 6716,
  [6803] = 6803,
  [6804] = 6716,
  [6805] = 6805,
  [6806] = 6718,
  [6807] = 6763,
  [6808] = 6710,
  [6809] = 6711,
  [6810] = 6716,
  [6811] = 6811,
  [6812] = 6812,
  [6813] = 6813,
  [6814] = 6814,
  [6815] = 6710,
  [6816] = 6718,
  [6817] = 6817,
  [6818] = 6711,
  [6819] = 6716,
  [6820] = 6734,
  [6821] = 6769,
  [6822] = 6710,
  [6823] = 6823,
  [6824] = 6718,
  [6825] = 6716,
  [6826] = 6711,
  [6827] = 6705,
  [6828] = 6706,
  [6829] = 6710,
  [6830] = 6830,
  [6831] = 6831,
  [6832] = 6711,
  [6833] = 6718,
  [6834] = 6732,
  [6835] = 6705,
  [6836] = 6710,
  [6837] = 6711,
  [6838] = 6705,
  [6839] = 6706,
  [6840] = 6705,
  [6841] = 6706,
  [6842] = 6706,
  [6843] = 6710,
  [6844] = 6732,
  [6845] = 6718,
  [6846] = 6716,
  [6847] = 6716,
  [6848] = 6718,
  [6849] = 6732,
  [6850] = 6710,
  [6851] = 6711,
  [6852] = 6705,
  [6853] = 6732,
  [6854] = 6706,
  [6855] = 6718,
  [6856] = 6856,
  [6857] = 6710,
  [6858] = 6732,
  [6859] = 6859,
  [6860] = 6710,
  [6861] = 6712,
  [6862] = 6862,
  [6863] = 6716,
  [6864] = 6710,
  [6865] = 6716,
  [6866] = 6718,
  [6867] = 6718,
  [6868] = 6716,
  [6869] = 6718,
  [6870] = 6870,
  [6871] = 6710,
  [6872] = 6711,
  [6873] = 6716,
  [6874] = 6718,
  [6875] = 6705,
  [6876] = 6711,
  [6877] = 6711,
  [6878] = 6710,
  [6879] = 6879,
  [6880] = 6823,
  [6881] = 6711,
  [6882] = 6705,
  [6883] = 6706,
  [6884] = 6705,
  [6885] = 6710,
  [6886] = 6705,
  [6887] = 6732,
  [6888] = 6888,
  [6889] = 6706,
  [6890] = 6706,
  [6891] = 6813,
  [6892] = 6710,
  [6893] = 6705,
  [6894] = 6732,
  [6895] = 6895,
  [6896] = 6706,
  [6897] = 6716,
  [6898] = 6898,
  [6899] = 6710,
  [6900] = 6706,
  [6901] = 6716,
  [6902] = 6718,
  [6903] = 6718,
  [6904] = 6711,
  [6905] = 6705,
  [6906] = 6710,
  [6907] = 6706,
  [6908] = 6732,
  [6909] = 6732,
  [6910] = 6711,
  [6911] = 6732,
  [6912] = 6732,
  [6913] = 6710,
  [6914] = 6711,
  [6915] = 6716,
  [6916] = 6718,
  [6917] = 6716,
  [6918] = 6718,
  [6919] = 6817,
  [6920] = 6710,
  [6921] = 6888,
  [6922] = 6767,
  [6923] = 6711,
  [6924] = 6716,
  [6925] = 6895,
  [6926] = 6718,
  [6927] = 6710,
  [6928] = 6928,
  [6929] = 6711,
  [6930] = 6705,
  [6931] = 6706,
  [6932] = 6814,
  [6933] = 6705,
  [6934] = 6710,
  [6935] = 6732,
  [6936] = 6706,
  [6937] = 6817,
  [6938] = 6938,
  [6939] = 6716,
  [6940] = 6711,
  [6941] = 6710,
  [6942] = 6732,
  [6943] = 6718,
  [6944] = 6716,
  [6945] = 6718,
  [6946] = 6946,
  [6947] = 6711,
  [6948] = 6710,
  [6949] = 6705,
  [6950] = 6706,
  [6951] = 6951,
  [6952] = 6729,
  [6953] = 6759,
  [6954] = 6954,
  [6955] = 6710,
  [6956] = 6705,
  [6957] = 6716,
  [6958] = 6711,
  [6959] = 6705,
  [6960] = 6960,
  [6961] = 6718,
  [6962] = 6710,
  [6963] = 6706,
  [6964] = 6705,
  [6965] = 6965,
  [6966] = 6711,
  [6967] = 6705,
  [6968] = 6706,
  [6969] = 6710,
  [6970] = 6970,
  [6971] = 6706,
  [6972] = 6732,
  [6973] = 6732,
  [6974] = 6705,
  [6975] = 6975,
  [6976] = 6710,
  [6977] = 6977,
  [6978] = 6732,
  [6979] = 6856,
  [6980] = 6980,
  [6981] = 6859,
  [6982] = 6706,
  [6983] = 6710,
  [6984] = 6716,
  [6985] = 6718,
  [6986] = 6711,
  [6987] = 6776,
  [6988] = 6777,
  [6989] = 6732,
  [6990] = 6710,
  [6991] = 6960,
  [6992] = 6716,
  [6993] = 6718,
  [6994] = 6711,
  [6995] = 6711,
  [6996] = 6785,
  [6997] = 6710,
  [6998] = 6705,
  [6999] = 6706,
  [7000] = 6789,
  [7001] = 7001,
  [7002] = 6710,
  [7003] = 6792,
  [7004] = 6710,
  [7005] = 6705,
  [7006] = 6732,
  [7007] = 6706,
  [7008] = 6706,
  [7009] = 6712,
  [7010] = 7010,
  [7011] = 6710,
  [7012] = 6732,
  [7013] = 6716,
  [7014] = 6803,
  [7015] = 6732,
  [7016] = 6805,
  [7017] = 6705,
  [7018] = 6710,
  [7019] = 6763,
  [7020] = 6706,
  [7021] = 6732,
  [7022] = 6718,
  [7023] = 6813,
  [7024] = 6814,
  [7025] = 6710,
  [7026] = 6716,
  [7027] = 6718,
  [7028] = 7028,
  [7029] = 6711,
  [7030] = 6734,
  [7031] = 6769,
  [7032] = 6710,
  [7033] = 6823,
  [7034] = 6705,
  [7035] = 6706,
  [7036] = 6716,
  [7037] = 7037,
  [7038] = 6732,
  [7039] = 6710,
  [7040] = 6830,
  [7041] = 6831,
  [7042] = 6718,
  [7043] = 6716,
  [7044] = 6711,
  [7045] = 7045,
  [7046] = 6710,
  [7047] = 6716,
  [7048] = 6705,
  [7049] = 6718,
  [7050] = 6862,
  [7051] = 6711,
  [7052] = 6705,
  [7053] = 6710,
  [7054] = 6716,
  [7055] = 6718,
  [7056] = 6706,
  [7057] = 6706,
  [7058] = 6711,
  [7059] = 6870,
  [7060] = 6710,
  [7061] = 6705,
  [7062] = 6706,
  [7063] = 6718,
  [7064] = 6711,
  [7065] = 6732,
  [7066] = 6792,
  [7067] = 6710,
  [7068] = 6732,
  [7069] = 6732,
  [7070] = 6732,
  [7071] = 6716,
  [7072] = 6718,
  [7073] = 6716,
  [7074] = 6710,
  [7075] = 6711,
  [7076] = 6716,
  [7077] = 6718,
  [7078] = 6705,
  [7079] = 6711,
  [7080] = 6705,
  [7081] = 6710,
  [7082] = 6718,
  [7083] = 6706,
  [7084] = 6711,
  [7085] = 6718,
  [7086] = 6716,
  [7087] = 6718,
  [7088] = 6710,
  [7089] = 6732,
  [7090] = 6716,
  [7091] = 6718,
  [7092] = 7092,
  [7093] = 6859,
  [7094] = 6711,
  [7095] = 6705,
  [7096] = 6711,
  [7097] = 6710,
  [7098] = 6705,
  [7099] = 6705,
  [7100] = 6706,
  [7101] = 6706,
  [7102] = 7102,
  [7103] = 6767,
  [7104] = 7104,
  [7105] = 7105,
  [7106] = 6732,
  [7107] = 6716,
  [7108] = 6718,
  [7109] = 6711,
  [7110] = 6711,
  [7111] = 6705,
  [7112] = 6817,
  [7113] = 6705,
  [7114] = 6706,
  [7115] = 6888,
  [7116] = 6895,
  [7117] = 7117,
  [7118] = 6716,
  [7119] = 6718,
  [7120] = 6716,
  [7121] = 6711,
  [7122] = 6705,
  [7123] = 6706,
  [7124] = 6716,
  [7125] = 6718,
  [7126] = 6732,
  [7127] = 6711,
  [7128] = 6705,
  [7129] = 7129,
  [7130] = 7130,
  [7131] = 6732,
  [7132] = 7132,
  [7133] = 6729,
  [7134] = 7134,
  [7135] = 6716,
  [7136] = 6759,
  [7137] = 7137,
  [7138] = 6718,
  [7139] = 6732,
  [7140] = 6779,
  [7141] = 7141,
  [7142] = 6711,
  [7143] = 7143,
  [7144] = 6856,
  [7145] = 7145,
  [7146] = 6960,
  [7147] = 6705,
  [7148] = 6716,
  [7149] = 6718,
  [7150] = 6928,
  [7151] = 6716,
  [7152] = 6711,
  [7153] = 6776,
  [7154] = 6777,
  [7155] = 6732,
  [7156] = 6705,
  [7157] = 6706,
  [7158] = 7158,
  [7159] = 6785,
  [7160] = 6965,
  [7161] = 6716,
  [7162] = 6789,
  [7163] = 7163,
  [7164] = 6732,
  [7165] = 6792,
  [7166] = 7166,
  [7167] = 6718,
  [7168] = 6716,
  [7169] = 6718,
  [7170] = 6718,
  [7171] = 6711,
  [7172] = 7172,
  [7173] = 6803,
  [7174] = 6705,
  [7175] = 6805,
  [7176] = 6716,
  [7177] = 6763,
  [7178] = 6718,
  [7179] = 7179,
  [7180] = 6813,
  [7181] = 6814,
  [7182] = 7182,
  [7183] = 6711,
  [7184] = 6716,
  [7185] = 6718,
  [7186] = 6705,
  [7187] = 6734,
  [7188] = 6769,
  [7189] = 6823,
  [7190] = 6711,
  [7191] = 6705,
  [7192] = 6711,
  [7193] = 6718,
  [7194] = 6711,
  [7195] = 6830,
  [7196] = 6831,
  [7197] = 6711,
  [7198] = 6705,
  [7199] = 6716,
  [7200] = 6718,
  [7201] = 6706,
  [7202] = 6711,
  [7203] = 6705,
  [7204] = 6705,
  [7205] = 6965,
  [7206] = 6706,
  [7207] = 6706,
  [7208] = 6732,
  [7209] = 6706,
  [7210] = 6732,
  [7211] = 6732,
  [7212] = 7212,
  [7213] = 6716,
  [7214] = 7214,
  [7215] = 6718,
  [7216] = 7216,
  [7217] = 6711,
  [7218] = 6705,
  [7219] = 7219,
  [7220] = 6732,
  [7221] = 7221,
  [7222] = 6777,
  [7223] = 6711,
  [7224] = 7224,
  [7225] = 6767,
  [7226] = 6705,
  [7227] = 6711,
  [7228] = 6716,
  [7229] = 6716,
  [7230] = 6718,
  [7231] = 6785,
  [7232] = 6817,
  [7233] = 6718,
  [7234] = 6705,
  [7235] = 6711,
  [7236] = 6705,
  [7237] = 6716,
  [7238] = 6716,
  [7239] = 6718,
  [7240] = 6706,
  [7241] = 6711,
  [7242] = 6705,
  [7243] = 6706,
  [7244] = 6718,
  [7245] = 7245,
  [7246] = 6716,
  [7247] = 6711,
  [7248] = 6888,
  [7249] = 7249,
  [7250] = 6705,
  [7251] = 6716,
  [7252] = 6718,
  [7253] = 6895,
  [7254] = 6718,
  [7255] = 7255,
  [7256] = 6711,
  [7257] = 6732,
  [7258] = 6732,
  [7259] = 6710,
  [7260] = 6776,
  [7261] = 6777,
  [7262] = 6732,
  [7263] = 6705,
  [7264] = 6706,
  [7265] = 6732,
  [7266] = 6813,
  [7267] = 6814,
  [7268] = 6716,
  [7269] = 6732,
  [7270] = 6718,
  [7271] = 7271,
  [7272] = 6711,
  [7273] = 6859,
  [7274] = 6716,
  [7275] = 6705,
  [7276] = 6706,
  [7277] = 6729,
  [7278] = 7137,
  [7279] = 6718,
  [7280] = 6711,
  [7281] = 6779,
  [7282] = 7141,
  [7283] = 6711,
  [7284] = 6705,
  [7285] = 6856,
  [7286] = 7145,
  [7287] = 6711,
  [7288] = 6705,
  [7289] = 6706,
  [7290] = 6928,
  [7291] = 6705,
  [7292] = 6732,
  [7293] = 6716,
  [7294] = 6718,
  [7295] = 6716,
  [7296] = 6711,
  [7297] = 6705,
  [7298] = 6759,
  [7299] = 6718,
  [7300] = 6716,
  [7301] = 6711,
  [7302] = 6705,
  [7303] = 6718,
  [7304] = 6718,
  [7305] = 6711,
  [7306] = 6706,
  [7307] = 6711,
  [7308] = 6710,
  [7309] = 6960,
  [7310] = 6705,
  [7311] = 6732,
  [7312] = 6779,
  [7313] = 6716,
  [7314] = 6767,
  [7315] = 7315,
  [7316] = 6711,
  [7317] = 6862,
  [7318] = 6779,
  [7319] = 6817,
  [7320] = 6705,
  [7321] = 6870,
  [7322] = 6718,
  [7323] = 6718,
  [7324] = 6718,
  [7325] = 6711,
  [7326] = 6716,
  [7327] = 6718,
  [7328] = 6705,
  [7329] = 6711,
  [7330] = 6705,
  [7331] = 6706,
  [7332] = 6705,
  [7333] = 6706,
  [7334] = 6706,
  [7335] = 6706,
  [7336] = 6711,
  [7337] = 7337,
  [7338] = 6856,
  [7339] = 6705,
  [7340] = 6789,
  [7341] = 6767,
  [7342] = 6965,
  [7343] = 6706,
  [7344] = 7344,
  [7345] = 6732,
  [7346] = 6716,
  [7347] = 6776,
  [7348] = 6777,
  [7349] = 6732,
  [7350] = 6718,
  [7351] = 6711,
  [7352] = 6711,
  [7353] = 6705,
  [7354] = 6706,
  [7355] = 6710,
  [7356] = 6856,
  [7357] = 6859,
  [7358] = 6710,
  [7359] = 6716,
  [7360] = 6712,
  [7361] = 6705,
  [7362] = 6862,
  [7363] = 6870,
  [7364] = 6732,
  [7365] = 6716,
  [7366] = 6805,
  [7367] = 6767,
  [7368] = 6718,
  [7369] = 7137,
  [7370] = 6718,
  [7371] = 7371,
  [7372] = 6817,
  [7373] = 7373,
  [7374] = 6716,
  [7375] = 6859,
  [7376] = 6859,
  [7377] = 6711,
  [7378] = 6718,
  [7379] = 6710,
  [7380] = 7137,
  [7381] = 7381,
  [7382] = 6705,
  [7383] = 6779,
  [7384] = 7141,
  [7385] = 6711,
  [7386] = 6732,
  [7387] = 6856,
  [7388] = 7145,
  [7389] = 6716,
  [7390] = 6718,
  [7391] = 6710,
  [7392] = 6928,
  [7393] = 6711,
  [7394] = 6705,
  [7395] = 6706,
  [7396] = 6888,
  [7397] = 6895,
  [7398] = 6711,
  [7399] = 6705,
  [7400] = 6705,
  [7401] = 7141,
  [7402] = 6706,
  [7403] = 6817,
  [7404] = 6732,
  [7405] = 7405,
  [7406] = 6706,
  [7407] = 6729,
  [7408] = 6706,
  [7409] = 6759,
  [7410] = 6779,
  [7411] = 7141,
  [7412] = 6856,
  [7413] = 7145,
  [7414] = 7414,
  [7415] = 6732,
  [7416] = 6928,
  [7417] = 6960,
  [7418] = 6706,
  [7419] = 7419,
  [7420] = 6965,
  [7421] = 6710,
  [7422] = 7145,
  [7423] = 7423,
  [7424] = 6705,
  [7425] = 7425,
  [7426] = 7426,
  [7427] = 7427,
  [7428] = 6732,
  [7429] = 6732,
  [7430] = 6803,
  [7431] = 6732,
  [7432] = 6716,
  [7433] = 6716,
  [7434] = 7141,
  [7435] = 7141,
  [7436] = 7141,
  [7437] = 7141,
  [7438] = 7141,
  [7439] = 7141,
  [7440] = 7141,
  [7441] = 7141,
  [7442] = 7141,
  [7443] = 7141,
  [7444] = 7141,
  [7445] = 7141,
  [7446] = 7141,
  [7447] = 7141,
  [7448] = 7141,
  [7449] = 7141,
  [7450] = 7141,
  [7451] = 7141,
  [7452] = 7141,
  [7453] = 7141,
  [7454] = 7141,
  [7455] = 7141,
  [7456] = 7141,
  [7457] = 7141,
  [7458] = 7141,
  [7459] = 7141,
  [7460] = 7141,
  [7461] = 7141,
  [7462] = 7141,
  [7463] = 7141,
  [7464] = 7141,
  [7465] = 7141,
  [7466] = 7141,
  [7467] = 7141,
  [7468] = 7141,
  [7469] = 7141,
  [7470] = 7141,
  [7471] = 7141,
  [7472] = 7141,
  [7473] = 7141,
  [7474] = 7141,
  [7475] = 7141,
  [7476] = 7141,
  [7477] = 7141,
  [7478] = 7141,
  [7479] = 7141,
  [7480] = 7141,
  [7481] = 7141,
  [7482] = 7141,
  [7483] = 7141,
  [7484] = 7141,
  [7485] = 7141,
  [7486] = 7141,
  [7487] = 7141,
  [7488] = 7141,
  [7489] = 7141,
  [7490] = 7141,
  [7491] = 7141,
  [7492] = 7141,
  [7493] = 7381,
  [7494] = 6718,
  [7495] = 6718,
  [7496] = 6831,
  [7497] = 6711,
  [7498] = 6705,
  [7499] = 6779,
  [7500] = 6776,
  [7501] = 6706,
  [7502] = 7381,
  [7503] = 6710,
  [7504] = 6716,
  [7505] = 6830,
  [7506] = 6767,
  [7507] = 7507,
  [7508] = 6718,
  [7509] = 7381,
  [7510] = 7381,
  [7511] = 7381,
  [7512] = 7381,
  [7513] = 7381,
  [7514] = 7381,
  [7515] = 7381,
  [7516] = 7381,
  [7517] = 7381,
  [7518] = 7381,
  [7519] = 7381,
  [7520] = 7381,
  [7521] = 7381,
  [7522] = 7381,
  [7523] = 7381,
  [7524] = 7381,
  [7525] = 7381,
  [7526] = 7381,
  [7527] = 7381,
  [7528] = 7381,
  [7529] = 7381,
  [7530] = 7381,
  [7531] = 7381,
  [7532] = 7381,
  [7533] = 7381,
  [7534] = 7381,
  [7535] = 7381,
  [7536] = 7381,
  [7537] = 7381,
  [7538] = 7381,
  [7539] = 7381,
  [7540] = 7381,
  [7541] = 7381,
  [7542] = 7381,
  [7543] = 7381,
  [7544] = 7381,
  [7545] = 7381,
  [7546] = 7381,
  [7547] = 7381,
  [7548] = 7381,
  [7549] = 7381,
  [7550] = 7381,
  [7551] = 7381,
  [7552] = 7381,
  [7553] = 7381,
  [7554] = 7381,
  [7555] = 7381,
  [7556] = 7381,
  [7557] = 7381,
  [7558] = 7381,
  [7559] = 7381,
  [7560] = 7381,
  [7561] = 7381,
  [7562] = 7381,
  [7563] = 7381,
  [7564] = 7381,
  [7565] = 7381,
  [7566] = 7381,
  [7567] = 7381,
  [7568] = 7381,
  [7569] = 7381,
  [7570] = 6716,
};

static const TSSymbol ts_supertype_symbols[SUPERTYPE_COUNT] = {
  sym__expression,
};

static const TSMapSlice ts_supertype_map_slices[] = {
  [sym__expression] = {.index = 0, .length = 7},
};

static const TSSymbol ts_supertype_map_entries[] = {
  [0] =
    sym_binary_expression,
    sym_concatenation,
    sym_parenthesized_expression,
    sym_postfix_expression,
    sym_ternary_expression,
    sym_unary_expression,
    sym_word,
};

static const TSCharacterRange sym__comment_word_character_set_1[] = {
  {0, 0x08}, {0x0e, 0x1f}, {'!', '!'}, {'#', '#'}, {'%', '%'}, {'*', ':'}, {'=', '='}, {'?', 'Z'},
  {'\\', '\\'}, {'^', '_'}, {'a', 'z'}, {'~', 0x10ffff},
};

static const TSCharacterRange sym_word_character_set_1[] = {
  {0, 0x08}, {0x0e, 0x1f}, {'!', '!'}, {'%', '%'}, {'*', ':'}, {'=', '='}, {'?', 'Z'}, {'\\', '\\'},
  {'^', '_'}, {'a', 'z'}, {'~', 0x10ffff},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '!', 815,
        '"', 783,
        '#', 820,
        '$', 776,
        '%', 641,
        '&', 595,
        '\'', 485,
        '(', 648,
        ')', 649,
        '*', 819,
        '+', 764,
        ',', 551,
        '-', 762,
        '.', 940,
        '/', 636,
        ':', 757,
        ';', 548,
        '<', 601,
        '=', 822,
        '>', 610,
        '?', 832,
        '@', 817,
        '[', 668,
        '\\', 298,
        ']', 669,
        '^', 589,
        '_', 937,
        '`', 851,
        'e', 947,
        'i', 946,
        '{', 660,
        '|', 586,
        '}', 773,
        '~', 766,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(539);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(769);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(397);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(412);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(413);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(414);
      END_STATE();
    case 5:
      if (lookahead == '\n') SKIP(6);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '\n', 682,
        '!', 664,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        ')', 649,
        '*', 632,
        '+', 765,
        '-', 763,
        '/', 638,
        '0', 797,
        ';', 549,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '\\', 304,
        '^', 590,
        '`', 851,
        '|', 586,
        '~', 766,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 7:
      if (lookahead == '\n') SKIP(399);
      END_STATE();
    case 8:
      if (lookahead == '\n') SKIP(415);
      END_STATE();
    case 9:
      if (lookahead == '\n') SKIP(416);
      END_STATE();
    case 10:
      if (lookahead == '\n') SKIP(400);
      END_STATE();
    case 11:
      if (lookahead == '\n') SKIP(401);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '\n', 683,
        '!', 664,
        '"', 783,
        '#', 811,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        ')', 649,
        '*', 632,
        '+', 624,
        '-', 627,
        '/', 638,
        '0', 801,
        ';', 549,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '@', 936,
        '\\', 14,
        '^', 590,
        '_', 938,
        '`', 850,
        '|', 586,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 13:
      if (lookahead == '\n') ADVANCE(875);
      END_STATE();
    case 14:
      if (lookahead == '\n') ADVANCE(875);
      if (lookahead == '\r') ADVANCE(13);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(12);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 15:
      if (lookahead == '\n') ADVANCE(934);
      END_STATE();
    case 16:
      if (lookahead == '\n') ADVANCE(934);
      if (lookahead == '\r') ADVANCE(15);
      END_STATE();
    case 17:
      if (lookahead == '\n') ADVANCE(934);
      if (lookahead == '\r') ADVANCE(15);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(949);
      END_STATE();
    case 18:
      if (lookahead == '\n') ADVANCE(913);
      END_STATE();
    case 19:
      if (lookahead == '\n') ADVANCE(913);
      if (lookahead == '\r') ADVANCE(18);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(398);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 20:
      if (lookahead == '\n') SKIP(156);
      END_STATE();
    case 21:
      if (lookahead == '\n') SKIP(420);
      END_STATE();
    case 22:
      if (lookahead == '\n') SKIP(417);
      END_STATE();
    case 23:
      if (lookahead == '\n') SKIP(236);
      END_STATE();
    case 24:
      if (lookahead == '\n') SKIP(239);
      END_STATE();
    case 25:
      if (lookahead == '\n') SKIP(242);
      END_STATE();
    case 26:
      if (lookahead == '\n') SKIP(245);
      END_STATE();
    case 27:
      if (lookahead == '\n') ADVANCE(877);
      END_STATE();
    case 28:
      if (lookahead == '\n') ADVANCE(877);
      if (lookahead == '\r') ADVANCE(27);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(216);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 29:
      if (lookahead == '\n') ADVANCE(879);
      END_STATE();
    case 30:
      if (lookahead == '\n') ADVANCE(879);
      if (lookahead == '\r') ADVANCE(29);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(235);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 31:
      if (lookahead == '\n') ADVANCE(881);
      END_STATE();
    case 32:
      if (lookahead == '\n') ADVANCE(881);
      if (lookahead == '\r') ADVANCE(31);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(238);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 33:
      if (lookahead == '\n') SKIP(248);
      END_STATE();
    case 34:
      if (lookahead == '\n') SKIP(251);
      END_STATE();
    case 35:
      if (lookahead == '\n') ADVANCE(883);
      END_STATE();
    case 36:
      if (lookahead == '\n') ADVANCE(883);
      if (lookahead == '\r') ADVANCE(35);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(241);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 37:
      if (lookahead == '\n') SKIP(254);
      END_STATE();
    case 38:
      if (lookahead == '\n') ADVANCE(887);
      END_STATE();
    case 39:
      if (lookahead == '\n') ADVANCE(887);
      if (lookahead == '\r') ADVANCE(38);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(247);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 40:
      if (lookahead == '\n') ADVANCE(891);
      END_STATE();
    case 41:
      if (lookahead == '\n') ADVANCE(891);
      if (lookahead == '\r') ADVANCE(40);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(253);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 42:
      if (lookahead == '\n') SKIP(257);
      END_STATE();
    case 43:
      if (lookahead == '\n') SKIP(451);
      END_STATE();
    case 44:
      if (lookahead == '\n') SKIP(260);
      END_STATE();
    case 45:
      if (lookahead == '\n') SKIP(455);
      END_STATE();
    case 46:
      if (lookahead == '\n') ADVANCE(893);
      END_STATE();
    case 47:
      if (lookahead == '\n') ADVANCE(893);
      if (lookahead == '\r') ADVANCE(46);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(256);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 48:
      if (lookahead == '\n') ADVANCE(895);
      END_STATE();
    case 49:
      if (lookahead == '\n') ADVANCE(895);
      if (lookahead == '\r') ADVANCE(48);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(259);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 50:
      if (lookahead == '\n') SKIP(269);
      END_STATE();
    case 51:
      if (lookahead == '\n') ADVANCE(901);
      END_STATE();
    case 52:
      if (lookahead == '\n') ADVANCE(901);
      if (lookahead == '\r') ADVANCE(51);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(268);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 53:
      if (lookahead == '\n') ADVANCE(904);
      END_STATE();
    case 54:
      if (lookahead == '\n') ADVANCE(904);
      if (lookahead == '\r') ADVANCE(53);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(273);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 55:
      if (lookahead == '\n') SKIP(464);
      END_STATE();
    case 56:
      if (lookahead == '\n') ADVANCE(915);
      END_STATE();
    case 57:
      if (lookahead == '\n') ADVANCE(915);
      if (lookahead == '\r') ADVANCE(56);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(405);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 58:
      if (lookahead == '\n') ADVANCE(907);
      END_STATE();
    case 59:
      if (lookahead == '\n') ADVANCE(907);
      if (lookahead == '\r') ADVANCE(58);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(279);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 60:
      if (lookahead == '\n') SKIP(458);
      END_STATE();
    case 61:
      if (lookahead == '\n') ADVANCE(916);
      END_STATE();
    case 62:
      if (lookahead == '\n') ADVANCE(916);
      if (lookahead == '\r') ADVANCE(61);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(406);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 63:
      if (lookahead == '\n') SKIP(454);
      END_STATE();
    case 64:
      if (lookahead == '\n') ADVANCE(917);
      END_STATE();
    case 65:
      if (lookahead == '\n') ADVANCE(917);
      if (lookahead == '\r') ADVANCE(64);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(407);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 66:
      if (lookahead == '\n') SKIP(452);
      END_STATE();
    case 67:
      if (lookahead == '\n') ADVANCE(908);
      END_STATE();
    case 68:
      if (lookahead == '\n') ADVANCE(908);
      if (lookahead == '\r') ADVANCE(67);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(281);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 69:
      if (lookahead == '\n') ADVANCE(924);
      END_STATE();
    case 70:
      if (lookahead == '\n') ADVANCE(924);
      if (lookahead == '\r') ADVANCE(69);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(424);
      END_STATE();
    case 71:
      if (lookahead == '\n') ADVANCE(923);
      END_STATE();
    case 72:
      if (lookahead == '\n') ADVANCE(923);
      if (lookahead == '\r') ADVANCE(71);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(423);
      END_STATE();
    case 73:
      if (lookahead == '\n') SKIP(460);
      END_STATE();
    case 74:
      if (lookahead == '\n') SKIP(428);
      END_STATE();
    case 75:
      if (lookahead == '\n') ADVANCE(918);
      END_STATE();
    case 76:
      if (lookahead == '\n') ADVANCE(918);
      if (lookahead == '\r') ADVANCE(75);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(408);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 77:
      if (lookahead == '\n') ADVANCE(922);
      END_STATE();
    case 78:
      if (lookahead == '\n') ADVANCE(922);
      if (lookahead == '\r') ADVANCE(77);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(422);
      END_STATE();
    case 79:
      if (lookahead == '\n') SKIP(418);
      END_STATE();
    case 80:
      if (lookahead == '\n') SKIP(429);
      END_STATE();
    case 81:
      if (lookahead == '\n') ADVANCE(926);
      END_STATE();
    case 82:
      if (lookahead == '\n') ADVANCE(926);
      if (lookahead == '\r') ADVANCE(81);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(426);
      END_STATE();
    case 83:
      if (lookahead == '\n') SKIP(419);
      END_STATE();
    case 84:
      if (lookahead == '\n') SKIP(431);
      END_STATE();
    case 85:
      if (lookahead == '\n') SKIP(437);
      END_STATE();
    case 86:
      if (lookahead == '\n') ADVANCE(914);
      END_STATE();
    case 87:
      if (lookahead == '\n') ADVANCE(914);
      if (lookahead == '\r') ADVANCE(86);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(404);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 88:
      if (lookahead == '\n') SKIP(432);
      END_STATE();
    case 89:
      if (lookahead == '\n') SKIP(294);
      END_STATE();
    case 90:
      if (lookahead == '\n') SKIP(434);
      END_STATE();
    case 91:
      if (lookahead == '\n') SKIP(92);
      END_STATE();
    case 92:
      ADVANCE_MAP(
        '\n', 684,
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        ',', 550,
        '-', 629,
        '/', 639,
        ';', 547,
        '<', 609,
        '=', 555,
        '>', 614,
      );
      if (lookahead == '\\') SKIP(361);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '|') ADVANCE(588);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(92);
      END_STATE();
    case 93:
      ADVANCE_MAP(
        '\n', 684,
        '"', 783,
        '#', 857,
        '$', 780,
        '&', 593,
        '(', 647,
        '+', 494,
        ',', 550,
        '-', 496,
        '0', 804,
        ';', 547,
      );
      if (lookahead == '\\') SKIP(375);
      if (lookahead == '`') ADVANCE(850);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(93);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(806);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(650);
      END_STATE();
    case 94:
      ADVANCE_MAP(
        '\n', 684,
        '#', 857,
        '$', 778,
        '&', 483,
        '(', 647,
        '-', 498,
        '0', 803,
        ':', 756,
        '<', 605,
        '>', 612,
      );
      if (lookahead == '\\') SKIP(385);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '|') ADVANCE(510);
      if (lookahead == '}') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(94);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(805);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 95:
      if (lookahead == '\n') ADVANCE(684);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(596);
      if (lookahead == ';') ADVANCE(548);
      if (lookahead == '<') ADVANCE(606);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(374);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == 'e') ADVANCE(508);
      if (lookahead == '|') ADVANCE(587);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(95);
      END_STATE();
    case 96:
      if (lookahead == '\n') ADVANCE(684);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(596);
      if (lookahead == ';') ADVANCE(548);
      if (lookahead == '<') ADVANCE(607);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(376);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == 'e') ADVANCE(508);
      if (lookahead == '|') ADVANCE(587);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(96);
      END_STATE();
    case 97:
      if (lookahead == '\n') ADVANCE(684);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(483);
      if (lookahead == '<') ADVANCE(605);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(386);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '|') ADVANCE(510);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(97);
      END_STATE();
    case 98:
      if (lookahead == '\n') ADVANCE(684);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(593);
      if (lookahead == ';') ADVANCE(549);
      if (lookahead == '\\') SKIP(389);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == 'i') ADVANCE(507);
      if (('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(98);
      END_STATE();
    case 99:
      if (lookahead == '\n') ADVANCE(876);
      END_STATE();
    case 100:
      if (lookahead == '\n') ADVANCE(876);
      if (lookahead == '\r') ADVANCE(99);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(202);
      END_STATE();
    case 101:
      if (lookahead == '\n') SKIP(436);
      END_STATE();
    case 102:
      if (lookahead == '\n') SKIP(433);
      END_STATE();
    case 103:
      if (lookahead == '\n') ADVANCE(880);
      END_STATE();
    case 104:
      if (lookahead == '\n') ADVANCE(880);
      if (lookahead == '\r') ADVANCE(103);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(237);
      END_STATE();
    case 105:
      if (lookahead == '\n') ADVANCE(882);
      END_STATE();
    case 106:
      if (lookahead == '\n') ADVANCE(882);
      if (lookahead == '\r') ADVANCE(105);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(240);
      END_STATE();
    case 107:
      if (lookahead == '\n') SKIP(466);
      END_STATE();
    case 108:
      if (lookahead == '\n') ADVANCE(888);
      END_STATE();
    case 109:
      if (lookahead == '\n') ADVANCE(888);
      if (lookahead == '\r') ADVANCE(108);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(249);
      END_STATE();
    case 110:
      if (lookahead == '\n') SKIP(296);
      END_STATE();
    case 111:
      if (lookahead == '\n') SKIP(476);
      END_STATE();
    case 112:
      if (lookahead == '\n') SKIP(467);
      END_STATE();
    case 113:
      if (lookahead == '\n') SKIP(472);
      END_STATE();
    case 114:
      if (lookahead == '\n') ADVANCE(911);
      END_STATE();
    case 115:
      if (lookahead == '\n') ADVANCE(911);
      if (lookahead == '\r') ADVANCE(114);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(287);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 116:
      if (lookahead == '\n') SKIP(445);
      END_STATE();
    case 117:
      if (lookahead == '\n') ADVANCE(927);
      END_STATE();
    case 118:
      if (lookahead == '\n') ADVANCE(927);
      if (lookahead == '\r') ADVANCE(117);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(438);
      END_STATE();
    case 119:
      if (lookahead == '\n') ADVANCE(896);
      END_STATE();
    case 120:
      if (lookahead == '\n') ADVANCE(896);
      if (lookahead == '\r') ADVANCE(119);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(261);
      END_STATE();
    case 121:
      if (lookahead == '\n') ADVANCE(928);
      END_STATE();
    case 122:
      if (lookahead == '\n') ADVANCE(928);
      if (lookahead == '\r') ADVANCE(121);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(439);
      END_STATE();
    case 123:
      if (lookahead == '\n') ADVANCE(921);
      END_STATE();
    case 124:
      if (lookahead == '\n') ADVANCE(921);
      if (lookahead == '\r') ADVANCE(123);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(411);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 125:
      if (lookahead == '\n') SKIP(473);
      END_STATE();
    case 126:
      if (lookahead == '\n') ADVANCE(912);
      END_STATE();
    case 127:
      if (lookahead == '\n') ADVANCE(912);
      if (lookahead == '\r') ADVANCE(126);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(289);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 128:
      if (lookahead == '\n') SKIP(95);
      END_STATE();
    case 129:
      if (lookahead == '\n') SKIP(93);
      END_STATE();
    case 130:
      if (lookahead == '\n') SKIP(468);
      END_STATE();
    case 131:
      if (lookahead == '\n') SKIP(448);
      END_STATE();
    case 132:
      if (lookahead == '\n') SKIP(480);
      END_STATE();
    case 133:
      if (lookahead == '\n') SKIP(477);
      END_STATE();
    case 134:
      if (lookahead == '\n') SKIP(478);
      END_STATE();
    case 135:
      if (lookahead == '\n') SKIP(469);
      END_STATE();
    case 136:
      if (lookahead == '\n') SKIP(481);
      END_STATE();
    case 137:
      if (lookahead == '\n') SKIP(94);
      END_STATE();
    case 138:
      if (lookahead == '\n') SKIP(97);
      END_STATE();
    case 139:
      if (lookahead == '\n') ADVANCE(902);
      END_STATE();
    case 140:
      if (lookahead == '\n') ADVANCE(902);
      if (lookahead == '\r') ADVANCE(139);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(270);
      END_STATE();
    case 141:
      if (lookahead == '\n') ADVANCE(931);
      END_STATE();
    case 142:
      if (lookahead == '\n') ADVANCE(931);
      if (lookahead == '\r') ADVANCE(141);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(442);
      END_STATE();
    case 143:
      if (lookahead == '\n') SKIP(449);
      END_STATE();
    case 144:
      if (lookahead == '\n') ADVANCE(788);
      if (lookahead == '\r') ADVANCE(785);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(788);
      if (lookahead != 0) ADVANCE(792);
      END_STATE();
    case 145:
      if (lookahead == '\n') ADVANCE(932);
      END_STATE();
    case 146:
      if (lookahead == '\n') ADVANCE(932);
      if (lookahead == '\r') ADVANCE(145);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(444);
      END_STATE();
    case 147:
      if (lookahead == '\n') ADVANCE(789);
      if (lookahead == '\r') ADVANCE(786);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(789);
      if (lookahead != 0) ADVANCE(792);
      END_STATE();
    case 148:
      if (lookahead == '\n') SKIP(479);
      END_STATE();
    case 149:
      if (lookahead == '\n') ADVANCE(933);
      END_STATE();
    case 150:
      if (lookahead == '\n') ADVANCE(933);
      if (lookahead == '\r') ADVANCE(149);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(447);
      END_STATE();
    case 151:
      if (lookahead == '\n') SKIP(98);
      END_STATE();
    case 152:
      if (lookahead == '\n') SKIP(470);
      END_STATE();
    case 153:
      if (lookahead == '\n') SKIP(471);
      END_STATE();
    case 154:
      if (lookahead == '\n') SKIP(482);
      END_STATE();
    case 155:
      if (lookahead == '\n') SKIP(402);
      END_STATE();
    case 156:
      ADVANCE_MAP(
        '\n', 685,
        '!', 942,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        ')', 649,
        '*', 632,
        '+', 624,
        '-', 627,
        '/', 638,
        '0', 797,
        ';', 549,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '\\', 312,
        '^', 590,
        '`', 851,
        '|', 586,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(156);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 157:
      if (lookahead == '\n') SKIP(233);
      END_STATE();
    case 158:
      if (lookahead == '\n') SKIP(421);
      END_STATE();
    case 159:
      if (lookahead == '\n') SKIP(274);
      END_STATE();
    case 160:
      if (lookahead == '\n') SKIP(276);
      END_STATE();
    case 161:
      if (lookahead == '\n') SKIP(278);
      END_STATE();
    case 162:
      if (lookahead == '\n') SKIP(282);
      END_STATE();
    case 163:
      if (lookahead == '\n') ADVANCE(885);
      END_STATE();
    case 164:
      if (lookahead == '\n') ADVANCE(885);
      if (lookahead == '\r') ADVANCE(163);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(244);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 165:
      if (lookahead == '\n') SKIP(286);
      END_STATE();
    case 166:
      if (lookahead == '\n') SKIP(291);
      END_STATE();
    case 167:
      if (lookahead == '\n') ADVANCE(889);
      END_STATE();
    case 168:
      if (lookahead == '\n') ADVANCE(889);
      if (lookahead == '\r') ADVANCE(167);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(250);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 169:
      if (lookahead == '\n') SKIP(280);
      END_STATE();
    case 170:
      if (lookahead == '\n') SKIP(284);
      END_STATE();
    case 171:
      if (lookahead == '\n') SKIP(290);
      END_STATE();
    case 172:
      if (lookahead == '\n') SKIP(456);
      END_STATE();
    case 173:
      if (lookahead == '\n') ADVANCE(899);
      END_STATE();
    case 174:
      if (lookahead == '\n') ADVANCE(899);
      if (lookahead == '\r') ADVANCE(173);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(265);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 175:
      if (lookahead == '\n') SKIP(295);
      END_STATE();
    case 176:
      if (lookahead == '\n') SKIP(465);
      END_STATE();
    case 177:
      if (lookahead == '\n') SKIP(459);
      END_STATE();
    case 178:
      if (lookahead == '\n') SKIP(457);
      END_STATE();
    case 179:
      if (lookahead == '\n') ADVANCE(910);
      END_STATE();
    case 180:
      if (lookahead == '\n') ADVANCE(910);
      if (lookahead == '\r') ADVANCE(179);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(285);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 181:
      if (lookahead == '\n') ADVANCE(925);
      END_STATE();
    case 182:
      if (lookahead == '\n') ADVANCE(925);
      if (lookahead == '\r') ADVANCE(181);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(425);
      END_STATE();
    case 183:
      if (lookahead == '\n') SKIP(462);
      END_STATE();
    case 184:
      if (lookahead == '\n') ADVANCE(878);
      END_STATE();
    case 185:
      if (lookahead == '\n') ADVANCE(878);
      if (lookahead == '\r') ADVANCE(184);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(234);
      END_STATE();
    case 186:
      if (lookahead == '\n') SKIP(430);
      END_STATE();
    case 187:
      if (lookahead == '\n') ADVANCE(884);
      END_STATE();
    case 188:
      if (lookahead == '\n') ADVANCE(884);
      if (lookahead == '\r') ADVANCE(187);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(243);
      END_STATE();
    case 189:
      if (lookahead == '\n') ADVANCE(894);
      END_STATE();
    case 190:
      if (lookahead == '\n') ADVANCE(894);
      if (lookahead == '\r') ADVANCE(189);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(258);
      END_STATE();
    case 191:
      if (lookahead == '\n') ADVANCE(890);
      END_STATE();
    case 192:
      if (lookahead == '\n') ADVANCE(890);
      if (lookahead == '\r') ADVANCE(191);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(252);
      END_STATE();
    case 193:
      if (lookahead == '\n') SKIP(297);
      END_STATE();
    case 194:
      if (lookahead == '\n') ADVANCE(929);
      END_STATE();
    case 195:
      if (lookahead == '\n') ADVANCE(929);
      if (lookahead == '\r') ADVANCE(194);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(440);
      END_STATE();
    case 196:
      if (lookahead == '\n') ADVANCE(898);
      END_STATE();
    case 197:
      if (lookahead == '\n') ADVANCE(898);
      if (lookahead == '\r') ADVANCE(196);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(264);
      END_STATE();
    case 198:
      if (lookahead == '\n') ADVANCE(930);
      END_STATE();
    case 199:
      if (lookahead == '\n') ADVANCE(930);
      if (lookahead == '\r') ADVANCE(198);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(441);
      END_STATE();
    case 200:
      if (lookahead == '\n') SKIP(96);
      END_STATE();
    case 201:
      if (lookahead == '\n') SKIP(403);
      END_STATE();
    case 202:
      ADVANCE_MAP(
        '\n', 686,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 548,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 100,
        '_', 939,
        'e', 872,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(202);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 203:
      if (lookahead == '\n') SKIP(288);
      END_STATE();
    case 204:
      if (lookahead == '\n') SKIP(292);
      END_STATE();
    case 205:
      if (lookahead == '\n') SKIP(293);
      END_STATE();
    case 206:
      if (lookahead == '\n') ADVANCE(905);
      END_STATE();
    case 207:
      if (lookahead == '\n') ADVANCE(905);
      if (lookahead == '\r') ADVANCE(206);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(275);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 208:
      if (lookahead == '\n') SKIP(461);
      END_STATE();
    case 209:
      if (lookahead == '\n') SKIP(453);
      END_STATE();
    case 210:
      if (lookahead == '\n') ADVANCE(886);
      END_STATE();
    case 211:
      if (lookahead == '\n') ADVANCE(886);
      if (lookahead == '\r') ADVANCE(210);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(246);
      END_STATE();
    case 212:
      if (lookahead == '\n') ADVANCE(900);
      END_STATE();
    case 213:
      if (lookahead == '\n') ADVANCE(900);
      if (lookahead == '\r') ADVANCE(212);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(267);
      END_STATE();
    case 214:
      if (lookahead == '\n') ADVANCE(892);
      END_STATE();
    case 215:
      if (lookahead == '\n') ADVANCE(892);
      if (lookahead == '\r') ADVANCE(214);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(255);
      END_STATE();
    case 216:
      ADVANCE_MAP(
        '\n', 687,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 28,
        '_', 938,
        '`', 850,
        'e', 866,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(216);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 217:
      if (lookahead == '\n') SKIP(263);
      END_STATE();
    case 218:
      if (lookahead == '\n') SKIP(266);
      END_STATE();
    case 219:
      if (lookahead == '\n') SKIP(272);
      END_STATE();
    case 220:
      if (lookahead == '\n') ADVANCE(897);
      END_STATE();
    case 221:
      if (lookahead == '\n') ADVANCE(897);
      if (lookahead == '\r') ADVANCE(220);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(262);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 222:
      if (lookahead == '\n') ADVANCE(903);
      END_STATE();
    case 223:
      if (lookahead == '\n') ADVANCE(903);
      if (lookahead == '\r') ADVANCE(222);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(271);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 224:
      if (lookahead == '\n') ADVANCE(906);
      END_STATE();
    case 225:
      if (lookahead == '\n') ADVANCE(906);
      if (lookahead == '\r') ADVANCE(224);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(277);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 226:
      if (lookahead == '\n') SKIP(463);
      END_STATE();
    case 227:
      if (lookahead == '\n') ADVANCE(919);
      END_STATE();
    case 228:
      if (lookahead == '\n') ADVANCE(919);
      if (lookahead == '\r') ADVANCE(227);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(409);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 229:
      if (lookahead == '\n') ADVANCE(909);
      END_STATE();
    case 230:
      if (lookahead == '\n') ADVANCE(909);
      if (lookahead == '\r') ADVANCE(229);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(283);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 231:
      if (lookahead == '\n') ADVANCE(920);
      END_STATE();
    case 232:
      if (lookahead == '\n') ADVANCE(920);
      if (lookahead == '\r') ADVANCE(231);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(410);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 233:
      ADVANCE_MAP(
        '\n', 688,
        '!', 942,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        ')', 649,
        '*', 632,
        '+', 624,
        '-', 627,
        '/', 638,
        '0', 797,
        ';', 549,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '\\', 313,
        '^', 590,
        '`', 850,
        '|', 586,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(233);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 234:
      ADVANCE_MAP(
        '\n', 689,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 548,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 185,
        '_', 939,
        'e', 872,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(234);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 235:
      ADVANCE_MAP(
        '\n', 690,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 30,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(235);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 236:
      ADVANCE_MAP(
        '\n', 691,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 317,
        '`', 850,
        'e', 947,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(236);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 237:
      ADVANCE_MAP(
        '\n', 692,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 548,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 104,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(237);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 238:
      ADVANCE_MAP(
        '\n', 693,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 32,
        '_', 938,
        '`', 850,
        'e', 866,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(238);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 239:
      ADVANCE_MAP(
        '\n', 694,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 318,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(239);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 240:
      ADVANCE_MAP(
        '\n', 695,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 106,
        '_', 939,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(240);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 241:
      ADVANCE_MAP(
        '\n', 696,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 36,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(241);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 242:
      ADVANCE_MAP(
        '\n', 697,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 319,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(242);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 243:
      ADVANCE_MAP(
        '\n', 698,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 548,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 188,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(243);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 244:
      ADVANCE_MAP(
        '\n', 699,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 164,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(244);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 245:
      ADVANCE_MAP(
        '\n', 700,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 798,
        ';', 548,
        '<', 604,
        '>', 611,
        '\\', 320,
        '`', 850,
        'e', 861,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(245);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 246:
      ADVANCE_MAP(
        '\n', 701,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 211,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(246);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 247:
      ADVANCE_MAP(
        '\n', 702,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 39,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(247);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 248:
      ADVANCE_MAP(
        '\n', 703,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 798,
        ';', 548,
        '<', 604,
        '>', 611,
        '\\', 321,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(248);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 249:
      ADVANCE_MAP(
        '\n', 704,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        ')', 649,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 109,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(249);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 250:
      ADVANCE_MAP(
        '\n', 705,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 168,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(250);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 251:
      ADVANCE_MAP(
        '\n', 706,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 798,
        ';', 549,
        '<', 604,
        '>', 611,
        '\\', 322,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(251);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 252:
      ADVANCE_MAP(
        '\n', 707,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        ')', 649,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 192,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(252);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 253:
      ADVANCE_MAP(
        '\n', 708,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 41,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(253);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 254:
      ADVANCE_MAP(
        '\n', 709,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 603,
        '>', 611,
        '\\', 323,
        '`', 850,
        'e', 947,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(254);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 255:
      ADVANCE_MAP(
        '\n', 710,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 215,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(255);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 256:
      ADVANCE_MAP(
        '\n', 711,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 47,
        '_', 938,
        '`', 850,
        'e', 866,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(256);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 257:
      ADVANCE_MAP(
        '\n', 712,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 603,
        '>', 611,
        '\\', 324,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(257);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 258:
      ADVANCE_MAP(
        '\n', 713,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 190,
        '_', 939,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(258);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 259:
      ADVANCE_MAP(
        '\n', 714,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 49,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(259);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 260:
      ADVANCE_MAP(
        '\n', 715,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 603,
        '>', 611,
        '\\', 326,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(260);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 261:
      ADVANCE_MAP(
        '\n', 716,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 120,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(261);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 262:
      ADVANCE_MAP(
        '\n', 717,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 221,
        '_', 938,
        '`', 850,
        'e', 866,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(262);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 263:
      ADVANCE_MAP(
        '\n', 718,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 604,
        '>', 611,
        '\\', 393,
        '`', 850,
        'e', 947,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(263);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 264:
      ADVANCE_MAP(
        '\n', 719,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 197,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(264);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 265:
      ADVANCE_MAP(
        '\n', 720,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 174,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(265);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 266:
      ADVANCE_MAP(
        '\n', 721,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 604,
        '>', 611,
        '\\', 394,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(266);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 267:
      ADVANCE_MAP(
        '\n', 722,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 605,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 213,
        '_', 939,
        '|', 510,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(267);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 268:
      ADVANCE_MAP(
        '\n', 723,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 52,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(268);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead)) ADVANCE(949);
      END_STATE();
    case 269:
      ADVANCE_MAP(
        '\n', 724,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 602,
        '>', 611,
        '\\', 328,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(269);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 270:
      ADVANCE_MAP(
        '\n', 725,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 593,
        '*', 631,
        '-', 626,
        ';', 549,
        '?', 754,
        '@', 935,
        '\\', 140,
        '_', 939,
        'i', 871,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(270);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 271:
      ADVANCE_MAP(
        '\n', 726,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 223,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(271);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 272:
      ADVANCE_MAP(
        '\n', 727,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 604,
        '>', 611,
        '\\', 395,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(272);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 273:
      ADVANCE_MAP(
        '\n', 728,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 54,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(273);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 274:
      ADVANCE_MAP(
        '\n', 729,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 330,
        '`', 851,
        'e', 947,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(274);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 275:
      ADVANCE_MAP(
        '\n', 730,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 207,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(275);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 276:
      ADVANCE_MAP(
        '\n', 731,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 332,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(276);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 277:
      ADVANCE_MAP(
        '\n', 732,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 225,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(277);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 278:
      ADVANCE_MAP(
        '\n', 733,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 334,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(278);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 279:
      ADVANCE_MAP(
        '\n', 734,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 59,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(279);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead)) ADVANCE(949);
      END_STATE();
    case 280:
      ADVANCE_MAP(
        '\n', 735,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 603,
        '>', 611,
        '\\', 336,
        '`', 851,
        'e', 947,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(280);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 281:
      ADVANCE_MAP(
        '\n', 736,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 68,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(281);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 282:
      ADVANCE_MAP(
        '\n', 737,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 798,
        ';', 548,
        '<', 604,
        '>', 611,
        '\\', 337,
        '`', 851,
        'e', 861,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(282);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 283:
      ADVANCE_MAP(
        '\n', 738,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 230,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(283);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 284:
      ADVANCE_MAP(
        '\n', 739,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 603,
        '>', 611,
        '\\', 341,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(284);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 285:
      ADVANCE_MAP(
        '\n', 740,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 602,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 180,
        '_', 938,
        '`', 850,
        '|', 510,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(285);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 286:
      ADVANCE_MAP(
        '\n', 741,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 798,
        ';', 548,
        '<', 604,
        '>', 611,
        '\\', 342,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(286);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 287:
      ADVANCE_MAP(
        '\n', 742,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 593,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 489,
        '>', 490,
        '?', 755,
        '@', 936,
        '\\', 115,
        '_', 938,
        '`', 850,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(287);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 288:
      ADVANCE_MAP(
        '\n', 743,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 604,
        '>', 611,
        '\\', 344,
        '`', 851,
        'e', 947,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(288);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 289:
      ADVANCE_MAP(
        '\n', 744,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 489,
        '>', 490,
        '?', 755,
        '@', 936,
        '\\', 127,
        '_', 938,
        '`', 850,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(289);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 290:
      ADVANCE_MAP(
        '\n', 745,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 603,
        '>', 611,
        '\\', 345,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(290);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 291:
      ADVANCE_MAP(
        '\n', 746,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 798,
        ';', 549,
        '<', 604,
        '>', 611,
        '\\', 346,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(291);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 292:
      ADVANCE_MAP(
        '\n', 747,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 548,
        '<', 604,
        '>', 611,
        '\\', 347,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(292);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 293:
      ADVANCE_MAP(
        '\n', 748,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 604,
        '>', 611,
        '\\', 349,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(293);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 294:
      ADVANCE_MAP(
        '\n', 749,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 593,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 489,
        '>', 490,
        '\\', 355,
        '`', 850,
        'e', 947,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(294);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 295:
      ADVANCE_MAP(
        '\n', 750,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 602,
        '>', 611,
        '\\', 365,
        '`', 851,
        '|', 510,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(295);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 296:
      ADVANCE_MAP(
        '\n', 751,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 593,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 489,
        '>', 490,
        '\\', 368,
        '`', 850,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(296);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 297:
      ADVANCE_MAP(
        '\n', 752,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 593,
        '\'', 485,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 489,
        '>', 490,
        '\\', 378,
        '`', 851,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(297);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 298:
      if (lookahead == '\r') SKIP(1);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(397);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 299:
      if (lookahead == '\r') ADVANCE(784);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(790);
      if (lookahead != 0) ADVANCE(792);
      END_STATE();
    case 300:
      if (lookahead == '\r') ADVANCE(793);
      if (lookahead != 0) ADVANCE(792);
      END_STATE();
    case 301:
      if (lookahead == '\r') SKIP(2);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(412);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 302:
      if (lookahead == '\r') SKIP(3);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(413);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 303:
      if (lookahead == '\r') SKIP(4);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(414);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 304:
      if (lookahead == '\r') SKIP(5);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(6);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 305:
      if (lookahead == '\r') SKIP(7);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(399);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 306:
      if (lookahead == '\r') SKIP(8);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(415);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 307:
      if (lookahead == '\r') SKIP(9);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(416);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 308:
      if (lookahead == '\r') SKIP(155);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(402);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 309:
      if (lookahead == '\r') SKIP(10);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(400);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 310:
      if (lookahead == '\r') SKIP(201);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(403);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 311:
      if (lookahead == '\r') SKIP(11);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(401);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 312:
      if (lookahead == '\r') SKIP(20);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(156);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 313:
      if (lookahead == '\r') SKIP(157);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(233);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 314:
      if (lookahead == '\r') SKIP(21);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(420);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 315:
      if (lookahead == '\r') SKIP(158);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(421);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 316:
      if (lookahead == '\r') SKIP(22);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(417);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 317:
      if (lookahead == '\r') SKIP(23);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(236);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 318:
      if (lookahead == '\r') SKIP(24);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(239);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 319:
      if (lookahead == '\r') SKIP(25);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(242);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 320:
      if (lookahead == '\r') SKIP(26);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(245);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 321:
      if (lookahead == '\r') SKIP(33);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(248);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 322:
      if (lookahead == '\r') SKIP(34);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(251);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 323:
      if (lookahead == '\r') SKIP(37);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(254);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 324:
      if (lookahead == '\r') SKIP(42);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(257);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 325:
      if (lookahead == '\r') SKIP(43);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(451);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 326:
      if (lookahead == '\r') SKIP(44);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(260);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 327:
      if (lookahead == '\r') SKIP(45);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(455);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 328:
      if (lookahead == '\r') SKIP(50);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(269);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 329:
      if (lookahead == '\r') SKIP(55);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(464);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 330:
      if (lookahead == '\r') SKIP(159);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(274);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 331:
      if (lookahead == '\r') SKIP(60);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(458);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 332:
      if (lookahead == '\r') SKIP(160);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(276);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 333:
      if (lookahead == '\r') SKIP(63);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(454);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 334:
      if (lookahead == '\r') SKIP(161);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(278);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 335:
      if (lookahead == '\r') SKIP(66);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(452);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 336:
      if (lookahead == '\r') SKIP(169);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(280);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 337:
      if (lookahead == '\r') SKIP(162);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(282);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 338:
      if (lookahead == '\r') SKIP(73);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(460);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 339:
      if (lookahead == '\r') SKIP(74);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(428);
      END_STATE();
    case 340:
      if (lookahead == '\r') SKIP(79);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(418);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 341:
      if (lookahead == '\r') SKIP(170);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(284);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 342:
      if (lookahead == '\r') SKIP(165);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(286);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 343:
      if (lookahead == '\r') SKIP(80);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(429);
      END_STATE();
    case 344:
      if (lookahead == '\r') SKIP(203);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(288);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 345:
      if (lookahead == '\r') SKIP(171);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(290);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 346:
      if (lookahead == '\r') SKIP(166);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(291);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 347:
      if (lookahead == '\r') SKIP(204);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(292);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 348:
      if (lookahead == '\r') SKIP(83);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(419);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 349:
      if (lookahead == '\r') SKIP(205);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(293);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 350:
      if (lookahead == '\r') SKIP(172);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(456);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 351:
      if (lookahead == '\r') SKIP(84);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(431);
      END_STATE();
    case 352:
      if (lookahead == '\r') SKIP(177);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(459);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 353:
      if (lookahead == '\r') SKIP(85);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(437);
      END_STATE();
    case 354:
      if (lookahead == '\r') SKIP(88);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(432);
      END_STATE();
    case 355:
      if (lookahead == '\r') SKIP(89);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(294);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 356:
      if (lookahead == '\r') SKIP(176);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(465);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 357:
      if (lookahead == '\r') SKIP(178);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(457);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 358:
      if (lookahead == '\r') SKIP(208);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(461);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 359:
      if (lookahead == '\r') SKIP(90);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(434);
      END_STATE();
    case 360:
      if (lookahead == '\r') SKIP(183);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(462);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 361:
      if (lookahead == '\r') SKIP(91);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(92);
      END_STATE();
    case 362:
      if (lookahead == '\r') SKIP(101);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(436);
      END_STATE();
    case 363:
      if (lookahead == '\r') SKIP(102);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(433);
      END_STATE();
    case 364:
      if (lookahead == '\r') SKIP(186);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(430);
      END_STATE();
    case 365:
      if (lookahead == '\r') SKIP(175);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(295);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 366:
      if (lookahead == '\r') SKIP(107);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(466);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 367:
      if (lookahead == '\r') SKIP(209);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(453);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 368:
      if (lookahead == '\r') SKIP(110);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(296);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 369:
      if (lookahead == '\r') SKIP(111);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(476);
      END_STATE();
    case 370:
      if (lookahead == '\r') SKIP(112);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(467);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 371:
      if (lookahead == '\r') SKIP(113);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(472);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 372:
      if (lookahead == '\r') SKIP(116);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(445);
      END_STATE();
    case 373:
      if (lookahead == '\r') SKIP(125);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(473);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 374:
      if (lookahead == '\r') SKIP(128);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(95);
      END_STATE();
    case 375:
      if (lookahead == '\r') SKIP(129);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(93);
      END_STATE();
    case 376:
      if (lookahead == '\r') SKIP(200);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(96);
      END_STATE();
    case 377:
      if (lookahead == '\r') SKIP(130);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(468);
      END_STATE();
    case 378:
      if (lookahead == '\r') SKIP(193);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(297);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 379:
      if (lookahead == '\r') SKIP(131);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(448);
      END_STATE();
    case 380:
      if (lookahead == '\r') SKIP(132);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(480);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 381:
      if (lookahead == '\r') SKIP(133);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(477);
      END_STATE();
    case 382:
      if (lookahead == '\r') SKIP(134);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(478);
      END_STATE();
    case 383:
      if (lookahead == '\r') SKIP(135);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(469);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 384:
      if (lookahead == '\r') SKIP(136);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(481);
      END_STATE();
    case 385:
      if (lookahead == '\r') SKIP(137);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(94);
      END_STATE();
    case 386:
      if (lookahead == '\r') SKIP(138);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(97);
      END_STATE();
    case 387:
      if (lookahead == '\r') SKIP(143);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(449);
      END_STATE();
    case 388:
      if (lookahead == '\r') SKIP(148);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(479);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 389:
      if (lookahead == '\r') SKIP(151);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(98);
      END_STATE();
    case 390:
      if (lookahead == '\r') SKIP(152);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(470);
      END_STATE();
    case 391:
      if (lookahead == '\r') SKIP(153);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(471);
      END_STATE();
    case 392:
      if (lookahead == '\r') SKIP(154);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(482);
      END_STATE();
    case 393:
      if (lookahead == '\r') SKIP(217);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(263);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 394:
      if (lookahead == '\r') SKIP(218);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(266);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 395:
      if (lookahead == '\r') SKIP(219);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(272);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 396:
      if (lookahead == '\r') SKIP(226);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(463);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 397:
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 811,
        '$', 776,
        '%', 641,
        '&', 595,
        '\'', 485,
        '(', 648,
        ')', 649,
        '*', 632,
        '+', 764,
        ',', 551,
        '-', 762,
        '/', 636,
        ':', 759,
        ';', 548,
        '<', 601,
        '=', 557,
        '>', 610,
        '?', 755,
        '@', 936,
        '[', 668,
        '\\', 298,
        ']', 669,
        '^', 589,
        '_', 937,
        '`', 851,
        'e', 947,
        'i', 946,
        '{', 660,
        '|', 586,
        '}', 813,
        '~', 766,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(397);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 398:
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 811,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        '*', 632,
        '+', 624,
        '-', 627,
        '/', 638,
        '0', 801,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '@', 936,
        '\\', 19,
        ']', 669,
        '^', 590,
        '_', 938,
        '`', 850,
        '|', 586,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(398);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < ' ' || '+' < lookahead) &&
          (lookahead < ';' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 399:
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        '*', 632,
        '+', 765,
        '-', 763,
        '/', 638,
        '0', 797,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '\\', 305,
        ']', 669,
        '^', 590,
        '`', 851,
        '|', 586,
        '~', 766,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(399);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < ' ' || '+' < lookahead) &&
          (lookahead < ';' || '?' < lookahead)) ADVANCE(949);
      END_STATE();
    case 400:
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 594,
        '\'', 485,
        '(', 647,
        ')', 649,
        '*', 632,
        '+', 765,
        '-', 763,
        '/', 638,
        '0', 797,
        '<', 608,
        '=', 554,
        '>', 613,
        '?', 755,
        '\\', 309,
        '^', 590,
        '`', 851,
        '|', 588,
        '~', 766,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(400);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < ';' || '?' < lookahead)) ADVANCE(949);
      END_STATE();
    case 401:
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 594,
        '\'', 485,
        '(', 647,
        '*', 632,
        '+', 765,
        '-', 763,
        '/', 638,
        '0', 797,
        ':', 759,
        '<', 608,
        '=', 554,
        '>', 613,
        '?', 755,
        '\\', 311,
        '^', 590,
        '`', 851,
        '|', 588,
        '~', 766,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(401);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < ' ' || '+' < lookahead) &&
          (lookahead < '/' || '?' < lookahead)) ADVANCE(949);
      END_STATE();
    case 402:
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 594,
        '\'', 485,
        '(', 647,
        '*', 632,
        '+', 765,
        '-', 763,
        '/', 638,
        '0', 797,
        '<', 608,
        '=', 554,
        '>', 613,
        '?', 755,
        '\\', 308,
        ']', 669,
        '^', 590,
        '`', 851,
        '|', 588,
        '~', 766,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(402);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < ' ' || '+' < lookahead) &&
          (lookahead < ';' || '?' < lookahead)) ADVANCE(949);
      END_STATE();
    case 403:
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 594,
        '\'', 485,
        '(', 647,
        '*', 632,
        '+', 765,
        '-', 763,
        '/', 638,
        '0', 797,
        '<', 608,
        '=', 554,
        '>', 613,
        '?', 755,
        '\\', 310,
        ']', 782,
        '^', 590,
        '`', 851,
        '|', 588,
        '~', 766,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(403);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < ' ' || '+' < lookahead) &&
          (lookahead < ';' || '?' < lookahead)) ADVANCE(949);
      END_STATE();
    case 404:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 502,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 602,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 87,
        '_', 938,
        '`', 850,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(404);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 405:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 57,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(405);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead)) ADVANCE(949);
      END_STATE();
    case 406:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 62,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(406);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead)) ADVANCE(949);
      END_STATE();
    case 407:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 65,
        ']', 669,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(407);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 408:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 76,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(408);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 409:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 228,
        ']', 669,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(409);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 410:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 232,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(410);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 411:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '\'', 485,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 489,
        '>', 490,
        '?', 755,
        '@', 936,
        '\\', 124,
        '_', 938,
        '`', 850,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(411);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 412:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        '(', 648,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 484,
        '<', 602,
        '>', 611,
        '[', 668,
        '\\', 301,
        '`', 850,
        '{', 660,
        '|', 584,
        ']', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(412);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 413:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        '(', 648,
        ')', 493,
        '+', 765,
        '-', 763,
        '0', 797,
        '<', 602,
        '>', 611,
        '[', 668,
        '\\', 302,
        '`', 850,
        '{', 660,
        '|', 585,
        '~', 766,
        ']', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(413);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 414:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        '(', 648,
        '+', 765,
        '-', 763,
        '0', 797,
        '<', 602,
        '>', 611,
        '[', 668,
        '\\', 303,
        ']', 669,
        '`', 850,
        '{', 660,
        '}', 781,
        '~', 766,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(414);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '~' < lookahead)) ADVANCE(949);
      END_STATE();
    case 415:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        '(', 648,
        '-', 941,
        '0', 797,
        ';', 484,
        '<', 602,
        '>', 611,
        '[', 668,
        '\\', 306,
        '`', 850,
        'e', 947,
        '{', 660,
        ']', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(415);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 416:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        '(', 648,
        '-', 941,
        '0', 797,
        '<', 602,
        '>', 611,
        '[', 668,
        '\\', 307,
        ']', 781,
        '`', 850,
        '{', 660,
        '}', 661,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(416);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 417:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        '(', 647,
        '+', 765,
        '-', 763,
        '0', 797,
        '<', 602,
        '>', 611,
        '[', 668,
        '\\', 316,
        '`', 850,
        '~', 766,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(417);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '~' < lookahead)) ADVANCE(949);
      END_STATE();
    case 418:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '\'', 485,
        '(', 648,
        '+', 765,
        '-', 763,
        '0', 797,
        '<', 489,
        '>', 490,
        '\\', 340,
        '`', 850,
        '{', 660,
        '~', 766,
        '[', 781,
        ']', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(418);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '~' < lookahead)) ADVANCE(949);
      END_STATE();
    case 419:
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '\'', 485,
        '(', 647,
        '+', 765,
        '-', 763,
        '0', 797,
        '<', 489,
        '>', 490,
        '\\', 348,
        '`', 850,
        '~', 766,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(419);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '~' < lookahead)) ADVANCE(949);
      END_STATE();
    case 420:
      ADVANCE_MAP(
        '!', 942,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        '*', 632,
        '+', 624,
        '-', 627,
        '/', 638,
        '0', 797,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '\\', 314,
        ']', 669,
        '^', 590,
        '`', 851,
        '|', 586,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(420);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < ' ' || '+' < lookahead) &&
          (lookahead < ';' || '?' < lookahead)) ADVANCE(949);
      END_STATE();
    case 421:
      ADVANCE_MAP(
        '!', 942,
        '"', 783,
        '#', 857,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        '*', 632,
        '+', 624,
        '-', 627,
        '/', 638,
        '0', 797,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '\\', 315,
        ']', 669,
        '^', 590,
        '`', 850,
        '|', 586,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(421);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < ' ' || '+' < lookahead) &&
          (lookahead < ';' || '?' < lookahead)) ADVANCE(949);
      END_STATE();
    case 422:
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        ')', 649,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 78,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(422);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 423:
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        ':', 756,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 72,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(423);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 424:
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 70,
        ']', 669,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(424);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 425:
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 182,
        ']', 503,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(425);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 426:
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 82,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(426);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 427:
      ADVANCE_MAP(
        '!', 500,
        '"', 783,
        '#', 857,
        '$', 780,
        '%', 644,
        '&', 594,
        ')', 649,
        '*', 633,
        '+', 625,
        ',', 550,
        '-', 628,
        '.', 497,
        '/', 639,
        ':', 756,
        ';', 484,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
      );
      if (lookahead == '\\') SKIP(339);
      if (lookahead == ']') ADVANCE(782);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == 'e') ADVANCE(508);
      if (lookahead == 'i') ADVANCE(507);
      if (lookahead == '|') ADVANCE(588);
      if (lookahead == '[' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(428);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(770);
      END_STATE();
    case 428:
      ADVANCE_MAP(
        '!', 500,
        '"', 783,
        '#', 857,
        '$', 780,
        '%', 644,
        '&', 594,
        ')', 649,
        '*', 633,
        '+', 625,
        ',', 550,
        '-', 628,
        '/', 639,
        ':', 756,
        ';', 484,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
      );
      if (lookahead == '\\') SKIP(339);
      if (lookahead == ']') ADVANCE(782);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == 'e') ADVANCE(508);
      if (lookahead == 'i') ADVANCE(507);
      if (lookahead == '|') ADVANCE(588);
      if (lookahead == '[' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(428);
      END_STATE();
    case 429:
      ADVANCE_MAP(
        '!', 500,
        '"', 783,
        '#', 857,
        '$', 492,
        '%', 644,
        '&', 594,
        '(', 488,
        ')', 493,
        '*', 633,
        '+', 625,
        ',', 550,
        '-', 628,
        '/', 639,
        ':', 756,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
      );
      if (lookahead == '\\') SKIP(343);
      if (lookahead == ']') ADVANCE(669);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '|') ADVANCE(588);
      if (lookahead == '[' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(429);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 430:
      ADVANCE_MAP(
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        ')', 649,
        '*', 633,
        '+', 625,
        ',', 550,
        '-', 629,
        '/', 639,
        '<', 609,
        '=', 555,
        '>', 614,
      );
      if (lookahead == '\\') SKIP(364);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '|') ADVANCE(588);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(430);
      END_STATE();
    case 431:
      ADVANCE_MAP(
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        ')', 649,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        ':', 756,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
      );
      if (lookahead == '\\') SKIP(351);
      if (lookahead == ']') ADVANCE(782);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '|') ADVANCE(588);
      if (lookahead == '[' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(431);
      END_STATE();
    case 432:
      ADVANCE_MAP(
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        ')', 649,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        ':', 756,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
      );
      if (lookahead == '\\') SKIP(354);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '|') ADVANCE(588);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(432);
      END_STATE();
    case 433:
      ADVANCE_MAP(
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        ')', 649,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '[', 667,
      );
      if (lookahead == '\\') SKIP(363);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '|') ADVANCE(588);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(433);
      END_STATE();
    case 434:
      ADVANCE_MAP(
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        ')', 493,
        '*', 633,
        '+', 625,
        ',', 550,
        '-', 628,
        '/', 639,
        ':', 756,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '[', 667,
      );
      if (lookahead == '\\') SKIP(359);
      if (lookahead == ']') ADVANCE(669);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '|') ADVANCE(588);
      if (lookahead == '}') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(434);
      END_STATE();
    case 435:
      ADVANCE_MAP(
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        ')', 493,
        '*', 633,
        '+', 625,
        ',', 550,
        '-', 629,
        '/', 639,
        '<', 609,
        '=', 555,
        '>', 614,
      );
      if (lookahead == '\\') SKIP(362);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '|') ADVANCE(588);
      if (lookahead == '}') ADVANCE(773);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(436);
      END_STATE();
    case 436:
      ADVANCE_MAP(
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        ')', 493,
        '*', 633,
        '+', 625,
        ',', 550,
        '-', 629,
        '/', 639,
        '<', 609,
        '=', 555,
        '>', 614,
      );
      if (lookahead == '\\') SKIP(362);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '|') ADVANCE(588);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(436);
      END_STATE();
    case 437:
      ADVANCE_MAP(
        '!', 500,
        '#', 857,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
      );
      if (lookahead == '\\') SKIP(353);
      if (lookahead == ']') ADVANCE(669);
      if (lookahead == '^') ADVANCE(591);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '|') ADVANCE(588);
      if (lookahead == '[' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(437);
      END_STATE();
    case 438:
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 118,
        ']', 669,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(438);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 439:
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 122,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 440:
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 195,
        ']', 669,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(440);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 441:
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 199,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(441);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 442:
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        ')', 649,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 142,
        '_', 939,
        '|', 584,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(442);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 443:
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 144,
        '_', 939,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(443);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(788);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      if (lookahead != 0 &&
          (lookahead < '_' || 'z' < lookahead)) ADVANCE(792);
      END_STATE();
    case 444:
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 146,
        '_', 939,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(444);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 445:
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 857,
        '$', 780,
        '&', 483,
        '\'', 485,
        '(', 647,
        '+', 765,
        '-', 763,
        '0', 803,
        '<', 606,
        '>', 612,
      );
      if (lookahead == '\\') SKIP(372);
      if (lookahead == ']') ADVANCE(669);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '|') ADVANCE(587);
      if (lookahead == '~') ADVANCE(766);
      if (lookahead == '[' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(445);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(805);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 446:
      ADVANCE_MAP(
        '!', 663,
        '#', 811,
        '$', 775,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 147,
        '_', 939,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(446);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(789);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      if (lookahead != 0 &&
          (lookahead < ' ' || '$' < lookahead) &&
          (lookahead < '_' || 'z' < lookahead)) ADVANCE(792);
      END_STATE();
    case 447:
      ADVANCE_MAP(
        '!', 663,
        '#', 811,
        '$', 775,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 150,
        '_', 939,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(447);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 448:
      if (lookahead == '!') ADVANCE(663);
      if (lookahead == '#') ADVANCE(811);
      if (lookahead == '$') ADVANCE(779);
      if (lookahead == '*') ADVANCE(631);
      if (lookahead == '-') ADVANCE(626);
      if (lookahead == '?') ADVANCE(754);
      if (lookahead == '@') ADVANCE(935);
      if (lookahead == '\\') SKIP(379);
      if (lookahead == '_') ADVANCE(939);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '}') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(448);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 449:
      if (lookahead == '!') ADVANCE(663);
      if (lookahead == '#') ADVANCE(811);
      if (lookahead == '$') ADVANCE(779);
      if (lookahead == '*') ADVANCE(631);
      if (lookahead == '-') ADVANCE(626);
      if (lookahead == '?') ADVANCE(754);
      if (lookahead == '@') ADVANCE(935);
      if (lookahead == '\\') SKIP(387);
      if (lookahead == '_') ADVANCE(939);
      if (lookahead == '`') ADVANCE(850);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(449);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 450:
      ADVANCE_MAP(
        '!', 814,
        '#', 820,
        '$', 779,
        '*', 631,
        '-', 626,
        '=', 821,
        '?', 754,
        '@', 935,
      );
      if (lookahead == '\\') SKIP(379);
      if (lookahead == '_') ADVANCE(939);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '}') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(448);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 451:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        '<', 602,
        '>', 611,
        '[', 668,
        '\\', 325,
        '`', 850,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(451);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 452:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        '<', 602,
        '>', 611,
        '\\', 335,
        '`', 850,
        '|', 584,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(452);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 453:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        '<', 602,
        '>', 611,
        '\\', 367,
        '`', 851,
        '|', 584,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(453);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 454:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '(', 647,
        ')', 649,
        '-', 941,
        '0', 797,
        '<', 603,
        '>', 611,
        '\\', 333,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(454);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 455:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 327,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(455);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          (lookahead < ';' || '>' < lookahead)) ADVANCE(949);
      END_STATE();
    case 456:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 350,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(456);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          (lookahead < ';' || '>' < lookahead)) ADVANCE(949);
      END_STATE();
    case 457:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        '<', 603,
        '>', 611,
        '\\', 357,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(457);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 458:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 603,
        '>', 611,
        '\\', 331,
        ']', 669,
        '`', 850,
        '|', 587,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(458);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 459:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 603,
        '>', 611,
        '\\', 352,
        ']', 669,
        '`', 851,
        '|', 587,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(459);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 460:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 604,
        '>', 611,
        '\\', 338,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(460);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 461:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 604,
        '>', 611,
        '\\', 358,
        ']', 669,
        '`', 851,
        '|', 587,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(461);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 462:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 604,
        '>', 611,
        '\\', 360,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(462);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 463:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 604,
        '>', 611,
        '\\', 396,
        ']', 669,
        '`', 850,
        '|', 587,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(463);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 464:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 798,
        '<', 604,
        '>', 611,
        '\\', 329,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(464);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 465:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 483,
        '\'', 485,
        '-', 941,
        '0', 798,
        '<', 604,
        '>', 611,
        '\\', 356,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(465);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 466:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        '<', 489,
        '>', 490,
        '\\', 366,
        '`', 850,
        'e', 947,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(466);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 467:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 776,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        '<', 489,
        '>', 490,
        '\\', 370,
        '`', 850,
        '}', 813,
        '[', 781,
        ']', 781,
        '{', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(467);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 468:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 780,
        '&', 483,
        '(', 647,
        ')', 493,
        '+', 495,
        '-', 496,
        '0', 804,
        '<', 607,
        '=', 553,
        '>', 612,
      );
      if (lookahead == '\\') SKIP(377);
      if (lookahead == ']') ADVANCE(669);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '|') ADVANCE(587);
      if (lookahead == '[' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(468);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(806);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(650);
      END_STATE();
    case 469:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 777,
        '\'', 485,
        '(', 647,
        ')', 649,
        '<', 489,
        '>', 490,
        '\\', 383,
        '`', 850,
        '|', 584,
        '}', 813,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(469);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '[' || ']' < lookahead) &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 470:
      ADVANCE_MAP(
        '"', 783,
        '#', 857,
        '$', 491,
        '%', 640,
        '*', 631,
        '+', 623,
        '-', 626,
        '/', 635,
        ':', 756,
      );
      if (lookahead == '\\') SKIP(390);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '}') ADVANCE(813);
      if (('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{') ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(470);
      END_STATE();
    case 471:
      if (lookahead == '"') ADVANCE(783);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '\'') ADVANCE(485);
      if (lookahead == ')') ADVANCE(649);
      if (lookahead == '\\') SKIP(391);
      if (lookahead == '}') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(837);
      END_STATE();
    case 472:
      ADVANCE_MAP(
        '"', 783,
        '#', 858,
        '$', 776,
        '\'', 485,
        '(', 647,
        '-', 941,
        '0', 797,
        '<', 489,
        '>', 490,
        '\\', 371,
        '`', 850,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(472);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 473:
      ADVANCE_MAP(
        '"', 783,
        '#', 858,
        '$', 776,
        '\'', 485,
        '-', 941,
        '0', 797,
        '<', 489,
        '>', 490,
        '\\', 373,
        ']', 669,
        '`', 850,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(473);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 474:
      if (lookahead == '"') ADVANCE(783);
      if (lookahead == '#') ADVANCE(791);
      if (lookahead == '$') ADVANCE(778);
      if (lookahead == '\\') ADVANCE(299);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(474);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(790);
      if (lookahead != 0) ADVANCE(792);
      END_STATE();
    case 475:
      ADVANCE_MAP(
        '#', 811,
        '%', 642,
        '*', 818,
        '+', 828,
        ',', 552,
        '-', 825,
        '/', 637,
        ':', 758,
        '=', 821,
        '?', 831,
        '@', 816,
        '[', 667,
      );
      if (lookahead == '\\') SKIP(369);
      if (lookahead == '^') ADVANCE(592);
      if (lookahead == '}') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(476);
      END_STATE();
    case 476:
      if (lookahead == '#') ADVANCE(811);
      if (lookahead == '%') ADVANCE(642);
      if (lookahead == ',') ADVANCE(552);
      if (lookahead == '/') ADVANCE(637);
      if (lookahead == ':') ADVANCE(756);
      if (lookahead == '[') ADVANCE(667);
      if (lookahead == '\\') SKIP(369);
      if (lookahead == '^') ADVANCE(592);
      if (lookahead == '}') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(476);
      END_STATE();
    case 477:
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '$') ADVANCE(509);
      if (lookahead == '&') ADVANCE(483);
      if (lookahead == '-') ADVANCE(498);
      if (lookahead == '0') ADVANCE(803);
      if (lookahead == '<') ADVANCE(607);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(381);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '|') ADVANCE(587);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(477);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(805);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 478:
      ADVANCE_MAP(
        '#', 857,
        '%', 640,
        '&', 483,
        '*', 631,
        '+', 623,
        '-', 626,
        '/', 635,
        '<', 606,
        '>', 612,
      );
      if (lookahead == '\\') SKIP(382);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '|') ADVANCE(587);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(478);
      END_STATE();
    case 479:
      ADVANCE_MAP(
        '#', 857,
        '&', 502,
        '(', 648,
        ';', 547,
        '<', 605,
        '>', 612,
        '[', 668,
        '\\', 388,
        '{', 660,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(479);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead) &&
          (lookahead < '&' || ')' < lookahead) &&
          (lookahead < '[' || ']' < lookahead) &&
          lookahead != '`' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 480:
      ADVANCE_MAP(
        '#', 857,
        '&', 483,
        '<', 606,
        '>', 612,
        '\\', 380,
        ']', 669,
        '`', 504,
        '|', 587,
        '[', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(480);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead) &&
          (lookahead < '&' || ')' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<') ADVANCE(949);
      END_STATE();
    case 481:
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(483);
      if (lookahead == '<') ADVANCE(607);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(384);
      if (lookahead == ']') ADVANCE(669);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '|') ADVANCE(587);
      if (lookahead == '[' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(481);
      END_STATE();
    case 482:
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '+') ADVANCE(501);
      if (lookahead == '/') ADVANCE(635);
      if (lookahead == '=') ADVANCE(553);
      if (lookahead == '[') ADVANCE(667);
      if (lookahead == '\\') SKIP(392);
      if (lookahead == '`') ADVANCE(504);
      if (lookahead == '}') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(482);
      END_STATE();
    case 483:
      if (lookahead == '&') ADVANCE(582);
      if (lookahead == '>') ADVANCE(674);
      END_STATE();
    case 484:
      if (lookahead == '&') ADVANCE(658);
      if (lookahead == ';') ADVANCE(657);
      END_STATE();
    case 485:
      if (lookahead == '\'') ADVANCE(794);
      if (lookahead != 0) ADVANCE(485);
      END_STATE();
    case 486:
      if (lookahead == '\'') ADVANCE(795);
      if (lookahead == '\\') ADVANCE(487);
      if (lookahead != 0) ADVANCE(486);
      END_STATE();
    case 487:
      if (lookahead == '\'') ADVANCE(796);
      if (lookahead == '\\') ADVANCE(487);
      if (lookahead != 0) ADVANCE(486);
      END_STATE();
    case 488:
      if (lookahead == '(') ADVANCE(545);
      END_STATE();
    case 489:
      if (lookahead == '(') ADVANCE(853);
      END_STATE();
    case 490:
      if (lookahead == '(') ADVANCE(854);
      END_STATE();
    case 491:
      if (lookahead == '(') ADVANCE(848);
      if (lookahead == '`') ADVANCE(852);
      END_STATE();
    case 492:
      if (lookahead == '(') ADVANCE(848);
      if (lookahead == '`') ADVANCE(852);
      if (lookahead == '{') ADVANCE(812);
      END_STATE();
    case 493:
      if (lookahead == ')') ADVANCE(546);
      END_STATE();
    case 494:
      if (lookahead == '+') ADVANCE(558);
      END_STATE();
    case 495:
      if (lookahead == '+') ADVANCE(558);
      if (lookahead == '=') ADVANCE(562);
      END_STATE();
    case 496:
      if (lookahead == '-') ADVANCE(560);
      if (lookahead == '0') ADVANCE(804);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(806);
      END_STATE();
    case 497:
      if (lookahead == '.') ADVANCE(771);
      END_STATE();
    case 498:
      if (lookahead == '0') ADVANCE(804);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(806);
      END_STATE();
    case 499:
      if (lookahead == '<') ADVANCE(753);
      END_STATE();
    case 500:
      if (lookahead == '=') ADVANCE(599);
      END_STATE();
    case 501:
      if (lookahead == '=') ADVANCE(562);
      END_STATE();
    case 502:
      if (lookahead == '>') ADVANCE(674);
      END_STATE();
    case 503:
      if (lookahead == ']') ADVANCE(671);
      END_STATE();
    case 504:
      if (lookahead == '`') ADVANCE(774);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(504);
      END_STATE();
    case 505:
      if (lookahead == 'a') ADVANCE(506);
      END_STATE();
    case 506:
      if (lookahead == 'c') ADVANCE(651);
      END_STATE();
    case 507:
      if (lookahead == 'n') ADVANCE(542);
      END_STATE();
    case 508:
      if (lookahead == 's') ADVANCE(505);
      END_STATE();
    case 509:
      if (lookahead == '{') ADVANCE(812);
      END_STATE();
    case 510:
      if (lookahead == '|') ADVANCE(580);
      END_STATE();
    case 511:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(806);
      END_STATE();
    case 512:
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(949);
      END_STATE();
    case 513:
      if (eof) ADVANCE(541);
      if (lookahead == '\n') ADVANCE(684);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(596);
      if (lookahead == ')') ADVANCE(649);
      if (lookahead == ';') ADVANCE(549);
      if (lookahead == '<') ADVANCE(606);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(535);
      if (lookahead == '`') ADVANCE(851);
      if (lookahead == '|') ADVANCE(587);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(513);
      END_STATE();
    case 514:
      if (eof) ADVANCE(541);
      if (lookahead == '\n') ADVANCE(684);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(596);
      if (lookahead == ')') ADVANCE(649);
      if (lookahead == ';') ADVANCE(549);
      if (lookahead == '<') ADVANCE(606);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(537);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '|') ADVANCE(587);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(514);
      END_STATE();
    case 515:
      if (eof) ADVANCE(541);
      if (lookahead == '\n') ADVANCE(684);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(596);
      if (lookahead == ')') ADVANCE(649);
      if (lookahead == ';') ADVANCE(549);
      if (lookahead == '<') ADVANCE(607);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(536);
      if (lookahead == '`') ADVANCE(851);
      if (lookahead == '|') ADVANCE(587);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(515);
      END_STATE();
    case 516:
      if (eof) ADVANCE(541);
      if (lookahead == '\n') ADVANCE(684);
      if (lookahead == '#') ADVANCE(857);
      if (lookahead == '&') ADVANCE(596);
      if (lookahead == ')') ADVANCE(649);
      if (lookahead == ';') ADVANCE(549);
      if (lookahead == '<') ADVANCE(607);
      if (lookahead == '>') ADVANCE(612);
      if (lookahead == '\\') SKIP(538);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '|') ADVANCE(587);
      if (('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(781);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(516);
      END_STATE();
    case 517:
      if (eof) ADVANCE(541);
      if (lookahead == '\n') SKIP(513);
      END_STATE();
    case 518:
      if (eof) ADVANCE(541);
      if (lookahead == '\n') SKIP(515);
      END_STATE();
    case 519:
      if (eof) ADVANCE(541);
      if (lookahead == '\n') SKIP(514);
      END_STATE();
    case 520:
      if (eof) ADVANCE(541);
      if (lookahead == '\n') SKIP(516);
      END_STATE();
    case 521:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 697,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 319,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(521);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 522:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 699,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 164,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(522);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 523:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 701,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 211,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(523);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 524:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 705,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 168,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(524);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 525:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 706,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 798,
        ';', 549,
        '<', 604,
        '>', 611,
        '\\', 322,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(525);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 526:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 710,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 215,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(526);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 527:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 715,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 603,
        '>', 611,
        '\\', 326,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(527);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 528:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 720,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 174,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(528);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 529:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 727,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 604,
        '>', 611,
        '\\', 395,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(529);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 530:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 730,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 207,
        '_', 938,
        '`', 850,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(530);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead)) ADVANCE(949);
      END_STATE();
    case 531:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 733,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '\\', 334,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(531);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 532:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 745,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 603,
        '>', 611,
        '\\', 345,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(532);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 533:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 746,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 798,
        ';', 549,
        '<', 604,
        '>', 611,
        '\\', 346,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(533);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 534:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '\n', 748,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 549,
        '<', 604,
        '>', 611,
        '\\', 349,
        '`', 851,
        '|', 587,
        '[', 781,
        ']', 781,
        '{', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(534);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0 &&
          (lookahead < '&' || ')' < lookahead)) ADVANCE(949);
      END_STATE();
    case 535:
      if (eof) ADVANCE(541);
      if (lookahead == '\r') SKIP(517);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(513);
      END_STATE();
    case 536:
      if (eof) ADVANCE(541);
      if (lookahead == '\r') SKIP(518);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(515);
      END_STATE();
    case 537:
      if (eof) ADVANCE(541);
      if (lookahead == '\r') SKIP(519);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(514);
      END_STATE();
    case 538:
      if (eof) ADVANCE(541);
      if (lookahead == '\r') SKIP(520);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(516);
      END_STATE();
    case 539:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 811,
        '$', 776,
        '%', 641,
        '&', 595,
        '\'', 485,
        '(', 648,
        ')', 649,
        '*', 632,
        '+', 764,
        ',', 551,
        '-', 762,
        '/', 636,
        ':', 759,
        ';', 548,
        '<', 601,
        '=', 557,
        '>', 610,
        '?', 755,
        '@', 936,
        '[', 668,
        '\\', 298,
        ']', 669,
        '^', 589,
        '_', 937,
        '`', 851,
        'e', 947,
        'i', 946,
        '{', 660,
        '|', 586,
        '}', 813,
        '~', 766,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(539);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 540:
      if (eof) ADVANCE(541);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 857,
        '$', 776,
        '&', 502,
        '\'', 485,
        '(', 648,
        ')', 649,
        '-', 941,
        '0', 797,
        ';', 484,
        '<', 602,
        '>', 611,
        '[', 668,
        '\\', 301,
        '`', 850,
        '{', 660,
        '|', 584,
        ']', 781,
        '}', 781,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(540);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if (lookahead != 0) ADVANCE(949);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(anon_sym_in);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_LPAREN_LPAREN);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_RPAREN_RPAREN);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_SEMI);
      if (lookahead == '&') ADVANCE(658);
      if (lookahead == ';') ADVANCE(657);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(anon_sym_SEMI);
      if (lookahead == ';') ADVANCE(656);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_COMMA);
      if (lookahead == ',') ADVANCE(845);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_COMMA);
      if (lookahead == ',') ADVANCE(844);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(598);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == '~') ADVANCE(673);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(597);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(597);
      if (lookahead == '~') ADVANCE(672);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_STAR_STAR_EQ);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_STAR_STAR_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_DASHo);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_DASHa);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '&') ADVANCE(662);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '&') ADVANCE(662);
      if (lookahead == '=') ADVANCE(579);
      if (lookahead == '|') ADVANCE(580);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '&') ADVANCE(662);
      if (lookahead == '|') ADVANCE(580);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(579);
      if (lookahead == '|') ADVANCE(580);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(578);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == '^') ADVANCE(847);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(578);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(577);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '^') ADVANCE(846);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(582);
      if (lookahead == '=') ADVANCE(576);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(582);
      if (lookahead == '=') ADVANCE(576);
      if (lookahead == '>') ADVANCE(674);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(582);
      if (lookahead == '>') ADVANCE(674);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '&') ADVANCE(676);
      if (lookahead == '(') ADVANCE(853);
      if (lookahead == '<') ADVANCE(619);
      if (lookahead == '=') ADVANCE(615);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '&') ADVANCE(676);
      if (lookahead == '(') ADVANCE(853);
      if (lookahead == '<') ADVANCE(499);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '&') ADVANCE(676);
      if (lookahead == '(') ADVANCE(853);
      if (lookahead == '<') ADVANCE(618);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '&') ADVANCE(676);
      if (lookahead == '(') ADVANCE(853);
      if (lookahead == '<') ADVANCE(617);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '&') ADVANCE(676);
      if (lookahead == '<') ADVANCE(499);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '&') ADVANCE(676);
      if (lookahead == '<') ADVANCE(618);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '&') ADVANCE(676);
      if (lookahead == '<') ADVANCE(617);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '(') ADVANCE(853);
      if (lookahead == '<') ADVANCE(620);
      if (lookahead == '=') ADVANCE(615);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(620);
      if (lookahead == '=') ADVANCE(615);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '&') ADVANCE(677);
      if (lookahead == '(') ADVANCE(854);
      if (lookahead == '=') ADVANCE(616);
      if (lookahead == '>') ADVANCE(622);
      if (lookahead == '|') ADVANCE(678);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '&') ADVANCE(677);
      if (lookahead == '(') ADVANCE(854);
      if (lookahead == '>') ADVANCE(621);
      if (lookahead == '|') ADVANCE(678);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '&') ADVANCE(677);
      if (lookahead == '>') ADVANCE(621);
      if (lookahead == '|') ADVANCE(678);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '(') ADVANCE(854);
      if (lookahead == '=') ADVANCE(616);
      if (lookahead == '>') ADVANCE(622);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(616);
      if (lookahead == '>') ADVANCE(622);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '-') ADVANCE(681);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '-') ADVANCE(681);
      if (lookahead == '<') ADVANCE(753);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '-') ADVANCE(681);
      if (lookahead == '<') ADVANCE(753);
      if (lookahead == '=') ADVANCE(574);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(574);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(575);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(559);
      if (lookahead == '=') ADVANCE(563);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(558);
      if (lookahead == '=') ADVANCE(562);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(561);
      if (lookahead == '0') ADVANCE(797);
      if (lookahead == '=') ADVANCE(565);
      if (lookahead == '\\') ADVANCE(512);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(560);
      if (lookahead == '=') ADVANCE(564);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(560);
      if (lookahead == '=') ADVANCE(564);
      if (lookahead == 'a') ADVANCE(583);
      if (lookahead == 'o') ADVANCE(581);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '0') ADVANCE(797);
      if (lookahead == '\\') ADVANCE(512);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(645);
      if (lookahead == '=') ADVANCE(567);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(646);
      if (lookahead == '=') ADVANCE(566);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '#') ADVANCE(841);
      if (lookahead == '%') ADVANCE(843);
      if (lookahead == '/') ADVANCE(839);
      if (lookahead == '=') ADVANCE(569);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym_word_character_set_1, 11, lookahead))) ADVANCE(949);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '#') ADVANCE(840);
      if (lookahead == '%') ADVANCE(842);
      if (lookahead == '/') ADVANCE(838);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '=') ADVANCE(569);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '=') ADVANCE(568);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '%') ADVANCE(836);
      if (lookahead == '=') ADVANCE(571);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '%') ADVANCE(835);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(571);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(570);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      if (lookahead == '=') ADVANCE(573);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      if (lookahead == '=') ADVANCE(572);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead == '(') ADVANCE(545);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(aux_sym__c_word_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(650);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(anon_sym_esac);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(anon_sym_esac);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(anon_sym_esac);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(anon_sym_esac);
      if (lookahead == '\\') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(anon_sym_esac);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(anon_sym_SEMI_SEMI);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(anon_sym_SEMI_SEMI);
      if (lookahead == '&') ADVANCE(659);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(anon_sym_SEMI_AMP);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(anon_sym_SEMI_SEMI_AMP);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(anon_sym_PIPE_AMP);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(600);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(599);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '[') ADVANCE(670);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(anon_sym_LBRACK_LBRACK);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(anon_sym_RBRACK_RBRACK);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(anon_sym_EQ_TILDE);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(anon_sym_EQ_TILDE);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(anon_sym_AMP_GT);
      if (lookahead == '>') ADVANCE(675);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(anon_sym_AMP_GT_GT);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(anon_sym_LT_AMP);
      if (lookahead == '-') ADVANCE(679);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(anon_sym_GT_AMP);
      if (lookahead == '-') ADVANCE(680);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(anon_sym_GT_PIPE);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(anon_sym_LT_AMP_DASH);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(anon_sym_GT_AMP_DASH);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(anon_sym_LT_LT_DASH);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(682);
      if (lookahead == '+') ADVANCE(765);
      if (lookahead == '-') ADVANCE(763);
      if (lookahead == '\\') ADVANCE(304);
      if (lookahead == '~') ADVANCE(766);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(683);
      if (lookahead == '\\') ADVANCE(14);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(684);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(685);
      if (lookahead == '\\') ADVANCE(312);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(686);
      if (lookahead == '\\') ADVANCE(100);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(687);
      if (lookahead == '\\') ADVANCE(28);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(688);
      if (lookahead == '\\') ADVANCE(313);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(689);
      if (lookahead == '\\') ADVANCE(185);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(690);
      if (lookahead == '\\') ADVANCE(30);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(691);
      if (lookahead == '\\') ADVANCE(317);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(692);
      if (lookahead == '\\') ADVANCE(104);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(693);
      if (lookahead == '\\') ADVANCE(32);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(694);
      if (lookahead == '\\') ADVANCE(318);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(695);
      if (lookahead == '\\') ADVANCE(106);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(696);
      if (lookahead == '\\') ADVANCE(36);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(697);
      if (lookahead == '\\') ADVANCE(319);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(698);
      if (lookahead == '\\') ADVANCE(188);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(699);
      if (lookahead == '\\') ADVANCE(164);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(700);
      if (lookahead == '\\') ADVANCE(320);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(701);
      if (lookahead == '\\') ADVANCE(211);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(702);
      if (lookahead == '\\') ADVANCE(39);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(703);
      if (lookahead == '\\') ADVANCE(321);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(704);
      if (lookahead == '\\') ADVANCE(109);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(705);
      if (lookahead == '\\') ADVANCE(168);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(706);
      if (lookahead == '\\') ADVANCE(322);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(192);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(708);
      if (lookahead == '\\') ADVANCE(41);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(709);
      if (lookahead == '\\') ADVANCE(323);
      END_STATE();
    case 710:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(710);
      if (lookahead == '\\') ADVANCE(215);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(711);
      if (lookahead == '\\') ADVANCE(47);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(712);
      if (lookahead == '\\') ADVANCE(324);
      END_STATE();
    case 713:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(713);
      if (lookahead == '\\') ADVANCE(190);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(714);
      if (lookahead == '\\') ADVANCE(49);
      END_STATE();
    case 715:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(715);
      if (lookahead == '\\') ADVANCE(326);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(716);
      if (lookahead == '\\') ADVANCE(120);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(717);
      if (lookahead == '\\') ADVANCE(221);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(718);
      if (lookahead == '\\') ADVANCE(393);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(719);
      if (lookahead == '\\') ADVANCE(197);
      END_STATE();
    case 720:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(720);
      if (lookahead == '\\') ADVANCE(174);
      END_STATE();
    case 721:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(721);
      if (lookahead == '\\') ADVANCE(394);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(722);
      if (lookahead == '\\') ADVANCE(213);
      END_STATE();
    case 723:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(723);
      if (lookahead == '\\') ADVANCE(52);
      END_STATE();
    case 724:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(724);
      if (lookahead == '\\') ADVANCE(328);
      END_STATE();
    case 725:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(725);
      if (lookahead == '\\') ADVANCE(140);
      END_STATE();
    case 726:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(726);
      if (lookahead == '\\') ADVANCE(223);
      END_STATE();
    case 727:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(727);
      if (lookahead == '\\') ADVANCE(395);
      END_STATE();
    case 728:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(728);
      if (lookahead == '\\') ADVANCE(54);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(729);
      if (lookahead == '\\') ADVANCE(330);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(730);
      if (lookahead == '\\') ADVANCE(207);
      END_STATE();
    case 731:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(731);
      if (lookahead == '\\') ADVANCE(332);
      END_STATE();
    case 732:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(732);
      if (lookahead == '\\') ADVANCE(225);
      END_STATE();
    case 733:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(733);
      if (lookahead == '\\') ADVANCE(334);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(734);
      if (lookahead == '\\') ADVANCE(59);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(735);
      if (lookahead == '\\') ADVANCE(336);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(736);
      if (lookahead == '\\') ADVANCE(68);
      END_STATE();
    case 737:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(737);
      if (lookahead == '\\') ADVANCE(337);
      END_STATE();
    case 738:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(738);
      if (lookahead == '\\') ADVANCE(230);
      END_STATE();
    case 739:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(739);
      if (lookahead == '\\') ADVANCE(341);
      END_STATE();
    case 740:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(740);
      if (lookahead == '\\') ADVANCE(180);
      END_STATE();
    case 741:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(741);
      if (lookahead == '\\') ADVANCE(342);
      END_STATE();
    case 742:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(742);
      if (lookahead == '\\') ADVANCE(115);
      END_STATE();
    case 743:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(743);
      if (lookahead == '\\') ADVANCE(344);
      END_STATE();
    case 744:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(744);
      if (lookahead == '\\') ADVANCE(127);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(745);
      if (lookahead == '\\') ADVANCE(345);
      END_STATE();
    case 746:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(746);
      if (lookahead == '\\') ADVANCE(346);
      END_STATE();
    case 747:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(747);
      if (lookahead == '\\') ADVANCE(347);
      END_STATE();
    case 748:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(748);
      if (lookahead == '\\') ADVANCE(349);
      END_STATE();
    case 749:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(749);
      if (lookahead == '\\') ADVANCE(355);
      END_STATE();
    case 750:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(750);
      if (lookahead == '\\') ADVANCE(365);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(751);
      if (lookahead == '\\') ADVANCE(368);
      END_STATE();
    case 752:
      ACCEPT_TOKEN(aux_sym_heredoc_redirect_token1);
      if (lookahead == '\n') ADVANCE(752);
      if (lookahead == '\\') ADVANCE(378);
      END_STATE();
    case 753:
      ACCEPT_TOKEN(anon_sym_LT_LT_LT);
      END_STATE();
    case 754:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 755:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 756:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '+') ADVANCE(830);
      if (lookahead == '-') ADVANCE(827);
      if (lookahead == '=') ADVANCE(824);
      if (lookahead == '?') ADVANCE(834);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 758:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '+') ADVANCE(829);
      if (lookahead == '-') ADVANCE(826);
      if (lookahead == '=') ADVANCE(823);
      if (lookahead == '?') ADVANCE(833);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS2);
      END_STATE();
    case 761:
      ACCEPT_TOKEN(anon_sym_DASH_DASH2);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(anon_sym_DASH2);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(anon_sym_DASH2);
      if (lookahead == '-') ADVANCE(761);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(anon_sym_PLUS2);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(anon_sym_PLUS2);
      if (lookahead == '+') ADVANCE(760);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 767:
      ACCEPT_TOKEN(anon_sym_DOLLAR_LPAREN_LPAREN);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(anon_sym_DOLLAR_LBRACK);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(aux_sym_brace_expression_token1);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(769);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 770:
      ACCEPT_TOKEN(aux_sym_brace_expression_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(770);
      END_STATE();
    case 771:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 772:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 773:
      ACCEPT_TOKEN(anon_sym_RBRACE2);
      END_STATE();
    case 774:
      ACCEPT_TOKEN(aux_sym_concatenation_token1);
      END_STATE();
    case 775:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '\'') ADVANCE(486);
      if (lookahead == '(') ADVANCE(849);
      if (lookahead == '[') ADVANCE(768);
      if (lookahead == '`') ADVANCE(852);
      if (lookahead == '{') ADVANCE(812);
      END_STATE();
    case 777:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '\'') ADVANCE(486);
      if (lookahead == '(') ADVANCE(848);
      if (lookahead == '`') ADVANCE(852);
      if (lookahead == '{') ADVANCE(812);
      END_STATE();
    case 778:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '(') ADVANCE(849);
      if (lookahead == '[') ADVANCE(768);
      if (lookahead == '`') ADVANCE(852);
      if (lookahead == '{') ADVANCE(812);
      END_STATE();
    case 779:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '(') ADVANCE(848);
      if (lookahead == '`') ADVANCE(852);
      END_STATE();
    case 780:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '(') ADVANCE(848);
      if (lookahead == '`') ADVANCE(852);
      if (lookahead == '{') ADVANCE(812);
      END_STATE();
    case 781:
      ACCEPT_TOKEN(sym__special_character);
      END_STATE();
    case 782:
      ACCEPT_TOKEN(sym__special_character);
      if (lookahead == ']') ADVANCE(671);
      END_STATE();
    case 783:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 784:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '\n') ADVANCE(790);
      if (lookahead == '\\') ADVANCE(300);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '$' &&
          lookahead != '`') ADVANCE(792);
      END_STATE();
    case 785:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '\n') ADVANCE(788);
      if (lookahead == '\\') ADVANCE(300);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '$' &&
          lookahead != '`') ADVANCE(792);
      END_STATE();
    case 786:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '\n') ADVANCE(789);
      if (lookahead == '\\') ADVANCE(300);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '$' &&
          lookahead != '`') ADVANCE(792);
      END_STATE();
    case 787:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '\n') ADVANCE(792);
      if (lookahead == '\\') ADVANCE(855);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '$' &&
          lookahead != '`') ADVANCE(791);
      END_STATE();
    case 788:
      ACCEPT_TOKEN(sym_string_content);
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 144,
        '_', 939,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(443);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(788);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      if (lookahead != 0 &&
          (lookahead < '_' || 'z' < lookahead)) ADVANCE(792);
      END_STATE();
    case 789:
      ACCEPT_TOKEN(sym_string_content);
      ADVANCE_MAP(
        '!', 663,
        '#', 811,
        '$', 775,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 147,
        '_', 939,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(446);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(789);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      if (lookahead != 0 &&
          (lookahead < ' ' || '$' < lookahead) &&
          (lookahead < '_' || 'z' < lookahead)) ADVANCE(792);
      END_STATE();
    case 790:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '"') ADVANCE(783);
      if (lookahead == '#') ADVANCE(791);
      if (lookahead == '$') ADVANCE(778);
      if (lookahead == '\\') ADVANCE(299);
      if (lookahead == '`') ADVANCE(850);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(474);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(790);
      if (lookahead != 0) ADVANCE(792);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '\\') ADVANCE(855);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '$' &&
          lookahead != '`') ADVANCE(791);
      END_STATE();
    case 792:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '\\') ADVANCE(300);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '$' &&
          lookahead != '`') ADVANCE(792);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '\\') ADVANCE(300);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '$' &&
          lookahead != '`') ADVANCE(792);
      END_STATE();
    case 794:
      ACCEPT_TOKEN(sym_raw_string);
      END_STATE();
    case 795:
      ACCEPT_TOKEN(sym_ansi_c_string);
      END_STATE();
    case 796:
      ACCEPT_TOKEN(sym_ansi_c_string);
      if (lookahead == '\'') ADVANCE(795);
      if (lookahead == '\\') ADVANCE(487);
      if (lookahead != 0) ADVANCE(486);
      END_STATE();
    case 797:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(809);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 'x') ADVANCE(948);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if ((!eof && set_contains(sym_word_character_set_1, 11, lookahead))) ADVANCE(949);
      END_STATE();
    case 798:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(809);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 'x') ADVANCE(862);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if ((!eof && set_contains(sym_word_character_set_1, 11, lookahead))) ADVANCE(949);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(809);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if ((!eof && set_contains(sym_word_character_set_1, 11, lookahead))) ADVANCE(949);
      END_STATE();
    case 800:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(809);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if ((!eof && set_contains(sym_word_character_set_1, 11, lookahead))) ADVANCE(949);
      END_STATE();
    case 801:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(809);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead == 'x') ADVANCE(867);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym_word_character_set_1, 11, lookahead))) ADVANCE(949);
      END_STATE();
    case 802:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(809);
      if (lookahead == '\\') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym_word_character_set_1, 11, lookahead))) ADVANCE(949);
      END_STATE();
    case 803:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(810);
      if (lookahead == 'x') ADVANCE(873);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(805);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 804:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(810);
      if (lookahead == 'x') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(806);
      END_STATE();
    case 805:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(810);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(805);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 806:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '#') ADVANCE(810);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(806);
      END_STATE();
    case 807:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(807);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 808:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(808);
      END_STATE();
    case 809:
      ACCEPT_TOKEN(aux_sym_number_token2);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(807);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(aux_sym_number_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(808);
      END_STATE();
    case 811:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 812:
      ACCEPT_TOKEN(anon_sym_DOLLAR_LBRACE);
      END_STATE();
    case 813:
      ACCEPT_TOKEN(anon_sym_RBRACE3);
      END_STATE();
    case 814:
      ACCEPT_TOKEN(anon_sym_BANG2);
      END_STATE();
    case 815:
      ACCEPT_TOKEN(anon_sym_BANG2);
      if (lookahead == '=') ADVANCE(600);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 816:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 817:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 818:
      ACCEPT_TOKEN(anon_sym_STAR2);
      END_STATE();
    case 819:
      ACCEPT_TOKEN(anon_sym_STAR2);
      if (lookahead == '*') ADVANCE(645);
      if (lookahead == '=') ADVANCE(567);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(anon_sym_POUND2);
      END_STATE();
    case 821:
      ACCEPT_TOKEN(anon_sym_EQ2);
      END_STATE();
    case 822:
      ACCEPT_TOKEN(anon_sym_EQ2);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 823:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 824:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 825:
      ACCEPT_TOKEN(anon_sym_DASH3);
      END_STATE();
    case 826:
      ACCEPT_TOKEN(anon_sym_COLON_DASH);
      END_STATE();
    case 827:
      ACCEPT_TOKEN(anon_sym_COLON_DASH);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(anon_sym_PLUS3);
      END_STATE();
    case 829:
      ACCEPT_TOKEN(anon_sym_COLON_PLUS);
      END_STATE();
    case 830:
      ACCEPT_TOKEN(anon_sym_COLON_PLUS);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 831:
      ACCEPT_TOKEN(anon_sym_QMARK2);
      END_STATE();
    case 832:
      ACCEPT_TOKEN(anon_sym_QMARK2);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(anon_sym_COLON_QMARK);
      END_STATE();
    case 834:
      ACCEPT_TOKEN(anon_sym_COLON_QMARK);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 835:
      ACCEPT_TOKEN(anon_sym_PERCENT_PERCENT);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(anon_sym_PERCENT_PERCENT);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 837:
      ACCEPT_TOKEN(aux_sym__expansion_regex_token1);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(837);
      END_STATE();
    case 838:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      END_STATE();
    case 839:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 840:
      ACCEPT_TOKEN(anon_sym_SLASH_POUND);
      END_STATE();
    case 841:
      ACCEPT_TOKEN(anon_sym_SLASH_POUND);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 842:
      ACCEPT_TOKEN(anon_sym_SLASH_PERCENT);
      END_STATE();
    case 843:
      ACCEPT_TOKEN(anon_sym_SLASH_PERCENT);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 844:
      ACCEPT_TOKEN(anon_sym_COMMA_COMMA);
      END_STATE();
    case 845:
      ACCEPT_TOKEN(anon_sym_COMMA_COMMA);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 846:
      ACCEPT_TOKEN(anon_sym_CARET_CARET);
      END_STATE();
    case 847:
      ACCEPT_TOKEN(anon_sym_CARET_CARET);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 848:
      ACCEPT_TOKEN(anon_sym_DOLLAR_LPAREN);
      END_STATE();
    case 849:
      ACCEPT_TOKEN(anon_sym_DOLLAR_LPAREN);
      if (lookahead == '(') ADVANCE(767);
      END_STATE();
    case 850:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      END_STATE();
    case 851:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      if (lookahead == '`') ADVANCE(774);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(504);
      END_STATE();
    case 852:
      ACCEPT_TOKEN(anon_sym_DOLLAR_BQUOTE);
      END_STATE();
    case 853:
      ACCEPT_TOKEN(anon_sym_LT_LPAREN);
      END_STATE();
    case 854:
      ACCEPT_TOKEN(anon_sym_GT_LPAREN);
      END_STATE();
    case 855:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(792);
      if (lookahead == '\r') ADVANCE(787);
      if (lookahead != 0) ADVANCE(791);
      END_STATE();
    case 856:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r')) ADVANCE(857);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(858);
      END_STATE();
    case 857:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(857);
      END_STATE();
    case 858:
      ACCEPT_TOKEN(sym__comment_word);
      if (lookahead == '\\') ADVANCE(856);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(858);
      END_STATE();
    case 859:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 'a') ADVANCE(860);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 860:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 'c') ADVANCE(652);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 861:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 's') ADVANCE(859);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 862:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(800);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 863:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(863);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 864:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead == 'a') ADVANCE(865);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 865:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead == 'c') ADVANCE(654);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 866:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead == 's') ADVANCE(864);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 867:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 868:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == '\\') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 869:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == 'a') ADVANCE(870);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == 'c') ADVANCE(655);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == 'n') ADVANCE(544);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (lookahead == 's') ADVANCE(869);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 873:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(805);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 874:
      ACCEPT_TOKEN(aux_sym__simple_variable_name_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 875:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 683,
        '!', 664,
        '"', 783,
        '#', 811,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        ')', 649,
        '*', 632,
        '+', 624,
        '-', 627,
        '/', 638,
        '0', 801,
        ';', 549,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '@', 936,
        '\\', 14,
        '^', 590,
        '_', 938,
        '`', 850,
        '|', 586,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < ';' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 876:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 686,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 548,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 100,
        '_', 939,
        'e', 872,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(202);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 877:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 687,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 28,
        '_', 938,
        '`', 850,
        'e', 866,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(216);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 878:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 689,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 548,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 185,
        '_', 939,
        'e', 872,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(234);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 879:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 690,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 30,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(235);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 880:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 692,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 548,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 104,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(237);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 881:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 693,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 32,
        '_', 938,
        '`', 850,
        'e', 866,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(238);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 695,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 106,
        '_', 939,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(240);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 696,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 36,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(241);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 884:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 698,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 548,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 188,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(243);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 885:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 699,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 164,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(244);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 886:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 701,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 211,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(246);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 887:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 702,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '(', 647,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 39,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(247);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 888:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 704,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        ')', 649,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 109,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(249);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 889:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 705,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 168,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(250);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 890:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 707,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        ')', 649,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 192,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(252);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 891:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 708,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 41,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(253);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 892:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 710,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 215,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(255);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 893:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 711,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 47,
        '_', 938,
        '`', 850,
        'e', 866,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(256);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 894:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 713,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 596,
        '*', 631,
        '-', 626,
        ';', 549,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 190,
        '_', 939,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(258);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 714,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 49,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(259);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 716,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 120,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(261);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 717,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 221,
        '_', 938,
        '`', 850,
        'e', 866,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(262);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 719,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 197,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(264);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 720,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 174,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(265);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 900:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 722,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 605,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 213,
        '_', 939,
        '|', 510,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(267);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 901:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 723,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 52,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(268);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 902:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 725,
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 593,
        '*', 631,
        '-', 626,
        ';', 549,
        '?', 754,
        '@', 935,
        '\\', 140,
        '_', 939,
        'i', 871,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(270);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 903:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 726,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 548,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 223,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(271);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 904:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 728,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 54,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(273);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 730,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 207,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(275);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 906:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 732,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 596,
        '\'', 485,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 225,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(277);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 907:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 734,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 59,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(279);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 908:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 736,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 68,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(281);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 909:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 738,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 230,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(283);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 740,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 602,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 180,
        '_', 938,
        '`', 850,
        '|', 510,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(285);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 911:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 742,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 593,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        ';', 549,
        '<', 489,
        '>', 490,
        '?', 755,
        '@', 936,
        '\\', 115,
        '_', 938,
        '`', 850,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(287);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 912:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '\n', 744,
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 489,
        '>', 490,
        '?', 755,
        '@', 936,
        '\\', 127,
        '_', 938,
        '`', 850,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(289);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 913:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 664,
        '"', 783,
        '#', 811,
        '$', 776,
        '%', 643,
        '&', 595,
        '\'', 485,
        '(', 647,
        '*', 632,
        '+', 624,
        '-', 627,
        '/', 638,
        '0', 801,
        '<', 601,
        '=', 554,
        '>', 610,
        '?', 755,
        '@', 936,
        '\\', 19,
        ']', 669,
        '^', 590,
        '_', 938,
        '`', 850,
        '|', 586,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(398);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < ' ' || '+' < lookahead) &&
          (lookahead < ';' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 502,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 602,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 87,
        '_', 938,
        '`', 850,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(404);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 915:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '(', 647,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 57,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(405);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 916:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '=', 943,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 62,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(406);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          (lookahead < ';' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 917:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 65,
        ']', 669,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(407);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 918:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 603,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 76,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(408);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 228,
        ']', 669,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(409);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 920:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '&', 483,
        '\'', 485,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 604,
        '>', 611,
        '?', 755,
        '@', 936,
        '\\', 232,
        '_', 938,
        '`', 850,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(410);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 921:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 666,
        '"', 783,
        '#', 811,
        '$', 776,
        '\'', 485,
        ')', 649,
        '*', 634,
        '-', 630,
        '0', 801,
        '<', 489,
        '>', 490,
        '?', 755,
        '@', 936,
        '\\', 124,
        '_', 938,
        '`', 850,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(411);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(802);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if (lookahead != 0 &&
          (lookahead < '&' || '*' < lookahead) &&
          lookahead != ';' &&
          lookahead != '<' &&
          (lookahead < '>' || ']' < lookahead) &&
          (lookahead < '_' || '}' < lookahead)) ADVANCE(949);
      END_STATE();
    case 922:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        ')', 649,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 78,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(422);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        ':', 756,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 72,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(423);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 924:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 70,
        ']', 669,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(424);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 182,
        ']', 503,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(425);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 926:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 665,
        '"', 783,
        '#', 811,
        '$', 775,
        '%', 644,
        '&', 594,
        '*', 633,
        '+', 625,
        '-', 628,
        '/', 639,
        '<', 609,
        '=', 556,
        '>', 614,
        '?', 754,
        '@', 935,
        '\\', 82,
        '^', 591,
        '_', 939,
        '|', 588,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(426);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 927:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 118,
        ']', 669,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(438);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 928:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 606,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 122,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 929:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 195,
        ']', 669,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(440);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 930:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '&', 483,
        '*', 631,
        '-', 626,
        '<', 607,
        '>', 612,
        '?', 754,
        '@', 935,
        '\\', 199,
        '_', 939,
        '|', 587,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(441);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 931:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        ')', 649,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 142,
        '_', 939,
        '|', 584,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(442);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 932:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 663,
        '"', 783,
        '#', 811,
        '$', 775,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 146,
        '_', 939,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(444);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 933:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      ADVANCE_MAP(
        '!', 663,
        '#', 811,
        '$', 775,
        '*', 631,
        '-', 626,
        '?', 754,
        '@', 935,
        '\\', 150,
        '_', 939,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(447);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 934:
      ACCEPT_TOKEN(aux_sym__multiline_variable_name_token1);
      if (lookahead == '\\') ADVANCE(16);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(934);
      END_STATE();
    case 935:
      ACCEPT_TOKEN(anon_sym_AT2);
      END_STATE();
    case 936:
      ACCEPT_TOKEN(anon_sym_AT2);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 938:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '\\') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(868);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 939:
      ACCEPT_TOKEN(anon_sym__);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(874);
      END_STATE();
    case 940:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '.') ADVANCE(772);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '0') ADVANCE(797);
      if (lookahead == '\\') ADVANCE(512);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 942:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '=') ADVANCE(600);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 943:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '=') ADVANCE(598);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == '~') ADVANCE(673);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 944:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 'a') ADVANCE(945);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 945:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 'c') ADVANCE(653);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 946:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 'n') ADVANCE(543);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(512);
      if (lookahead == 's') ADVANCE(944);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 948:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(799);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    case 949:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(512);
      if ((!eof && set_contains(sym__comment_word_character_set_1, 12, lookahead))) ADVANCE(949);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == 'A') ADVANCE(1);
      if (lookahead == 'E') ADVANCE(2);
      if (lookahead == 'K') ADVANCE(3);
      if (lookahead == 'L') ADVANCE(4);
      if (lookahead == 'P') ADVANCE(5);
      if (lookahead == 'Q') ADVANCE(6);
      if (lookahead == 'U') ADVANCE(7);
      if (lookahead == '\\') SKIP(8);
      if (lookahead == 'a') ADVANCE(9);
      if (lookahead == 'c') ADVANCE(10);
      if (lookahead == 'd') ADVANCE(11);
      if (lookahead == 'e') ADVANCE(12);
      if (lookahead == 'f') ADVANCE(13);
      if (lookahead == 'i') ADVANCE(14);
      if (lookahead == 'k') ADVANCE(15);
      if (lookahead == 'l') ADVANCE(16);
      if (lookahead == 'r') ADVANCE(17);
      if (lookahead == 's') ADVANCE(18);
      if (lookahead == 't') ADVANCE(19);
      if (lookahead == 'u') ADVANCE(20);
      if (lookahead == 'w') ADVANCE(21);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      END_STATE();
    case 1:
      ACCEPT_TOKEN(anon_sym_A);
      END_STATE();
    case 2:
      ACCEPT_TOKEN(anon_sym_E);
      END_STATE();
    case 3:
      ACCEPT_TOKEN(anon_sym_K);
      END_STATE();
    case 4:
      ACCEPT_TOKEN(anon_sym_L);
      END_STATE();
    case 5:
      ACCEPT_TOKEN(anon_sym_P);
      END_STATE();
    case 6:
      ACCEPT_TOKEN(anon_sym_Q);
      END_STATE();
    case 7:
      ACCEPT_TOKEN(anon_sym_U);
      END_STATE();
    case 8:
      if (lookahead == '\r') SKIP(23);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(22);
      END_STATE();
    case 9:
      ACCEPT_TOKEN(anon_sym_a);
      END_STATE();
    case 10:
      if (lookahead == 'a') ADVANCE(24);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(25);
      if (lookahead == 'o') ADVANCE(26);
      END_STATE();
    case 12:
      if (lookahead == 'l') ADVANCE(27);
      if (lookahead == 'x') ADVANCE(28);
      END_STATE();
    case 13:
      if (lookahead == 'i') ADVANCE(29);
      if (lookahead == 'o') ADVANCE(30);
      if (lookahead == 'u') ADVANCE(31);
      END_STATE();
    case 14:
      if (lookahead == 'f') ADVANCE(32);
      END_STATE();
    case 15:
      ACCEPT_TOKEN(anon_sym_k);
      END_STATE();
    case 16:
      if (lookahead == 'o') ADVANCE(33);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(34);
      END_STATE();
    case 18:
      if (lookahead == 'e') ADVANCE(35);
      END_STATE();
    case 19:
      if (lookahead == 'h') ADVANCE(36);
      if (lookahead == 'y') ADVANCE(37);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(anon_sym_u);
      if (lookahead == 'n') ADVANCE(38);
      END_STATE();
    case 21:
      if (lookahead == 'h') ADVANCE(39);
      END_STATE();
    case 22:
      if (lookahead == '\\') SKIP(8);
      if (lookahead == 'c') ADVANCE(10);
      if (lookahead == 'd') ADVANCE(11);
      if (lookahead == 'e') ADVANCE(12);
      if (lookahead == 'f') ADVANCE(13);
      if (lookahead == 'i') ADVANCE(14);
      if (lookahead == 'l') ADVANCE(16);
      if (lookahead == 'r') ADVANCE(17);
      if (lookahead == 's') ADVANCE(18);
      if (lookahead == 't') ADVANCE(19);
      if (lookahead == 'u') ADVANCE(40);
      if (lookahead == 'w') ADVANCE(21);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      END_STATE();
    case 23:
      if (lookahead == '\n') SKIP(22);
      END_STATE();
    case 24:
      if (lookahead == 's') ADVANCE(41);
      END_STATE();
    case 25:
      if (lookahead == 'c') ADVANCE(42);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_do);
      if (lookahead == 'n') ADVANCE(43);
      END_STATE();
    case 27:
      if (lookahead == 'i') ADVANCE(44);
      if (lookahead == 's') ADVANCE(45);
      END_STATE();
    case 28:
      if (lookahead == 'p') ADVANCE(46);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_fi);
      END_STATE();
    case 30:
      if (lookahead == 'r') ADVANCE(47);
      END_STATE();
    case 31:
      if (lookahead == 'n') ADVANCE(48);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 33:
      if (lookahead == 'c') ADVANCE(49);
      END_STATE();
    case 34:
      if (lookahead == 'a') ADVANCE(50);
      END_STATE();
    case 35:
      if (lookahead == 'l') ADVANCE(51);
      END_STATE();
    case 36:
      if (lookahead == 'e') ADVANCE(52);
      END_STATE();
    case 37:
      if (lookahead == 'p') ADVANCE(53);
      END_STATE();
    case 38:
      if (lookahead == 's') ADVANCE(54);
      if (lookahead == 't') ADVANCE(55);
      END_STATE();
    case 39:
      if (lookahead == 'i') ADVANCE(56);
      END_STATE();
    case 40:
      if (lookahead == 'n') ADVANCE(38);
      END_STATE();
    case 41:
      if (lookahead == 'e') ADVANCE(57);
      END_STATE();
    case 42:
      if (lookahead == 'l') ADVANCE(58);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(59);
      END_STATE();
    case 44:
      if (lookahead == 'f') ADVANCE(60);
      END_STATE();
    case 45:
      if (lookahead == 'e') ADVANCE(61);
      END_STATE();
    case 46:
      if (lookahead == 'o') ADVANCE(62);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 48:
      if (lookahead == 'c') ADVANCE(63);
      END_STATE();
    case 49:
      if (lookahead == 'a') ADVANCE(64);
      END_STATE();
    case 50:
      if (lookahead == 'd') ADVANCE(65);
      END_STATE();
    case 51:
      if (lookahead == 'e') ADVANCE(66);
      END_STATE();
    case 52:
      if (lookahead == 'n') ADVANCE(67);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(68);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(69);
      END_STATE();
    case 55:
      if (lookahead == 'i') ADVANCE(70);
      END_STATE();
    case 56:
      if (lookahead == 'l') ADVANCE(71);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 58:
      if (lookahead == 'a') ADVANCE(72);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_done);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_elif);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 62:
      if (lookahead == 'r') ADVANCE(73);
      END_STATE();
    case 63:
      if (lookahead == 't') ADVANCE(74);
      END_STATE();
    case 64:
      if (lookahead == 'l') ADVANCE(75);
      END_STATE();
    case 65:
      if (lookahead == 'o') ADVANCE(76);
      END_STATE();
    case 66:
      if (lookahead == 'c') ADVANCE(77);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 68:
      if (lookahead == 's') ADVANCE(78);
      END_STATE();
    case 69:
      if (lookahead == 't') ADVANCE(79);
      END_STATE();
    case 70:
      if (lookahead == 'l') ADVANCE(80);
      END_STATE();
    case 71:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 72:
      if (lookahead == 'r') ADVANCE(82);
      END_STATE();
    case 73:
      if (lookahead == 't') ADVANCE(83);
      END_STATE();
    case 74:
      if (lookahead == 'i') ADVANCE(84);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_local);
      END_STATE();
    case 76:
      if (lookahead == 'n') ADVANCE(85);
      END_STATE();
    case 77:
      if (lookahead == 't') ADVANCE(86);
      END_STATE();
    case 78:
      if (lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_unset);
      if (lookahead == 'e') ADVANCE(88);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_until);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 82:
      if (lookahead == 'e') ADVANCE(89);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_export);
      END_STATE();
    case 84:
      if (lookahead == 'o') ADVANCE(90);
      END_STATE();
    case 85:
      if (lookahead == 'l') ADVANCE(91);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_select);
      END_STATE();
    case 87:
      if (lookahead == 't') ADVANCE(92);
      END_STATE();
    case 88:
      if (lookahead == 'n') ADVANCE(93);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_declare);
      END_STATE();
    case 90:
      if (lookahead == 'n') ADVANCE(94);
      END_STATE();
    case 91:
      if (lookahead == 'y') ADVANCE(95);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_typeset);
      END_STATE();
    case 93:
      if (lookahead == 'v') ADVANCE(96);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_readonly);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_unsetenv);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 540, .external_lex_state = 2},
  [2] = {.lex_state = 413, .external_lex_state = 2},
  [3] = {.lex_state = 413, .external_lex_state = 2},
  [4] = {.lex_state = 413, .external_lex_state = 2},
  [5] = {.lex_state = 414, .external_lex_state = 3},
  [6] = {.lex_state = 414, .external_lex_state = 3},
  [7] = {.lex_state = 414, .external_lex_state = 3},
  [8] = {.lex_state = 414, .external_lex_state = 3},
  [9] = {.lex_state = 414, .external_lex_state = 3},
  [10] = {.lex_state = 414, .external_lex_state = 3},
  [11] = {.lex_state = 414, .external_lex_state = 3},
  [12] = {.lex_state = 414, .external_lex_state = 3},
  [13] = {.lex_state = 6, .external_lex_state = 4},
  [14] = {.lex_state = 540, .external_lex_state = 2},
  [15] = {.lex_state = 540, .external_lex_state = 2},
  [16] = {.lex_state = 540, .external_lex_state = 2},
  [17] = {.lex_state = 540, .external_lex_state = 2},
  [18] = {.lex_state = 540, .external_lex_state = 2},
  [19] = {.lex_state = 540, .external_lex_state = 2},
  [20] = {.lex_state = 540, .external_lex_state = 2},
  [21] = {.lex_state = 540, .external_lex_state = 2},
  [22] = {.lex_state = 399, .external_lex_state = 5},
  [23] = {.lex_state = 415, .external_lex_state = 6},
  [24] = {.lex_state = 415, .external_lex_state = 6},
  [25] = {.lex_state = 415, .external_lex_state = 6},
  [26] = {.lex_state = 540, .external_lex_state = 2},
  [27] = {.lex_state = 415, .external_lex_state = 6},
  [28] = {.lex_state = 415, .external_lex_state = 6},
  [29] = {.lex_state = 415, .external_lex_state = 6},
  [30] = {.lex_state = 415, .external_lex_state = 6},
  [31] = {.lex_state = 415, .external_lex_state = 6},
  [32] = {.lex_state = 415, .external_lex_state = 6},
  [33] = {.lex_state = 415, .external_lex_state = 6},
  [34] = {.lex_state = 415, .external_lex_state = 6},
  [35] = {.lex_state = 415, .external_lex_state = 6},
  [36] = {.lex_state = 540, .external_lex_state = 2},
  [37] = {.lex_state = 540, .external_lex_state = 2},
  [38] = {.lex_state = 540, .external_lex_state = 2},
  [39] = {.lex_state = 540, .external_lex_state = 2},
  [40] = {.lex_state = 540, .external_lex_state = 2},
  [41] = {.lex_state = 540, .external_lex_state = 2},
  [42] = {.lex_state = 540, .external_lex_state = 2},
  [43] = {.lex_state = 540, .external_lex_state = 2},
  [44] = {.lex_state = 540, .external_lex_state = 2},
  [45] = {.lex_state = 540, .external_lex_state = 2},
  [46] = {.lex_state = 540, .external_lex_state = 2},
  [47] = {.lex_state = 540, .external_lex_state = 2},
  [48] = {.lex_state = 540, .external_lex_state = 2},
  [49] = {.lex_state = 540, .external_lex_state = 2},
  [50] = {.lex_state = 540, .external_lex_state = 2},
  [51] = {.lex_state = 540, .external_lex_state = 2},
  [52] = {.lex_state = 540, .external_lex_state = 2},
  [53] = {.lex_state = 540, .external_lex_state = 2},
  [54] = {.lex_state = 540, .external_lex_state = 2},
  [55] = {.lex_state = 540, .external_lex_state = 2},
  [56] = {.lex_state = 540, .external_lex_state = 2},
  [57] = {.lex_state = 540, .external_lex_state = 2},
  [58] = {.lex_state = 540, .external_lex_state = 2},
  [59] = {.lex_state = 540, .external_lex_state = 2},
  [60] = {.lex_state = 540, .external_lex_state = 2},
  [61] = {.lex_state = 540, .external_lex_state = 2},
  [62] = {.lex_state = 540, .external_lex_state = 2},
  [63] = {.lex_state = 540, .external_lex_state = 2},
  [64] = {.lex_state = 416, .external_lex_state = 2},
  [65] = {.lex_state = 540, .external_lex_state = 2},
  [66] = {.lex_state = 416, .external_lex_state = 2},
  [67] = {.lex_state = 416, .external_lex_state = 2},
  [68] = {.lex_state = 540, .external_lex_state = 2},
  [69] = {.lex_state = 416, .external_lex_state = 2},
  [70] = {.lex_state = 540, .external_lex_state = 2},
  [71] = {.lex_state = 416, .external_lex_state = 2},
  [72] = {.lex_state = 540, .external_lex_state = 2},
  [73] = {.lex_state = 540, .external_lex_state = 2},
  [74] = {.lex_state = 416, .external_lex_state = 2},
  [75] = {.lex_state = 416, .external_lex_state = 2},
  [76] = {.lex_state = 540, .external_lex_state = 2},
  [77] = {.lex_state = 540, .external_lex_state = 2},
  [78] = {.lex_state = 416, .external_lex_state = 2},
  [79] = {.lex_state = 416, .external_lex_state = 2},
  [80] = {.lex_state = 540, .external_lex_state = 2},
  [81] = {.lex_state = 540, .external_lex_state = 2},
  [82] = {.lex_state = 416, .external_lex_state = 2},
  [83] = {.lex_state = 540, .external_lex_state = 2},
  [84] = {.lex_state = 416, .external_lex_state = 2},
  [85] = {.lex_state = 540, .external_lex_state = 2},
  [86] = {.lex_state = 416, .external_lex_state = 2},
  [87] = {.lex_state = 416, .external_lex_state = 2},
  [88] = {.lex_state = 540, .external_lex_state = 2},
  [89] = {.lex_state = 540, .external_lex_state = 2},
  [90] = {.lex_state = 416, .external_lex_state = 2},
  [91] = {.lex_state = 540, .external_lex_state = 2},
  [92] = {.lex_state = 416, .external_lex_state = 2},
  [93] = {.lex_state = 540, .external_lex_state = 2},
  [94] = {.lex_state = 540, .external_lex_state = 2},
  [95] = {.lex_state = 416, .external_lex_state = 2},
  [96] = {.lex_state = 540, .external_lex_state = 2},
  [97] = {.lex_state = 416, .external_lex_state = 2},
  [98] = {.lex_state = 540, .external_lex_state = 2},
  [99] = {.lex_state = 540, .external_lex_state = 2},
  [100] = {.lex_state = 416, .external_lex_state = 2},
  [101] = {.lex_state = 416, .external_lex_state = 2},
  [102] = {.lex_state = 540, .external_lex_state = 2},
  [103] = {.lex_state = 540, .external_lex_state = 2},
  [104] = {.lex_state = 540, .external_lex_state = 2},
  [105] = {.lex_state = 540, .external_lex_state = 2},
  [106] = {.lex_state = 540, .external_lex_state = 2},
  [107] = {.lex_state = 540, .external_lex_state = 2},
  [108] = {.lex_state = 540, .external_lex_state = 2},
  [109] = {.lex_state = 540, .external_lex_state = 2},
  [110] = {.lex_state = 540, .external_lex_state = 2},
  [111] = {.lex_state = 540, .external_lex_state = 2},
  [112] = {.lex_state = 540, .external_lex_state = 2},
  [113] = {.lex_state = 540, .external_lex_state = 2},
  [114] = {.lex_state = 540, .external_lex_state = 2},
  [115] = {.lex_state = 540, .external_lex_state = 2},
  [116] = {.lex_state = 540, .external_lex_state = 2},
  [117] = {.lex_state = 540, .external_lex_state = 2},
  [118] = {.lex_state = 540, .external_lex_state = 2},
  [119] = {.lex_state = 540, .external_lex_state = 2},
  [120] = {.lex_state = 540, .external_lex_state = 2},
  [121] = {.lex_state = 540, .external_lex_state = 2},
  [122] = {.lex_state = 540, .external_lex_state = 2},
  [123] = {.lex_state = 540, .external_lex_state = 2},
  [124] = {.lex_state = 540, .external_lex_state = 2},
  [125] = {.lex_state = 540, .external_lex_state = 2},
  [126] = {.lex_state = 540, .external_lex_state = 2},
  [127] = {.lex_state = 540, .external_lex_state = 2},
  [128] = {.lex_state = 540, .external_lex_state = 2},
  [129] = {.lex_state = 540, .external_lex_state = 2},
  [130] = {.lex_state = 540, .external_lex_state = 2},
  [131] = {.lex_state = 540, .external_lex_state = 2},
  [132] = {.lex_state = 540, .external_lex_state = 2},
  [133] = {.lex_state = 540, .external_lex_state = 2},
  [134] = {.lex_state = 540, .external_lex_state = 2},
  [135] = {.lex_state = 540, .external_lex_state = 2},
  [136] = {.lex_state = 540, .external_lex_state = 2},
  [137] = {.lex_state = 540, .external_lex_state = 2},
  [138] = {.lex_state = 540, .external_lex_state = 2},
  [139] = {.lex_state = 540, .external_lex_state = 2},
  [140] = {.lex_state = 540, .external_lex_state = 2},
  [141] = {.lex_state = 540, .external_lex_state = 2},
  [142] = {.lex_state = 540, .external_lex_state = 2},
  [143] = {.lex_state = 540, .external_lex_state = 2},
  [144] = {.lex_state = 540, .external_lex_state = 2},
  [145] = {.lex_state = 540, .external_lex_state = 2},
  [146] = {.lex_state = 540, .external_lex_state = 2},
  [147] = {.lex_state = 540, .external_lex_state = 2},
  [148] = {.lex_state = 540, .external_lex_state = 2},
  [149] = {.lex_state = 540, .external_lex_state = 2},
  [150] = {.lex_state = 540, .external_lex_state = 2},
  [151] = {.lex_state = 540, .external_lex_state = 2},
  [152] = {.lex_state = 540, .external_lex_state = 2},
  [153] = {.lex_state = 540, .external_lex_state = 2},
  [154] = {.lex_state = 540, .external_lex_state = 2},
  [155] = {.lex_state = 540, .external_lex_state = 2},
  [156] = {.lex_state = 540, .external_lex_state = 2},
  [157] = {.lex_state = 540, .external_lex_state = 2},
  [158] = {.lex_state = 540, .external_lex_state = 2},
  [159] = {.lex_state = 540, .external_lex_state = 2},
  [160] = {.lex_state = 540, .external_lex_state = 2},
  [161] = {.lex_state = 540, .external_lex_state = 2},
  [162] = {.lex_state = 540, .external_lex_state = 2},
  [163] = {.lex_state = 540, .external_lex_state = 2},
  [164] = {.lex_state = 540, .external_lex_state = 2},
  [165] = {.lex_state = 540, .external_lex_state = 2},
  [166] = {.lex_state = 540, .external_lex_state = 2},
  [167] = {.lex_state = 540, .external_lex_state = 2},
  [168] = {.lex_state = 540, .external_lex_state = 2},
  [169] = {.lex_state = 540, .external_lex_state = 2},
  [170] = {.lex_state = 540, .external_lex_state = 2},
  [171] = {.lex_state = 540, .external_lex_state = 2},
  [172] = {.lex_state = 540, .external_lex_state = 2},
  [173] = {.lex_state = 540, .external_lex_state = 2},
  [174] = {.lex_state = 540, .external_lex_state = 2},
  [175] = {.lex_state = 540, .external_lex_state = 2},
  [176] = {.lex_state = 540, .external_lex_state = 2},
  [177] = {.lex_state = 540, .external_lex_state = 2},
  [178] = {.lex_state = 540, .external_lex_state = 2},
  [179] = {.lex_state = 540, .external_lex_state = 2},
  [180] = {.lex_state = 540, .external_lex_state = 2},
  [181] = {.lex_state = 540, .external_lex_state = 2},
  [182] = {.lex_state = 540, .external_lex_state = 2},
  [183] = {.lex_state = 540, .external_lex_state = 2},
  [184] = {.lex_state = 540, .external_lex_state = 2},
  [185] = {.lex_state = 540, .external_lex_state = 2},
  [186] = {.lex_state = 540, .external_lex_state = 2},
  [187] = {.lex_state = 540, .external_lex_state = 2},
  [188] = {.lex_state = 540, .external_lex_state = 2},
  [189] = {.lex_state = 540, .external_lex_state = 2},
  [190] = {.lex_state = 540, .external_lex_state = 2},
  [191] = {.lex_state = 540, .external_lex_state = 2},
  [192] = {.lex_state = 540, .external_lex_state = 2},
  [193] = {.lex_state = 540, .external_lex_state = 2},
  [194] = {.lex_state = 540, .external_lex_state = 2},
  [195] = {.lex_state = 540, .external_lex_state = 2},
  [196] = {.lex_state = 540, .external_lex_state = 2},
  [197] = {.lex_state = 540, .external_lex_state = 2},
  [198] = {.lex_state = 540, .external_lex_state = 2},
  [199] = {.lex_state = 540, .external_lex_state = 2},
  [200] = {.lex_state = 540, .external_lex_state = 2},
  [201] = {.lex_state = 540, .external_lex_state = 2},
  [202] = {.lex_state = 540, .external_lex_state = 2},
  [203] = {.lex_state = 540, .external_lex_state = 2},
  [204] = {.lex_state = 540, .external_lex_state = 2},
  [205] = {.lex_state = 540, .external_lex_state = 2},
  [206] = {.lex_state = 540, .external_lex_state = 2},
  [207] = {.lex_state = 540, .external_lex_state = 2},
  [208] = {.lex_state = 540, .external_lex_state = 2},
  [209] = {.lex_state = 540, .external_lex_state = 2},
  [210] = {.lex_state = 540, .external_lex_state = 2},
  [211] = {.lex_state = 540, .external_lex_state = 2},
  [212] = {.lex_state = 540, .external_lex_state = 2},
  [213] = {.lex_state = 540, .external_lex_state = 2},
  [214] = {.lex_state = 540, .external_lex_state = 2},
  [215] = {.lex_state = 540, .external_lex_state = 2},
  [216] = {.lex_state = 540, .external_lex_state = 2},
  [217] = {.lex_state = 540, .external_lex_state = 2},
  [218] = {.lex_state = 540, .external_lex_state = 2},
  [219] = {.lex_state = 540, .external_lex_state = 2},
  [220] = {.lex_state = 540, .external_lex_state = 2},
  [221] = {.lex_state = 540, .external_lex_state = 2},
  [222] = {.lex_state = 540, .external_lex_state = 2},
  [223] = {.lex_state = 540, .external_lex_state = 2},
  [224] = {.lex_state = 540, .external_lex_state = 2},
  [225] = {.lex_state = 540, .external_lex_state = 2},
  [226] = {.lex_state = 540, .external_lex_state = 2},
  [227] = {.lex_state = 540, .external_lex_state = 2},
  [228] = {.lex_state = 540, .external_lex_state = 2},
  [229] = {.lex_state = 540, .external_lex_state = 2},
  [230] = {.lex_state = 540, .external_lex_state = 2},
  [231] = {.lex_state = 540, .external_lex_state = 2},
  [232] = {.lex_state = 540, .external_lex_state = 2},
  [233] = {.lex_state = 540, .external_lex_state = 2},
  [234] = {.lex_state = 540, .external_lex_state = 2},
  [235] = {.lex_state = 540, .external_lex_state = 2},
  [236] = {.lex_state = 540, .external_lex_state = 2},
  [237] = {.lex_state = 540, .external_lex_state = 2},
  [238] = {.lex_state = 540, .external_lex_state = 2},
  [239] = {.lex_state = 540, .external_lex_state = 2},
  [240] = {.lex_state = 540, .external_lex_state = 2},
  [241] = {.lex_state = 540, .external_lex_state = 2},
  [242] = {.lex_state = 540, .external_lex_state = 2},
  [243] = {.lex_state = 540, .external_lex_state = 2},
  [244] = {.lex_state = 540, .external_lex_state = 2},
  [245] = {.lex_state = 540, .external_lex_state = 2},
  [246] = {.lex_state = 540, .external_lex_state = 2},
  [247] = {.lex_state = 540, .external_lex_state = 2},
  [248] = {.lex_state = 540, .external_lex_state = 2},
  [249] = {.lex_state = 540, .external_lex_state = 2},
  [250] = {.lex_state = 540, .external_lex_state = 2},
  [251] = {.lex_state = 540, .external_lex_state = 2},
  [252] = {.lex_state = 540, .external_lex_state = 2},
  [253] = {.lex_state = 540, .external_lex_state = 2},
  [254] = {.lex_state = 540, .external_lex_state = 2},
  [255] = {.lex_state = 540, .external_lex_state = 2},
  [256] = {.lex_state = 540, .external_lex_state = 2},
  [257] = {.lex_state = 540, .external_lex_state = 2},
  [258] = {.lex_state = 540, .external_lex_state = 2},
  [259] = {.lex_state = 540, .external_lex_state = 2},
  [260] = {.lex_state = 540, .external_lex_state = 2},
  [261] = {.lex_state = 540, .external_lex_state = 2},
  [262] = {.lex_state = 540, .external_lex_state = 2},
  [263] = {.lex_state = 540, .external_lex_state = 2},
  [264] = {.lex_state = 540, .external_lex_state = 2},
  [265] = {.lex_state = 540, .external_lex_state = 2},
  [266] = {.lex_state = 540, .external_lex_state = 2},
  [267] = {.lex_state = 540, .external_lex_state = 2},
  [268] = {.lex_state = 540, .external_lex_state = 2},
  [269] = {.lex_state = 540, .external_lex_state = 2},
  [270] = {.lex_state = 540, .external_lex_state = 2},
  [271] = {.lex_state = 540, .external_lex_state = 2},
  [272] = {.lex_state = 540, .external_lex_state = 2},
  [273] = {.lex_state = 540, .external_lex_state = 2},
  [274] = {.lex_state = 540, .external_lex_state = 2},
  [275] = {.lex_state = 540, .external_lex_state = 2},
  [276] = {.lex_state = 540, .external_lex_state = 2},
  [277] = {.lex_state = 540, .external_lex_state = 2},
  [278] = {.lex_state = 540, .external_lex_state = 2},
  [279] = {.lex_state = 540, .external_lex_state = 2},
  [280] = {.lex_state = 540, .external_lex_state = 2},
  [281] = {.lex_state = 540, .external_lex_state = 2},
  [282] = {.lex_state = 540, .external_lex_state = 2},
  [283] = {.lex_state = 540, .external_lex_state = 2},
  [284] = {.lex_state = 540, .external_lex_state = 2},
  [285] = {.lex_state = 540, .external_lex_state = 2},
  [286] = {.lex_state = 540, .external_lex_state = 2},
  [287] = {.lex_state = 540, .external_lex_state = 2},
  [288] = {.lex_state = 540, .external_lex_state = 2},
  [289] = {.lex_state = 540, .external_lex_state = 2},
  [290] = {.lex_state = 540, .external_lex_state = 2},
  [291] = {.lex_state = 540, .external_lex_state = 2},
  [292] = {.lex_state = 540, .external_lex_state = 2},
  [293] = {.lex_state = 540, .external_lex_state = 2},
  [294] = {.lex_state = 540, .external_lex_state = 2},
  [295] = {.lex_state = 540, .external_lex_state = 2},
  [296] = {.lex_state = 540, .external_lex_state = 2},
  [297] = {.lex_state = 540, .external_lex_state = 2},
  [298] = {.lex_state = 540, .external_lex_state = 2},
  [299] = {.lex_state = 540, .external_lex_state = 2},
  [300] = {.lex_state = 540, .external_lex_state = 2},
  [301] = {.lex_state = 540, .external_lex_state = 2},
  [302] = {.lex_state = 540, .external_lex_state = 2},
  [303] = {.lex_state = 540, .external_lex_state = 2},
  [304] = {.lex_state = 540, .external_lex_state = 2},
  [305] = {.lex_state = 540, .external_lex_state = 2},
  [306] = {.lex_state = 540, .external_lex_state = 2},
  [307] = {.lex_state = 540, .external_lex_state = 2},
  [308] = {.lex_state = 540, .external_lex_state = 2},
  [309] = {.lex_state = 540, .external_lex_state = 2},
  [310] = {.lex_state = 540, .external_lex_state = 2},
  [311] = {.lex_state = 540, .external_lex_state = 2},
  [312] = {.lex_state = 540, .external_lex_state = 2},
  [313] = {.lex_state = 540, .external_lex_state = 2},
  [314] = {.lex_state = 540, .external_lex_state = 2},
  [315] = {.lex_state = 540, .external_lex_state = 2},
  [316] = {.lex_state = 540, .external_lex_state = 2},
  [317] = {.lex_state = 540, .external_lex_state = 2},
  [318] = {.lex_state = 540, .external_lex_state = 2},
  [319] = {.lex_state = 540, .external_lex_state = 2},
  [320] = {.lex_state = 540, .external_lex_state = 2},
  [321] = {.lex_state = 540, .external_lex_state = 2},
  [322] = {.lex_state = 540, .external_lex_state = 2},
  [323] = {.lex_state = 540, .external_lex_state = 2},
  [324] = {.lex_state = 540, .external_lex_state = 2},
  [325] = {.lex_state = 540, .external_lex_state = 2},
  [326] = {.lex_state = 540, .external_lex_state = 2},
  [327] = {.lex_state = 540, .external_lex_state = 2},
  [328] = {.lex_state = 540, .external_lex_state = 2},
  [329] = {.lex_state = 540, .external_lex_state = 2},
  [330] = {.lex_state = 540, .external_lex_state = 2},
  [331] = {.lex_state = 540, .external_lex_state = 2},
  [332] = {.lex_state = 540, .external_lex_state = 2},
  [333] = {.lex_state = 540, .external_lex_state = 2},
  [334] = {.lex_state = 540, .external_lex_state = 2},
  [335] = {.lex_state = 540, .external_lex_state = 2},
  [336] = {.lex_state = 540, .external_lex_state = 2},
  [337] = {.lex_state = 540, .external_lex_state = 2},
  [338] = {.lex_state = 540, .external_lex_state = 2},
  [339] = {.lex_state = 540, .external_lex_state = 2},
  [340] = {.lex_state = 540, .external_lex_state = 2},
  [341] = {.lex_state = 540, .external_lex_state = 2},
  [342] = {.lex_state = 540, .external_lex_state = 2},
  [343] = {.lex_state = 540, .external_lex_state = 2},
  [344] = {.lex_state = 540, .external_lex_state = 2},
  [345] = {.lex_state = 540, .external_lex_state = 2},
  [346] = {.lex_state = 540, .external_lex_state = 2},
  [347] = {.lex_state = 540, .external_lex_state = 2},
  [348] = {.lex_state = 540, .external_lex_state = 2},
  [349] = {.lex_state = 540, .external_lex_state = 2},
  [350] = {.lex_state = 540, .external_lex_state = 2},
  [351] = {.lex_state = 540, .external_lex_state = 2},
  [352] = {.lex_state = 540, .external_lex_state = 2},
  [353] = {.lex_state = 540, .external_lex_state = 2},
  [354] = {.lex_state = 540, .external_lex_state = 2},
  [355] = {.lex_state = 540, .external_lex_state = 2},
  [356] = {.lex_state = 540, .external_lex_state = 2},
  [357] = {.lex_state = 540, .external_lex_state = 2},
  [358] = {.lex_state = 540, .external_lex_state = 2},
  [359] = {.lex_state = 540, .external_lex_state = 2},
  [360] = {.lex_state = 540, .external_lex_state = 2},
  [361] = {.lex_state = 540, .external_lex_state = 2},
  [362] = {.lex_state = 540, .external_lex_state = 2},
  [363] = {.lex_state = 540, .external_lex_state = 2},
  [364] = {.lex_state = 540, .external_lex_state = 2},
  [365] = {.lex_state = 540, .external_lex_state = 2},
  [366] = {.lex_state = 540, .external_lex_state = 2},
  [367] = {.lex_state = 540, .external_lex_state = 2},
  [368] = {.lex_state = 540, .external_lex_state = 2},
  [369] = {.lex_state = 540, .external_lex_state = 2},
  [370] = {.lex_state = 540, .external_lex_state = 2},
  [371] = {.lex_state = 540, .external_lex_state = 2},
  [372] = {.lex_state = 540, .external_lex_state = 2},
  [373] = {.lex_state = 540, .external_lex_state = 2},
  [374] = {.lex_state = 540, .external_lex_state = 2},
  [375] = {.lex_state = 540, .external_lex_state = 2},
  [376] = {.lex_state = 540, .external_lex_state = 2},
  [377] = {.lex_state = 540, .external_lex_state = 2},
  [378] = {.lex_state = 540, .external_lex_state = 2},
  [379] = {.lex_state = 540, .external_lex_state = 2},
  [380] = {.lex_state = 540, .external_lex_state = 2},
  [381] = {.lex_state = 540, .external_lex_state = 2},
  [382] = {.lex_state = 540, .external_lex_state = 2},
  [383] = {.lex_state = 540, .external_lex_state = 2},
  [384] = {.lex_state = 540, .external_lex_state = 2},
  [385] = {.lex_state = 540, .external_lex_state = 2},
  [386] = {.lex_state = 540, .external_lex_state = 2},
  [387] = {.lex_state = 540, .external_lex_state = 2},
  [388] = {.lex_state = 540, .external_lex_state = 2},
  [389] = {.lex_state = 540, .external_lex_state = 2},
  [390] = {.lex_state = 540, .external_lex_state = 2},
  [391] = {.lex_state = 540, .external_lex_state = 2},
  [392] = {.lex_state = 540, .external_lex_state = 2},
  [393] = {.lex_state = 540, .external_lex_state = 2},
  [394] = {.lex_state = 540, .external_lex_state = 2},
  [395] = {.lex_state = 540, .external_lex_state = 2},
  [396] = {.lex_state = 540, .external_lex_state = 2},
  [397] = {.lex_state = 540, .external_lex_state = 2},
  [398] = {.lex_state = 540, .external_lex_state = 2},
  [399] = {.lex_state = 540, .external_lex_state = 2},
  [400] = {.lex_state = 540, .external_lex_state = 2},
  [401] = {.lex_state = 540, .external_lex_state = 2},
  [402] = {.lex_state = 540, .external_lex_state = 2},
  [403] = {.lex_state = 540, .external_lex_state = 2},
  [404] = {.lex_state = 540, .external_lex_state = 2},
  [405] = {.lex_state = 540, .external_lex_state = 2},
  [406] = {.lex_state = 540, .external_lex_state = 2},
  [407] = {.lex_state = 540, .external_lex_state = 2},
  [408] = {.lex_state = 540, .external_lex_state = 2},
  [409] = {.lex_state = 540, .external_lex_state = 2},
  [410] = {.lex_state = 540, .external_lex_state = 2},
  [411] = {.lex_state = 540, .external_lex_state = 2},
  [412] = {.lex_state = 540, .external_lex_state = 2},
  [413] = {.lex_state = 540, .external_lex_state = 2},
  [414] = {.lex_state = 540, .external_lex_state = 2},
  [415] = {.lex_state = 540, .external_lex_state = 2},
  [416] = {.lex_state = 540, .external_lex_state = 2},
  [417] = {.lex_state = 540, .external_lex_state = 2},
  [418] = {.lex_state = 540, .external_lex_state = 2},
  [419] = {.lex_state = 540, .external_lex_state = 2},
  [420] = {.lex_state = 540, .external_lex_state = 2},
  [421] = {.lex_state = 540, .external_lex_state = 2},
  [422] = {.lex_state = 540, .external_lex_state = 2},
  [423] = {.lex_state = 540, .external_lex_state = 2},
  [424] = {.lex_state = 540, .external_lex_state = 2},
  [425] = {.lex_state = 540, .external_lex_state = 2},
  [426] = {.lex_state = 540, .external_lex_state = 2},
  [427] = {.lex_state = 540, .external_lex_state = 2},
  [428] = {.lex_state = 540, .external_lex_state = 2},
  [429] = {.lex_state = 540, .external_lex_state = 2},
  [430] = {.lex_state = 540, .external_lex_state = 2},
  [431] = {.lex_state = 540, .external_lex_state = 2},
  [432] = {.lex_state = 540, .external_lex_state = 2},
  [433] = {.lex_state = 540, .external_lex_state = 2},
  [434] = {.lex_state = 540, .external_lex_state = 2},
  [435] = {.lex_state = 540, .external_lex_state = 2},
  [436] = {.lex_state = 540, .external_lex_state = 2},
  [437] = {.lex_state = 540, .external_lex_state = 2},
  [438] = {.lex_state = 540, .external_lex_state = 2},
  [439] = {.lex_state = 540, .external_lex_state = 2},
  [440] = {.lex_state = 540, .external_lex_state = 2},
  [441] = {.lex_state = 540, .external_lex_state = 2},
  [442] = {.lex_state = 540, .external_lex_state = 2},
  [443] = {.lex_state = 540, .external_lex_state = 2},
  [444] = {.lex_state = 540, .external_lex_state = 2},
  [445] = {.lex_state = 540, .external_lex_state = 2},
  [446] = {.lex_state = 540, .external_lex_state = 2},
  [447] = {.lex_state = 402, .external_lex_state = 7},
  [448] = {.lex_state = 402, .external_lex_state = 7},
  [449] = {.lex_state = 402, .external_lex_state = 7},
  [450] = {.lex_state = 402, .external_lex_state = 7},
  [451] = {.lex_state = 402, .external_lex_state = 7},
  [452] = {.lex_state = 400, .external_lex_state = 8},
  [453] = {.lex_state = 403, .external_lex_state = 8},
  [454] = {.lex_state = 402, .external_lex_state = 7},
  [455] = {.lex_state = 401, .external_lex_state = 8},
  [456] = {.lex_state = 402, .external_lex_state = 7},
  [457] = {.lex_state = 402, .external_lex_state = 7},
  [458] = {.lex_state = 400, .external_lex_state = 8},
  [459] = {.lex_state = 12, .external_lex_state = 9},
  [460] = {.lex_state = 12, .external_lex_state = 9},
  [461] = {.lex_state = 398, .external_lex_state = 10},
  [462] = {.lex_state = 398, .external_lex_state = 10},
  [463] = {.lex_state = 156, .external_lex_state = 4},
  [464] = {.lex_state = 156, .external_lex_state = 4},
  [465] = {.lex_state = 156, .external_lex_state = 4},
  [466] = {.lex_state = 156, .external_lex_state = 4},
  [467] = {.lex_state = 156, .external_lex_state = 4},
  [468] = {.lex_state = 156, .external_lex_state = 4},
  [469] = {.lex_state = 156, .external_lex_state = 4},
  [470] = {.lex_state = 156, .external_lex_state = 4},
  [471] = {.lex_state = 156, .external_lex_state = 4},
  [472] = {.lex_state = 156, .external_lex_state = 4},
  [473] = {.lex_state = 156, .external_lex_state = 4},
  [474] = {.lex_state = 156, .external_lex_state = 4},
  [475] = {.lex_state = 156, .external_lex_state = 4},
  [476] = {.lex_state = 156, .external_lex_state = 4},
  [477] = {.lex_state = 156, .external_lex_state = 4},
  [478] = {.lex_state = 156, .external_lex_state = 4},
  [479] = {.lex_state = 156, .external_lex_state = 4},
  [480] = {.lex_state = 156, .external_lex_state = 4},
  [481] = {.lex_state = 156, .external_lex_state = 4},
  [482] = {.lex_state = 156, .external_lex_state = 4},
  [483] = {.lex_state = 156, .external_lex_state = 4},
  [484] = {.lex_state = 156, .external_lex_state = 4},
  [485] = {.lex_state = 156, .external_lex_state = 4},
  [486] = {.lex_state = 156, .external_lex_state = 4},
  [487] = {.lex_state = 156, .external_lex_state = 4},
  [488] = {.lex_state = 233, .external_lex_state = 11},
  [489] = {.lex_state = 233, .external_lex_state = 11},
  [490] = {.lex_state = 233, .external_lex_state = 11},
  [491] = {.lex_state = 233, .external_lex_state = 11},
  [492] = {.lex_state = 420, .external_lex_state = 5},
  [493] = {.lex_state = 420, .external_lex_state = 5},
  [494] = {.lex_state = 420, .external_lex_state = 5},
  [495] = {.lex_state = 420, .external_lex_state = 5},
  [496] = {.lex_state = 420, .external_lex_state = 5},
  [497] = {.lex_state = 420, .external_lex_state = 5},
  [498] = {.lex_state = 420, .external_lex_state = 5},
  [499] = {.lex_state = 420, .external_lex_state = 5},
  [500] = {.lex_state = 420, .external_lex_state = 5},
  [501] = {.lex_state = 420, .external_lex_state = 5},
  [502] = {.lex_state = 420, .external_lex_state = 5},
  [503] = {.lex_state = 420, .external_lex_state = 5},
  [504] = {.lex_state = 420, .external_lex_state = 5},
  [505] = {.lex_state = 420, .external_lex_state = 5},
  [506] = {.lex_state = 420, .external_lex_state = 5},
  [507] = {.lex_state = 420, .external_lex_state = 5},
  [508] = {.lex_state = 420, .external_lex_state = 5},
  [509] = {.lex_state = 420, .external_lex_state = 5},
  [510] = {.lex_state = 420, .external_lex_state = 5},
  [511] = {.lex_state = 420, .external_lex_state = 5},
  [512] = {.lex_state = 420, .external_lex_state = 5},
  [513] = {.lex_state = 420, .external_lex_state = 5},
  [514] = {.lex_state = 420, .external_lex_state = 5},
  [515] = {.lex_state = 420, .external_lex_state = 5},
  [516] = {.lex_state = 420, .external_lex_state = 5},
  [517] = {.lex_state = 421, .external_lex_state = 12},
  [518] = {.lex_state = 421, .external_lex_state = 12},
  [519] = {.lex_state = 421, .external_lex_state = 12},
  [520] = {.lex_state = 421, .external_lex_state = 12},
  [521] = {.lex_state = 417, .external_lex_state = 2},
  [522] = {.lex_state = 417, .external_lex_state = 2},
  [523] = {.lex_state = 236, .external_lex_state = 13},
  [524] = {.lex_state = 236, .external_lex_state = 13},
  [525] = {.lex_state = 239, .external_lex_state = 11},
  [526] = {.lex_state = 239, .external_lex_state = 11},
  [527] = {.lex_state = 236, .external_lex_state = 14},
  [528] = {.lex_state = 521, .external_lex_state = 11},
  [529] = {.lex_state = 236, .external_lex_state = 14},
  [530] = {.lex_state = 521, .external_lex_state = 11},
  [531] = {.lex_state = 236, .external_lex_state = 14},
  [532] = {.lex_state = 521, .external_lex_state = 11},
  [533] = {.lex_state = 521, .external_lex_state = 11},
  [534] = {.lex_state = 245, .external_lex_state = 15},
  [535] = {.lex_state = 239, .external_lex_state = 16},
  [536] = {.lex_state = 216, .external_lex_state = 17},
  [537] = {.lex_state = 216, .external_lex_state = 17},
  [538] = {.lex_state = 521, .external_lex_state = 11},
  [539] = {.lex_state = 245, .external_lex_state = 15},
  [540] = {.lex_state = 521, .external_lex_state = 11},
  [541] = {.lex_state = 245, .external_lex_state = 15},
  [542] = {.lex_state = 521, .external_lex_state = 11},
  [543] = {.lex_state = 239, .external_lex_state = 16},
  [544] = {.lex_state = 521, .external_lex_state = 11},
  [545] = {.lex_state = 239, .external_lex_state = 16},
  [546] = {.lex_state = 235, .external_lex_state = 9},
  [547] = {.lex_state = 238, .external_lex_state = 18},
  [548] = {.lex_state = 521, .external_lex_state = 16},
  [549] = {.lex_state = 235, .external_lex_state = 9},
  [550] = {.lex_state = 248, .external_lex_state = 19},
  [551] = {.lex_state = 521, .external_lex_state = 16},
  [552] = {.lex_state = 521, .external_lex_state = 16},
  [553] = {.lex_state = 521, .external_lex_state = 16},
  [554] = {.lex_state = 248, .external_lex_state = 19},
  [555] = {.lex_state = 521, .external_lex_state = 16},
  [556] = {.lex_state = 521, .external_lex_state = 16},
  [557] = {.lex_state = 248, .external_lex_state = 19},
  [558] = {.lex_state = 238, .external_lex_state = 18},
  [559] = {.lex_state = 525, .external_lex_state = 19},
  [560] = {.lex_state = 241, .external_lex_state = 20},
  [561] = {.lex_state = 521, .external_lex_state = 16},
  [562] = {.lex_state = 521, .external_lex_state = 16},
  [563] = {.lex_state = 525, .external_lex_state = 19},
  [564] = {.lex_state = 241, .external_lex_state = 20},
  [565] = {.lex_state = 525, .external_lex_state = 19},
  [566] = {.lex_state = 525, .external_lex_state = 19},
  [567] = {.lex_state = 522, .external_lex_state = 9},
  [568] = {.lex_state = 525, .external_lex_state = 19},
  [569] = {.lex_state = 254, .external_lex_state = 15},
  [570] = {.lex_state = 540, .external_lex_state = 2},
  [571] = {.lex_state = 254, .external_lex_state = 15},
  [572] = {.lex_state = 254, .external_lex_state = 15},
  [573] = {.lex_state = 525, .external_lex_state = 19},
  [574] = {.lex_state = 522, .external_lex_state = 9},
  [575] = {.lex_state = 247, .external_lex_state = 9},
  [576] = {.lex_state = 247, .external_lex_state = 9},
  [577] = {.lex_state = 521, .external_lex_state = 16},
  [578] = {.lex_state = 521, .external_lex_state = 16},
  [579] = {.lex_state = 521, .external_lex_state = 16},
  [580] = {.lex_state = 415, .external_lex_state = 6},
  [581] = {.lex_state = 239, .external_lex_state = 11},
  [582] = {.lex_state = 524, .external_lex_state = 20},
  [583] = {.lex_state = 524, .external_lex_state = 20},
  [584] = {.lex_state = 253, .external_lex_state = 20},
  [585] = {.lex_state = 253, .external_lex_state = 20},
  [586] = {.lex_state = 254, .external_lex_state = 15},
  [587] = {.lex_state = 254, .external_lex_state = 15},
  [588] = {.lex_state = 245, .external_lex_state = 21},
  [589] = {.lex_state = 525, .external_lex_state = 19},
  [590] = {.lex_state = 540, .external_lex_state = 2},
  [591] = {.lex_state = 245, .external_lex_state = 21},
  [592] = {.lex_state = 254, .external_lex_state = 21},
  [593] = {.lex_state = 254, .external_lex_state = 21},
  [594] = {.lex_state = 254, .external_lex_state = 21},
  [595] = {.lex_state = 257, .external_lex_state = 19},
  [596] = {.lex_state = 257, .external_lex_state = 19},
  [597] = {.lex_state = 257, .external_lex_state = 19},
  [598] = {.lex_state = 245, .external_lex_state = 21},
  [599] = {.lex_state = 415, .external_lex_state = 6},
  [600] = {.lex_state = 525, .external_lex_state = 19},
  [601] = {.lex_state = 525, .external_lex_state = 19},
  [602] = {.lex_state = 522, .external_lex_state = 9},
  [603] = {.lex_state = 525, .external_lex_state = 19},
  [604] = {.lex_state = 522, .external_lex_state = 9},
  [605] = {.lex_state = 239, .external_lex_state = 11},
  [606] = {.lex_state = 540, .external_lex_state = 2},
  [607] = {.lex_state = 525, .external_lex_state = 19},
  [608] = {.lex_state = 451, .external_lex_state = 2},
  [609] = {.lex_state = 527, .external_lex_state = 19},
  [610] = {.lex_state = 451, .external_lex_state = 2},
  [611] = {.lex_state = 248, .external_lex_state = 22},
  [612] = {.lex_state = 257, .external_lex_state = 19},
  [613] = {.lex_state = 257, .external_lex_state = 19},
  [614] = {.lex_state = 248, .external_lex_state = 22},
  [615] = {.lex_state = 527, .external_lex_state = 19},
  [616] = {.lex_state = 527, .external_lex_state = 19},
  [617] = {.lex_state = 257, .external_lex_state = 22},
  [618] = {.lex_state = 451, .external_lex_state = 2},
  [619] = {.lex_state = 455, .external_lex_state = 23},
  [620] = {.lex_state = 257, .external_lex_state = 22},
  [621] = {.lex_state = 257, .external_lex_state = 22},
  [622] = {.lex_state = 527, .external_lex_state = 19},
  [623] = {.lex_state = 527, .external_lex_state = 19},
  [624] = {.lex_state = 451, .external_lex_state = 2},
  [625] = {.lex_state = 256, .external_lex_state = 15},
  [626] = {.lex_state = 451, .external_lex_state = 2},
  [627] = {.lex_state = 256, .external_lex_state = 15},
  [628] = {.lex_state = 256, .external_lex_state = 15},
  [629] = {.lex_state = 527, .external_lex_state = 19},
  [630] = {.lex_state = 524, .external_lex_state = 20},
  [631] = {.lex_state = 451, .external_lex_state = 2},
  [632] = {.lex_state = 524, .external_lex_state = 20},
  [633] = {.lex_state = 263, .external_lex_state = 21},
  [634] = {.lex_state = 451, .external_lex_state = 2},
  [635] = {.lex_state = 263, .external_lex_state = 21},
  [636] = {.lex_state = 248, .external_lex_state = 22},
  [637] = {.lex_state = 451, .external_lex_state = 2},
  [638] = {.lex_state = 263, .external_lex_state = 21},
  [639] = {.lex_state = 455, .external_lex_state = 23},
  [640] = {.lex_state = 254, .external_lex_state = 21},
  [641] = {.lex_state = 254, .external_lex_state = 21},
  [642] = {.lex_state = 256, .external_lex_state = 15},
  [643] = {.lex_state = 239, .external_lex_state = 16},
  [644] = {.lex_state = 525, .external_lex_state = 22},
  [645] = {.lex_state = 527, .external_lex_state = 22},
  [646] = {.lex_state = 527, .external_lex_state = 22},
  [647] = {.lex_state = 527, .external_lex_state = 22},
  [648] = {.lex_state = 525, .external_lex_state = 22},
  [649] = {.lex_state = 527, .external_lex_state = 19},
  [650] = {.lex_state = 259, .external_lex_state = 19},
  [651] = {.lex_state = 527, .external_lex_state = 19},
  [652] = {.lex_state = 263, .external_lex_state = 21},
  [653] = {.lex_state = 263, .external_lex_state = 21},
  [654] = {.lex_state = 527, .external_lex_state = 19},
  [655] = {.lex_state = 527, .external_lex_state = 19},
  [656] = {.lex_state = 525, .external_lex_state = 22},
  [657] = {.lex_state = 525, .external_lex_state = 22},
  [658] = {.lex_state = 259, .external_lex_state = 19},
  [659] = {.lex_state = 527, .external_lex_state = 22},
  [660] = {.lex_state = 266, .external_lex_state = 22},
  [661] = {.lex_state = 266, .external_lex_state = 22},
  [662] = {.lex_state = 266, .external_lex_state = 22},
  [663] = {.lex_state = 525, .external_lex_state = 22},
  [664] = {.lex_state = 257, .external_lex_state = 22},
  [665] = {.lex_state = 257, .external_lex_state = 22},
  [666] = {.lex_state = 527, .external_lex_state = 22},
  [667] = {.lex_state = 262, .external_lex_state = 15},
  [668] = {.lex_state = 262, .external_lex_state = 15},
  [669] = {.lex_state = 262, .external_lex_state = 15},
  [670] = {.lex_state = 262, .external_lex_state = 15},
  [671] = {.lex_state = 262, .external_lex_state = 15},
  [672] = {.lex_state = 262, .external_lex_state = 15},
  [673] = {.lex_state = 527, .external_lex_state = 22},
  [674] = {.lex_state = 259, .external_lex_state = 19},
  [675] = {.lex_state = 259, .external_lex_state = 19},
  [676] = {.lex_state = 527, .external_lex_state = 19},
  [677] = {.lex_state = 527, .external_lex_state = 19},
  [678] = {.lex_state = 527, .external_lex_state = 19},
  [679] = {.lex_state = 239, .external_lex_state = 16},
  [680] = {.lex_state = 239, .external_lex_state = 16},
  [681] = {.lex_state = 525, .external_lex_state = 22},
  [682] = {.lex_state = 540, .external_lex_state = 2},
  [683] = {.lex_state = 266, .external_lex_state = 22},
  [684] = {.lex_state = 527, .external_lex_state = 22},
  [685] = {.lex_state = 266, .external_lex_state = 22},
  [686] = {.lex_state = 527, .external_lex_state = 22},
  [687] = {.lex_state = 269, .external_lex_state = 24},
  [688] = {.lex_state = 269, .external_lex_state = 24},
  [689] = {.lex_state = 269, .external_lex_state = 24},
  [690] = {.lex_state = 529, .external_lex_state = 22},
  [691] = {.lex_state = 540, .external_lex_state = 2},
  [692] = {.lex_state = 528, .external_lex_state = 19},
  [693] = {.lex_state = 528, .external_lex_state = 19},
  [694] = {.lex_state = 269, .external_lex_state = 24},
  [695] = {.lex_state = 455, .external_lex_state = 25},
  [696] = {.lex_state = 269, .external_lex_state = 24},
  [697] = {.lex_state = 269, .external_lex_state = 24},
  [698] = {.lex_state = 529, .external_lex_state = 22},
  [699] = {.lex_state = 455, .external_lex_state = 25},
  [700] = {.lex_state = 268, .external_lex_state = 9},
  [701] = {.lex_state = 268, .external_lex_state = 9},
  [702] = {.lex_state = 455, .external_lex_state = 25},
  [703] = {.lex_state = 527, .external_lex_state = 22},
  [704] = {.lex_state = 269, .external_lex_state = 24},
  [705] = {.lex_state = 525, .external_lex_state = 22},
  [706] = {.lex_state = 269, .external_lex_state = 24},
  [707] = {.lex_state = 529, .external_lex_state = 22},
  [708] = {.lex_state = 269, .external_lex_state = 24},
  [709] = {.lex_state = 527, .external_lex_state = 22},
  [710] = {.lex_state = 269, .external_lex_state = 24},
  [711] = {.lex_state = 529, .external_lex_state = 22},
  [712] = {.lex_state = 527, .external_lex_state = 22},
  [713] = {.lex_state = 271, .external_lex_state = 19},
  [714] = {.lex_state = 529, .external_lex_state = 22},
  [715] = {.lex_state = 271, .external_lex_state = 19},
  [716] = {.lex_state = 525, .external_lex_state = 22},
  [717] = {.lex_state = 271, .external_lex_state = 19},
  [718] = {.lex_state = 527, .external_lex_state = 22},
  [719] = {.lex_state = 273, .external_lex_state = 19},
  [720] = {.lex_state = 527, .external_lex_state = 22},
  [721] = {.lex_state = 525, .external_lex_state = 22},
  [722] = {.lex_state = 527, .external_lex_state = 22},
  [723] = {.lex_state = 529, .external_lex_state = 22},
  [724] = {.lex_state = 527, .external_lex_state = 22},
  [725] = {.lex_state = 525, .external_lex_state = 22},
  [726] = {.lex_state = 540, .external_lex_state = 2},
  [727] = {.lex_state = 271, .external_lex_state = 19},
  [728] = {.lex_state = 248, .external_lex_state = 19},
  [729] = {.lex_state = 528, .external_lex_state = 19},
  [730] = {.lex_state = 273, .external_lex_state = 19},
  [731] = {.lex_state = 248, .external_lex_state = 19},
  [732] = {.lex_state = 273, .external_lex_state = 19},
  [733] = {.lex_state = 271, .external_lex_state = 19},
  [734] = {.lex_state = 271, .external_lex_state = 19},
  [735] = {.lex_state = 273, .external_lex_state = 19},
  [736] = {.lex_state = 525, .external_lex_state = 22},
  [737] = {.lex_state = 527, .external_lex_state = 19},
  [738] = {.lex_state = 528, .external_lex_state = 19},
  [739] = {.lex_state = 527, .external_lex_state = 19},
  [740] = {.lex_state = 248, .external_lex_state = 19},
  [741] = {.lex_state = 416, .external_lex_state = 2},
  [742] = {.lex_state = 530, .external_lex_state = 19},
  [743] = {.lex_state = 529, .external_lex_state = 22},
  [744] = {.lex_state = 530, .external_lex_state = 19},
  [745] = {.lex_state = 277, .external_lex_state = 19},
  [746] = {.lex_state = 277, .external_lex_state = 19},
  [747] = {.lex_state = 464, .external_lex_state = 26},
  [748] = {.lex_state = 530, .external_lex_state = 19},
  [749] = {.lex_state = 405, .external_lex_state = 27},
  [750] = {.lex_state = 405, .external_lex_state = 27},
  [751] = {.lex_state = 530, .external_lex_state = 19},
  [752] = {.lex_state = 530, .external_lex_state = 19},
  [753] = {.lex_state = 540, .external_lex_state = 2},
  [754] = {.lex_state = 279, .external_lex_state = 20},
  [755] = {.lex_state = 279, .external_lex_state = 20},
  [756] = {.lex_state = 529, .external_lex_state = 22},
  [757] = {.lex_state = 529, .external_lex_state = 22},
  [758] = {.lex_state = 529, .external_lex_state = 22},
  [759] = {.lex_state = 529, .external_lex_state = 22},
  [760] = {.lex_state = 277, .external_lex_state = 19},
  [761] = {.lex_state = 464, .external_lex_state = 26},
  [762] = {.lex_state = 527, .external_lex_state = 22},
  [763] = {.lex_state = 540, .external_lex_state = 2},
  [764] = {.lex_state = 527, .external_lex_state = 22},
  [765] = {.lex_state = 529, .external_lex_state = 22},
  [766] = {.lex_state = 529, .external_lex_state = 22},
  [767] = {.lex_state = 277, .external_lex_state = 19},
  [768] = {.lex_state = 529, .external_lex_state = 22},
  [769] = {.lex_state = 527, .external_lex_state = 22},
  [770] = {.lex_state = 527, .external_lex_state = 22},
  [771] = {.lex_state = 529, .external_lex_state = 22},
  [772] = {.lex_state = 277, .external_lex_state = 19},
  [773] = {.lex_state = 277, .external_lex_state = 19},
  [774] = {.lex_state = 528, .external_lex_state = 19},
  [775] = {.lex_state = 530, .external_lex_state = 19},
  [776] = {.lex_state = 528, .external_lex_state = 19},
  [777] = {.lex_state = 528, .external_lex_state = 19},
  [778] = {.lex_state = 540, .external_lex_state = 2},
  [779] = {.lex_state = 464, .external_lex_state = 26},
  [780] = {.lex_state = 528, .external_lex_state = 19},
  [781] = {.lex_state = 274, .external_lex_state = 28},
  [782] = {.lex_state = 254, .external_lex_state = 15},
  [783] = {.lex_state = 274, .external_lex_state = 28},
  [784] = {.lex_state = 530, .external_lex_state = 19},
  [785] = {.lex_state = 254, .external_lex_state = 15},
  [786] = {.lex_state = 458, .external_lex_state = 29},
  [787] = {.lex_state = 530, .external_lex_state = 19},
  [788] = {.lex_state = 529, .external_lex_state = 22},
  [789] = {.lex_state = 529, .external_lex_state = 22},
  [790] = {.lex_state = 529, .external_lex_state = 22},
  [791] = {.lex_state = 529, .external_lex_state = 22},
  [792] = {.lex_state = 406, .external_lex_state = 30},
  [793] = {.lex_state = 254, .external_lex_state = 15},
  [794] = {.lex_state = 458, .external_lex_state = 29},
  [795] = {.lex_state = 257, .external_lex_state = 19},
  [796] = {.lex_state = 274, .external_lex_state = 28},
  [797] = {.lex_state = 257, .external_lex_state = 19},
  [798] = {.lex_state = 257, .external_lex_state = 19},
  [799] = {.lex_state = 406, .external_lex_state = 30},
  [800] = {.lex_state = 254, .external_lex_state = 15},
  [801] = {.lex_state = 458, .external_lex_state = 29},
  [802] = {.lex_state = 274, .external_lex_state = 28},
  [803] = {.lex_state = 274, .external_lex_state = 28},
  [804] = {.lex_state = 274, .external_lex_state = 28},
  [805] = {.lex_state = 274, .external_lex_state = 28},
  [806] = {.lex_state = 530, .external_lex_state = 19},
  [807] = {.lex_state = 530, .external_lex_state = 19},
  [808] = {.lex_state = 530, .external_lex_state = 19},
  [809] = {.lex_state = 530, .external_lex_state = 19},
  [810] = {.lex_state = 274, .external_lex_state = 31},
  [811] = {.lex_state = 274, .external_lex_state = 28},
  [812] = {.lex_state = 274, .external_lex_state = 28},
  [813] = {.lex_state = 274, .external_lex_state = 31},
  [814] = {.lex_state = 257, .external_lex_state = 19},
  [815] = {.lex_state = 274, .external_lex_state = 31},
  [816] = {.lex_state = 274, .external_lex_state = 31},
  [817] = {.lex_state = 274, .external_lex_state = 31},
  [818] = {.lex_state = 274, .external_lex_state = 31},
  [819] = {.lex_state = 274, .external_lex_state = 31},
  [820] = {.lex_state = 458, .external_lex_state = 32},
  [821] = {.lex_state = 458, .external_lex_state = 32},
  [822] = {.lex_state = 257, .external_lex_state = 22},
  [823] = {.lex_state = 458, .external_lex_state = 29},
  [824] = {.lex_state = 274, .external_lex_state = 28},
  [825] = {.lex_state = 274, .external_lex_state = 28},
  [826] = {.lex_state = 274, .external_lex_state = 31},
  [827] = {.lex_state = 257, .external_lex_state = 22},
  [828] = {.lex_state = 274, .external_lex_state = 31},
  [829] = {.lex_state = 458, .external_lex_state = 32},
  [830] = {.lex_state = 276, .external_lex_state = 4},
  [831] = {.lex_state = 276, .external_lex_state = 4},
  [832] = {.lex_state = 274, .external_lex_state = 28},
  [833] = {.lex_state = 276, .external_lex_state = 4},
  [834] = {.lex_state = 274, .external_lex_state = 28},
  [835] = {.lex_state = 276, .external_lex_state = 4},
  [836] = {.lex_state = 274, .external_lex_state = 28},
  [837] = {.lex_state = 274, .external_lex_state = 28},
  [838] = {.lex_state = 274, .external_lex_state = 31},
  [839] = {.lex_state = 274, .external_lex_state = 31},
  [840] = {.lex_state = 276, .external_lex_state = 4},
  [841] = {.lex_state = 274, .external_lex_state = 28},
  [842] = {.lex_state = 454, .external_lex_state = 26},
  [843] = {.lex_state = 248, .external_lex_state = 22},
  [844] = {.lex_state = 454, .external_lex_state = 26},
  [845] = {.lex_state = 458, .external_lex_state = 29},
  [846] = {.lex_state = 257, .external_lex_state = 19},
  [847] = {.lex_state = 274, .external_lex_state = 28},
  [848] = {.lex_state = 274, .external_lex_state = 28},
  [849] = {.lex_state = 276, .external_lex_state = 4},
  [850] = {.lex_state = 454, .external_lex_state = 26},
  [851] = {.lex_state = 248, .external_lex_state = 22},
  [852] = {.lex_state = 274, .external_lex_state = 28},
  [853] = {.lex_state = 274, .external_lex_state = 28},
  [854] = {.lex_state = 257, .external_lex_state = 22},
  [855] = {.lex_state = 257, .external_lex_state = 19},
  [856] = {.lex_state = 274, .external_lex_state = 31},
  [857] = {.lex_state = 274, .external_lex_state = 28},
  [858] = {.lex_state = 274, .external_lex_state = 28},
  [859] = {.lex_state = 274, .external_lex_state = 28},
  [860] = {.lex_state = 257, .external_lex_state = 19},
  [861] = {.lex_state = 274, .external_lex_state = 28},
  [862] = {.lex_state = 274, .external_lex_state = 28},
  [863] = {.lex_state = 248, .external_lex_state = 22},
  [864] = {.lex_state = 257, .external_lex_state = 19},
  [865] = {.lex_state = 276, .external_lex_state = 4},
  [866] = {.lex_state = 257, .external_lex_state = 19},
  [867] = {.lex_state = 274, .external_lex_state = 28},
  [868] = {.lex_state = 527, .external_lex_state = 19},
  [869] = {.lex_state = 454, .external_lex_state = 26},
  [870] = {.lex_state = 454, .external_lex_state = 33},
  [871] = {.lex_state = 454, .external_lex_state = 33},
  [872] = {.lex_state = 454, .external_lex_state = 33},
  [873] = {.lex_state = 527, .external_lex_state = 19},
  [874] = {.lex_state = 407, .external_lex_state = 29},
  [875] = {.lex_state = 407, .external_lex_state = 29},
  [876] = {.lex_state = 464, .external_lex_state = 33},
  [877] = {.lex_state = 531, .external_lex_state = 4},
  [878] = {.lex_state = 276, .external_lex_state = 34},
  [879] = {.lex_state = 276, .external_lex_state = 34},
  [880] = {.lex_state = 452, .external_lex_state = 35},
  [881] = {.lex_state = 276, .external_lex_state = 34},
  [882] = {.lex_state = 276, .external_lex_state = 34},
  [883] = {.lex_state = 531, .external_lex_state = 4},
  [884] = {.lex_state = 527, .external_lex_state = 19},
  [885] = {.lex_state = 464, .external_lex_state = 33},
  [886] = {.lex_state = 531, .external_lex_state = 4},
  [887] = {.lex_state = 236, .external_lex_state = 13},
  [888] = {.lex_state = 274, .external_lex_state = 31},
  [889] = {.lex_state = 274, .external_lex_state = 31},
  [890] = {.lex_state = 274, .external_lex_state = 31},
  [891] = {.lex_state = 274, .external_lex_state = 31},
  [892] = {.lex_state = 274, .external_lex_state = 31},
  [893] = {.lex_state = 274, .external_lex_state = 31},
  [894] = {.lex_state = 274, .external_lex_state = 31},
  [895] = {.lex_state = 531, .external_lex_state = 4},
  [896] = {.lex_state = 276, .external_lex_state = 4},
  [897] = {.lex_state = 276, .external_lex_state = 4},
  [898] = {.lex_state = 276, .external_lex_state = 4},
  [899] = {.lex_state = 276, .external_lex_state = 4},
  [900] = {.lex_state = 281, .external_lex_state = 19},
  [901] = {.lex_state = 281, .external_lex_state = 19},
  [902] = {.lex_state = 276, .external_lex_state = 4},
  [903] = {.lex_state = 274, .external_lex_state = 31},
  [904] = {.lex_state = 274, .external_lex_state = 31},
  [905] = {.lex_state = 276, .external_lex_state = 4},
  [906] = {.lex_state = 276, .external_lex_state = 4},
  [907] = {.lex_state = 276, .external_lex_state = 34},
  [908] = {.lex_state = 274, .external_lex_state = 31},
  [909] = {.lex_state = 274, .external_lex_state = 31},
  [910] = {.lex_state = 276, .external_lex_state = 34},
  [911] = {.lex_state = 276, .external_lex_state = 34},
  [912] = {.lex_state = 276, .external_lex_state = 34},
  [913] = {.lex_state = 276, .external_lex_state = 4},
  [914] = {.lex_state = 276, .external_lex_state = 4},
  [915] = {.lex_state = 274, .external_lex_state = 31},
  [916] = {.lex_state = 274, .external_lex_state = 31},
  [917] = {.lex_state = 274, .external_lex_state = 31},
  [918] = {.lex_state = 274, .external_lex_state = 31},
  [919] = {.lex_state = 274, .external_lex_state = 31},
  [920] = {.lex_state = 276, .external_lex_state = 4},
  [921] = {.lex_state = 276, .external_lex_state = 4},
  [922] = {.lex_state = 274, .external_lex_state = 31},
  [923] = {.lex_state = 274, .external_lex_state = 31},
  [924] = {.lex_state = 454, .external_lex_state = 26},
  [925] = {.lex_state = 281, .external_lex_state = 19},
  [926] = {.lex_state = 281, .external_lex_state = 19},
  [927] = {.lex_state = 276, .external_lex_state = 4},
  [928] = {.lex_state = 276, .external_lex_state = 4},
  [929] = {.lex_state = 276, .external_lex_state = 4},
  [930] = {.lex_state = 276, .external_lex_state = 4},
  [931] = {.lex_state = 531, .external_lex_state = 4},
  [932] = {.lex_state = 276, .external_lex_state = 4},
  [933] = {.lex_state = 464, .external_lex_state = 33},
  [934] = {.lex_state = 276, .external_lex_state = 4},
  [935] = {.lex_state = 276, .external_lex_state = 4},
  [936] = {.lex_state = 276, .external_lex_state = 4},
  [937] = {.lex_state = 452, .external_lex_state = 35},
  [938] = {.lex_state = 452, .external_lex_state = 35},
  [939] = {.lex_state = 527, .external_lex_state = 19},
  [940] = {.lex_state = 407, .external_lex_state = 29},
  [941] = {.lex_state = 407, .external_lex_state = 29},
  [942] = {.lex_state = 452, .external_lex_state = 35},
  [943] = {.lex_state = 236, .external_lex_state = 13},
  [944] = {.lex_state = 531, .external_lex_state = 4},
  [945] = {.lex_state = 531, .external_lex_state = 4},
  [946] = {.lex_state = 266, .external_lex_state = 22},
  [947] = {.lex_state = 266, .external_lex_state = 22},
  [948] = {.lex_state = 266, .external_lex_state = 22},
  [949] = {.lex_state = 452, .external_lex_state = 35},
  [950] = {.lex_state = 531, .external_lex_state = 4},
  [951] = {.lex_state = 276, .external_lex_state = 34},
  [952] = {.lex_state = 276, .external_lex_state = 34},
  [953] = {.lex_state = 527, .external_lex_state = 19},
  [954] = {.lex_state = 531, .external_lex_state = 4},
  [955] = {.lex_state = 531, .external_lex_state = 4},
  [956] = {.lex_state = 531, .external_lex_state = 4},
  [957] = {.lex_state = 531, .external_lex_state = 4},
  [958] = {.lex_state = 527, .external_lex_state = 19},
  [959] = {.lex_state = 276, .external_lex_state = 34},
  [960] = {.lex_state = 276, .external_lex_state = 34},
  [961] = {.lex_state = 452, .external_lex_state = 35},
  [962] = {.lex_state = 527, .external_lex_state = 19},
  [963] = {.lex_state = 531, .external_lex_state = 4},
  [964] = {.lex_state = 463, .external_lex_state = 32},
  [965] = {.lex_state = 463, .external_lex_state = 32},
  [966] = {.lex_state = 458, .external_lex_state = 32},
  [967] = {.lex_state = 458, .external_lex_state = 32},
  [968] = {.lex_state = 531, .external_lex_state = 4},
  [969] = {.lex_state = 527, .external_lex_state = 19},
  [970] = {.lex_state = 452, .external_lex_state = 35},
  [971] = {.lex_state = 463, .external_lex_state = 32},
  [972] = {.lex_state = 424, .external_lex_state = 36},
  [973] = {.lex_state = 424, .external_lex_state = 36},
  [974] = {.lex_state = 452, .external_lex_state = 35},
  [975] = {.lex_state = 257, .external_lex_state = 22},
  [976] = {.lex_state = 257, .external_lex_state = 22},
  [977] = {.lex_state = 274, .external_lex_state = 31},
  [978] = {.lex_state = 531, .external_lex_state = 4},
  [979] = {.lex_state = 409, .external_lex_state = 29},
  [980] = {.lex_state = 423, .external_lex_state = 37},
  [981] = {.lex_state = 423, .external_lex_state = 37},
  [982] = {.lex_state = 531, .external_lex_state = 34},
  [983] = {.lex_state = 531, .external_lex_state = 4},
  [984] = {.lex_state = 236, .external_lex_state = 13},
  [985] = {.lex_state = 280, .external_lex_state = 38},
  [986] = {.lex_state = 280, .external_lex_state = 38},
  [987] = {.lex_state = 280, .external_lex_state = 38},
  [988] = {.lex_state = 282, .external_lex_state = 38},
  [989] = {.lex_state = 282, .external_lex_state = 38},
  [990] = {.lex_state = 282, .external_lex_state = 38},
  [991] = {.lex_state = 280, .external_lex_state = 38},
  [992] = {.lex_state = 282, .external_lex_state = 38},
  [993] = {.lex_state = 527, .external_lex_state = 19},
  [994] = {.lex_state = 531, .external_lex_state = 34},
  [995] = {.lex_state = 236, .external_lex_state = 14},
  [996] = {.lex_state = 531, .external_lex_state = 4},
  [997] = {.lex_state = 531, .external_lex_state = 4},
  [998] = {.lex_state = 460, .external_lex_state = 33},
  [999] = {.lex_state = 460, .external_lex_state = 33},
  [1000] = {.lex_state = 460, .external_lex_state = 33},
  [1001] = {.lex_state = 454, .external_lex_state = 33},
  [1002] = {.lex_state = 283, .external_lex_state = 19},
  [1003] = {.lex_state = 454, .external_lex_state = 33},
  [1004] = {.lex_state = 283, .external_lex_state = 19},
  [1005] = {.lex_state = 239, .external_lex_state = 11},
  [1006] = {.lex_state = 283, .external_lex_state = 19},
  [1007] = {.lex_state = 283, .external_lex_state = 19},
  [1008] = {.lex_state = 280, .external_lex_state = 38},
  [1009] = {.lex_state = 280, .external_lex_state = 38},
  [1010] = {.lex_state = 276, .external_lex_state = 34},
  [1011] = {.lex_state = 276, .external_lex_state = 34},
  [1012] = {.lex_state = 276, .external_lex_state = 34},
  [1013] = {.lex_state = 276, .external_lex_state = 34},
  [1014] = {.lex_state = 276, .external_lex_state = 34},
  [1015] = {.lex_state = 280, .external_lex_state = 38},
  [1016] = {.lex_state = 280, .external_lex_state = 38},
  [1017] = {.lex_state = 276, .external_lex_state = 34},
  [1018] = {.lex_state = 276, .external_lex_state = 34},
  [1019] = {.lex_state = 280, .external_lex_state = 38},
  [1020] = {.lex_state = 280, .external_lex_state = 38},
  [1021] = {.lex_state = 280, .external_lex_state = 38},
  [1022] = {.lex_state = 283, .external_lex_state = 19},
  [1023] = {.lex_state = 283, .external_lex_state = 19},
  [1024] = {.lex_state = 276, .external_lex_state = 34},
  [1025] = {.lex_state = 276, .external_lex_state = 34},
  [1026] = {.lex_state = 531, .external_lex_state = 34},
  [1027] = {.lex_state = 236, .external_lex_state = 14},
  [1028] = {.lex_state = 531, .external_lex_state = 34},
  [1029] = {.lex_state = 236, .external_lex_state = 14},
  [1030] = {.lex_state = 276, .external_lex_state = 34},
  [1031] = {.lex_state = 276, .external_lex_state = 34},
  [1032] = {.lex_state = 531, .external_lex_state = 4},
  [1033] = {.lex_state = 276, .external_lex_state = 34},
  [1034] = {.lex_state = 276, .external_lex_state = 34},
  [1035] = {.lex_state = 276, .external_lex_state = 34},
  [1036] = {.lex_state = 276, .external_lex_state = 34},
  [1037] = {.lex_state = 276, .external_lex_state = 34},
  [1038] = {.lex_state = 276, .external_lex_state = 34},
  [1039] = {.lex_state = 276, .external_lex_state = 34},
  [1040] = {.lex_state = 276, .external_lex_state = 34},
  [1041] = {.lex_state = 531, .external_lex_state = 4},
  [1042] = {.lex_state = 531, .external_lex_state = 4},
  [1043] = {.lex_state = 531, .external_lex_state = 4},
  [1044] = {.lex_state = 531, .external_lex_state = 4},
  [1045] = {.lex_state = 427, .external_lex_state = 39},
  [1046] = {.lex_state = 531, .external_lex_state = 4},
  [1047] = {.lex_state = 527, .external_lex_state = 19},
  [1048] = {.lex_state = 531, .external_lex_state = 4},
  [1049] = {.lex_state = 531, .external_lex_state = 4},
  [1050] = {.lex_state = 531, .external_lex_state = 4},
  [1051] = {.lex_state = 531, .external_lex_state = 4},
  [1052] = {.lex_state = 531, .external_lex_state = 4},
  [1053] = {.lex_state = 531, .external_lex_state = 34},
  [1054] = {.lex_state = 531, .external_lex_state = 4},
  [1055] = {.lex_state = 531, .external_lex_state = 34},
  [1056] = {.lex_state = 236, .external_lex_state = 13},
  [1057] = {.lex_state = 408, .external_lex_state = 26},
  [1058] = {.lex_state = 408, .external_lex_state = 26},
  [1059] = {.lex_state = 424, .external_lex_state = 40},
  [1060] = {.lex_state = 527, .external_lex_state = 19},
  [1061] = {.lex_state = 424, .external_lex_state = 40},
  [1062] = {.lex_state = 409, .external_lex_state = 29},
  [1063] = {.lex_state = 282, .external_lex_state = 38},
  [1064] = {.lex_state = 282, .external_lex_state = 38},
  [1065] = {.lex_state = 408, .external_lex_state = 26},
  [1066] = {.lex_state = 531, .external_lex_state = 4},
  [1067] = {.lex_state = 531, .external_lex_state = 4},
  [1068] = {.lex_state = 531, .external_lex_state = 4},
  [1069] = {.lex_state = 531, .external_lex_state = 4},
  [1070] = {.lex_state = 531, .external_lex_state = 4},
  [1071] = {.lex_state = 236, .external_lex_state = 14},
  [1072] = {.lex_state = 531, .external_lex_state = 4},
  [1073] = {.lex_state = 531, .external_lex_state = 4},
  [1074] = {.lex_state = 527, .external_lex_state = 19},
  [1075] = {.lex_state = 531, .external_lex_state = 4},
  [1076] = {.lex_state = 531, .external_lex_state = 4},
  [1077] = {.lex_state = 531, .external_lex_state = 4},
  [1078] = {.lex_state = 531, .external_lex_state = 4},
  [1079] = {.lex_state = 531, .external_lex_state = 4},
  [1080] = {.lex_state = 531, .external_lex_state = 4},
  [1081] = {.lex_state = 531, .external_lex_state = 4},
  [1082] = {.lex_state = 531, .external_lex_state = 4},
  [1083] = {.lex_state = 236, .external_lex_state = 14},
  [1084] = {.lex_state = 531, .external_lex_state = 4},
  [1085] = {.lex_state = 531, .external_lex_state = 4},
  [1086] = {.lex_state = 531, .external_lex_state = 4},
  [1087] = {.lex_state = 531, .external_lex_state = 4},
  [1088] = {.lex_state = 531, .external_lex_state = 4},
  [1089] = {.lex_state = 239, .external_lex_state = 11},
  [1090] = {.lex_state = 531, .external_lex_state = 4},
  [1091] = {.lex_state = 531, .external_lex_state = 4},
  [1092] = {.lex_state = 527, .external_lex_state = 19},
  [1093] = {.lex_state = 531, .external_lex_state = 4},
  [1094] = {.lex_state = 531, .external_lex_state = 34},
  [1095] = {.lex_state = 531, .external_lex_state = 34},
  [1096] = {.lex_state = 280, .external_lex_state = 38},
  [1097] = {.lex_state = 527, .external_lex_state = 19},
  [1098] = {.lex_state = 527, .external_lex_state = 19},
  [1099] = {.lex_state = 531, .external_lex_state = 34},
  [1100] = {.lex_state = 531, .external_lex_state = 34},
  [1101] = {.lex_state = 531, .external_lex_state = 34},
  [1102] = {.lex_state = 531, .external_lex_state = 34},
  [1103] = {.lex_state = 425, .external_lex_state = 37},
  [1104] = {.lex_state = 425, .external_lex_state = 37},
  [1105] = {.lex_state = 531, .external_lex_state = 34},
  [1106] = {.lex_state = 531, .external_lex_state = 34},
  [1107] = {.lex_state = 531, .external_lex_state = 34},
  [1108] = {.lex_state = 531, .external_lex_state = 34},
  [1109] = {.lex_state = 531, .external_lex_state = 4},
  [1110] = {.lex_state = 531, .external_lex_state = 4},
  [1111] = {.lex_state = 463, .external_lex_state = 32},
  [1112] = {.lex_state = 531, .external_lex_state = 34},
  [1113] = {.lex_state = 463, .external_lex_state = 32},
  [1114] = {.lex_state = 531, .external_lex_state = 34},
  [1115] = {.lex_state = 531, .external_lex_state = 34},
  [1116] = {.lex_state = 531, .external_lex_state = 34},
  [1117] = {.lex_state = 531, .external_lex_state = 34},
  [1118] = {.lex_state = 531, .external_lex_state = 34},
  [1119] = {.lex_state = 531, .external_lex_state = 34},
  [1120] = {.lex_state = 531, .external_lex_state = 34},
  [1121] = {.lex_state = 280, .external_lex_state = 38},
  [1122] = {.lex_state = 280, .external_lex_state = 38},
  [1123] = {.lex_state = 282, .external_lex_state = 38},
  [1124] = {.lex_state = 282, .external_lex_state = 38},
  [1125] = {.lex_state = 531, .external_lex_state = 4},
  [1126] = {.lex_state = 531, .external_lex_state = 4},
  [1127] = {.lex_state = 531, .external_lex_state = 4},
  [1128] = {.lex_state = 527, .external_lex_state = 19},
  [1129] = {.lex_state = 531, .external_lex_state = 4},
  [1130] = {.lex_state = 527, .external_lex_state = 19},
  [1131] = {.lex_state = 422, .external_lex_state = 37},
  [1132] = {.lex_state = 266, .external_lex_state = 22},
  [1133] = {.lex_state = 266, .external_lex_state = 22},
  [1134] = {.lex_state = 422, .external_lex_state = 37},
  [1135] = {.lex_state = 408, .external_lex_state = 26},
  [1136] = {.lex_state = 527, .external_lex_state = 19},
  [1137] = {.lex_state = 282, .external_lex_state = 41},
  [1138] = {.lex_state = 531, .external_lex_state = 34},
  [1139] = {.lex_state = 239, .external_lex_state = 16},
  [1140] = {.lex_state = 280, .external_lex_state = 38},
  [1141] = {.lex_state = 280, .external_lex_state = 38},
  [1142] = {.lex_state = 280, .external_lex_state = 38},
  [1143] = {.lex_state = 280, .external_lex_state = 38},
  [1144] = {.lex_state = 282, .external_lex_state = 38},
  [1145] = {.lex_state = 282, .external_lex_state = 38},
  [1146] = {.lex_state = 282, .external_lex_state = 38},
  [1147] = {.lex_state = 282, .external_lex_state = 41},
  [1148] = {.lex_state = 531, .external_lex_state = 34},
  [1149] = {.lex_state = 531, .external_lex_state = 34},
  [1150] = {.lex_state = 236, .external_lex_state = 14},
  [1151] = {.lex_state = 531, .external_lex_state = 34},
  [1152] = {.lex_state = 531, .external_lex_state = 34},
  [1153] = {.lex_state = 236, .external_lex_state = 14},
  [1154] = {.lex_state = 531, .external_lex_state = 34},
  [1155] = {.lex_state = 280, .external_lex_state = 38},
  [1156] = {.lex_state = 531, .external_lex_state = 34},
  [1157] = {.lex_state = 531, .external_lex_state = 34},
  [1158] = {.lex_state = 280, .external_lex_state = 41},
  [1159] = {.lex_state = 521, .external_lex_state = 11},
  [1160] = {.lex_state = 531, .external_lex_state = 34},
  [1161] = {.lex_state = 280, .external_lex_state = 41},
  [1162] = {.lex_state = 280, .external_lex_state = 41},
  [1163] = {.lex_state = 236, .external_lex_state = 14},
  [1164] = {.lex_state = 282, .external_lex_state = 38},
  [1165] = {.lex_state = 280, .external_lex_state = 41},
  [1166] = {.lex_state = 280, .external_lex_state = 41},
  [1167] = {.lex_state = 280, .external_lex_state = 38},
  [1168] = {.lex_state = 280, .external_lex_state = 38},
  [1169] = {.lex_state = 280, .external_lex_state = 41},
  [1170] = {.lex_state = 282, .external_lex_state = 38},
  [1171] = {.lex_state = 282, .external_lex_state = 38},
  [1172] = {.lex_state = 280, .external_lex_state = 38},
  [1173] = {.lex_state = 282, .external_lex_state = 38},
  [1174] = {.lex_state = 531, .external_lex_state = 34},
  [1175] = {.lex_state = 531, .external_lex_state = 34},
  [1176] = {.lex_state = 460, .external_lex_state = 33},
  [1177] = {.lex_state = 531, .external_lex_state = 34},
  [1178] = {.lex_state = 531, .external_lex_state = 34},
  [1179] = {.lex_state = 410, .external_lex_state = 26},
  [1180] = {.lex_state = 410, .external_lex_state = 26},
  [1181] = {.lex_state = 521, .external_lex_state = 11},
  [1182] = {.lex_state = 531, .external_lex_state = 34},
  [1183] = {.lex_state = 460, .external_lex_state = 33},
  [1184] = {.lex_state = 280, .external_lex_state = 38},
  [1185] = {.lex_state = 280, .external_lex_state = 38},
  [1186] = {.lex_state = 418, .external_lex_state = 42},
  [1187] = {.lex_state = 410, .external_lex_state = 26},
  [1188] = {.lex_state = 410, .external_lex_state = 26},
  [1189] = {.lex_state = 531, .external_lex_state = 34},
  [1190] = {.lex_state = 282, .external_lex_state = 41},
  [1191] = {.lex_state = 284, .external_lex_state = 43},
  [1192] = {.lex_state = 280, .external_lex_state = 38},
  [1193] = {.lex_state = 280, .external_lex_state = 38},
  [1194] = {.lex_state = 284, .external_lex_state = 43},
  [1195] = {.lex_state = 531, .external_lex_state = 34},
  [1196] = {.lex_state = 236, .external_lex_state = 14},
  [1197] = {.lex_state = 236, .external_lex_state = 14},
  [1198] = {.lex_state = 284, .external_lex_state = 43},
  [1199] = {.lex_state = 418, .external_lex_state = 42},
  [1200] = {.lex_state = 284, .external_lex_state = 43},
  [1201] = {.lex_state = 282, .external_lex_state = 41},
  [1202] = {.lex_state = 282, .external_lex_state = 38},
  [1203] = {.lex_state = 282, .external_lex_state = 41},
  [1204] = {.lex_state = 531, .external_lex_state = 34},
  [1205] = {.lex_state = 531, .external_lex_state = 34},
  [1206] = {.lex_state = 418, .external_lex_state = 42},
  [1207] = {.lex_state = 286, .external_lex_state = 43},
  [1208] = {.lex_state = 282, .external_lex_state = 38},
  [1209] = {.lex_state = 282, .external_lex_state = 38},
  [1210] = {.lex_state = 284, .external_lex_state = 43},
  [1211] = {.lex_state = 284, .external_lex_state = 43},
  [1212] = {.lex_state = 236, .external_lex_state = 14},
  [1213] = {.lex_state = 286, .external_lex_state = 43},
  [1214] = {.lex_state = 239, .external_lex_state = 11},
  [1215] = {.lex_state = 418, .external_lex_state = 42},
  [1216] = {.lex_state = 429, .external_lex_state = 44},
  [1217] = {.lex_state = 418, .external_lex_state = 42},
  [1218] = {.lex_state = 418, .external_lex_state = 42},
  [1219] = {.lex_state = 286, .external_lex_state = 43},
  [1220] = {.lex_state = 239, .external_lex_state = 11},
  [1221] = {.lex_state = 284, .external_lex_state = 43},
  [1222] = {.lex_state = 282, .external_lex_state = 41},
  [1223] = {.lex_state = 284, .external_lex_state = 43},
  [1224] = {.lex_state = 280, .external_lex_state = 38},
  [1225] = {.lex_state = 284, .external_lex_state = 43},
  [1226] = {.lex_state = 286, .external_lex_state = 43},
  [1227] = {.lex_state = 286, .external_lex_state = 43},
  [1228] = {.lex_state = 531, .external_lex_state = 34},
  [1229] = {.lex_state = 531, .external_lex_state = 34},
  [1230] = {.lex_state = 239, .external_lex_state = 16},
  [1231] = {.lex_state = 531, .external_lex_state = 34},
  [1232] = {.lex_state = 521, .external_lex_state = 11},
  [1233] = {.lex_state = 284, .external_lex_state = 43},
  [1234] = {.lex_state = 284, .external_lex_state = 43},
  [1235] = {.lex_state = 239, .external_lex_state = 16},
  [1236] = {.lex_state = 531, .external_lex_state = 34},
  [1237] = {.lex_state = 521, .external_lex_state = 11},
  [1238] = {.lex_state = 531, .external_lex_state = 34},
  [1239] = {.lex_state = 286, .external_lex_state = 43},
  [1240] = {.lex_state = 284, .external_lex_state = 43},
  [1241] = {.lex_state = 282, .external_lex_state = 38},
  [1242] = {.lex_state = 280, .external_lex_state = 38},
  [1243] = {.lex_state = 282, .external_lex_state = 38},
  [1244] = {.lex_state = 426, .external_lex_state = 37},
  [1245] = {.lex_state = 239, .external_lex_state = 16},
  [1246] = {.lex_state = 531, .external_lex_state = 34},
  [1247] = {.lex_state = 531, .external_lex_state = 34},
  [1248] = {.lex_state = 531, .external_lex_state = 34},
  [1249] = {.lex_state = 531, .external_lex_state = 34},
  [1250] = {.lex_state = 426, .external_lex_state = 37},
  [1251] = {.lex_state = 531, .external_lex_state = 34},
  [1252] = {.lex_state = 531, .external_lex_state = 34},
  [1253] = {.lex_state = 280, .external_lex_state = 38},
  [1254] = {.lex_state = 280, .external_lex_state = 38},
  [1255] = {.lex_state = 280, .external_lex_state = 38},
  [1256] = {.lex_state = 280, .external_lex_state = 38},
  [1257] = {.lex_state = 531, .external_lex_state = 34},
  [1258] = {.lex_state = 239, .external_lex_state = 16},
  [1259] = {.lex_state = 531, .external_lex_state = 34},
  [1260] = {.lex_state = 531, .external_lex_state = 34},
  [1261] = {.lex_state = 531, .external_lex_state = 34},
  [1262] = {.lex_state = 531, .external_lex_state = 34},
  [1263] = {.lex_state = 280, .external_lex_state = 38},
  [1264] = {.lex_state = 286, .external_lex_state = 43},
  [1265] = {.lex_state = 286, .external_lex_state = 43},
  [1266] = {.lex_state = 284, .external_lex_state = 43},
  [1267] = {.lex_state = 410, .external_lex_state = 26},
  [1268] = {.lex_state = 531, .external_lex_state = 34},
  [1269] = {.lex_state = 531, .external_lex_state = 34},
  [1270] = {.lex_state = 531, .external_lex_state = 34},
  [1271] = {.lex_state = 410, .external_lex_state = 26},
  [1272] = {.lex_state = 531, .external_lex_state = 34},
  [1273] = {.lex_state = 531, .external_lex_state = 34},
  [1274] = {.lex_state = 282, .external_lex_state = 38},
  [1275] = {.lex_state = 531, .external_lex_state = 34},
  [1276] = {.lex_state = 531, .external_lex_state = 34},
  [1277] = {.lex_state = 282, .external_lex_state = 38},
  [1278] = {.lex_state = 282, .external_lex_state = 38},
  [1279] = {.lex_state = 531, .external_lex_state = 34},
  [1280] = {.lex_state = 531, .external_lex_state = 34},
  [1281] = {.lex_state = 531, .external_lex_state = 34},
  [1282] = {.lex_state = 531, .external_lex_state = 34},
  [1283] = {.lex_state = 531, .external_lex_state = 34},
  [1284] = {.lex_state = 531, .external_lex_state = 34},
  [1285] = {.lex_state = 531, .external_lex_state = 34},
  [1286] = {.lex_state = 531, .external_lex_state = 34},
  [1287] = {.lex_state = 282, .external_lex_state = 38},
  [1288] = {.lex_state = 282, .external_lex_state = 38},
  [1289] = {.lex_state = 282, .external_lex_state = 38},
  [1290] = {.lex_state = 282, .external_lex_state = 38},
  [1291] = {.lex_state = 284, .external_lex_state = 43},
  [1292] = {.lex_state = 288, .external_lex_state = 41},
  [1293] = {.lex_state = 286, .external_lex_state = 43},
  [1294] = {.lex_state = 286, .external_lex_state = 43},
  [1295] = {.lex_state = 286, .external_lex_state = 43},
  [1296] = {.lex_state = 284, .external_lex_state = 43},
  [1297] = {.lex_state = 284, .external_lex_state = 45},
  [1298] = {.lex_state = 286, .external_lex_state = 43},
  [1299] = {.lex_state = 286, .external_lex_state = 43},
  [1300] = {.lex_state = 284, .external_lex_state = 43},
  [1301] = {.lex_state = 532, .external_lex_state = 43},
  [1302] = {.lex_state = 284, .external_lex_state = 43},
  [1303] = {.lex_state = 284, .external_lex_state = 43},
  [1304] = {.lex_state = 282, .external_lex_state = 41},
  [1305] = {.lex_state = 269, .external_lex_state = 24},
  [1306] = {.lex_state = 532, .external_lex_state = 43},
  [1307] = {.lex_state = 532, .external_lex_state = 43},
  [1308] = {.lex_state = 286, .external_lex_state = 43},
  [1309] = {.lex_state = 286, .external_lex_state = 43},
  [1310] = {.lex_state = 282, .external_lex_state = 41},
  [1311] = {.lex_state = 288, .external_lex_state = 41},
  [1312] = {.lex_state = 282, .external_lex_state = 41},
  [1313] = {.lex_state = 284, .external_lex_state = 43},
  [1314] = {.lex_state = 286, .external_lex_state = 43},
  [1315] = {.lex_state = 286, .external_lex_state = 43},
  [1316] = {.lex_state = 286, .external_lex_state = 43},
  [1317] = {.lex_state = 284, .external_lex_state = 45},
  [1318] = {.lex_state = 284, .external_lex_state = 43},
  [1319] = {.lex_state = 286, .external_lex_state = 43},
  [1320] = {.lex_state = 254, .external_lex_state = 15},
  [1321] = {.lex_state = 280, .external_lex_state = 41},
  [1322] = {.lex_state = 532, .external_lex_state = 43},
  [1323] = {.lex_state = 286, .external_lex_state = 45},
  [1324] = {.lex_state = 286, .external_lex_state = 45},
  [1325] = {.lex_state = 532, .external_lex_state = 43},
  [1326] = {.lex_state = 286, .external_lex_state = 45},
  [1327] = {.lex_state = 282, .external_lex_state = 41},
  [1328] = {.lex_state = 282, .external_lex_state = 41},
  [1329] = {.lex_state = 280, .external_lex_state = 41},
  [1330] = {.lex_state = 239, .external_lex_state = 16},
  [1331] = {.lex_state = 282, .external_lex_state = 41},
  [1332] = {.lex_state = 239, .external_lex_state = 16},
  [1333] = {.lex_state = 286, .external_lex_state = 43},
  [1334] = {.lex_state = 521, .external_lex_state = 16},
  [1335] = {.lex_state = 282, .external_lex_state = 41},
  [1336] = {.lex_state = 286, .external_lex_state = 43},
  [1337] = {.lex_state = 254, .external_lex_state = 15},
  [1338] = {.lex_state = 286, .external_lex_state = 45},
  [1339] = {.lex_state = 521, .external_lex_state = 11},
  [1340] = {.lex_state = 280, .external_lex_state = 41},
  [1341] = {.lex_state = 532, .external_lex_state = 43},
  [1342] = {.lex_state = 282, .external_lex_state = 41},
  [1343] = {.lex_state = 280, .external_lex_state = 41},
  [1344] = {.lex_state = 532, .external_lex_state = 43},
  [1345] = {.lex_state = 286, .external_lex_state = 45},
  [1346] = {.lex_state = 284, .external_lex_state = 45},
  [1347] = {.lex_state = 239, .external_lex_state = 16},
  [1348] = {.lex_state = 284, .external_lex_state = 45},
  [1349] = {.lex_state = 280, .external_lex_state = 41},
  [1350] = {.lex_state = 521, .external_lex_state = 11},
  [1351] = {.lex_state = 282, .external_lex_state = 41},
  [1352] = {.lex_state = 288, .external_lex_state = 41},
  [1353] = {.lex_state = 532, .external_lex_state = 43},
  [1354] = {.lex_state = 532, .external_lex_state = 43},
  [1355] = {.lex_state = 532, .external_lex_state = 43},
  [1356] = {.lex_state = 532, .external_lex_state = 43},
  [1357] = {.lex_state = 532, .external_lex_state = 43},
  [1358] = {.lex_state = 284, .external_lex_state = 43},
  [1359] = {.lex_state = 286, .external_lex_state = 43},
  [1360] = {.lex_state = 521, .external_lex_state = 16},
  [1361] = {.lex_state = 521, .external_lex_state = 11},
  [1362] = {.lex_state = 532, .external_lex_state = 43},
  [1363] = {.lex_state = 532, .external_lex_state = 43},
  [1364] = {.lex_state = 284, .external_lex_state = 43},
  [1365] = {.lex_state = 286, .external_lex_state = 43},
  [1366] = {.lex_state = 521, .external_lex_state = 16},
  [1367] = {.lex_state = 533, .external_lex_state = 43},
  [1368] = {.lex_state = 533, .external_lex_state = 43},
  [1369] = {.lex_state = 239, .external_lex_state = 16},
  [1370] = {.lex_state = 532, .external_lex_state = 43},
  [1371] = {.lex_state = 533, .external_lex_state = 43},
  [1372] = {.lex_state = 533, .external_lex_state = 43},
  [1373] = {.lex_state = 532, .external_lex_state = 43},
  [1374] = {.lex_state = 532, .external_lex_state = 43},
  [1375] = {.lex_state = 533, .external_lex_state = 43},
  [1376] = {.lex_state = 533, .external_lex_state = 43},
  [1377] = {.lex_state = 533, .external_lex_state = 43},
  [1378] = {.lex_state = 533, .external_lex_state = 43},
  [1379] = {.lex_state = 288, .external_lex_state = 41},
  [1380] = {.lex_state = 280, .external_lex_state = 41},
  [1381] = {.lex_state = 532, .external_lex_state = 43},
  [1382] = {.lex_state = 532, .external_lex_state = 43},
  [1383] = {.lex_state = 280, .external_lex_state = 41},
  [1384] = {.lex_state = 284, .external_lex_state = 43},
  [1385] = {.lex_state = 429, .external_lex_state = 46},
  [1386] = {.lex_state = 532, .external_lex_state = 43},
  [1387] = {.lex_state = 521, .external_lex_state = 16},
  [1388] = {.lex_state = 280, .external_lex_state = 41},
  [1389] = {.lex_state = 532, .external_lex_state = 43},
  [1390] = {.lex_state = 269, .external_lex_state = 24},
  [1391] = {.lex_state = 254, .external_lex_state = 15},
  [1392] = {.lex_state = 286, .external_lex_state = 43},
  [1393] = {.lex_state = 284, .external_lex_state = 45},
  [1394] = {.lex_state = 284, .external_lex_state = 43},
  [1395] = {.lex_state = 521, .external_lex_state = 16},
  [1396] = {.lex_state = 286, .external_lex_state = 43},
  [1397] = {.lex_state = 521, .external_lex_state = 16},
  [1398] = {.lex_state = 280, .external_lex_state = 41},
  [1399] = {.lex_state = 284, .external_lex_state = 43},
  [1400] = {.lex_state = 280, .external_lex_state = 41},
  [1401] = {.lex_state = 288, .external_lex_state = 41},
  [1402] = {.lex_state = 286, .external_lex_state = 45},
  [1403] = {.lex_state = 280, .external_lex_state = 41},
  [1404] = {.lex_state = 282, .external_lex_state = 41},
  [1405] = {.lex_state = 280, .external_lex_state = 41},
  [1406] = {.lex_state = 282, .external_lex_state = 41},
  [1407] = {.lex_state = 280, .external_lex_state = 41},
  [1408] = {.lex_state = 239, .external_lex_state = 16},
  [1409] = {.lex_state = 280, .external_lex_state = 41},
  [1410] = {.lex_state = 245, .external_lex_state = 15},
  [1411] = {.lex_state = 254, .external_lex_state = 15},
  [1412] = {.lex_state = 521, .external_lex_state = 16},
  [1413] = {.lex_state = 282, .external_lex_state = 41},
  [1414] = {.lex_state = 280, .external_lex_state = 41},
  [1415] = {.lex_state = 282, .external_lex_state = 41},
  [1416] = {.lex_state = 532, .external_lex_state = 43},
  [1417] = {.lex_state = 286, .external_lex_state = 43},
  [1418] = {.lex_state = 532, .external_lex_state = 43},
  [1419] = {.lex_state = 286, .external_lex_state = 43},
  [1420] = {.lex_state = 532, .external_lex_state = 43},
  [1421] = {.lex_state = 288, .external_lex_state = 41},
  [1422] = {.lex_state = 532, .external_lex_state = 43},
  [1423] = {.lex_state = 254, .external_lex_state = 15},
  [1424] = {.lex_state = 521, .external_lex_state = 16},
  [1425] = {.lex_state = 245, .external_lex_state = 15},
  [1426] = {.lex_state = 282, .external_lex_state = 41},
  [1427] = {.lex_state = 245, .external_lex_state = 15},
  [1428] = {.lex_state = 284, .external_lex_state = 43},
  [1429] = {.lex_state = 269, .external_lex_state = 24},
  [1430] = {.lex_state = 532, .external_lex_state = 43},
  [1431] = {.lex_state = 521, .external_lex_state = 11},
  [1432] = {.lex_state = 282, .external_lex_state = 41},
  [1433] = {.lex_state = 280, .external_lex_state = 41},
  [1434] = {.lex_state = 280, .external_lex_state = 41},
  [1435] = {.lex_state = 280, .external_lex_state = 41},
  [1436] = {.lex_state = 521, .external_lex_state = 16},
  [1437] = {.lex_state = 533, .external_lex_state = 43},
  [1438] = {.lex_state = 239, .external_lex_state = 16},
  [1439] = {.lex_state = 284, .external_lex_state = 43},
  [1440] = {.lex_state = 284, .external_lex_state = 43},
  [1441] = {.lex_state = 284, .external_lex_state = 43},
  [1442] = {.lex_state = 282, .external_lex_state = 41},
  [1443] = {.lex_state = 533, .external_lex_state = 43},
  [1444] = {.lex_state = 533, .external_lex_state = 43},
  [1445] = {.lex_state = 533, .external_lex_state = 43},
  [1446] = {.lex_state = 533, .external_lex_state = 43},
  [1447] = {.lex_state = 533, .external_lex_state = 43},
  [1448] = {.lex_state = 254, .external_lex_state = 15},
  [1449] = {.lex_state = 284, .external_lex_state = 43},
  [1450] = {.lex_state = 532, .external_lex_state = 43},
  [1451] = {.lex_state = 282, .external_lex_state = 41},
  [1452] = {.lex_state = 284, .external_lex_state = 43},
  [1453] = {.lex_state = 284, .external_lex_state = 43},
  [1454] = {.lex_state = 533, .external_lex_state = 43},
  [1455] = {.lex_state = 284, .external_lex_state = 43},
  [1456] = {.lex_state = 532, .external_lex_state = 43},
  [1457] = {.lex_state = 254, .external_lex_state = 15},
  [1458] = {.lex_state = 282, .external_lex_state = 41},
  [1459] = {.lex_state = 280, .external_lex_state = 41},
  [1460] = {.lex_state = 282, .external_lex_state = 41},
  [1461] = {.lex_state = 533, .external_lex_state = 43},
  [1462] = {.lex_state = 284, .external_lex_state = 45},
  [1463] = {.lex_state = 521, .external_lex_state = 16},
  [1464] = {.lex_state = 245, .external_lex_state = 21},
  [1465] = {.lex_state = 245, .external_lex_state = 15},
  [1466] = {.lex_state = 288, .external_lex_state = 41},
  [1467] = {.lex_state = 288, .external_lex_state = 41},
  [1468] = {.lex_state = 245, .external_lex_state = 15},
  [1469] = {.lex_state = 285, .external_lex_state = 47},
  [1470] = {.lex_state = 285, .external_lex_state = 47},
  [1471] = {.lex_state = 248, .external_lex_state = 19},
  [1472] = {.lex_state = 532, .external_lex_state = 43},
  [1473] = {.lex_state = 288, .external_lex_state = 41},
  [1474] = {.lex_state = 245, .external_lex_state = 21},
  [1475] = {.lex_state = 288, .external_lex_state = 41},
  [1476] = {.lex_state = 288, .external_lex_state = 41},
  [1477] = {.lex_state = 533, .external_lex_state = 43},
  [1478] = {.lex_state = 532, .external_lex_state = 43},
  [1479] = {.lex_state = 254, .external_lex_state = 15},
  [1480] = {.lex_state = 257, .external_lex_state = 19},
  [1481] = {.lex_state = 288, .external_lex_state = 41},
  [1482] = {.lex_state = 288, .external_lex_state = 41},
  [1483] = {.lex_state = 521, .external_lex_state = 16},
  [1484] = {.lex_state = 254, .external_lex_state = 21},
  [1485] = {.lex_state = 533, .external_lex_state = 43},
  [1486] = {.lex_state = 533, .external_lex_state = 43},
  [1487] = {.lex_state = 533, .external_lex_state = 43},
  [1488] = {.lex_state = 533, .external_lex_state = 45},
  [1489] = {.lex_state = 288, .external_lex_state = 41},
  [1490] = {.lex_state = 532, .external_lex_state = 43},
  [1491] = {.lex_state = 254, .external_lex_state = 21},
  [1492] = {.lex_state = 533, .external_lex_state = 43},
  [1493] = {.lex_state = 288, .external_lex_state = 41},
  [1494] = {.lex_state = 532, .external_lex_state = 43},
  [1495] = {.lex_state = 532, .external_lex_state = 43},
  [1496] = {.lex_state = 533, .external_lex_state = 45},
  [1497] = {.lex_state = 286, .external_lex_state = 45},
  [1498] = {.lex_state = 286, .external_lex_state = 45},
  [1499] = {.lex_state = 532, .external_lex_state = 43},
  [1500] = {.lex_state = 532, .external_lex_state = 43},
  [1501] = {.lex_state = 257, .external_lex_state = 19},
  [1502] = {.lex_state = 257, .external_lex_state = 19},
  [1503] = {.lex_state = 286, .external_lex_state = 45},
  [1504] = {.lex_state = 257, .external_lex_state = 19},
  [1505] = {.lex_state = 532, .external_lex_state = 43},
  [1506] = {.lex_state = 286, .external_lex_state = 45},
  [1507] = {.lex_state = 532, .external_lex_state = 43},
  [1508] = {.lex_state = 257, .external_lex_state = 19},
  [1509] = {.lex_state = 286, .external_lex_state = 45},
  [1510] = {.lex_state = 292, .external_lex_state = 45},
  [1511] = {.lex_state = 288, .external_lex_state = 41},
  [1512] = {.lex_state = 288, .external_lex_state = 41},
  [1513] = {.lex_state = 292, .external_lex_state = 45},
  [1514] = {.lex_state = 248, .external_lex_state = 19},
  [1515] = {.lex_state = 292, .external_lex_state = 45},
  [1516] = {.lex_state = 286, .external_lex_state = 45},
  [1517] = {.lex_state = 286, .external_lex_state = 45},
  [1518] = {.lex_state = 533, .external_lex_state = 43},
  [1519] = {.lex_state = 419, .external_lex_state = 48},
  [1520] = {.lex_state = 533, .external_lex_state = 43},
  [1521] = {.lex_state = 532, .external_lex_state = 43},
  [1522] = {.lex_state = 292, .external_lex_state = 45},
  [1523] = {.lex_state = 292, .external_lex_state = 45},
  [1524] = {.lex_state = 292, .external_lex_state = 45},
  [1525] = {.lex_state = 284, .external_lex_state = 45},
  [1526] = {.lex_state = 284, .external_lex_state = 45},
  [1527] = {.lex_state = 532, .external_lex_state = 43},
  [1528] = {.lex_state = 284, .external_lex_state = 45},
  [1529] = {.lex_state = 532, .external_lex_state = 43},
  [1530] = {.lex_state = 284, .external_lex_state = 45},
  [1531] = {.lex_state = 284, .external_lex_state = 45},
  [1532] = {.lex_state = 288, .external_lex_state = 41},
  [1533] = {.lex_state = 288, .external_lex_state = 41},
  [1534] = {.lex_state = 284, .external_lex_state = 45},
  [1535] = {.lex_state = 288, .external_lex_state = 41},
  [1536] = {.lex_state = 288, .external_lex_state = 41},
  [1537] = {.lex_state = 284, .external_lex_state = 45},
  [1538] = {.lex_state = 288, .external_lex_state = 41},
  [1539] = {.lex_state = 286, .external_lex_state = 45},
  [1540] = {.lex_state = 286, .external_lex_state = 45},
  [1541] = {.lex_state = 269, .external_lex_state = 24},
  [1542] = {.lex_state = 257, .external_lex_state = 19},
  [1543] = {.lex_state = 269, .external_lex_state = 24},
  [1544] = {.lex_state = 288, .external_lex_state = 41},
  [1545] = {.lex_state = 288, .external_lex_state = 41},
  [1546] = {.lex_state = 288, .external_lex_state = 41},
  [1547] = {.lex_state = 254, .external_lex_state = 15},
  [1548] = {.lex_state = 533, .external_lex_state = 45},
  [1549] = {.lex_state = 286, .external_lex_state = 45},
  [1550] = {.lex_state = 286, .external_lex_state = 45},
  [1551] = {.lex_state = 532, .external_lex_state = 43},
  [1552] = {.lex_state = 532, .external_lex_state = 43},
  [1553] = {.lex_state = 284, .external_lex_state = 45},
  [1554] = {.lex_state = 284, .external_lex_state = 45},
  [1555] = {.lex_state = 533, .external_lex_state = 43},
  [1556] = {.lex_state = 532, .external_lex_state = 43},
  [1557] = {.lex_state = 284, .external_lex_state = 45},
  [1558] = {.lex_state = 284, .external_lex_state = 45},
  [1559] = {.lex_state = 286, .external_lex_state = 45},
  [1560] = {.lex_state = 286, .external_lex_state = 45},
  [1561] = {.lex_state = 286, .external_lex_state = 45},
  [1562] = {.lex_state = 286, .external_lex_state = 45},
  [1563] = {.lex_state = 533, .external_lex_state = 43},
  [1564] = {.lex_state = 419, .external_lex_state = 48},
  [1565] = {.lex_state = 532, .external_lex_state = 43},
  [1566] = {.lex_state = 286, .external_lex_state = 45},
  [1567] = {.lex_state = 532, .external_lex_state = 43},
  [1568] = {.lex_state = 532, .external_lex_state = 45},
  [1569] = {.lex_state = 286, .external_lex_state = 45},
  [1570] = {.lex_state = 286, .external_lex_state = 45},
  [1571] = {.lex_state = 286, .external_lex_state = 45},
  [1572] = {.lex_state = 532, .external_lex_state = 45},
  [1573] = {.lex_state = 532, .external_lex_state = 43},
  [1574] = {.lex_state = 532, .external_lex_state = 43},
  [1575] = {.lex_state = 284, .external_lex_state = 45},
  [1576] = {.lex_state = 284, .external_lex_state = 45},
  [1577] = {.lex_state = 284, .external_lex_state = 45},
  [1578] = {.lex_state = 284, .external_lex_state = 45},
  [1579] = {.lex_state = 284, .external_lex_state = 45},
  [1580] = {.lex_state = 284, .external_lex_state = 45},
  [1581] = {.lex_state = 284, .external_lex_state = 45},
  [1582] = {.lex_state = 284, .external_lex_state = 45},
  [1583] = {.lex_state = 532, .external_lex_state = 45},
  [1584] = {.lex_state = 532, .external_lex_state = 43},
  [1585] = {.lex_state = 419, .external_lex_state = 48},
  [1586] = {.lex_state = 521, .external_lex_state = 16},
  [1587] = {.lex_state = 532, .external_lex_state = 43},
  [1588] = {.lex_state = 532, .external_lex_state = 45},
  [1589] = {.lex_state = 419, .external_lex_state = 48},
  [1590] = {.lex_state = 532, .external_lex_state = 43},
  [1591] = {.lex_state = 532, .external_lex_state = 43},
  [1592] = {.lex_state = 533, .external_lex_state = 43},
  [1593] = {.lex_state = 533, .external_lex_state = 43},
  [1594] = {.lex_state = 533, .external_lex_state = 45},
  [1595] = {.lex_state = 276, .external_lex_state = 4},
  [1596] = {.lex_state = 532, .external_lex_state = 43},
  [1597] = {.lex_state = 532, .external_lex_state = 45},
  [1598] = {.lex_state = 533, .external_lex_state = 45},
  [1599] = {.lex_state = 532, .external_lex_state = 45},
  [1600] = {.lex_state = 532, .external_lex_state = 45},
  [1601] = {.lex_state = 257, .external_lex_state = 19},
  [1602] = {.lex_state = 257, .external_lex_state = 19},
  [1603] = {.lex_state = 532, .external_lex_state = 45},
  [1604] = {.lex_state = 254, .external_lex_state = 15},
  [1605] = {.lex_state = 248, .external_lex_state = 19},
  [1606] = {.lex_state = 521, .external_lex_state = 16},
  [1607] = {.lex_state = 521, .external_lex_state = 16},
  [1608] = {.lex_state = 254, .external_lex_state = 15},
  [1609] = {.lex_state = 254, .external_lex_state = 15},
  [1610] = {.lex_state = 532, .external_lex_state = 45},
  [1611] = {.lex_state = 532, .external_lex_state = 45},
  [1612] = {.lex_state = 521, .external_lex_state = 16},
  [1613] = {.lex_state = 521, .external_lex_state = 16},
  [1614] = {.lex_state = 533, .external_lex_state = 45},
  [1615] = {.lex_state = 533, .external_lex_state = 45},
  [1616] = {.lex_state = 533, .external_lex_state = 43},
  [1617] = {.lex_state = 533, .external_lex_state = 43},
  [1618] = {.lex_state = 533, .external_lex_state = 43},
  [1619] = {.lex_state = 533, .external_lex_state = 43},
  [1620] = {.lex_state = 533, .external_lex_state = 43},
  [1621] = {.lex_state = 533, .external_lex_state = 43},
  [1622] = {.lex_state = 533, .external_lex_state = 43},
  [1623] = {.lex_state = 533, .external_lex_state = 45},
  [1624] = {.lex_state = 533, .external_lex_state = 43},
  [1625] = {.lex_state = 532, .external_lex_state = 43},
  [1626] = {.lex_state = 533, .external_lex_state = 45},
  [1627] = {.lex_state = 257, .external_lex_state = 19},
  [1628] = {.lex_state = 521, .external_lex_state = 16},
  [1629] = {.lex_state = 533, .external_lex_state = 43},
  [1630] = {.lex_state = 533, .external_lex_state = 43},
  [1631] = {.lex_state = 533, .external_lex_state = 43},
  [1632] = {.lex_state = 533, .external_lex_state = 45},
  [1633] = {.lex_state = 533, .external_lex_state = 43},
  [1634] = {.lex_state = 533, .external_lex_state = 43},
  [1635] = {.lex_state = 521, .external_lex_state = 16},
  [1636] = {.lex_state = 533, .external_lex_state = 45},
  [1637] = {.lex_state = 533, .external_lex_state = 43},
  [1638] = {.lex_state = 533, .external_lex_state = 43},
  [1639] = {.lex_state = 533, .external_lex_state = 43},
  [1640] = {.lex_state = 533, .external_lex_state = 43},
  [1641] = {.lex_state = 533, .external_lex_state = 43},
  [1642] = {.lex_state = 533, .external_lex_state = 43},
  [1643] = {.lex_state = 521, .external_lex_state = 16},
  [1644] = {.lex_state = 254, .external_lex_state = 15},
  [1645] = {.lex_state = 532, .external_lex_state = 43},
  [1646] = {.lex_state = 521, .external_lex_state = 16},
  [1647] = {.lex_state = 532, .external_lex_state = 43},
  [1648] = {.lex_state = 532, .external_lex_state = 43},
  [1649] = {.lex_state = 521, .external_lex_state = 16},
  [1650] = {.lex_state = 532, .external_lex_state = 43},
  [1651] = {.lex_state = 532, .external_lex_state = 43},
  [1652] = {.lex_state = 532, .external_lex_state = 45},
  [1653] = {.lex_state = 532, .external_lex_state = 45},
  [1654] = {.lex_state = 521, .external_lex_state = 16},
  [1655] = {.lex_state = 254, .external_lex_state = 15},
  [1656] = {.lex_state = 533, .external_lex_state = 43},
  [1657] = {.lex_state = 532, .external_lex_state = 43},
  [1658] = {.lex_state = 532, .external_lex_state = 43},
  [1659] = {.lex_state = 533, .external_lex_state = 43},
  [1660] = {.lex_state = 245, .external_lex_state = 15},
  [1661] = {.lex_state = 532, .external_lex_state = 43},
  [1662] = {.lex_state = 532, .external_lex_state = 43},
  [1663] = {.lex_state = 532, .external_lex_state = 43},
  [1664] = {.lex_state = 532, .external_lex_state = 43},
  [1665] = {.lex_state = 533, .external_lex_state = 43},
  [1666] = {.lex_state = 533, .external_lex_state = 43},
  [1667] = {.lex_state = 532, .external_lex_state = 43},
  [1668] = {.lex_state = 532, .external_lex_state = 43},
  [1669] = {.lex_state = 532, .external_lex_state = 43},
  [1670] = {.lex_state = 254, .external_lex_state = 15},
  [1671] = {.lex_state = 533, .external_lex_state = 45},
  [1672] = {.lex_state = 532, .external_lex_state = 43},
  [1673] = {.lex_state = 254, .external_lex_state = 15},
  [1674] = {.lex_state = 532, .external_lex_state = 43},
  [1675] = {.lex_state = 532, .external_lex_state = 43},
  [1676] = {.lex_state = 532, .external_lex_state = 43},
  [1677] = {.lex_state = 532, .external_lex_state = 43},
  [1678] = {.lex_state = 532, .external_lex_state = 43},
  [1679] = {.lex_state = 533, .external_lex_state = 43},
  [1680] = {.lex_state = 533, .external_lex_state = 43},
  [1681] = {.lex_state = 254, .external_lex_state = 15},
  [1682] = {.lex_state = 532, .external_lex_state = 43},
  [1683] = {.lex_state = 533, .external_lex_state = 43},
  [1684] = {.lex_state = 419, .external_lex_state = 48},
  [1685] = {.lex_state = 533, .external_lex_state = 43},
  [1686] = {.lex_state = 533, .external_lex_state = 43},
  [1687] = {.lex_state = 254, .external_lex_state = 15},
  [1688] = {.lex_state = 532, .external_lex_state = 43},
  [1689] = {.lex_state = 533, .external_lex_state = 43},
  [1690] = {.lex_state = 419, .external_lex_state = 48},
  [1691] = {.lex_state = 276, .external_lex_state = 4},
  [1692] = {.lex_state = 276, .external_lex_state = 4},
  [1693] = {.lex_state = 276, .external_lex_state = 4},
  [1694] = {.lex_state = 533, .external_lex_state = 43},
  [1695] = {.lex_state = 257, .external_lex_state = 19},
  [1696] = {.lex_state = 533, .external_lex_state = 43},
  [1697] = {.lex_state = 276, .external_lex_state = 4},
  [1698] = {.lex_state = 257, .external_lex_state = 19},
  [1699] = {.lex_state = 532, .external_lex_state = 43},
  [1700] = {.lex_state = 532, .external_lex_state = 43},
  [1701] = {.lex_state = 532, .external_lex_state = 43},
  [1702] = {.lex_state = 533, .external_lex_state = 43},
  [1703] = {.lex_state = 533, .external_lex_state = 43},
  [1704] = {.lex_state = 532, .external_lex_state = 43},
  [1705] = {.lex_state = 533, .external_lex_state = 43},
  [1706] = {.lex_state = 245, .external_lex_state = 15},
  [1707] = {.lex_state = 276, .external_lex_state = 4},
  [1708] = {.lex_state = 419, .external_lex_state = 49},
  [1709] = {.lex_state = 257, .external_lex_state = 19},
  [1710] = {.lex_state = 533, .external_lex_state = 45},
  [1711] = {.lex_state = 534, .external_lex_state = 45},
  [1712] = {.lex_state = 292, .external_lex_state = 45},
  [1713] = {.lex_state = 257, .external_lex_state = 19},
  [1714] = {.lex_state = 292, .external_lex_state = 45},
  [1715] = {.lex_state = 534, .external_lex_state = 45},
  [1716] = {.lex_state = 452, .external_lex_state = 35},
  [1717] = {.lex_state = 292, .external_lex_state = 45},
  [1718] = {.lex_state = 292, .external_lex_state = 45},
  [1719] = {.lex_state = 533, .external_lex_state = 45},
  [1720] = {.lex_state = 527, .external_lex_state = 19},
  [1721] = {.lex_state = 257, .external_lex_state = 22},
  [1722] = {.lex_state = 263, .external_lex_state = 21},
  [1723] = {.lex_state = 534, .external_lex_state = 45},
  [1724] = {.lex_state = 532, .external_lex_state = 45},
  [1725] = {.lex_state = 292, .external_lex_state = 45},
  [1726] = {.lex_state = 292, .external_lex_state = 45},
  [1727] = {.lex_state = 292, .external_lex_state = 45},
  [1728] = {.lex_state = 292, .external_lex_state = 45},
  [1729] = {.lex_state = 292, .external_lex_state = 45},
  [1730] = {.lex_state = 533, .external_lex_state = 45},
  [1731] = {.lex_state = 533, .external_lex_state = 45},
  [1732] = {.lex_state = 533, .external_lex_state = 45},
  [1733] = {.lex_state = 533, .external_lex_state = 45},
  [1734] = {.lex_state = 292, .external_lex_state = 45},
  [1735] = {.lex_state = 292, .external_lex_state = 45},
  [1736] = {.lex_state = 292, .external_lex_state = 45},
  [1737] = {.lex_state = 454, .external_lex_state = 26},
  [1738] = {.lex_state = 533, .external_lex_state = 45},
  [1739] = {.lex_state = 532, .external_lex_state = 45},
  [1740] = {.lex_state = 532, .external_lex_state = 45},
  [1741] = {.lex_state = 532, .external_lex_state = 45},
  [1742] = {.lex_state = 419, .external_lex_state = 49},
  [1743] = {.lex_state = 532, .external_lex_state = 45},
  [1744] = {.lex_state = 454, .external_lex_state = 26},
  [1745] = {.lex_state = 532, .external_lex_state = 45},
  [1746] = {.lex_state = 452, .external_lex_state = 35},
  [1747] = {.lex_state = 532, .external_lex_state = 45},
  [1748] = {.lex_state = 532, .external_lex_state = 45},
  [1749] = {.lex_state = 532, .external_lex_state = 45},
  [1750] = {.lex_state = 532, .external_lex_state = 45},
  [1751] = {.lex_state = 454, .external_lex_state = 26},
  [1752] = {.lex_state = 532, .external_lex_state = 45},
  [1753] = {.lex_state = 534, .external_lex_state = 45},
  [1754] = {.lex_state = 419, .external_lex_state = 42},
  [1755] = {.lex_state = 532, .external_lex_state = 45},
  [1756] = {.lex_state = 525, .external_lex_state = 19},
  [1757] = {.lex_state = 534, .external_lex_state = 45},
  [1758] = {.lex_state = 532, .external_lex_state = 45},
  [1759] = {.lex_state = 534, .external_lex_state = 45},
  [1760] = {.lex_state = 532, .external_lex_state = 45},
  [1761] = {.lex_state = 532, .external_lex_state = 45},
  [1762] = {.lex_state = 245, .external_lex_state = 21},
  [1763] = {.lex_state = 248, .external_lex_state = 19},
  [1764] = {.lex_state = 533, .external_lex_state = 45},
  [1765] = {.lex_state = 257, .external_lex_state = 19},
  [1766] = {.lex_state = 533, .external_lex_state = 45},
  [1767] = {.lex_state = 533, .external_lex_state = 45},
  [1768] = {.lex_state = 532, .external_lex_state = 45},
  [1769] = {.lex_state = 419, .external_lex_state = 42},
  [1770] = {.lex_state = 419, .external_lex_state = 49},
  [1771] = {.lex_state = 525, .external_lex_state = 19},
  [1772] = {.lex_state = 532, .external_lex_state = 45},
  [1773] = {.lex_state = 533, .external_lex_state = 45},
  [1774] = {.lex_state = 532, .external_lex_state = 45},
  [1775] = {.lex_state = 532, .external_lex_state = 45},
  [1776] = {.lex_state = 257, .external_lex_state = 19},
  [1777] = {.lex_state = 532, .external_lex_state = 45},
  [1778] = {.lex_state = 276, .external_lex_state = 34},
  [1779] = {.lex_state = 276, .external_lex_state = 34},
  [1780] = {.lex_state = 532, .external_lex_state = 45},
  [1781] = {.lex_state = 419, .external_lex_state = 42},
  [1782] = {.lex_state = 532, .external_lex_state = 45},
  [1783] = {.lex_state = 532, .external_lex_state = 45},
  [1784] = {.lex_state = 532, .external_lex_state = 45},
  [1785] = {.lex_state = 419, .external_lex_state = 42},
  [1786] = {.lex_state = 532, .external_lex_state = 45},
  [1787] = {.lex_state = 527, .external_lex_state = 19},
  [1788] = {.lex_state = 532, .external_lex_state = 45},
  [1789] = {.lex_state = 419, .external_lex_state = 42},
  [1790] = {.lex_state = 527, .external_lex_state = 19},
  [1791] = {.lex_state = 534, .external_lex_state = 45},
  [1792] = {.lex_state = 532, .external_lex_state = 45},
  [1793] = {.lex_state = 419, .external_lex_state = 42},
  [1794] = {.lex_state = 532, .external_lex_state = 45},
  [1795] = {.lex_state = 532, .external_lex_state = 45},
  [1796] = {.lex_state = 532, .external_lex_state = 45},
  [1797] = {.lex_state = 532, .external_lex_state = 45},
  [1798] = {.lex_state = 419, .external_lex_state = 42},
  [1799] = {.lex_state = 534, .external_lex_state = 45},
  [1800] = {.lex_state = 534, .external_lex_state = 45},
  [1801] = {.lex_state = 248, .external_lex_state = 22},
  [1802] = {.lex_state = 257, .external_lex_state = 19},
  [1803] = {.lex_state = 527, .external_lex_state = 19},
  [1804] = {.lex_state = 532, .external_lex_state = 45},
  [1805] = {.lex_state = 419, .external_lex_state = 42},
  [1806] = {.lex_state = 532, .external_lex_state = 45},
  [1807] = {.lex_state = 532, .external_lex_state = 45},
  [1808] = {.lex_state = 532, .external_lex_state = 45},
  [1809] = {.lex_state = 527, .external_lex_state = 19},
  [1810] = {.lex_state = 532, .external_lex_state = 45},
  [1811] = {.lex_state = 263, .external_lex_state = 21},
  [1812] = {.lex_state = 532, .external_lex_state = 45},
  [1813] = {.lex_state = 257, .external_lex_state = 19},
  [1814] = {.lex_state = 527, .external_lex_state = 19},
  [1815] = {.lex_state = 532, .external_lex_state = 45},
  [1816] = {.lex_state = 532, .external_lex_state = 45},
  [1817] = {.lex_state = 532, .external_lex_state = 45},
  [1818] = {.lex_state = 527, .external_lex_state = 19},
  [1819] = {.lex_state = 527, .external_lex_state = 19},
  [1820] = {.lex_state = 525, .external_lex_state = 19},
  [1821] = {.lex_state = 532, .external_lex_state = 45},
  [1822] = {.lex_state = 532, .external_lex_state = 45},
  [1823] = {.lex_state = 257, .external_lex_state = 19},
  [1824] = {.lex_state = 257, .external_lex_state = 19},
  [1825] = {.lex_state = 527, .external_lex_state = 19},
  [1826] = {.lex_state = 532, .external_lex_state = 45},
  [1827] = {.lex_state = 525, .external_lex_state = 19},
  [1828] = {.lex_state = 525, .external_lex_state = 19},
  [1829] = {.lex_state = 248, .external_lex_state = 19},
  [1830] = {.lex_state = 292, .external_lex_state = 45},
  [1831] = {.lex_state = 292, .external_lex_state = 45},
  [1832] = {.lex_state = 533, .external_lex_state = 45},
  [1833] = {.lex_state = 257, .external_lex_state = 19},
  [1834] = {.lex_state = 527, .external_lex_state = 19},
  [1835] = {.lex_state = 248, .external_lex_state = 19},
  [1836] = {.lex_state = 533, .external_lex_state = 45},
  [1837] = {.lex_state = 257, .external_lex_state = 19},
  [1838] = {.lex_state = 533, .external_lex_state = 45},
  [1839] = {.lex_state = 292, .external_lex_state = 45},
  [1840] = {.lex_state = 533, .external_lex_state = 45},
  [1841] = {.lex_state = 533, .external_lex_state = 45},
  [1842] = {.lex_state = 533, .external_lex_state = 45},
  [1843] = {.lex_state = 248, .external_lex_state = 22},
  [1844] = {.lex_state = 533, .external_lex_state = 45},
  [1845] = {.lex_state = 533, .external_lex_state = 45},
  [1846] = {.lex_state = 292, .external_lex_state = 45},
  [1847] = {.lex_state = 533, .external_lex_state = 45},
  [1848] = {.lex_state = 533, .external_lex_state = 45},
  [1849] = {.lex_state = 456, .external_lex_state = 50},
  [1850] = {.lex_state = 534, .external_lex_state = 45},
  [1851] = {.lex_state = 534, .external_lex_state = 45},
  [1852] = {.lex_state = 533, .external_lex_state = 45},
  [1853] = {.lex_state = 533, .external_lex_state = 45},
  [1854] = {.lex_state = 533, .external_lex_state = 45},
  [1855] = {.lex_state = 533, .external_lex_state = 45},
  [1856] = {.lex_state = 533, .external_lex_state = 45},
  [1857] = {.lex_state = 533, .external_lex_state = 45},
  [1858] = {.lex_state = 292, .external_lex_state = 45},
  [1859] = {.lex_state = 533, .external_lex_state = 45},
  [1860] = {.lex_state = 533, .external_lex_state = 45},
  [1861] = {.lex_state = 533, .external_lex_state = 45},
  [1862] = {.lex_state = 533, .external_lex_state = 45},
  [1863] = {.lex_state = 533, .external_lex_state = 45},
  [1864] = {.lex_state = 533, .external_lex_state = 45},
  [1865] = {.lex_state = 452, .external_lex_state = 35},
  [1866] = {.lex_state = 533, .external_lex_state = 45},
  [1867] = {.lex_state = 456, .external_lex_state = 50},
  [1868] = {.lex_state = 527, .external_lex_state = 19},
  [1869] = {.lex_state = 456, .external_lex_state = 50},
  [1870] = {.lex_state = 527, .external_lex_state = 19},
  [1871] = {.lex_state = 292, .external_lex_state = 45},
  [1872] = {.lex_state = 533, .external_lex_state = 45},
  [1873] = {.lex_state = 419, .external_lex_state = 49},
  [1874] = {.lex_state = 248, .external_lex_state = 19},
  [1875] = {.lex_state = 533, .external_lex_state = 45},
  [1876] = {.lex_state = 533, .external_lex_state = 45},
  [1877] = {.lex_state = 292, .external_lex_state = 45},
  [1878] = {.lex_state = 456, .external_lex_state = 50},
  [1879] = {.lex_state = 456, .external_lex_state = 50},
  [1880] = {.lex_state = 533, .external_lex_state = 45},
  [1881] = {.lex_state = 533, .external_lex_state = 45},
  [1882] = {.lex_state = 456, .external_lex_state = 50},
  [1883] = {.lex_state = 419, .external_lex_state = 49},
  [1884] = {.lex_state = 419, .external_lex_state = 49},
  [1885] = {.lex_state = 527, .external_lex_state = 19},
  [1886] = {.lex_state = 456, .external_lex_state = 50},
  [1887] = {.lex_state = 533, .external_lex_state = 45},
  [1888] = {.lex_state = 254, .external_lex_state = 21},
  [1889] = {.lex_state = 276, .external_lex_state = 34},
  [1890] = {.lex_state = 276, .external_lex_state = 34},
  [1891] = {.lex_state = 533, .external_lex_state = 45},
  [1892] = {.lex_state = 525, .external_lex_state = 19},
  [1893] = {.lex_state = 276, .external_lex_state = 34},
  [1894] = {.lex_state = 276, .external_lex_state = 34},
  [1895] = {.lex_state = 534, .external_lex_state = 45},
  [1896] = {.lex_state = 533, .external_lex_state = 45},
  [1897] = {.lex_state = 419, .external_lex_state = 49},
  [1898] = {.lex_state = 276, .external_lex_state = 34},
  [1899] = {.lex_state = 276, .external_lex_state = 34},
  [1900] = {.lex_state = 276, .external_lex_state = 34},
  [1901] = {.lex_state = 276, .external_lex_state = 34},
  [1902] = {.lex_state = 276, .external_lex_state = 34},
  [1903] = {.lex_state = 257, .external_lex_state = 22},
  [1904] = {.lex_state = 533, .external_lex_state = 45},
  [1905] = {.lex_state = 527, .external_lex_state = 19},
  [1906] = {.lex_state = 257, .external_lex_state = 19},
  [1907] = {.lex_state = 527, .external_lex_state = 19},
  [1908] = {.lex_state = 527, .external_lex_state = 19},
  [1909] = {.lex_state = 527, .external_lex_state = 19},
  [1910] = {.lex_state = 534, .external_lex_state = 45},
  [1911] = {.lex_state = 525, .external_lex_state = 19},
  [1912] = {.lex_state = 534, .external_lex_state = 45},
  [1913] = {.lex_state = 419, .external_lex_state = 42},
  [1914] = {.lex_state = 456, .external_lex_state = 51},
  [1915] = {.lex_state = 419, .external_lex_state = 42},
  [1916] = {.lex_state = 456, .external_lex_state = 51},
  [1917] = {.lex_state = 419, .external_lex_state = 42},
  [1918] = {.lex_state = 419, .external_lex_state = 42},
  [1919] = {.lex_state = 419, .external_lex_state = 42},
  [1920] = {.lex_state = 419, .external_lex_state = 42},
  [1921] = {.lex_state = 419, .external_lex_state = 42},
  [1922] = {.lex_state = 419, .external_lex_state = 42},
  [1923] = {.lex_state = 534, .external_lex_state = 45},
  [1924] = {.lex_state = 534, .external_lex_state = 45},
  [1925] = {.lex_state = 452, .external_lex_state = 35},
  [1926] = {.lex_state = 419, .external_lex_state = 42},
  [1927] = {.lex_state = 419, .external_lex_state = 42},
  [1928] = {.lex_state = 419, .external_lex_state = 42},
  [1929] = {.lex_state = 419, .external_lex_state = 42},
  [1930] = {.lex_state = 534, .external_lex_state = 45},
  [1931] = {.lex_state = 534, .external_lex_state = 45},
  [1932] = {.lex_state = 419, .external_lex_state = 42},
  [1933] = {.lex_state = 534, .external_lex_state = 45},
  [1934] = {.lex_state = 456, .external_lex_state = 51},
  [1935] = {.lex_state = 419, .external_lex_state = 42},
  [1936] = {.lex_state = 456, .external_lex_state = 50},
  [1937] = {.lex_state = 419, .external_lex_state = 42},
  [1938] = {.lex_state = 419, .external_lex_state = 42},
  [1939] = {.lex_state = 527, .external_lex_state = 19},
  [1940] = {.lex_state = 419, .external_lex_state = 42},
  [1941] = {.lex_state = 419, .external_lex_state = 42},
  [1942] = {.lex_state = 419, .external_lex_state = 42},
  [1943] = {.lex_state = 534, .external_lex_state = 45},
  [1944] = {.lex_state = 419, .external_lex_state = 42},
  [1945] = {.lex_state = 419, .external_lex_state = 42},
  [1946] = {.lex_state = 419, .external_lex_state = 42},
  [1947] = {.lex_state = 419, .external_lex_state = 42},
  [1948] = {.lex_state = 419, .external_lex_state = 42},
  [1949] = {.lex_state = 419, .external_lex_state = 42},
  [1950] = {.lex_state = 534, .external_lex_state = 45},
  [1951] = {.lex_state = 534, .external_lex_state = 45},
  [1952] = {.lex_state = 419, .external_lex_state = 42},
  [1953] = {.lex_state = 534, .external_lex_state = 45},
  [1954] = {.lex_state = 419, .external_lex_state = 42},
  [1955] = {.lex_state = 419, .external_lex_state = 42},
  [1956] = {.lex_state = 534, .external_lex_state = 45},
  [1957] = {.lex_state = 419, .external_lex_state = 42},
  [1958] = {.lex_state = 419, .external_lex_state = 42},
  [1959] = {.lex_state = 419, .external_lex_state = 42},
  [1960] = {.lex_state = 419, .external_lex_state = 42},
  [1961] = {.lex_state = 419, .external_lex_state = 42},
  [1962] = {.lex_state = 527, .external_lex_state = 19},
  [1963] = {.lex_state = 419, .external_lex_state = 42},
  [1964] = {.lex_state = 419, .external_lex_state = 42},
  [1965] = {.lex_state = 419, .external_lex_state = 42},
  [1966] = {.lex_state = 419, .external_lex_state = 42},
  [1967] = {.lex_state = 419, .external_lex_state = 42},
  [1968] = {.lex_state = 525, .external_lex_state = 22},
  [1969] = {.lex_state = 456, .external_lex_state = 50},
  [1970] = {.lex_state = 456, .external_lex_state = 51},
  [1971] = {.lex_state = 525, .external_lex_state = 19},
  [1972] = {.lex_state = 419, .external_lex_state = 42},
  [1973] = {.lex_state = 527, .external_lex_state = 19},
  [1974] = {.lex_state = 419, .external_lex_state = 42},
  [1975] = {.lex_state = 534, .external_lex_state = 45},
  [1976] = {.lex_state = 419, .external_lex_state = 42},
  [1977] = {.lex_state = 419, .external_lex_state = 42},
  [1978] = {.lex_state = 419, .external_lex_state = 42},
  [1979] = {.lex_state = 525, .external_lex_state = 19},
  [1980] = {.lex_state = 419, .external_lex_state = 42},
  [1981] = {.lex_state = 456, .external_lex_state = 50},
  [1982] = {.lex_state = 527, .external_lex_state = 19},
  [1983] = {.lex_state = 419, .external_lex_state = 42},
  [1984] = {.lex_state = 534, .external_lex_state = 45},
  [1985] = {.lex_state = 456, .external_lex_state = 50},
  [1986] = {.lex_state = 534, .external_lex_state = 45},
  [1987] = {.lex_state = 527, .external_lex_state = 19},
  [1988] = {.lex_state = 456, .external_lex_state = 50},
  [1989] = {.lex_state = 419, .external_lex_state = 42},
  [1990] = {.lex_state = 534, .external_lex_state = 45},
  [1991] = {.lex_state = 534, .external_lex_state = 45},
  [1992] = {.lex_state = 534, .external_lex_state = 45},
  [1993] = {.lex_state = 419, .external_lex_state = 42},
  [1994] = {.lex_state = 456, .external_lex_state = 50},
  [1995] = {.lex_state = 534, .external_lex_state = 45},
  [1996] = {.lex_state = 534, .external_lex_state = 45},
  [1997] = {.lex_state = 456, .external_lex_state = 50},
  [1998] = {.lex_state = 419, .external_lex_state = 42},
  [1999] = {.lex_state = 527, .external_lex_state = 19},
  [2000] = {.lex_state = 419, .external_lex_state = 42},
  [2001] = {.lex_state = 527, .external_lex_state = 22},
  [2002] = {.lex_state = 534, .external_lex_state = 45},
  [2003] = {.lex_state = 456, .external_lex_state = 50},
  [2004] = {.lex_state = 263, .external_lex_state = 21},
  [2005] = {.lex_state = 534, .external_lex_state = 45},
  [2006] = {.lex_state = 456, .external_lex_state = 50},
  [2007] = {.lex_state = 534, .external_lex_state = 45},
  [2008] = {.lex_state = 534, .external_lex_state = 45},
  [2009] = {.lex_state = 534, .external_lex_state = 45},
  [2010] = {.lex_state = 534, .external_lex_state = 45},
  [2011] = {.lex_state = 534, .external_lex_state = 45},
  [2012] = {.lex_state = 419, .external_lex_state = 42},
  [2013] = {.lex_state = 534, .external_lex_state = 45},
  [2014] = {.lex_state = 534, .external_lex_state = 45},
  [2015] = {.lex_state = 419, .external_lex_state = 42},
  [2016] = {.lex_state = 527, .external_lex_state = 19},
  [2017] = {.lex_state = 534, .external_lex_state = 45},
  [2018] = {.lex_state = 527, .external_lex_state = 19},
  [2019] = {.lex_state = 527, .external_lex_state = 19},
  [2020] = {.lex_state = 527, .external_lex_state = 19},
  [2021] = {.lex_state = 534, .external_lex_state = 45},
  [2022] = {.lex_state = 534, .external_lex_state = 45},
  [2023] = {.lex_state = 534, .external_lex_state = 45},
  [2024] = {.lex_state = 456, .external_lex_state = 50},
  [2025] = {.lex_state = 419, .external_lex_state = 42},
  [2026] = {.lex_state = 527, .external_lex_state = 22},
  [2027] = {.lex_state = 527, .external_lex_state = 22},
  [2028] = {.lex_state = 534, .external_lex_state = 45},
  [2029] = {.lex_state = 456, .external_lex_state = 50},
  [2030] = {.lex_state = 527, .external_lex_state = 19},
  [2031] = {.lex_state = 527, .external_lex_state = 19},
  [2032] = {.lex_state = 419, .external_lex_state = 42},
  [2033] = {.lex_state = 419, .external_lex_state = 42},
  [2034] = {.lex_state = 527, .external_lex_state = 19},
  [2035] = {.lex_state = 527, .external_lex_state = 19},
  [2036] = {.lex_state = 527, .external_lex_state = 19},
  [2037] = {.lex_state = 534, .external_lex_state = 45},
  [2038] = {.lex_state = 534, .external_lex_state = 45},
  [2039] = {.lex_state = 534, .external_lex_state = 45},
  [2040] = {.lex_state = 419, .external_lex_state = 42},
  [2041] = {.lex_state = 419, .external_lex_state = 42},
  [2042] = {.lex_state = 431, .external_lex_state = 52},
  [2043] = {.lex_state = 527, .external_lex_state = 19},
  [2044] = {.lex_state = 456, .external_lex_state = 51},
  [2045] = {.lex_state = 525, .external_lex_state = 22},
  [2046] = {.lex_state = 419, .external_lex_state = 42},
  [2047] = {.lex_state = 527, .external_lex_state = 19},
  [2048] = {.lex_state = 419, .external_lex_state = 42},
  [2049] = {.lex_state = 527, .external_lex_state = 19},
  [2050] = {.lex_state = 419, .external_lex_state = 42},
  [2051] = {.lex_state = 534, .external_lex_state = 45},
  [2052] = {.lex_state = 534, .external_lex_state = 45},
  [2053] = {.lex_state = 525, .external_lex_state = 19},
  [2054] = {.lex_state = 534, .external_lex_state = 45},
  [2055] = {.lex_state = 527, .external_lex_state = 19},
  [2056] = {.lex_state = 525, .external_lex_state = 19},
  [2057] = {.lex_state = 527, .external_lex_state = 19},
  [2058] = {.lex_state = 419, .external_lex_state = 42},
  [2059] = {.lex_state = 534, .external_lex_state = 45},
  [2060] = {.lex_state = 534, .external_lex_state = 45},
  [2061] = {.lex_state = 527, .external_lex_state = 19},
  [2062] = {.lex_state = 456, .external_lex_state = 50},
  [2063] = {.lex_state = 456, .external_lex_state = 50},
  [2064] = {.lex_state = 419, .external_lex_state = 42},
  [2065] = {.lex_state = 456, .external_lex_state = 50},
  [2066] = {.lex_state = 419, .external_lex_state = 42},
  [2067] = {.lex_state = 419, .external_lex_state = 42},
  [2068] = {.lex_state = 527, .external_lex_state = 19},
  [2069] = {.lex_state = 534, .external_lex_state = 45},
  [2070] = {.lex_state = 527, .external_lex_state = 19},
  [2071] = {.lex_state = 419, .external_lex_state = 42},
  [2072] = {.lex_state = 525, .external_lex_state = 22},
  [2073] = {.lex_state = 527, .external_lex_state = 19},
  [2074] = {.lex_state = 527, .external_lex_state = 19},
  [2075] = {.lex_state = 527, .external_lex_state = 19},
  [2076] = {.lex_state = 248, .external_lex_state = 22},
  [2077] = {.lex_state = 527, .external_lex_state = 19},
  [2078] = {.lex_state = 456, .external_lex_state = 51},
  [2079] = {.lex_state = 419, .external_lex_state = 42},
  [2080] = {.lex_state = 419, .external_lex_state = 42},
  [2081] = {.lex_state = 527, .external_lex_state = 19},
  [2082] = {.lex_state = 525, .external_lex_state = 19},
  [2083] = {.lex_state = 527, .external_lex_state = 19},
  [2084] = {.lex_state = 527, .external_lex_state = 19},
  [2085] = {.lex_state = 525, .external_lex_state = 19},
  [2086] = {.lex_state = 527, .external_lex_state = 19},
  [2087] = {.lex_state = 525, .external_lex_state = 22},
  [2088] = {.lex_state = 527, .external_lex_state = 19},
  [2089] = {.lex_state = 419, .external_lex_state = 42},
  [2090] = {.lex_state = 527, .external_lex_state = 19},
  [2091] = {.lex_state = 527, .external_lex_state = 19},
  [2092] = {.lex_state = 527, .external_lex_state = 19},
  [2093] = {.lex_state = 527, .external_lex_state = 19},
  [2094] = {.lex_state = 527, .external_lex_state = 19},
  [2095] = {.lex_state = 527, .external_lex_state = 19},
  [2096] = {.lex_state = 527, .external_lex_state = 19},
  [2097] = {.lex_state = 527, .external_lex_state = 19},
  [2098] = {.lex_state = 527, .external_lex_state = 19},
  [2099] = {.lex_state = 419, .external_lex_state = 42},
  [2100] = {.lex_state = 527, .external_lex_state = 19},
  [2101] = {.lex_state = 527, .external_lex_state = 19},
  [2102] = {.lex_state = 527, .external_lex_state = 19},
  [2103] = {.lex_state = 527, .external_lex_state = 19},
  [2104] = {.lex_state = 527, .external_lex_state = 19},
  [2105] = {.lex_state = 527, .external_lex_state = 19},
  [2106] = {.lex_state = 527, .external_lex_state = 19},
  [2107] = {.lex_state = 527, .external_lex_state = 19},
  [2108] = {.lex_state = 527, .external_lex_state = 19},
  [2109] = {.lex_state = 527, .external_lex_state = 19},
  [2110] = {.lex_state = 266, .external_lex_state = 22},
  [2111] = {.lex_state = 456, .external_lex_state = 50},
  [2112] = {.lex_state = 527, .external_lex_state = 22},
  [2113] = {.lex_state = 456, .external_lex_state = 51},
  [2114] = {.lex_state = 456, .external_lex_state = 51},
  [2115] = {.lex_state = 419, .external_lex_state = 42},
  [2116] = {.lex_state = 456, .external_lex_state = 51},
  [2117] = {.lex_state = 456, .external_lex_state = 51},
  [2118] = {.lex_state = 419, .external_lex_state = 42},
  [2119] = {.lex_state = 419, .external_lex_state = 42},
  [2120] = {.lex_state = 419, .external_lex_state = 42},
  [2121] = {.lex_state = 527, .external_lex_state = 19},
  [2122] = {.lex_state = 527, .external_lex_state = 19},
  [2123] = {.lex_state = 527, .external_lex_state = 19},
  [2124] = {.lex_state = 527, .external_lex_state = 19},
  [2125] = {.lex_state = 527, .external_lex_state = 19},
  [2126] = {.lex_state = 419, .external_lex_state = 42},
  [2127] = {.lex_state = 527, .external_lex_state = 19},
  [2128] = {.lex_state = 527, .external_lex_state = 19},
  [2129] = {.lex_state = 419, .external_lex_state = 42},
  [2130] = {.lex_state = 527, .external_lex_state = 19},
  [2131] = {.lex_state = 419, .external_lex_state = 42},
  [2132] = {.lex_state = 419, .external_lex_state = 42},
  [2133] = {.lex_state = 419, .external_lex_state = 42},
  [2134] = {.lex_state = 527, .external_lex_state = 19},
  [2135] = {.lex_state = 419, .external_lex_state = 42},
  [2136] = {.lex_state = 527, .external_lex_state = 19},
  [2137] = {.lex_state = 456, .external_lex_state = 50},
  [2138] = {.lex_state = 419, .external_lex_state = 42},
  [2139] = {.lex_state = 527, .external_lex_state = 19},
  [2140] = {.lex_state = 527, .external_lex_state = 19},
  [2141] = {.lex_state = 527, .external_lex_state = 19},
  [2142] = {.lex_state = 456, .external_lex_state = 51},
  [2143] = {.lex_state = 527, .external_lex_state = 19},
  [2144] = {.lex_state = 456, .external_lex_state = 50},
  [2145] = {.lex_state = 419, .external_lex_state = 42},
  [2146] = {.lex_state = 527, .external_lex_state = 19},
  [2147] = {.lex_state = 419, .external_lex_state = 42},
  [2148] = {.lex_state = 452, .external_lex_state = 35},
  [2149] = {.lex_state = 266, .external_lex_state = 22},
  [2150] = {.lex_state = 456, .external_lex_state = 50},
  [2151] = {.lex_state = 527, .external_lex_state = 19},
  [2152] = {.lex_state = 419, .external_lex_state = 42},
  [2153] = {.lex_state = 527, .external_lex_state = 19},
  [2154] = {.lex_state = 419, .external_lex_state = 42},
  [2155] = {.lex_state = 419, .external_lex_state = 42},
  [2156] = {.lex_state = 527, .external_lex_state = 19},
  [2157] = {.lex_state = 419, .external_lex_state = 42},
  [2158] = {.lex_state = 527, .external_lex_state = 19},
  [2159] = {.lex_state = 419, .external_lex_state = 42},
  [2160] = {.lex_state = 419, .external_lex_state = 42},
  [2161] = {.lex_state = 419, .external_lex_state = 42},
  [2162] = {.lex_state = 419, .external_lex_state = 42},
  [2163] = {.lex_state = 419, .external_lex_state = 42},
  [2164] = {.lex_state = 419, .external_lex_state = 42},
  [2165] = {.lex_state = 527, .external_lex_state = 19},
  [2166] = {.lex_state = 419, .external_lex_state = 42},
  [2167] = {.lex_state = 419, .external_lex_state = 42},
  [2168] = {.lex_state = 419, .external_lex_state = 42},
  [2169] = {.lex_state = 419, .external_lex_state = 42},
  [2170] = {.lex_state = 419, .external_lex_state = 42},
  [2171] = {.lex_state = 527, .external_lex_state = 19},
  [2172] = {.lex_state = 419, .external_lex_state = 42},
  [2173] = {.lex_state = 419, .external_lex_state = 42},
  [2174] = {.lex_state = 527, .external_lex_state = 19},
  [2175] = {.lex_state = 419, .external_lex_state = 42},
  [2176] = {.lex_state = 527, .external_lex_state = 19},
  [2177] = {.lex_state = 456, .external_lex_state = 51},
  [2178] = {.lex_state = 419, .external_lex_state = 42},
  [2179] = {.lex_state = 456, .external_lex_state = 50},
  [2180] = {.lex_state = 419, .external_lex_state = 42},
  [2181] = {.lex_state = 419, .external_lex_state = 42},
  [2182] = {.lex_state = 527, .external_lex_state = 19},
  [2183] = {.lex_state = 527, .external_lex_state = 19},
  [2184] = {.lex_state = 419, .external_lex_state = 42},
  [2185] = {.lex_state = 419, .external_lex_state = 42},
  [2186] = {.lex_state = 419, .external_lex_state = 42},
  [2187] = {.lex_state = 527, .external_lex_state = 19},
  [2188] = {.lex_state = 419, .external_lex_state = 42},
  [2189] = {.lex_state = 527, .external_lex_state = 19},
  [2190] = {.lex_state = 419, .external_lex_state = 42},
  [2191] = {.lex_state = 419, .external_lex_state = 42},
  [2192] = {.lex_state = 527, .external_lex_state = 19},
  [2193] = {.lex_state = 527, .external_lex_state = 19},
  [2194] = {.lex_state = 527, .external_lex_state = 19},
  [2195] = {.lex_state = 525, .external_lex_state = 19},
  [2196] = {.lex_state = 527, .external_lex_state = 19},
  [2197] = {.lex_state = 527, .external_lex_state = 19},
  [2198] = {.lex_state = 527, .external_lex_state = 19},
  [2199] = {.lex_state = 527, .external_lex_state = 19},
  [2200] = {.lex_state = 527, .external_lex_state = 19},
  [2201] = {.lex_state = 527, .external_lex_state = 19},
  [2202] = {.lex_state = 527, .external_lex_state = 19},
  [2203] = {.lex_state = 527, .external_lex_state = 19},
  [2204] = {.lex_state = 527, .external_lex_state = 19},
  [2205] = {.lex_state = 527, .external_lex_state = 19},
  [2206] = {.lex_state = 527, .external_lex_state = 19},
  [2207] = {.lex_state = 527, .external_lex_state = 19},
  [2208] = {.lex_state = 527, .external_lex_state = 19},
  [2209] = {.lex_state = 419, .external_lex_state = 42},
  [2210] = {.lex_state = 527, .external_lex_state = 19},
  [2211] = {.lex_state = 527, .external_lex_state = 19},
  [2212] = {.lex_state = 419, .external_lex_state = 42},
  [2213] = {.lex_state = 419, .external_lex_state = 42},
  [2214] = {.lex_state = 257, .external_lex_state = 22},
  [2215] = {.lex_state = 527, .external_lex_state = 19},
  [2216] = {.lex_state = 527, .external_lex_state = 19},
  [2217] = {.lex_state = 529, .external_lex_state = 22},
  [2218] = {.lex_state = 456, .external_lex_state = 51},
  [2219] = {.lex_state = 431, .external_lex_state = 52},
  [2220] = {.lex_state = 456, .external_lex_state = 51},
  [2221] = {.lex_state = 456, .external_lex_state = 51},
  [2222] = {.lex_state = 456, .external_lex_state = 51},
  [2223] = {.lex_state = 431, .external_lex_state = 52},
  [2224] = {.lex_state = 431, .external_lex_state = 52},
  [2225] = {.lex_state = 431, .external_lex_state = 52},
  [2226] = {.lex_state = 431, .external_lex_state = 52},
  [2227] = {.lex_state = 431, .external_lex_state = 52},
  [2228] = {.lex_state = 459, .external_lex_state = 53},
  [2229] = {.lex_state = 431, .external_lex_state = 52},
  [2230] = {.lex_state = 431, .external_lex_state = 52},
  [2231] = {.lex_state = 459, .external_lex_state = 53},
  [2232] = {.lex_state = 431, .external_lex_state = 52},
  [2233] = {.lex_state = 431, .external_lex_state = 52},
  [2234] = {.lex_state = 431, .external_lex_state = 52},
  [2235] = {.lex_state = 525, .external_lex_state = 22},
  [2236] = {.lex_state = 431, .external_lex_state = 52},
  [2237] = {.lex_state = 431, .external_lex_state = 52},
  [2238] = {.lex_state = 459, .external_lex_state = 53},
  [2239] = {.lex_state = 431, .external_lex_state = 52},
  [2240] = {.lex_state = 431, .external_lex_state = 52},
  [2241] = {.lex_state = 431, .external_lex_state = 52},
  [2242] = {.lex_state = 431, .external_lex_state = 52},
  [2243] = {.lex_state = 431, .external_lex_state = 52},
  [2244] = {.lex_state = 431, .external_lex_state = 52},
  [2245] = {.lex_state = 456, .external_lex_state = 51},
  [2246] = {.lex_state = 437, .external_lex_state = 44},
  [2247] = {.lex_state = 525, .external_lex_state = 22},
  [2248] = {.lex_state = 456, .external_lex_state = 51},
  [2249] = {.lex_state = 455, .external_lex_state = 23},
  [2250] = {.lex_state = 459, .external_lex_state = 53},
  [2251] = {.lex_state = 456, .external_lex_state = 51},
  [2252] = {.lex_state = 459, .external_lex_state = 53},
  [2253] = {.lex_state = 529, .external_lex_state = 22},
  [2254] = {.lex_state = 284, .external_lex_state = 43},
  [2255] = {.lex_state = 284, .external_lex_state = 43},
  [2256] = {.lex_state = 286, .external_lex_state = 43},
  [2257] = {.lex_state = 286, .external_lex_state = 43},
  [2258] = {.lex_state = 456, .external_lex_state = 51},
  [2259] = {.lex_state = 437, .external_lex_state = 44},
  [2260] = {.lex_state = 456, .external_lex_state = 51},
  [2261] = {.lex_state = 456, .external_lex_state = 51},
  [2262] = {.lex_state = 404, .external_lex_state = 35},
  [2263] = {.lex_state = 456, .external_lex_state = 51},
  [2264] = {.lex_state = 459, .external_lex_state = 53},
  [2265] = {.lex_state = 456, .external_lex_state = 51},
  [2266] = {.lex_state = 456, .external_lex_state = 51},
  [2267] = {.lex_state = 456, .external_lex_state = 51},
  [2268] = {.lex_state = 527, .external_lex_state = 19},
  [2269] = {.lex_state = 527, .external_lex_state = 19},
  [2270] = {.lex_state = 459, .external_lex_state = 53},
  [2271] = {.lex_state = 456, .external_lex_state = 51},
  [2272] = {.lex_state = 456, .external_lex_state = 51},
  [2273] = {.lex_state = 459, .external_lex_state = 53},
  [2274] = {.lex_state = 456, .external_lex_state = 51},
  [2275] = {.lex_state = 459, .external_lex_state = 53},
  [2276] = {.lex_state = 266, .external_lex_state = 22},
  [2277] = {.lex_state = 432, .external_lex_state = 52},
  [2278] = {.lex_state = 456, .external_lex_state = 51},
  [2279] = {.lex_state = 529, .external_lex_state = 22},
  [2280] = {.lex_state = 529, .external_lex_state = 22},
  [2281] = {.lex_state = 527, .external_lex_state = 22},
  [2282] = {.lex_state = 459, .external_lex_state = 53},
  [2283] = {.lex_state = 459, .external_lex_state = 53},
  [2284] = {.lex_state = 432, .external_lex_state = 52},
  [2285] = {.lex_state = 527, .external_lex_state = 19},
  [2286] = {.lex_state = 284, .external_lex_state = 43},
  [2287] = {.lex_state = 284, .external_lex_state = 43},
  [2288] = {.lex_state = 286, .external_lex_state = 43},
  [2289] = {.lex_state = 286, .external_lex_state = 43},
  [2290] = {.lex_state = 284, .external_lex_state = 43},
  [2291] = {.lex_state = 284, .external_lex_state = 43},
  [2292] = {.lex_state = 284, .external_lex_state = 43},
  [2293] = {.lex_state = 284, .external_lex_state = 43},
  [2294] = {.lex_state = 284, .external_lex_state = 43},
  [2295] = {.lex_state = 284, .external_lex_state = 43},
  [2296] = {.lex_state = 284, .external_lex_state = 43},
  [2297] = {.lex_state = 284, .external_lex_state = 43},
  [2298] = {.lex_state = 527, .external_lex_state = 22},
  [2299] = {.lex_state = 431, .external_lex_state = 52},
  [2300] = {.lex_state = 286, .external_lex_state = 43},
  [2301] = {.lex_state = 286, .external_lex_state = 43},
  [2302] = {.lex_state = 456, .external_lex_state = 51},
  [2303] = {.lex_state = 284, .external_lex_state = 43},
  [2304] = {.lex_state = 286, .external_lex_state = 43},
  [2305] = {.lex_state = 404, .external_lex_state = 35},
  [2306] = {.lex_state = 459, .external_lex_state = 53},
  [2307] = {.lex_state = 455, .external_lex_state = 23},
  [2308] = {.lex_state = 286, .external_lex_state = 45},
  [2309] = {.lex_state = 437, .external_lex_state = 44},
  [2310] = {.lex_state = 286, .external_lex_state = 45},
  [2311] = {.lex_state = 286, .external_lex_state = 45},
  [2312] = {.lex_state = 432, .external_lex_state = 39},
  [2313] = {.lex_state = 427, .external_lex_state = 54},
  [2314] = {.lex_state = 431, .external_lex_state = 52},
  [2315] = {.lex_state = 431, .external_lex_state = 52},
  [2316] = {.lex_state = 459, .external_lex_state = 53},
  [2317] = {.lex_state = 437, .external_lex_state = 44},
  [2318] = {.lex_state = 459, .external_lex_state = 53},
  [2319] = {.lex_state = 459, .external_lex_state = 53},
  [2320] = {.lex_state = 294, .external_lex_state = 55},
  [2321] = {.lex_state = 465, .external_lex_state = 56},
  [2322] = {.lex_state = 294, .external_lex_state = 55},
  [2323] = {.lex_state = 455, .external_lex_state = 25},
  [2324] = {.lex_state = 437, .external_lex_state = 44},
  [2325] = {.lex_state = 429, .external_lex_state = 44},
  [2326] = {.lex_state = 294, .external_lex_state = 55},
  [2327] = {.lex_state = 429, .external_lex_state = 44},
  [2328] = {.lex_state = 459, .external_lex_state = 53},
  [2329] = {.lex_state = 455, .external_lex_state = 25},
  [2330] = {.lex_state = 437, .external_lex_state = 44},
  [2331] = {.lex_state = 294, .external_lex_state = 55},
  [2332] = {.lex_state = 437, .external_lex_state = 44},
  [2333] = {.lex_state = 459, .external_lex_state = 53},
  [2334] = {.lex_state = 294, .external_lex_state = 55},
  [2335] = {.lex_state = 457, .external_lex_state = 56},
  [2336] = {.lex_state = 294, .external_lex_state = 55},
  [2337] = {.lex_state = 427, .external_lex_state = 54},
  [2338] = {.lex_state = 459, .external_lex_state = 53},
  [2339] = {.lex_state = 459, .external_lex_state = 53},
  [2340] = {.lex_state = 427, .external_lex_state = 54},
  [2341] = {.lex_state = 459, .external_lex_state = 53},
  [2342] = {.lex_state = 437, .external_lex_state = 44},
  [2343] = {.lex_state = 459, .external_lex_state = 53},
  [2344] = {.lex_state = 431, .external_lex_state = 52},
  [2345] = {.lex_state = 429, .external_lex_state = 44},
  [2346] = {.lex_state = 457, .external_lex_state = 56},
  [2347] = {.lex_state = 459, .external_lex_state = 53},
  [2348] = {.lex_state = 427, .external_lex_state = 54},
  [2349] = {.lex_state = 455, .external_lex_state = 25},
  [2350] = {.lex_state = 459, .external_lex_state = 57},
  [2351] = {.lex_state = 529, .external_lex_state = 22},
  [2352] = {.lex_state = 529, .external_lex_state = 22},
  [2353] = {.lex_state = 459, .external_lex_state = 53},
  [2354] = {.lex_state = 465, .external_lex_state = 56},
  [2355] = {.lex_state = 437, .external_lex_state = 44},
  [2356] = {.lex_state = 457, .external_lex_state = 56},
  [2357] = {.lex_state = 437, .external_lex_state = 44},
  [2358] = {.lex_state = 459, .external_lex_state = 53},
  [2359] = {.lex_state = 429, .external_lex_state = 44},
  [2360] = {.lex_state = 459, .external_lex_state = 53},
  [2361] = {.lex_state = 431, .external_lex_state = 52},
  [2362] = {.lex_state = 437, .external_lex_state = 44},
  [2363] = {.lex_state = 429, .external_lex_state = 44},
  [2364] = {.lex_state = 457, .external_lex_state = 56},
  [2365] = {.lex_state = 465, .external_lex_state = 56},
  [2366] = {.lex_state = 429, .external_lex_state = 44},
  [2367] = {.lex_state = 465, .external_lex_state = 56},
  [2368] = {.lex_state = 457, .external_lex_state = 56},
  [2369] = {.lex_state = 457, .external_lex_state = 56},
  [2370] = {.lex_state = 459, .external_lex_state = 53},
  [2371] = {.lex_state = 465, .external_lex_state = 56},
  [2372] = {.lex_state = 459, .external_lex_state = 53},
  [2373] = {.lex_state = 429, .external_lex_state = 44},
  [2374] = {.lex_state = 294, .external_lex_state = 55},
  [2375] = {.lex_state = 294, .external_lex_state = 55},
  [2376] = {.lex_state = 459, .external_lex_state = 57},
  [2377] = {.lex_state = 294, .external_lex_state = 55},
  [2378] = {.lex_state = 294, .external_lex_state = 55},
  [2379] = {.lex_state = 294, .external_lex_state = 55},
  [2380] = {.lex_state = 459, .external_lex_state = 57},
  [2381] = {.lex_state = 431, .external_lex_state = 52},
  [2382] = {.lex_state = 459, .external_lex_state = 57},
  [2383] = {.lex_state = 294, .external_lex_state = 55},
  [2384] = {.lex_state = 459, .external_lex_state = 57},
  [2385] = {.lex_state = 294, .external_lex_state = 55},
  [2386] = {.lex_state = 431, .external_lex_state = 52},
  [2387] = {.lex_state = 457, .external_lex_state = 56},
  [2388] = {.lex_state = 457, .external_lex_state = 56},
  [2389] = {.lex_state = 294, .external_lex_state = 55},
  [2390] = {.lex_state = 427, .external_lex_state = 54},
  [2391] = {.lex_state = 457, .external_lex_state = 56},
  [2392] = {.lex_state = 286, .external_lex_state = 45},
  [2393] = {.lex_state = 286, .external_lex_state = 45},
  [2394] = {.lex_state = 294, .external_lex_state = 55},
  [2395] = {.lex_state = 465, .external_lex_state = 56},
  [2396] = {.lex_state = 431, .external_lex_state = 52},
  [2397] = {.lex_state = 459, .external_lex_state = 53},
  [2398] = {.lex_state = 465, .external_lex_state = 56},
  [2399] = {.lex_state = 455, .external_lex_state = 25},
  [2400] = {.lex_state = 431, .external_lex_state = 52},
  [2401] = {.lex_state = 459, .external_lex_state = 53},
  [2402] = {.lex_state = 455, .external_lex_state = 23},
  [2403] = {.lex_state = 437, .external_lex_state = 44},
  [2404] = {.lex_state = 459, .external_lex_state = 53},
  [2405] = {.lex_state = 455, .external_lex_state = 25},
  [2406] = {.lex_state = 459, .external_lex_state = 57},
  [2407] = {.lex_state = 429, .external_lex_state = 44},
  [2408] = {.lex_state = 457, .external_lex_state = 56},
  [2409] = {.lex_state = 432, .external_lex_state = 39},
  [2410] = {.lex_state = 457, .external_lex_state = 56},
  [2411] = {.lex_state = 284, .external_lex_state = 45},
  [2412] = {.lex_state = 455, .external_lex_state = 23},
  [2413] = {.lex_state = 284, .external_lex_state = 45},
  [2414] = {.lex_state = 459, .external_lex_state = 53},
  [2415] = {.lex_state = 427, .external_lex_state = 54},
  [2416] = {.lex_state = 284, .external_lex_state = 45},
  [2417] = {.lex_state = 437, .external_lex_state = 44},
  [2418] = {.lex_state = 437, .external_lex_state = 44},
  [2419] = {.lex_state = 457, .external_lex_state = 56},
  [2420] = {.lex_state = 465, .external_lex_state = 56},
  [2421] = {.lex_state = 431, .external_lex_state = 52},
  [2422] = {.lex_state = 432, .external_lex_state = 52},
  [2423] = {.lex_state = 457, .external_lex_state = 56},
  [2424] = {.lex_state = 284, .external_lex_state = 45},
  [2425] = {.lex_state = 284, .external_lex_state = 45},
  [2426] = {.lex_state = 457, .external_lex_state = 56},
  [2427] = {.lex_state = 427, .external_lex_state = 54},
  [2428] = {.lex_state = 427, .external_lex_state = 54},
  [2429] = {.lex_state = 427, .external_lex_state = 54},
  [2430] = {.lex_state = 294, .external_lex_state = 55},
  [2431] = {.lex_state = 437, .external_lex_state = 44},
  [2432] = {.lex_state = 429, .external_lex_state = 58},
  [2433] = {.lex_state = 457, .external_lex_state = 56},
  [2434] = {.lex_state = 457, .external_lex_state = 56},
  [2435] = {.lex_state = 459, .external_lex_state = 57},
  [2436] = {.lex_state = 458, .external_lex_state = 29},
  [2437] = {.lex_state = 457, .external_lex_state = 56},
  [2438] = {.lex_state = 465, .external_lex_state = 56},
  [2439] = {.lex_state = 437, .external_lex_state = 44},
  [2440] = {.lex_state = 465, .external_lex_state = 56},
  [2441] = {.lex_state = 437, .external_lex_state = 44},
  [2442] = {.lex_state = 427, .external_lex_state = 39},
  [2443] = {.lex_state = 437, .external_lex_state = 44},
  [2444] = {.lex_state = 429, .external_lex_state = 58},
  [2445] = {.lex_state = 465, .external_lex_state = 56},
  [2446] = {.lex_state = 465, .external_lex_state = 56},
  [2447] = {.lex_state = 457, .external_lex_state = 56},
  [2448] = {.lex_state = 459, .external_lex_state = 57},
  [2449] = {.lex_state = 455, .external_lex_state = 25},
  [2450] = {.lex_state = 457, .external_lex_state = 56},
  [2451] = {.lex_state = 427, .external_lex_state = 39},
  [2452] = {.lex_state = 429, .external_lex_state = 46},
  [2453] = {.lex_state = 457, .external_lex_state = 56},
  [2454] = {.lex_state = 459, .external_lex_state = 57},
  [2455] = {.lex_state = 437, .external_lex_state = 44},
  [2456] = {.lex_state = 457, .external_lex_state = 56},
  [2457] = {.lex_state = 459, .external_lex_state = 57},
  [2458] = {.lex_state = 458, .external_lex_state = 29},
  [2459] = {.lex_state = 437, .external_lex_state = 44},
  [2460] = {.lex_state = 459, .external_lex_state = 57},
  [2461] = {.lex_state = 465, .external_lex_state = 56},
  [2462] = {.lex_state = 465, .external_lex_state = 56},
  [2463] = {.lex_state = 459, .external_lex_state = 57},
  [2464] = {.lex_state = 459, .external_lex_state = 57},
  [2465] = {.lex_state = 465, .external_lex_state = 59},
  [2466] = {.lex_state = 457, .external_lex_state = 56},
  [2467] = {.lex_state = 429, .external_lex_state = 58},
  [2468] = {.lex_state = 457, .external_lex_state = 56},
  [2469] = {.lex_state = 459, .external_lex_state = 57},
  [2470] = {.lex_state = 457, .external_lex_state = 56},
  [2471] = {.lex_state = 465, .external_lex_state = 56},
  [2472] = {.lex_state = 457, .external_lex_state = 56},
  [2473] = {.lex_state = 461, .external_lex_state = 57},
  [2474] = {.lex_state = 465, .external_lex_state = 59},
  [2475] = {.lex_state = 461, .external_lex_state = 57},
  [2476] = {.lex_state = 461, .external_lex_state = 57},
  [2477] = {.lex_state = 457, .external_lex_state = 56},
  [2478] = {.lex_state = 457, .external_lex_state = 56},
  [2479] = {.lex_state = 465, .external_lex_state = 59},
  [2480] = {.lex_state = 455, .external_lex_state = 25},
  [2481] = {.lex_state = 458, .external_lex_state = 29},
  [2482] = {.lex_state = 437, .external_lex_state = 44},
  [2483] = {.lex_state = 459, .external_lex_state = 57},
  [2484] = {.lex_state = 437, .external_lex_state = 44},
  [2485] = {.lex_state = 457, .external_lex_state = 56},
  [2486] = {.lex_state = 465, .external_lex_state = 56},
  [2487] = {.lex_state = 429, .external_lex_state = 60},
  [2488] = {.lex_state = 455, .external_lex_state = 25},
  [2489] = {.lex_state = 437, .external_lex_state = 44},
  [2490] = {.lex_state = 461, .external_lex_state = 57},
  [2491] = {.lex_state = 434, .external_lex_state = 61},
  [2492] = {.lex_state = 457, .external_lex_state = 56},
  [2493] = {.lex_state = 465, .external_lex_state = 56},
  [2494] = {.lex_state = 465, .external_lex_state = 56},
  [2495] = {.lex_state = 429, .external_lex_state = 60},
  [2496] = {.lex_state = 458, .external_lex_state = 29},
  [2497] = {.lex_state = 455, .external_lex_state = 25},
  [2498] = {.lex_state = 459, .external_lex_state = 57},
  [2499] = {.lex_state = 437, .external_lex_state = 44},
  [2500] = {.lex_state = 437, .external_lex_state = 44},
  [2501] = {.lex_state = 429, .external_lex_state = 58},
  [2502] = {.lex_state = 429, .external_lex_state = 44},
  [2503] = {.lex_state = 465, .external_lex_state = 59},
  [2504] = {.lex_state = 457, .external_lex_state = 59},
  [2505] = {.lex_state = 465, .external_lex_state = 56},
  [2506] = {.lex_state = 465, .external_lex_state = 56},
  [2507] = {.lex_state = 465, .external_lex_state = 56},
  [2508] = {.lex_state = 427, .external_lex_state = 39},
  [2509] = {.lex_state = 455, .external_lex_state = 25},
  [2510] = {.lex_state = 457, .external_lex_state = 56},
  [2511] = {.lex_state = 465, .external_lex_state = 56},
  [2512] = {.lex_state = 427, .external_lex_state = 39},
  [2513] = {.lex_state = 465, .external_lex_state = 59},
  [2514] = {.lex_state = 457, .external_lex_state = 59},
  [2515] = {.lex_state = 459, .external_lex_state = 57},
  [2516] = {.lex_state = 437, .external_lex_state = 44},
  [2517] = {.lex_state = 437, .external_lex_state = 44},
  [2518] = {.lex_state = 427, .external_lex_state = 39},
  [2519] = {.lex_state = 457, .external_lex_state = 59},
  [2520] = {.lex_state = 429, .external_lex_state = 60},
  [2521] = {.lex_state = 459, .external_lex_state = 57},
  [2522] = {.lex_state = 432, .external_lex_state = 39},
  [2523] = {.lex_state = 437, .external_lex_state = 44},
  [2524] = {.lex_state = 437, .external_lex_state = 44},
  [2525] = {.lex_state = 437, .external_lex_state = 44},
  [2526] = {.lex_state = 465, .external_lex_state = 59},
  [2527] = {.lex_state = 457, .external_lex_state = 59},
  [2528] = {.lex_state = 431, .external_lex_state = 52},
  [2529] = {.lex_state = 437, .external_lex_state = 44},
  [2530] = {.lex_state = 431, .external_lex_state = 52},
  [2531] = {.lex_state = 457, .external_lex_state = 59},
  [2532] = {.lex_state = 459, .external_lex_state = 57},
  [2533] = {.lex_state = 427, .external_lex_state = 39},
  [2534] = {.lex_state = 429, .external_lex_state = 58},
  [2535] = {.lex_state = 465, .external_lex_state = 56},
  [2536] = {.lex_state = 461, .external_lex_state = 57},
  [2537] = {.lex_state = 429, .external_lex_state = 58},
  [2538] = {.lex_state = 461, .external_lex_state = 57},
  [2539] = {.lex_state = 292, .external_lex_state = 45},
  [2540] = {.lex_state = 457, .external_lex_state = 59},
  [2541] = {.lex_state = 427, .external_lex_state = 39},
  [2542] = {.lex_state = 465, .external_lex_state = 56},
  [2543] = {.lex_state = 429, .external_lex_state = 58},
  [2544] = {.lex_state = 458, .external_lex_state = 29},
  [2545] = {.lex_state = 427, .external_lex_state = 39},
  [2546] = {.lex_state = 459, .external_lex_state = 57},
  [2547] = {.lex_state = 292, .external_lex_state = 45},
  [2548] = {.lex_state = 465, .external_lex_state = 56},
  [2549] = {.lex_state = 429, .external_lex_state = 46},
  [2550] = {.lex_state = 459, .external_lex_state = 57},
  [2551] = {.lex_state = 457, .external_lex_state = 56},
  [2552] = {.lex_state = 459, .external_lex_state = 57},
  [2553] = {.lex_state = 457, .external_lex_state = 56},
  [2554] = {.lex_state = 465, .external_lex_state = 56},
  [2555] = {.lex_state = 292, .external_lex_state = 45},
  [2556] = {.lex_state = 292, .external_lex_state = 45},
  [2557] = {.lex_state = 431, .external_lex_state = 52},
  [2558] = {.lex_state = 429, .external_lex_state = 58},
  [2559] = {.lex_state = 429, .external_lex_state = 58},
  [2560] = {.lex_state = 465, .external_lex_state = 56},
  [2561] = {.lex_state = 292, .external_lex_state = 45},
  [2562] = {.lex_state = 459, .external_lex_state = 57},
  [2563] = {.lex_state = 437, .external_lex_state = 44},
  [2564] = {.lex_state = 437, .external_lex_state = 44},
  [2565] = {.lex_state = 429, .external_lex_state = 60},
  [2566] = {.lex_state = 427, .external_lex_state = 39},
  [2567] = {.lex_state = 457, .external_lex_state = 56},
  [2568] = {.lex_state = 455, .external_lex_state = 25},
  [2569] = {.lex_state = 458, .external_lex_state = 29},
  [2570] = {.lex_state = 459, .external_lex_state = 57},
  [2571] = {.lex_state = 437, .external_lex_state = 44},
  [2572] = {.lex_state = 459, .external_lex_state = 57},
  [2573] = {.lex_state = 461, .external_lex_state = 57},
  [2574] = {.lex_state = 461, .external_lex_state = 57},
  [2575] = {.lex_state = 462, .external_lex_state = 59},
  [2576] = {.lex_state = 462, .external_lex_state = 59},
  [2577] = {.lex_state = 462, .external_lex_state = 59},
  [2578] = {.lex_state = 462, .external_lex_state = 59},
  [2579] = {.lex_state = 457, .external_lex_state = 59},
  [2580] = {.lex_state = 457, .external_lex_state = 59},
  [2581] = {.lex_state = 457, .external_lex_state = 59},
  [2582] = {.lex_state = 457, .external_lex_state = 59},
  [2583] = {.lex_state = 457, .external_lex_state = 59},
  [2584] = {.lex_state = 429, .external_lex_state = 61},
  [2585] = {.lex_state = 457, .external_lex_state = 59},
  [2586] = {.lex_state = 457, .external_lex_state = 59},
  [2587] = {.lex_state = 429, .external_lex_state = 61},
  [2588] = {.lex_state = 429, .external_lex_state = 61},
  [2589] = {.lex_state = 429, .external_lex_state = 62},
  [2590] = {.lex_state = 429, .external_lex_state = 62},
  [2591] = {.lex_state = 429, .external_lex_state = 62},
  [2592] = {.lex_state = 429, .external_lex_state = 62},
  [2593] = {.lex_state = 429, .external_lex_state = 62},
  [2594] = {.lex_state = 429, .external_lex_state = 62},
  [2595] = {.lex_state = 429, .external_lex_state = 61},
  [2596] = {.lex_state = 429, .external_lex_state = 61},
  [2597] = {.lex_state = 429, .external_lex_state = 62},
  [2598] = {.lex_state = 429, .external_lex_state = 62},
  [2599] = {.lex_state = 429, .external_lex_state = 62},
  [2600] = {.lex_state = 457, .external_lex_state = 59},
  [2601] = {.lex_state = 457, .external_lex_state = 59},
  [2602] = {.lex_state = 92, .external_lex_state = 63},
  [2603] = {.lex_state = 458, .external_lex_state = 29},
  [2604] = {.lex_state = 458, .external_lex_state = 29},
  [2605] = {.lex_state = 464, .external_lex_state = 26},
  [2606] = {.lex_state = 457, .external_lex_state = 59},
  [2607] = {.lex_state = 457, .external_lex_state = 59},
  [2608] = {.lex_state = 429, .external_lex_state = 44},
  [2609] = {.lex_state = 454, .external_lex_state = 26},
  [2610] = {.lex_state = 464, .external_lex_state = 26},
  [2611] = {.lex_state = 454, .external_lex_state = 26},
  [2612] = {.lex_state = 457, .external_lex_state = 59},
  [2613] = {.lex_state = 457, .external_lex_state = 59},
  [2614] = {.lex_state = 457, .external_lex_state = 59},
  [2615] = {.lex_state = 457, .external_lex_state = 59},
  [2616] = {.lex_state = 457, .external_lex_state = 59},
  [2617] = {.lex_state = 429, .external_lex_state = 61},
  [2618] = {.lex_state = 454, .external_lex_state = 26},
  [2619] = {.lex_state = 429, .external_lex_state = 61},
  [2620] = {.lex_state = 457, .external_lex_state = 59},
  [2621] = {.lex_state = 457, .external_lex_state = 59},
  [2622] = {.lex_state = 457, .external_lex_state = 59},
  [2623] = {.lex_state = 429, .external_lex_state = 61},
  [2624] = {.lex_state = 429, .external_lex_state = 44},
  [2625] = {.lex_state = 429, .external_lex_state = 44},
  [2626] = {.lex_state = 429, .external_lex_state = 44},
  [2627] = {.lex_state = 429, .external_lex_state = 44},
  [2628] = {.lex_state = 429, .external_lex_state = 44},
  [2629] = {.lex_state = 429, .external_lex_state = 61},
  [2630] = {.lex_state = 458, .external_lex_state = 32},
  [2631] = {.lex_state = 429, .external_lex_state = 61},
  [2632] = {.lex_state = 454, .external_lex_state = 26},
  [2633] = {.lex_state = 454, .external_lex_state = 26},
  [2634] = {.lex_state = 454, .external_lex_state = 26},
  [2635] = {.lex_state = 429, .external_lex_state = 44},
  [2636] = {.lex_state = 429, .external_lex_state = 44},
  [2637] = {.lex_state = 429, .external_lex_state = 44},
  [2638] = {.lex_state = 429, .external_lex_state = 44},
  [2639] = {.lex_state = 429, .external_lex_state = 44},
  [2640] = {.lex_state = 429, .external_lex_state = 44},
  [2641] = {.lex_state = 429, .external_lex_state = 44},
  [2642] = {.lex_state = 429, .external_lex_state = 44},
  [2643] = {.lex_state = 429, .external_lex_state = 44},
  [2644] = {.lex_state = 429, .external_lex_state = 44},
  [2645] = {.lex_state = 429, .external_lex_state = 44},
  [2646] = {.lex_state = 429, .external_lex_state = 44},
  [2647] = {.lex_state = 429, .external_lex_state = 44},
  [2648] = {.lex_state = 429, .external_lex_state = 44},
  [2649] = {.lex_state = 429, .external_lex_state = 44},
  [2650] = {.lex_state = 429, .external_lex_state = 44},
  [2651] = {.lex_state = 429, .external_lex_state = 44},
  [2652] = {.lex_state = 202, .external_lex_state = 64},
  [2653] = {.lex_state = 202, .external_lex_state = 64},
  [2654] = {.lex_state = 462, .external_lex_state = 59},
  [2655] = {.lex_state = 462, .external_lex_state = 59},
  [2656] = {.lex_state = 429, .external_lex_state = 61},
  [2657] = {.lex_state = 429, .external_lex_state = 44},
  [2658] = {.lex_state = 429, .external_lex_state = 46},
  [2659] = {.lex_state = 429, .external_lex_state = 61},
  [2660] = {.lex_state = 429, .external_lex_state = 44},
  [2661] = {.lex_state = 458, .external_lex_state = 29},
  [2662] = {.lex_state = 461, .external_lex_state = 57},
  [2663] = {.lex_state = 429, .external_lex_state = 44},
  [2664] = {.lex_state = 429, .external_lex_state = 61},
  [2665] = {.lex_state = 458, .external_lex_state = 29},
  [2666] = {.lex_state = 458, .external_lex_state = 29},
  [2667] = {.lex_state = 429, .external_lex_state = 61},
  [2668] = {.lex_state = 429, .external_lex_state = 44},
  [2669] = {.lex_state = 429, .external_lex_state = 61},
  [2670] = {.lex_state = 429, .external_lex_state = 44},
  [2671] = {.lex_state = 429, .external_lex_state = 61},
  [2672] = {.lex_state = 429, .external_lex_state = 61},
  [2673] = {.lex_state = 429, .external_lex_state = 61},
  [2674] = {.lex_state = 429, .external_lex_state = 61},
  [2675] = {.lex_state = 429, .external_lex_state = 61},
  [2676] = {.lex_state = 429, .external_lex_state = 61},
  [2677] = {.lex_state = 458, .external_lex_state = 29},
  [2678] = {.lex_state = 429, .external_lex_state = 61},
  [2679] = {.lex_state = 429, .external_lex_state = 61},
  [2680] = {.lex_state = 429, .external_lex_state = 61},
  [2681] = {.lex_state = 429, .external_lex_state = 61},
  [2682] = {.lex_state = 429, .external_lex_state = 61},
  [2683] = {.lex_state = 429, .external_lex_state = 61},
  [2684] = {.lex_state = 429, .external_lex_state = 61},
  [2685] = {.lex_state = 429, .external_lex_state = 61},
  [2686] = {.lex_state = 458, .external_lex_state = 29},
  [2687] = {.lex_state = 429, .external_lex_state = 61},
  [2688] = {.lex_state = 429, .external_lex_state = 61},
  [2689] = {.lex_state = 429, .external_lex_state = 61},
  [2690] = {.lex_state = 429, .external_lex_state = 61},
  [2691] = {.lex_state = 429, .external_lex_state = 61},
  [2692] = {.lex_state = 429, .external_lex_state = 61},
  [2693] = {.lex_state = 429, .external_lex_state = 61},
  [2694] = {.lex_state = 429, .external_lex_state = 61},
  [2695] = {.lex_state = 429, .external_lex_state = 61},
  [2696] = {.lex_state = 429, .external_lex_state = 61},
  [2697] = {.lex_state = 429, .external_lex_state = 61},
  [2698] = {.lex_state = 429, .external_lex_state = 61},
  [2699] = {.lex_state = 429, .external_lex_state = 61},
  [2700] = {.lex_state = 429, .external_lex_state = 61},
  [2701] = {.lex_state = 429, .external_lex_state = 61},
  [2702] = {.lex_state = 429, .external_lex_state = 61},
  [2703] = {.lex_state = 429, .external_lex_state = 61},
  [2704] = {.lex_state = 429, .external_lex_state = 61},
  [2705] = {.lex_state = 429, .external_lex_state = 61},
  [2706] = {.lex_state = 429, .external_lex_state = 61},
  [2707] = {.lex_state = 429, .external_lex_state = 61},
  [2708] = {.lex_state = 429, .external_lex_state = 61},
  [2709] = {.lex_state = 429, .external_lex_state = 61},
  [2710] = {.lex_state = 429, .external_lex_state = 61},
  [2711] = {.lex_state = 429, .external_lex_state = 61},
  [2712] = {.lex_state = 429, .external_lex_state = 61},
  [2713] = {.lex_state = 429, .external_lex_state = 61},
  [2714] = {.lex_state = 429, .external_lex_state = 61},
  [2715] = {.lex_state = 429, .external_lex_state = 61},
  [2716] = {.lex_state = 429, .external_lex_state = 61},
  [2717] = {.lex_state = 429, .external_lex_state = 61},
  [2718] = {.lex_state = 429, .external_lex_state = 61},
  [2719] = {.lex_state = 429, .external_lex_state = 61},
  [2720] = {.lex_state = 429, .external_lex_state = 61},
  [2721] = {.lex_state = 429, .external_lex_state = 61},
  [2722] = {.lex_state = 429, .external_lex_state = 61},
  [2723] = {.lex_state = 429, .external_lex_state = 61},
  [2724] = {.lex_state = 429, .external_lex_state = 61},
  [2725] = {.lex_state = 429, .external_lex_state = 61},
  [2726] = {.lex_state = 429, .external_lex_state = 61},
  [2727] = {.lex_state = 429, .external_lex_state = 61},
  [2728] = {.lex_state = 429, .external_lex_state = 61},
  [2729] = {.lex_state = 429, .external_lex_state = 61},
  [2730] = {.lex_state = 429, .external_lex_state = 61},
  [2731] = {.lex_state = 429, .external_lex_state = 61},
  [2732] = {.lex_state = 429, .external_lex_state = 61},
  [2733] = {.lex_state = 429, .external_lex_state = 61},
  [2734] = {.lex_state = 429, .external_lex_state = 61},
  [2735] = {.lex_state = 429, .external_lex_state = 61},
  [2736] = {.lex_state = 465, .external_lex_state = 59},
  [2737] = {.lex_state = 464, .external_lex_state = 26},
  [2738] = {.lex_state = 429, .external_lex_state = 61},
  [2739] = {.lex_state = 465, .external_lex_state = 59},
  [2740] = {.lex_state = 465, .external_lex_state = 59},
  [2741] = {.lex_state = 429, .external_lex_state = 61},
  [2742] = {.lex_state = 429, .external_lex_state = 61},
  [2743] = {.lex_state = 465, .external_lex_state = 59},
  [2744] = {.lex_state = 465, .external_lex_state = 59},
  [2745] = {.lex_state = 429, .external_lex_state = 61},
  [2746] = {.lex_state = 429, .external_lex_state = 61},
  [2747] = {.lex_state = 465, .external_lex_state = 59},
  [2748] = {.lex_state = 465, .external_lex_state = 59},
  [2749] = {.lex_state = 429, .external_lex_state = 44},
  [2750] = {.lex_state = 429, .external_lex_state = 44},
  [2751] = {.lex_state = 429, .external_lex_state = 61},
  [2752] = {.lex_state = 429, .external_lex_state = 61},
  [2753] = {.lex_state = 465, .external_lex_state = 59},
  [2754] = {.lex_state = 465, .external_lex_state = 59},
  [2755] = {.lex_state = 465, .external_lex_state = 59},
  [2756] = {.lex_state = 465, .external_lex_state = 59},
  [2757] = {.lex_state = 465, .external_lex_state = 59},
  [2758] = {.lex_state = 465, .external_lex_state = 59},
  [2759] = {.lex_state = 465, .external_lex_state = 59},
  [2760] = {.lex_state = 465, .external_lex_state = 59},
  [2761] = {.lex_state = 465, .external_lex_state = 59},
  [2762] = {.lex_state = 465, .external_lex_state = 59},
  [2763] = {.lex_state = 465, .external_lex_state = 59},
  [2764] = {.lex_state = 465, .external_lex_state = 59},
  [2765] = {.lex_state = 429, .external_lex_state = 61},
  [2766] = {.lex_state = 429, .external_lex_state = 61},
  [2767] = {.lex_state = 429, .external_lex_state = 61},
  [2768] = {.lex_state = 429, .external_lex_state = 61},
  [2769] = {.lex_state = 429, .external_lex_state = 61},
  [2770] = {.lex_state = 429, .external_lex_state = 61},
  [2771] = {.lex_state = 429, .external_lex_state = 61},
  [2772] = {.lex_state = 429, .external_lex_state = 61},
  [2773] = {.lex_state = 429, .external_lex_state = 61},
  [2774] = {.lex_state = 429, .external_lex_state = 61},
  [2775] = {.lex_state = 429, .external_lex_state = 61},
  [2776] = {.lex_state = 429, .external_lex_state = 61},
  [2777] = {.lex_state = 461, .external_lex_state = 57},
  [2778] = {.lex_state = 429, .external_lex_state = 61},
  [2779] = {.lex_state = 461, .external_lex_state = 57},
  [2780] = {.lex_state = 461, .external_lex_state = 57},
  [2781] = {.lex_state = 461, .external_lex_state = 57},
  [2782] = {.lex_state = 461, .external_lex_state = 57},
  [2783] = {.lex_state = 429, .external_lex_state = 61},
  [2784] = {.lex_state = 429, .external_lex_state = 61},
  [2785] = {.lex_state = 429, .external_lex_state = 61},
  [2786] = {.lex_state = 454, .external_lex_state = 26},
  [2787] = {.lex_state = 461, .external_lex_state = 57},
  [2788] = {.lex_state = 461, .external_lex_state = 57},
  [2789] = {.lex_state = 429, .external_lex_state = 61},
  [2790] = {.lex_state = 429, .external_lex_state = 44},
  [2791] = {.lex_state = 429, .external_lex_state = 61},
  [2792] = {.lex_state = 427, .external_lex_state = 39},
  [2793] = {.lex_state = 458, .external_lex_state = 32},
  [2794] = {.lex_state = 461, .external_lex_state = 57},
  [2795] = {.lex_state = 461, .external_lex_state = 57},
  [2796] = {.lex_state = 461, .external_lex_state = 57},
  [2797] = {.lex_state = 461, .external_lex_state = 57},
  [2798] = {.lex_state = 461, .external_lex_state = 57},
  [2799] = {.lex_state = 461, .external_lex_state = 57},
  [2800] = {.lex_state = 461, .external_lex_state = 57},
  [2801] = {.lex_state = 461, .external_lex_state = 57},
  [2802] = {.lex_state = 461, .external_lex_state = 57},
  [2803] = {.lex_state = 429, .external_lex_state = 61},
  [2804] = {.lex_state = 427, .external_lex_state = 39},
  [2805] = {.lex_state = 429, .external_lex_state = 46},
  [2806] = {.lex_state = 427, .external_lex_state = 39},
  [2807] = {.lex_state = 92, .external_lex_state = 63},
  [2808] = {.lex_state = 462, .external_lex_state = 59},
  [2809] = {.lex_state = 429, .external_lex_state = 61},
  [2810] = {.lex_state = 429, .external_lex_state = 61},
  [2811] = {.lex_state = 429, .external_lex_state = 46},
  [2812] = {.lex_state = 427, .external_lex_state = 39},
  [2813] = {.lex_state = 462, .external_lex_state = 59},
  [2814] = {.lex_state = 462, .external_lex_state = 59},
  [2815] = {.lex_state = 429, .external_lex_state = 46},
  [2816] = {.lex_state = 429, .external_lex_state = 61},
  [2817] = {.lex_state = 429, .external_lex_state = 61},
  [2818] = {.lex_state = 429, .external_lex_state = 46},
  [2819] = {.lex_state = 427, .external_lex_state = 39},
  [2820] = {.lex_state = 92, .external_lex_state = 63},
  [2821] = {.lex_state = 429, .external_lex_state = 61},
  [2822] = {.lex_state = 434, .external_lex_state = 65},
  [2823] = {.lex_state = 429, .external_lex_state = 61},
  [2824] = {.lex_state = 429, .external_lex_state = 46},
  [2825] = {.lex_state = 427, .external_lex_state = 39},
  [2826] = {.lex_state = 92, .external_lex_state = 63},
  [2827] = {.lex_state = 429, .external_lex_state = 61},
  [2828] = {.lex_state = 429, .external_lex_state = 61},
  [2829] = {.lex_state = 92, .external_lex_state = 63},
  [2830] = {.lex_state = 429, .external_lex_state = 61},
  [2831] = {.lex_state = 464, .external_lex_state = 33},
  [2832] = {.lex_state = 462, .external_lex_state = 59},
  [2833] = {.lex_state = 454, .external_lex_state = 26},
  [2834] = {.lex_state = 462, .external_lex_state = 59},
  [2835] = {.lex_state = 92, .external_lex_state = 63},
  [2836] = {.lex_state = 92, .external_lex_state = 63},
  [2837] = {.lex_state = 92, .external_lex_state = 63},
  [2838] = {.lex_state = 92, .external_lex_state = 63},
  [2839] = {.lex_state = 464, .external_lex_state = 26},
  [2840] = {.lex_state = 427, .external_lex_state = 39},
  [2841] = {.lex_state = 464, .external_lex_state = 26},
  [2842] = {.lex_state = 429, .external_lex_state = 46},
  [2843] = {.lex_state = 429, .external_lex_state = 46},
  [2844] = {.lex_state = 429, .external_lex_state = 46},
  [2845] = {.lex_state = 429, .external_lex_state = 46},
  [2846] = {.lex_state = 462, .external_lex_state = 59},
  [2847] = {.lex_state = 429, .external_lex_state = 46},
  [2848] = {.lex_state = 462, .external_lex_state = 59},
  [2849] = {.lex_state = 462, .external_lex_state = 59},
  [2850] = {.lex_state = 454, .external_lex_state = 33},
  [2851] = {.lex_state = 427, .external_lex_state = 39},
  [2852] = {.lex_state = 454, .external_lex_state = 26},
  [2853] = {.lex_state = 429, .external_lex_state = 46},
  [2854] = {.lex_state = 427, .external_lex_state = 39},
  [2855] = {.lex_state = 429, .external_lex_state = 46},
  [2856] = {.lex_state = 462, .external_lex_state = 59},
  [2857] = {.lex_state = 427, .external_lex_state = 39},
  [2858] = {.lex_state = 435, .external_lex_state = 61},
  [2859] = {.lex_state = 463, .external_lex_state = 32},
  [2860] = {.lex_state = 462, .external_lex_state = 59},
  [2861] = {.lex_state = 427, .external_lex_state = 39},
  [2862] = {.lex_state = 429, .external_lex_state = 46},
  [2863] = {.lex_state = 429, .external_lex_state = 61},
  [2864] = {.lex_state = 462, .external_lex_state = 59},
  [2865] = {.lex_state = 462, .external_lex_state = 59},
  [2866] = {.lex_state = 92, .external_lex_state = 63},
  [2867] = {.lex_state = 427, .external_lex_state = 39},
  [2868] = {.lex_state = 429, .external_lex_state = 46},
  [2869] = {.lex_state = 462, .external_lex_state = 59},
  [2870] = {.lex_state = 427, .external_lex_state = 39},
  [2871] = {.lex_state = 454, .external_lex_state = 26},
  [2872] = {.lex_state = 429, .external_lex_state = 46},
  [2873] = {.lex_state = 429, .external_lex_state = 46},
  [2874] = {.lex_state = 454, .external_lex_state = 26},
  [2875] = {.lex_state = 427, .external_lex_state = 39},
  [2876] = {.lex_state = 454, .external_lex_state = 26},
  [2877] = {.lex_state = 429, .external_lex_state = 66},
  [2878] = {.lex_state = 429, .external_lex_state = 66},
  [2879] = {.lex_state = 92, .external_lex_state = 63},
  [2880] = {.lex_state = 429, .external_lex_state = 46},
  [2881] = {.lex_state = 92, .external_lex_state = 63},
  [2882] = {.lex_state = 92, .external_lex_state = 63},
  [2883] = {.lex_state = 427, .external_lex_state = 39},
  [2884] = {.lex_state = 427, .external_lex_state = 39},
  [2885] = {.lex_state = 427, .external_lex_state = 39},
  [2886] = {.lex_state = 427, .external_lex_state = 39},
  [2887] = {.lex_state = 427, .external_lex_state = 39},
  [2888] = {.lex_state = 92, .external_lex_state = 63},
  [2889] = {.lex_state = 429, .external_lex_state = 61},
  [2890] = {.lex_state = 462, .external_lex_state = 59},
  [2891] = {.lex_state = 462, .external_lex_state = 59},
  [2892] = {.lex_state = 462, .external_lex_state = 59},
  [2893] = {.lex_state = 462, .external_lex_state = 59},
  [2894] = {.lex_state = 429, .external_lex_state = 46},
  [2895] = {.lex_state = 427, .external_lex_state = 39},
  [2896] = {.lex_state = 234, .external_lex_state = 64},
  [2897] = {.lex_state = 234, .external_lex_state = 64},
  [2898] = {.lex_state = 464, .external_lex_state = 26},
  [2899] = {.lex_state = 92, .external_lex_state = 63},
  [2900] = {.lex_state = 429, .external_lex_state = 46},
  [2901] = {.lex_state = 464, .external_lex_state = 26},
  [2902] = {.lex_state = 92, .external_lex_state = 63},
  [2903] = {.lex_state = 427, .external_lex_state = 39},
  [2904] = {.lex_state = 427, .external_lex_state = 39},
  [2905] = {.lex_state = 92, .external_lex_state = 63},
  [2906] = {.lex_state = 92, .external_lex_state = 63},
  [2907] = {.lex_state = 92, .external_lex_state = 63},
  [2908] = {.lex_state = 433, .external_lex_state = 61},
  [2909] = {.lex_state = 427, .external_lex_state = 39},
  [2910] = {.lex_state = 427, .external_lex_state = 39},
  [2911] = {.lex_state = 427, .external_lex_state = 39},
  [2912] = {.lex_state = 427, .external_lex_state = 39},
  [2913] = {.lex_state = 427, .external_lex_state = 39},
  [2914] = {.lex_state = 427, .external_lex_state = 39},
  [2915] = {.lex_state = 427, .external_lex_state = 39},
  [2916] = {.lex_state = 427, .external_lex_state = 39},
  [2917] = {.lex_state = 427, .external_lex_state = 39},
  [2918] = {.lex_state = 427, .external_lex_state = 39},
  [2919] = {.lex_state = 92, .external_lex_state = 63},
  [2920] = {.lex_state = 429, .external_lex_state = 46},
  [2921] = {.lex_state = 464, .external_lex_state = 33},
  [2922] = {.lex_state = 427, .external_lex_state = 39},
  [2923] = {.lex_state = 427, .external_lex_state = 39},
  [2924] = {.lex_state = 92, .external_lex_state = 63},
  [2925] = {.lex_state = 92, .external_lex_state = 63},
  [2926] = {.lex_state = 92, .external_lex_state = 63},
  [2927] = {.lex_state = 454, .external_lex_state = 26},
  [2928] = {.lex_state = 429, .external_lex_state = 66},
  [2929] = {.lex_state = 454, .external_lex_state = 26},
  [2930] = {.lex_state = 454, .external_lex_state = 26},
  [2931] = {.lex_state = 92, .external_lex_state = 63},
  [2932] = {.lex_state = 92, .external_lex_state = 63},
  [2933] = {.lex_state = 429, .external_lex_state = 66},
  [2934] = {.lex_state = 92, .external_lex_state = 63},
  [2935] = {.lex_state = 430, .external_lex_state = 61},
  [2936] = {.lex_state = 234, .external_lex_state = 64},
  [2937] = {.lex_state = 234, .external_lex_state = 64},
  [2938] = {.lex_state = 427, .external_lex_state = 39},
  [2939] = {.lex_state = 427, .external_lex_state = 39},
  [2940] = {.lex_state = 237, .external_lex_state = 67},
  [2941] = {.lex_state = 237, .external_lex_state = 67},
  [2942] = {.lex_state = 429, .external_lex_state = 61},
  [2943] = {.lex_state = 429, .external_lex_state = 46},
  [2944] = {.lex_state = 427, .external_lex_state = 39},
  [2945] = {.lex_state = 454, .external_lex_state = 26},
  [2946] = {.lex_state = 429, .external_lex_state = 46},
  [2947] = {.lex_state = 429, .external_lex_state = 61},
  [2948] = {.lex_state = 427, .external_lex_state = 39},
  [2949] = {.lex_state = 92, .external_lex_state = 63},
  [2950] = {.lex_state = 92, .external_lex_state = 63},
  [2951] = {.lex_state = 427, .external_lex_state = 39},
  [2952] = {.lex_state = 427, .external_lex_state = 39},
  [2953] = {.lex_state = 92, .external_lex_state = 63},
  [2954] = {.lex_state = 427, .external_lex_state = 39},
  [2955] = {.lex_state = 427, .external_lex_state = 39},
  [2956] = {.lex_state = 427, .external_lex_state = 39},
  [2957] = {.lex_state = 427, .external_lex_state = 39},
  [2958] = {.lex_state = 427, .external_lex_state = 39},
  [2959] = {.lex_state = 427, .external_lex_state = 60},
  [2960] = {.lex_state = 427, .external_lex_state = 60},
  [2961] = {.lex_state = 427, .external_lex_state = 39},
  [2962] = {.lex_state = 427, .external_lex_state = 39},
  [2963] = {.lex_state = 427, .external_lex_state = 39},
  [2964] = {.lex_state = 427, .external_lex_state = 39},
  [2965] = {.lex_state = 427, .external_lex_state = 39},
  [2966] = {.lex_state = 427, .external_lex_state = 39},
  [2967] = {.lex_state = 427, .external_lex_state = 39},
  [2968] = {.lex_state = 427, .external_lex_state = 39},
  [2969] = {.lex_state = 427, .external_lex_state = 39},
  [2970] = {.lex_state = 427, .external_lex_state = 39},
  [2971] = {.lex_state = 427, .external_lex_state = 39},
  [2972] = {.lex_state = 427, .external_lex_state = 39},
  [2973] = {.lex_state = 427, .external_lex_state = 39},
  [2974] = {.lex_state = 427, .external_lex_state = 39},
  [2975] = {.lex_state = 454, .external_lex_state = 33},
  [2976] = {.lex_state = 427, .external_lex_state = 60},
  [2977] = {.lex_state = 427, .external_lex_state = 60},
  [2978] = {.lex_state = 92, .external_lex_state = 63},
  [2979] = {.lex_state = 427, .external_lex_state = 39},
  [2980] = {.lex_state = 429, .external_lex_state = 61},
  [2981] = {.lex_state = 429, .external_lex_state = 61},
  [2982] = {.lex_state = 429, .external_lex_state = 46},
  [2983] = {.lex_state = 427, .external_lex_state = 39},
  [2984] = {.lex_state = 92, .external_lex_state = 63},
  [2985] = {.lex_state = 92, .external_lex_state = 63},
  [2986] = {.lex_state = 429, .external_lex_state = 61},
  [2987] = {.lex_state = 427, .external_lex_state = 39},
  [2988] = {.lex_state = 427, .external_lex_state = 39},
  [2989] = {.lex_state = 427, .external_lex_state = 39},
  [2990] = {.lex_state = 427, .external_lex_state = 39},
  [2991] = {.lex_state = 454, .external_lex_state = 26},
  [2992] = {.lex_state = 427, .external_lex_state = 39},
  [2993] = {.lex_state = 429, .external_lex_state = 61},
  [2994] = {.lex_state = 429, .external_lex_state = 46},
  [2995] = {.lex_state = 427, .external_lex_state = 39},
  [2996] = {.lex_state = 92, .external_lex_state = 63},
  [2997] = {.lex_state = 427, .external_lex_state = 39},
  [2998] = {.lex_state = 429, .external_lex_state = 46},
  [2999] = {.lex_state = 463, .external_lex_state = 32},
  [3000] = {.lex_state = 429, .external_lex_state = 46},
  [3001] = {.lex_state = 429, .external_lex_state = 46},
  [3002] = {.lex_state = 429, .external_lex_state = 46},
  [3003] = {.lex_state = 429, .external_lex_state = 46},
  [3004] = {.lex_state = 427, .external_lex_state = 39},
  [3005] = {.lex_state = 429, .external_lex_state = 46},
  [3006] = {.lex_state = 427, .external_lex_state = 39},
  [3007] = {.lex_state = 458, .external_lex_state = 32},
  [3008] = {.lex_state = 454, .external_lex_state = 26},
  [3009] = {.lex_state = 462, .external_lex_state = 59},
  [3010] = {.lex_state = 429, .external_lex_state = 61},
  [3011] = {.lex_state = 429, .external_lex_state = 46},
  [3012] = {.lex_state = 427, .external_lex_state = 39},
  [3013] = {.lex_state = 429, .external_lex_state = 46},
  [3014] = {.lex_state = 462, .external_lex_state = 59},
  [3015] = {.lex_state = 427, .external_lex_state = 39},
  [3016] = {.lex_state = 429, .external_lex_state = 46},
  [3017] = {.lex_state = 429, .external_lex_state = 61},
  [3018] = {.lex_state = 427, .external_lex_state = 39},
  [3019] = {.lex_state = 427, .external_lex_state = 39},
  [3020] = {.lex_state = 429, .external_lex_state = 65},
  [3021] = {.lex_state = 427, .external_lex_state = 61},
  [3022] = {.lex_state = 427, .external_lex_state = 61},
  [3023] = {.lex_state = 429, .external_lex_state = 65},
  [3024] = {.lex_state = 429, .external_lex_state = 65},
  [3025] = {.lex_state = 427, .external_lex_state = 61},
  [3026] = {.lex_state = 429, .external_lex_state = 65},
  [3027] = {.lex_state = 429, .external_lex_state = 65},
  [3028] = {.lex_state = 429, .external_lex_state = 65},
  [3029] = {.lex_state = 427, .external_lex_state = 61},
  [3030] = {.lex_state = 429, .external_lex_state = 65},
  [3031] = {.lex_state = 429, .external_lex_state = 65},
  [3032] = {.lex_state = 427, .external_lex_state = 61},
  [3033] = {.lex_state = 429, .external_lex_state = 65},
  [3034] = {.lex_state = 429, .external_lex_state = 65},
  [3035] = {.lex_state = 427, .external_lex_state = 61},
  [3036] = {.lex_state = 429, .external_lex_state = 65},
  [3037] = {.lex_state = 427, .external_lex_state = 61},
  [3038] = {.lex_state = 429, .external_lex_state = 65},
  [3039] = {.lex_state = 427, .external_lex_state = 61},
  [3040] = {.lex_state = 429, .external_lex_state = 65},
  [3041] = {.lex_state = 427, .external_lex_state = 61},
  [3042] = {.lex_state = 429, .external_lex_state = 65},
  [3043] = {.lex_state = 427, .external_lex_state = 61},
  [3044] = {.lex_state = 429, .external_lex_state = 65},
  [3045] = {.lex_state = 427, .external_lex_state = 61},
  [3046] = {.lex_state = 429, .external_lex_state = 65},
  [3047] = {.lex_state = 430, .external_lex_state = 61},
  [3048] = {.lex_state = 429, .external_lex_state = 65},
  [3049] = {.lex_state = 430, .external_lex_state = 61},
  [3050] = {.lex_state = 429, .external_lex_state = 65},
  [3051] = {.lex_state = 430, .external_lex_state = 61},
  [3052] = {.lex_state = 429, .external_lex_state = 65},
  [3053] = {.lex_state = 430, .external_lex_state = 61},
  [3054] = {.lex_state = 429, .external_lex_state = 65},
  [3055] = {.lex_state = 429, .external_lex_state = 65},
  [3056] = {.lex_state = 430, .external_lex_state = 61},
  [3057] = {.lex_state = 429, .external_lex_state = 65},
  [3058] = {.lex_state = 429, .external_lex_state = 65},
  [3059] = {.lex_state = 430, .external_lex_state = 61},
  [3060] = {.lex_state = 429, .external_lex_state = 65},
  [3061] = {.lex_state = 429, .external_lex_state = 65},
  [3062] = {.lex_state = 240, .external_lex_state = 67},
  [3063] = {.lex_state = 429, .external_lex_state = 65},
  [3064] = {.lex_state = 430, .external_lex_state = 61},
  [3065] = {.lex_state = 429, .external_lex_state = 65},
  [3066] = {.lex_state = 430, .external_lex_state = 61},
  [3067] = {.lex_state = 429, .external_lex_state = 65},
  [3068] = {.lex_state = 430, .external_lex_state = 61},
  [3069] = {.lex_state = 429, .external_lex_state = 65},
  [3070] = {.lex_state = 430, .external_lex_state = 61},
  [3071] = {.lex_state = 429, .external_lex_state = 65},
  [3072] = {.lex_state = 429, .external_lex_state = 65},
  [3073] = {.lex_state = 295, .external_lex_state = 68},
  [3074] = {.lex_state = 429, .external_lex_state = 65},
  [3075] = {.lex_state = 427, .external_lex_state = 61},
  [3076] = {.lex_state = 429, .external_lex_state = 65},
  [3077] = {.lex_state = 430, .external_lex_state = 61},
  [3078] = {.lex_state = 430, .external_lex_state = 61},
  [3079] = {.lex_state = 429, .external_lex_state = 65},
  [3080] = {.lex_state = 295, .external_lex_state = 68},
  [3081] = {.lex_state = 429, .external_lex_state = 65},
  [3082] = {.lex_state = 295, .external_lex_state = 68},
  [3083] = {.lex_state = 429, .external_lex_state = 65},
  [3084] = {.lex_state = 429, .external_lex_state = 65},
  [3085] = {.lex_state = 429, .external_lex_state = 65},
  [3086] = {.lex_state = 429, .external_lex_state = 65},
  [3087] = {.lex_state = 435, .external_lex_state = 61},
  [3088] = {.lex_state = 429, .external_lex_state = 65},
  [3089] = {.lex_state = 429, .external_lex_state = 65},
  [3090] = {.lex_state = 429, .external_lex_state = 65},
  [3091] = {.lex_state = 427, .external_lex_state = 61},
  [3092] = {.lex_state = 427, .external_lex_state = 61},
  [3093] = {.lex_state = 429, .external_lex_state = 65},
  [3094] = {.lex_state = 429, .external_lex_state = 65},
  [3095] = {.lex_state = 435, .external_lex_state = 61},
  [3096] = {.lex_state = 429, .external_lex_state = 65},
  [3097] = {.lex_state = 429, .external_lex_state = 65},
  [3098] = {.lex_state = 429, .external_lex_state = 65},
  [3099] = {.lex_state = 435, .external_lex_state = 61},
  [3100] = {.lex_state = 429, .external_lex_state = 65},
  [3101] = {.lex_state = 429, .external_lex_state = 65},
  [3102] = {.lex_state = 429, .external_lex_state = 65},
  [3103] = {.lex_state = 435, .external_lex_state = 61},
  [3104] = {.lex_state = 429, .external_lex_state = 65},
  [3105] = {.lex_state = 435, .external_lex_state = 61},
  [3106] = {.lex_state = 429, .external_lex_state = 65},
  [3107] = {.lex_state = 435, .external_lex_state = 61},
  [3108] = {.lex_state = 429, .external_lex_state = 65},
  [3109] = {.lex_state = 427, .external_lex_state = 61},
  [3110] = {.lex_state = 429, .external_lex_state = 65},
  [3111] = {.lex_state = 430, .external_lex_state = 61},
  [3112] = {.lex_state = 429, .external_lex_state = 65},
  [3113] = {.lex_state = 429, .external_lex_state = 65},
  [3114] = {.lex_state = 435, .external_lex_state = 61},
  [3115] = {.lex_state = 429, .external_lex_state = 65},
  [3116] = {.lex_state = 452, .external_lex_state = 35},
  [3117] = {.lex_state = 435, .external_lex_state = 61},
  [3118] = {.lex_state = 429, .external_lex_state = 65},
  [3119] = {.lex_state = 435, .external_lex_state = 61},
  [3120] = {.lex_state = 435, .external_lex_state = 61},
  [3121] = {.lex_state = 429, .external_lex_state = 65},
  [3122] = {.lex_state = 435, .external_lex_state = 61},
  [3123] = {.lex_state = 435, .external_lex_state = 61},
  [3124] = {.lex_state = 429, .external_lex_state = 65},
  [3125] = {.lex_state = 435, .external_lex_state = 61},
  [3126] = {.lex_state = 429, .external_lex_state = 65},
  [3127] = {.lex_state = 435, .external_lex_state = 61},
  [3128] = {.lex_state = 429, .external_lex_state = 65},
  [3129] = {.lex_state = 427, .external_lex_state = 61},
  [3130] = {.lex_state = 429, .external_lex_state = 65},
  [3131] = {.lex_state = 435, .external_lex_state = 61},
  [3132] = {.lex_state = 429, .external_lex_state = 65},
  [3133] = {.lex_state = 435, .external_lex_state = 61},
  [3134] = {.lex_state = 429, .external_lex_state = 65},
  [3135] = {.lex_state = 435, .external_lex_state = 61},
  [3136] = {.lex_state = 460, .external_lex_state = 33},
  [3137] = {.lex_state = 427, .external_lex_state = 61},
  [3138] = {.lex_state = 243, .external_lex_state = 67},
  [3139] = {.lex_state = 243, .external_lex_state = 67},
  [3140] = {.lex_state = 427, .external_lex_state = 61},
  [3141] = {.lex_state = 429, .external_lex_state = 65},
  [3142] = {.lex_state = 243, .external_lex_state = 67},
  [3143] = {.lex_state = 243, .external_lex_state = 67},
  [3144] = {.lex_state = 435, .external_lex_state = 61},
  [3145] = {.lex_state = 427, .external_lex_state = 61},
  [3146] = {.lex_state = 435, .external_lex_state = 61},
  [3147] = {.lex_state = 429, .external_lex_state = 65},
  [3148] = {.lex_state = 435, .external_lex_state = 61},
  [3149] = {.lex_state = 427, .external_lex_state = 61},
  [3150] = {.lex_state = 427, .external_lex_state = 61},
  [3151] = {.lex_state = 464, .external_lex_state = 33},
  [3152] = {.lex_state = 429, .external_lex_state = 65},
  [3153] = {.lex_state = 429, .external_lex_state = 65},
  [3154] = {.lex_state = 427, .external_lex_state = 61},
  [3155] = {.lex_state = 429, .external_lex_state = 65},
  [3156] = {.lex_state = 427, .external_lex_state = 61},
  [3157] = {.lex_state = 435, .external_lex_state = 61},
  [3158] = {.lex_state = 427, .external_lex_state = 61},
  [3159] = {.lex_state = 427, .external_lex_state = 61},
  [3160] = {.lex_state = 466, .external_lex_state = 69},
  [3161] = {.lex_state = 466, .external_lex_state = 69},
  [3162] = {.lex_state = 429, .external_lex_state = 65},
  [3163] = {.lex_state = 466, .external_lex_state = 69},
  [3164] = {.lex_state = 430, .external_lex_state = 61},
  [3165] = {.lex_state = 430, .external_lex_state = 61},
  [3166] = {.lex_state = 466, .external_lex_state = 69},
  [3167] = {.lex_state = 429, .external_lex_state = 65},
  [3168] = {.lex_state = 466, .external_lex_state = 69},
  [3169] = {.lex_state = 429, .external_lex_state = 65},
  [3170] = {.lex_state = 430, .external_lex_state = 61},
  [3171] = {.lex_state = 430, .external_lex_state = 61},
  [3172] = {.lex_state = 429, .external_lex_state = 65},
  [3173] = {.lex_state = 429, .external_lex_state = 65},
  [3174] = {.lex_state = 427, .external_lex_state = 39},
  [3175] = {.lex_state = 429, .external_lex_state = 65},
  [3176] = {.lex_state = 429, .external_lex_state = 65},
  [3177] = {.lex_state = 429, .external_lex_state = 65},
  [3178] = {.lex_state = 429, .external_lex_state = 65},
  [3179] = {.lex_state = 429, .external_lex_state = 65},
  [3180] = {.lex_state = 427, .external_lex_state = 61},
  [3181] = {.lex_state = 427, .external_lex_state = 61},
  [3182] = {.lex_state = 427, .external_lex_state = 61},
  [3183] = {.lex_state = 466, .external_lex_state = 69},
  [3184] = {.lex_state = 427, .external_lex_state = 61},
  [3185] = {.lex_state = 466, .external_lex_state = 69},
  [3186] = {.lex_state = 427, .external_lex_state = 61},
  [3187] = {.lex_state = 466, .external_lex_state = 69},
  [3188] = {.lex_state = 466, .external_lex_state = 69},
  [3189] = {.lex_state = 435, .external_lex_state = 61},
  [3190] = {.lex_state = 429, .external_lex_state = 65},
  [3191] = {.lex_state = 429, .external_lex_state = 65},
  [3192] = {.lex_state = 429, .external_lex_state = 65},
  [3193] = {.lex_state = 429, .external_lex_state = 65},
  [3194] = {.lex_state = 429, .external_lex_state = 65},
  [3195] = {.lex_state = 435, .external_lex_state = 61},
  [3196] = {.lex_state = 435, .external_lex_state = 61},
  [3197] = {.lex_state = 429, .external_lex_state = 65},
  [3198] = {.lex_state = 429, .external_lex_state = 65},
  [3199] = {.lex_state = 435, .external_lex_state = 61},
  [3200] = {.lex_state = 427, .external_lex_state = 61},
  [3201] = {.lex_state = 435, .external_lex_state = 61},
  [3202] = {.lex_state = 427, .external_lex_state = 61},
  [3203] = {.lex_state = 427, .external_lex_state = 61},
  [3204] = {.lex_state = 523, .external_lex_state = 67},
  [3205] = {.lex_state = 523, .external_lex_state = 67},
  [3206] = {.lex_state = 427, .external_lex_state = 61},
  [3207] = {.lex_state = 427, .external_lex_state = 61},
  [3208] = {.lex_state = 427, .external_lex_state = 61},
  [3209] = {.lex_state = 466, .external_lex_state = 69},
  [3210] = {.lex_state = 427, .external_lex_state = 61},
  [3211] = {.lex_state = 430, .external_lex_state = 61},
  [3212] = {.lex_state = 427, .external_lex_state = 61},
  [3213] = {.lex_state = 430, .external_lex_state = 61},
  [3214] = {.lex_state = 427, .external_lex_state = 61},
  [3215] = {.lex_state = 430, .external_lex_state = 61},
  [3216] = {.lex_state = 430, .external_lex_state = 61},
  [3217] = {.lex_state = 427, .external_lex_state = 39},
  [3218] = {.lex_state = 430, .external_lex_state = 61},
  [3219] = {.lex_state = 466, .external_lex_state = 69},
  [3220] = {.lex_state = 430, .external_lex_state = 61},
  [3221] = {.lex_state = 430, .external_lex_state = 61},
  [3222] = {.lex_state = 466, .external_lex_state = 69},
  [3223] = {.lex_state = 427, .external_lex_state = 61},
  [3224] = {.lex_state = 430, .external_lex_state = 61},
  [3225] = {.lex_state = 466, .external_lex_state = 69},
  [3226] = {.lex_state = 466, .external_lex_state = 69},
  [3227] = {.lex_state = 430, .external_lex_state = 61},
  [3228] = {.lex_state = 249, .external_lex_state = 67},
  [3229] = {.lex_state = 249, .external_lex_state = 67},
  [3230] = {.lex_state = 454, .external_lex_state = 33},
  [3231] = {.lex_state = 435, .external_lex_state = 61},
  [3232] = {.lex_state = 435, .external_lex_state = 61},
  [3233] = {.lex_state = 435, .external_lex_state = 61},
  [3234] = {.lex_state = 435, .external_lex_state = 61},
  [3235] = {.lex_state = 429, .external_lex_state = 65},
  [3236] = {.lex_state = 430, .external_lex_state = 61},
  [3237] = {.lex_state = 430, .external_lex_state = 61},
  [3238] = {.lex_state = 430, .external_lex_state = 61},
  [3239] = {.lex_state = 460, .external_lex_state = 33},
  [3240] = {.lex_state = 466, .external_lex_state = 69},
  [3241] = {.lex_state = 240, .external_lex_state = 67},
  [3242] = {.lex_state = 427, .external_lex_state = 39},
  [3243] = {.lex_state = 427, .external_lex_state = 39},
  [3244] = {.lex_state = 427, .external_lex_state = 39},
  [3245] = {.lex_state = 427, .external_lex_state = 39},
  [3246] = {.lex_state = 427, .external_lex_state = 39},
  [3247] = {.lex_state = 427, .external_lex_state = 39},
  [3248] = {.lex_state = 427, .external_lex_state = 39},
  [3249] = {.lex_state = 427, .external_lex_state = 39},
  [3250] = {.lex_state = 427, .external_lex_state = 39},
  [3251] = {.lex_state = 429, .external_lex_state = 65},
  [3252] = {.lex_state = 427, .external_lex_state = 39},
  [3253] = {.lex_state = 427, .external_lex_state = 39},
  [3254] = {.lex_state = 427, .external_lex_state = 39},
  [3255] = {.lex_state = 427, .external_lex_state = 39},
  [3256] = {.lex_state = 463, .external_lex_state = 32},
  [3257] = {.lex_state = 429, .external_lex_state = 65},
  [3258] = {.lex_state = 427, .external_lex_state = 39},
  [3259] = {.lex_state = 427, .external_lex_state = 39},
  [3260] = {.lex_state = 427, .external_lex_state = 39},
  [3261] = {.lex_state = 430, .external_lex_state = 61},
  [3262] = {.lex_state = 427, .external_lex_state = 61},
  [3263] = {.lex_state = 430, .external_lex_state = 61},
  [3264] = {.lex_state = 430, .external_lex_state = 61},
  [3265] = {.lex_state = 429, .external_lex_state = 65},
  [3266] = {.lex_state = 429, .external_lex_state = 65},
  [3267] = {.lex_state = 427, .external_lex_state = 61},
  [3268] = {.lex_state = 429, .external_lex_state = 65},
  [3269] = {.lex_state = 429, .external_lex_state = 65},
  [3270] = {.lex_state = 429, .external_lex_state = 65},
  [3271] = {.lex_state = 429, .external_lex_state = 65},
  [3272] = {.lex_state = 427, .external_lex_state = 61},
  [3273] = {.lex_state = 429, .external_lex_state = 65},
  [3274] = {.lex_state = 427, .external_lex_state = 61},
  [3275] = {.lex_state = 435, .external_lex_state = 61},
  [3276] = {.lex_state = 429, .external_lex_state = 65},
  [3277] = {.lex_state = 435, .external_lex_state = 61},
  [3278] = {.lex_state = 429, .external_lex_state = 65},
  [3279] = {.lex_state = 295, .external_lex_state = 68},
  [3280] = {.lex_state = 429, .external_lex_state = 65},
  [3281] = {.lex_state = 295, .external_lex_state = 68},
  [3282] = {.lex_state = 427, .external_lex_state = 61},
  [3283] = {.lex_state = 295, .external_lex_state = 68},
  [3284] = {.lex_state = 427, .external_lex_state = 61},
  [3285] = {.lex_state = 429, .external_lex_state = 65},
  [3286] = {.lex_state = 429, .external_lex_state = 65},
  [3287] = {.lex_state = 429, .external_lex_state = 65},
  [3288] = {.lex_state = 429, .external_lex_state = 65},
  [3289] = {.lex_state = 466, .external_lex_state = 69},
  [3290] = {.lex_state = 252, .external_lex_state = 67},
  [3291] = {.lex_state = 526, .external_lex_state = 67},
  [3292] = {.lex_state = 526, .external_lex_state = 67},
  [3293] = {.lex_state = 295, .external_lex_state = 68},
  [3294] = {.lex_state = 295, .external_lex_state = 68},
  [3295] = {.lex_state = 295, .external_lex_state = 68},
  [3296] = {.lex_state = 295, .external_lex_state = 68},
  [3297] = {.lex_state = 295, .external_lex_state = 68},
  [3298] = {.lex_state = 460, .external_lex_state = 33},
  [3299] = {.lex_state = 454, .external_lex_state = 48},
  [3300] = {.lex_state = 454, .external_lex_state = 48},
  [3301] = {.lex_state = 295, .external_lex_state = 68},
  [3302] = {.lex_state = 454, .external_lex_state = 48},
  [3303] = {.lex_state = 454, .external_lex_state = 48},
  [3304] = {.lex_state = 454, .external_lex_state = 48},
  [3305] = {.lex_state = 295, .external_lex_state = 68},
  [3306] = {.lex_state = 454, .external_lex_state = 48},
  [3307] = {.lex_state = 454, .external_lex_state = 48},
  [3308] = {.lex_state = 526, .external_lex_state = 67},
  [3309] = {.lex_state = 526, .external_lex_state = 67},
  [3310] = {.lex_state = 454, .external_lex_state = 48},
  [3311] = {.lex_state = 258, .external_lex_state = 67},
  [3312] = {.lex_state = 295, .external_lex_state = 68},
  [3313] = {.lex_state = 295, .external_lex_state = 68},
  [3314] = {.lex_state = 454, .external_lex_state = 48},
  [3315] = {.lex_state = 258, .external_lex_state = 67},
  [3316] = {.lex_state = 295, .external_lex_state = 68},
  [3317] = {.lex_state = 523, .external_lex_state = 67},
  [3318] = {.lex_state = 258, .external_lex_state = 67},
  [3319] = {.lex_state = 454, .external_lex_state = 48},
  [3320] = {.lex_state = 454, .external_lex_state = 48},
  [3321] = {.lex_state = 523, .external_lex_state = 67},
  [3322] = {.lex_state = 454, .external_lex_state = 48},
  [3323] = {.lex_state = 454, .external_lex_state = 48},
  [3324] = {.lex_state = 454, .external_lex_state = 48},
  [3325] = {.lex_state = 454, .external_lex_state = 48},
  [3326] = {.lex_state = 454, .external_lex_state = 48},
  [3327] = {.lex_state = 454, .external_lex_state = 48},
  [3328] = {.lex_state = 454, .external_lex_state = 48},
  [3329] = {.lex_state = 295, .external_lex_state = 68},
  [3330] = {.lex_state = 454, .external_lex_state = 48},
  [3331] = {.lex_state = 454, .external_lex_state = 48},
  [3332] = {.lex_state = 454, .external_lex_state = 48},
  [3333] = {.lex_state = 295, .external_lex_state = 68},
  [3334] = {.lex_state = 454, .external_lex_state = 48},
  [3335] = {.lex_state = 295, .external_lex_state = 68},
  [3336] = {.lex_state = 454, .external_lex_state = 48},
  [3337] = {.lex_state = 295, .external_lex_state = 68},
  [3338] = {.lex_state = 258, .external_lex_state = 67},
  [3339] = {.lex_state = 252, .external_lex_state = 67},
  [3340] = {.lex_state = 295, .external_lex_state = 68},
  [3341] = {.lex_state = 295, .external_lex_state = 68},
  [3342] = {.lex_state = 295, .external_lex_state = 68},
  [3343] = {.lex_state = 252, .external_lex_state = 67},
  [3344] = {.lex_state = 295, .external_lex_state = 68},
  [3345] = {.lex_state = 252, .external_lex_state = 67},
  [3346] = {.lex_state = 295, .external_lex_state = 68},
  [3347] = {.lex_state = 454, .external_lex_state = 48},
  [3348] = {.lex_state = 526, .external_lex_state = 67},
  [3349] = {.lex_state = 453, .external_lex_state = 70},
  [3350] = {.lex_state = 296, .external_lex_state = 71},
  [3351] = {.lex_state = 453, .external_lex_state = 70},
  [3352] = {.lex_state = 453, .external_lex_state = 70},
  [3353] = {.lex_state = 526, .external_lex_state = 67},
  [3354] = {.lex_state = 453, .external_lex_state = 70},
  [3355] = {.lex_state = 296, .external_lex_state = 71},
  [3356] = {.lex_state = 453, .external_lex_state = 70},
  [3357] = {.lex_state = 454, .external_lex_state = 48},
  [3358] = {.lex_state = 453, .external_lex_state = 70},
  [3359] = {.lex_state = 453, .external_lex_state = 70},
  [3360] = {.lex_state = 296, .external_lex_state = 71},
  [3361] = {.lex_state = 453, .external_lex_state = 70},
  [3362] = {.lex_state = 453, .external_lex_state = 70},
  [3363] = {.lex_state = 269, .external_lex_state = 24},
  [3364] = {.lex_state = 453, .external_lex_state = 70},
  [3365] = {.lex_state = 296, .external_lex_state = 71},
  [3366] = {.lex_state = 475, .external_lex_state = 72},
  [3367] = {.lex_state = 296, .external_lex_state = 71},
  [3368] = {.lex_state = 467, .external_lex_state = 73},
  [3369] = {.lex_state = 269, .external_lex_state = 24},
  [3370] = {.lex_state = 467, .external_lex_state = 73},
  [3371] = {.lex_state = 467, .external_lex_state = 73},
  [3372] = {.lex_state = 453, .external_lex_state = 70},
  [3373] = {.lex_state = 453, .external_lex_state = 70},
  [3374] = {.lex_state = 453, .external_lex_state = 70},
  [3375] = {.lex_state = 526, .external_lex_state = 67},
  [3376] = {.lex_state = 453, .external_lex_state = 70},
  [3377] = {.lex_state = 526, .external_lex_state = 67},
  [3378] = {.lex_state = 475, .external_lex_state = 72},
  [3379] = {.lex_state = 453, .external_lex_state = 70},
  [3380] = {.lex_state = 453, .external_lex_state = 70},
  [3381] = {.lex_state = 472, .external_lex_state = 74},
  [3382] = {.lex_state = 453, .external_lex_state = 70},
  [3383] = {.lex_state = 453, .external_lex_state = 70},
  [3384] = {.lex_state = 472, .external_lex_state = 74},
  [3385] = {.lex_state = 475, .external_lex_state = 72},
  [3386] = {.lex_state = 475, .external_lex_state = 72},
  [3387] = {.lex_state = 472, .external_lex_state = 74},
  [3388] = {.lex_state = 472, .external_lex_state = 74},
  [3389] = {.lex_state = 472, .external_lex_state = 74},
  [3390] = {.lex_state = 472, .external_lex_state = 74},
  [3391] = {.lex_state = 472, .external_lex_state = 74},
  [3392] = {.lex_state = 472, .external_lex_state = 74},
  [3393] = {.lex_state = 472, .external_lex_state = 74},
  [3394] = {.lex_state = 472, .external_lex_state = 74},
  [3395] = {.lex_state = 472, .external_lex_state = 74},
  [3396] = {.lex_state = 472, .external_lex_state = 74},
  [3397] = {.lex_state = 472, .external_lex_state = 74},
  [3398] = {.lex_state = 472, .external_lex_state = 74},
  [3399] = {.lex_state = 472, .external_lex_state = 74},
  [3400] = {.lex_state = 472, .external_lex_state = 74},
  [3401] = {.lex_state = 472, .external_lex_state = 74},
  [3402] = {.lex_state = 453, .external_lex_state = 70},
  [3403] = {.lex_state = 475, .external_lex_state = 72},
  [3404] = {.lex_state = 453, .external_lex_state = 70},
  [3405] = {.lex_state = 453, .external_lex_state = 70},
  [3406] = {.lex_state = 453, .external_lex_state = 70},
  [3407] = {.lex_state = 453, .external_lex_state = 70},
  [3408] = {.lex_state = 453, .external_lex_state = 70},
  [3409] = {.lex_state = 453, .external_lex_state = 70},
  [3410] = {.lex_state = 453, .external_lex_state = 70},
  [3411] = {.lex_state = 453, .external_lex_state = 70},
  [3412] = {.lex_state = 453, .external_lex_state = 70},
  [3413] = {.lex_state = 453, .external_lex_state = 70},
  [3414] = {.lex_state = 453, .external_lex_state = 70},
  [3415] = {.lex_state = 453, .external_lex_state = 70},
  [3416] = {.lex_state = 287, .external_lex_state = 75},
  [3417] = {.lex_state = 287, .external_lex_state = 75},
  [3418] = {.lex_state = 453, .external_lex_state = 70},
  [3419] = {.lex_state = 269, .external_lex_state = 24},
  [3420] = {.lex_state = 472, .external_lex_state = 74},
  [3421] = {.lex_state = 472, .external_lex_state = 74},
  [3422] = {.lex_state = 453, .external_lex_state = 70},
  [3423] = {.lex_state = 472, .external_lex_state = 74},
  [3424] = {.lex_state = 472, .external_lex_state = 74},
  [3425] = {.lex_state = 472, .external_lex_state = 74},
  [3426] = {.lex_state = 472, .external_lex_state = 74},
  [3427] = {.lex_state = 452, .external_lex_state = 35},
  [3428] = {.lex_state = 445, .external_lex_state = 76},
  [3429] = {.lex_state = 445, .external_lex_state = 76},
  [3430] = {.lex_state = 445, .external_lex_state = 76},
  [3431] = {.lex_state = 445, .external_lex_state = 76},
  [3432] = {.lex_state = 452, .external_lex_state = 35},
  [3433] = {.lex_state = 438, .external_lex_state = 77},
  [3434] = {.lex_state = 445, .external_lex_state = 76},
  [3435] = {.lex_state = 445, .external_lex_state = 76},
  [3436] = {.lex_state = 445, .external_lex_state = 76},
  [3437] = {.lex_state = 445, .external_lex_state = 76},
  [3438] = {.lex_state = 445, .external_lex_state = 76},
  [3439] = {.lex_state = 445, .external_lex_state = 76},
  [3440] = {.lex_state = 445, .external_lex_state = 76},
  [3441] = {.lex_state = 445, .external_lex_state = 76},
  [3442] = {.lex_state = 452, .external_lex_state = 35},
  [3443] = {.lex_state = 438, .external_lex_state = 77},
  [3444] = {.lex_state = 445, .external_lex_state = 76},
  [3445] = {.lex_state = 445, .external_lex_state = 76},
  [3446] = {.lex_state = 445, .external_lex_state = 76},
  [3447] = {.lex_state = 445, .external_lex_state = 76},
  [3448] = {.lex_state = 445, .external_lex_state = 76},
  [3449] = {.lex_state = 452, .external_lex_state = 35},
  [3450] = {.lex_state = 261, .external_lex_state = 67},
  [3451] = {.lex_state = 452, .external_lex_state = 35},
  [3452] = {.lex_state = 452, .external_lex_state = 35},
  [3453] = {.lex_state = 445, .external_lex_state = 76},
  [3454] = {.lex_state = 452, .external_lex_state = 35},
  [3455] = {.lex_state = 261, .external_lex_state = 67},
  [3456] = {.lex_state = 445, .external_lex_state = 76},
  [3457] = {.lex_state = 445, .external_lex_state = 76},
  [3458] = {.lex_state = 445, .external_lex_state = 76},
  [3459] = {.lex_state = 445, .external_lex_state = 76},
  [3460] = {.lex_state = 454, .external_lex_state = 78},
  [3461] = {.lex_state = 445, .external_lex_state = 76},
  [3462] = {.lex_state = 454, .external_lex_state = 78},
  [3463] = {.lex_state = 445, .external_lex_state = 76},
  [3464] = {.lex_state = 445, .external_lex_state = 76},
  [3465] = {.lex_state = 445, .external_lex_state = 76},
  [3466] = {.lex_state = 445, .external_lex_state = 76},
  [3467] = {.lex_state = 445, .external_lex_state = 76},
  [3468] = {.lex_state = 454, .external_lex_state = 78},
  [3469] = {.lex_state = 445, .external_lex_state = 76},
  [3470] = {.lex_state = 454, .external_lex_state = 78},
  [3471] = {.lex_state = 445, .external_lex_state = 76},
  [3472] = {.lex_state = 454, .external_lex_state = 78},
  [3473] = {.lex_state = 454, .external_lex_state = 78},
  [3474] = {.lex_state = 454, .external_lex_state = 78},
  [3475] = {.lex_state = 445, .external_lex_state = 76},
  [3476] = {.lex_state = 454, .external_lex_state = 78},
  [3477] = {.lex_state = 454, .external_lex_state = 78},
  [3478] = {.lex_state = 454, .external_lex_state = 78},
  [3479] = {.lex_state = 454, .external_lex_state = 78},
  [3480] = {.lex_state = 454, .external_lex_state = 78},
  [3481] = {.lex_state = 454, .external_lex_state = 78},
  [3482] = {.lex_state = 454, .external_lex_state = 78},
  [3483] = {.lex_state = 454, .external_lex_state = 78},
  [3484] = {.lex_state = 454, .external_lex_state = 78},
  [3485] = {.lex_state = 454, .external_lex_state = 78},
  [3486] = {.lex_state = 454, .external_lex_state = 78},
  [3487] = {.lex_state = 454, .external_lex_state = 78},
  [3488] = {.lex_state = 454, .external_lex_state = 78},
  [3489] = {.lex_state = 454, .external_lex_state = 78},
  [3490] = {.lex_state = 454, .external_lex_state = 78},
  [3491] = {.lex_state = 452, .external_lex_state = 35},
  [3492] = {.lex_state = 257, .external_lex_state = 71},
  [3493] = {.lex_state = 445, .external_lex_state = 76},
  [3494] = {.lex_state = 445, .external_lex_state = 76},
  [3495] = {.lex_state = 445, .external_lex_state = 76},
  [3496] = {.lex_state = 445, .external_lex_state = 76},
  [3497] = {.lex_state = 445, .external_lex_state = 76},
  [3498] = {.lex_state = 445, .external_lex_state = 76},
  [3499] = {.lex_state = 454, .external_lex_state = 79},
  [3500] = {.lex_state = 445, .external_lex_state = 76},
  [3501] = {.lex_state = 445, .external_lex_state = 76},
  [3502] = {.lex_state = 445, .external_lex_state = 76},
  [3503] = {.lex_state = 475, .external_lex_state = 80},
  [3504] = {.lex_state = 445, .external_lex_state = 76},
  [3505] = {.lex_state = 445, .external_lex_state = 76},
  [3506] = {.lex_state = 445, .external_lex_state = 76},
  [3507] = {.lex_state = 454, .external_lex_state = 79},
  [3508] = {.lex_state = 445, .external_lex_state = 76},
  [3509] = {.lex_state = 264, .external_lex_state = 67},
  [3510] = {.lex_state = 445, .external_lex_state = 76},
  [3511] = {.lex_state = 445, .external_lex_state = 76},
  [3512] = {.lex_state = 264, .external_lex_state = 67},
  [3513] = {.lex_state = 445, .external_lex_state = 76},
  [3514] = {.lex_state = 445, .external_lex_state = 76},
  [3515] = {.lex_state = 445, .external_lex_state = 76},
  [3516] = {.lex_state = 452, .external_lex_state = 35},
  [3517] = {.lex_state = 257, .external_lex_state = 71},
  [3518] = {.lex_state = 257, .external_lex_state = 71},
  [3519] = {.lex_state = 445, .external_lex_state = 76},
  [3520] = {.lex_state = 452, .external_lex_state = 35},
  [3521] = {.lex_state = 445, .external_lex_state = 76},
  [3522] = {.lex_state = 445, .external_lex_state = 76},
  [3523] = {.lex_state = 445, .external_lex_state = 76},
  [3524] = {.lex_state = 454, .external_lex_state = 78},
  [3525] = {.lex_state = 445, .external_lex_state = 76},
  [3526] = {.lex_state = 257, .external_lex_state = 71},
  [3527] = {.lex_state = 445, .external_lex_state = 76},
  [3528] = {.lex_state = 257, .external_lex_state = 71},
  [3529] = {.lex_state = 257, .external_lex_state = 71},
  [3530] = {.lex_state = 454, .external_lex_state = 78},
  [3531] = {.lex_state = 445, .external_lex_state = 76},
  [3532] = {.lex_state = 445, .external_lex_state = 76},
  [3533] = {.lex_state = 445, .external_lex_state = 76},
  [3534] = {.lex_state = 445, .external_lex_state = 76},
  [3535] = {.lex_state = 257, .external_lex_state = 71},
  [3536] = {.lex_state = 257, .external_lex_state = 71},
  [3537] = {.lex_state = 445, .external_lex_state = 76},
  [3538] = {.lex_state = 445, .external_lex_state = 76},
  [3539] = {.lex_state = 445, .external_lex_state = 76},
  [3540] = {.lex_state = 257, .external_lex_state = 71},
  [3541] = {.lex_state = 257, .external_lex_state = 71},
  [3542] = {.lex_state = 454, .external_lex_state = 78},
  [3543] = {.lex_state = 445, .external_lex_state = 76},
  [3544] = {.lex_state = 445, .external_lex_state = 76},
  [3545] = {.lex_state = 454, .external_lex_state = 78},
  [3546] = {.lex_state = 445, .external_lex_state = 76},
  [3547] = {.lex_state = 445, .external_lex_state = 76},
  [3548] = {.lex_state = 445, .external_lex_state = 76},
  [3549] = {.lex_state = 445, .external_lex_state = 76},
  [3550] = {.lex_state = 454, .external_lex_state = 78},
  [3551] = {.lex_state = 257, .external_lex_state = 71},
  [3552] = {.lex_state = 454, .external_lex_state = 78},
  [3553] = {.lex_state = 445, .external_lex_state = 76},
  [3554] = {.lex_state = 445, .external_lex_state = 76},
  [3555] = {.lex_state = 445, .external_lex_state = 76},
  [3556] = {.lex_state = 445, .external_lex_state = 76},
  [3557] = {.lex_state = 445, .external_lex_state = 76},
  [3558] = {.lex_state = 445, .external_lex_state = 76},
  [3559] = {.lex_state = 445, .external_lex_state = 76},
  [3560] = {.lex_state = 445, .external_lex_state = 76},
  [3561] = {.lex_state = 454, .external_lex_state = 78},
  [3562] = {.lex_state = 454, .external_lex_state = 78},
  [3563] = {.lex_state = 445, .external_lex_state = 76},
  [3564] = {.lex_state = 454, .external_lex_state = 78},
  [3565] = {.lex_state = 445, .external_lex_state = 76},
  [3566] = {.lex_state = 445, .external_lex_state = 76},
  [3567] = {.lex_state = 445, .external_lex_state = 76},
  [3568] = {.lex_state = 445, .external_lex_state = 76},
  [3569] = {.lex_state = 445, .external_lex_state = 76},
  [3570] = {.lex_state = 445, .external_lex_state = 76},
  [3571] = {.lex_state = 445, .external_lex_state = 76},
  [3572] = {.lex_state = 445, .external_lex_state = 76},
  [3573] = {.lex_state = 445, .external_lex_state = 76},
  [3574] = {.lex_state = 445, .external_lex_state = 76},
  [3575] = {.lex_state = 445, .external_lex_state = 76},
  [3576] = {.lex_state = 445, .external_lex_state = 76},
  [3577] = {.lex_state = 445, .external_lex_state = 76},
  [3578] = {.lex_state = 445, .external_lex_state = 76},
  [3579] = {.lex_state = 445, .external_lex_state = 76},
  [3580] = {.lex_state = 445, .external_lex_state = 76},
  [3581] = {.lex_state = 445, .external_lex_state = 76},
  [3582] = {.lex_state = 445, .external_lex_state = 76},
  [3583] = {.lex_state = 445, .external_lex_state = 76},
  [3584] = {.lex_state = 445, .external_lex_state = 76},
  [3585] = {.lex_state = 445, .external_lex_state = 76},
  [3586] = {.lex_state = 445, .external_lex_state = 76},
  [3587] = {.lex_state = 445, .external_lex_state = 76},
  [3588] = {.lex_state = 445, .external_lex_state = 76},
  [3589] = {.lex_state = 445, .external_lex_state = 76},
  [3590] = {.lex_state = 445, .external_lex_state = 76},
  [3591] = {.lex_state = 445, .external_lex_state = 76},
  [3592] = {.lex_state = 445, .external_lex_state = 76},
  [3593] = {.lex_state = 445, .external_lex_state = 76},
  [3594] = {.lex_state = 445, .external_lex_state = 76},
  [3595] = {.lex_state = 445, .external_lex_state = 76},
  [3596] = {.lex_state = 445, .external_lex_state = 76},
  [3597] = {.lex_state = 445, .external_lex_state = 76},
  [3598] = {.lex_state = 445, .external_lex_state = 76},
  [3599] = {.lex_state = 445, .external_lex_state = 76},
  [3600] = {.lex_state = 445, .external_lex_state = 76},
  [3601] = {.lex_state = 445, .external_lex_state = 76},
  [3602] = {.lex_state = 445, .external_lex_state = 76},
  [3603] = {.lex_state = 445, .external_lex_state = 76},
  [3604] = {.lex_state = 445, .external_lex_state = 76},
  [3605] = {.lex_state = 445, .external_lex_state = 76},
  [3606] = {.lex_state = 445, .external_lex_state = 76},
  [3607] = {.lex_state = 445, .external_lex_state = 76},
  [3608] = {.lex_state = 445, .external_lex_state = 76},
  [3609] = {.lex_state = 445, .external_lex_state = 76},
  [3610] = {.lex_state = 445, .external_lex_state = 76},
  [3611] = {.lex_state = 445, .external_lex_state = 76},
  [3612] = {.lex_state = 445, .external_lex_state = 76},
  [3613] = {.lex_state = 445, .external_lex_state = 76},
  [3614] = {.lex_state = 445, .external_lex_state = 76},
  [3615] = {.lex_state = 445, .external_lex_state = 76},
  [3616] = {.lex_state = 445, .external_lex_state = 76},
  [3617] = {.lex_state = 445, .external_lex_state = 76},
  [3618] = {.lex_state = 445, .external_lex_state = 76},
  [3619] = {.lex_state = 445, .external_lex_state = 76},
  [3620] = {.lex_state = 445, .external_lex_state = 76},
  [3621] = {.lex_state = 445, .external_lex_state = 76},
  [3622] = {.lex_state = 445, .external_lex_state = 76},
  [3623] = {.lex_state = 445, .external_lex_state = 76},
  [3624] = {.lex_state = 445, .external_lex_state = 76},
  [3625] = {.lex_state = 445, .external_lex_state = 76},
  [3626] = {.lex_state = 445, .external_lex_state = 76},
  [3627] = {.lex_state = 445, .external_lex_state = 76},
  [3628] = {.lex_state = 445, .external_lex_state = 76},
  [3629] = {.lex_state = 445, .external_lex_state = 76},
  [3630] = {.lex_state = 445, .external_lex_state = 76},
  [3631] = {.lex_state = 445, .external_lex_state = 76},
  [3632] = {.lex_state = 445, .external_lex_state = 76},
  [3633] = {.lex_state = 445, .external_lex_state = 76},
  [3634] = {.lex_state = 445, .external_lex_state = 76},
  [3635] = {.lex_state = 445, .external_lex_state = 76},
  [3636] = {.lex_state = 445, .external_lex_state = 76},
  [3637] = {.lex_state = 445, .external_lex_state = 76},
  [3638] = {.lex_state = 445, .external_lex_state = 76},
  [3639] = {.lex_state = 445, .external_lex_state = 76},
  [3640] = {.lex_state = 439, .external_lex_state = 81},
  [3641] = {.lex_state = 445, .external_lex_state = 76},
  [3642] = {.lex_state = 445, .external_lex_state = 76},
  [3643] = {.lex_state = 439, .external_lex_state = 81},
  [3644] = {.lex_state = 445, .external_lex_state = 76},
  [3645] = {.lex_state = 445, .external_lex_state = 76},
  [3646] = {.lex_state = 445, .external_lex_state = 76},
  [3647] = {.lex_state = 445, .external_lex_state = 76},
  [3648] = {.lex_state = 445, .external_lex_state = 76},
  [3649] = {.lex_state = 445, .external_lex_state = 76},
  [3650] = {.lex_state = 445, .external_lex_state = 76},
  [3651] = {.lex_state = 445, .external_lex_state = 76},
  [3652] = {.lex_state = 445, .external_lex_state = 76},
  [3653] = {.lex_state = 445, .external_lex_state = 76},
  [3654] = {.lex_state = 445, .external_lex_state = 76},
  [3655] = {.lex_state = 445, .external_lex_state = 76},
  [3656] = {.lex_state = 445, .external_lex_state = 76},
  [3657] = {.lex_state = 445, .external_lex_state = 76},
  [3658] = {.lex_state = 445, .external_lex_state = 76},
  [3659] = {.lex_state = 445, .external_lex_state = 76},
  [3660] = {.lex_state = 445, .external_lex_state = 76},
  [3661] = {.lex_state = 445, .external_lex_state = 76},
  [3662] = {.lex_state = 452, .external_lex_state = 35},
  [3663] = {.lex_state = 445, .external_lex_state = 76},
  [3664] = {.lex_state = 445, .external_lex_state = 76},
  [3665] = {.lex_state = 445, .external_lex_state = 76},
  [3666] = {.lex_state = 445, .external_lex_state = 76},
  [3667] = {.lex_state = 445, .external_lex_state = 76},
  [3668] = {.lex_state = 445, .external_lex_state = 76},
  [3669] = {.lex_state = 445, .external_lex_state = 76},
  [3670] = {.lex_state = 445, .external_lex_state = 76},
  [3671] = {.lex_state = 445, .external_lex_state = 76},
  [3672] = {.lex_state = 445, .external_lex_state = 76},
  [3673] = {.lex_state = 445, .external_lex_state = 76},
  [3674] = {.lex_state = 445, .external_lex_state = 76},
  [3675] = {.lex_state = 445, .external_lex_state = 76},
  [3676] = {.lex_state = 445, .external_lex_state = 76},
  [3677] = {.lex_state = 445, .external_lex_state = 76},
  [3678] = {.lex_state = 445, .external_lex_state = 76},
  [3679] = {.lex_state = 445, .external_lex_state = 76},
  [3680] = {.lex_state = 445, .external_lex_state = 76},
  [3681] = {.lex_state = 445, .external_lex_state = 76},
  [3682] = {.lex_state = 445, .external_lex_state = 76},
  [3683] = {.lex_state = 445, .external_lex_state = 76},
  [3684] = {.lex_state = 445, .external_lex_state = 76},
  [3685] = {.lex_state = 445, .external_lex_state = 76},
  [3686] = {.lex_state = 445, .external_lex_state = 76},
  [3687] = {.lex_state = 264, .external_lex_state = 67},
  [3688] = {.lex_state = 264, .external_lex_state = 67},
  [3689] = {.lex_state = 454, .external_lex_state = 79},
  [3690] = {.lex_state = 445, .external_lex_state = 76},
  [3691] = {.lex_state = 452, .external_lex_state = 35},
  [3692] = {.lex_state = 452, .external_lex_state = 35},
  [3693] = {.lex_state = 445, .external_lex_state = 76},
  [3694] = {.lex_state = 445, .external_lex_state = 76},
  [3695] = {.lex_state = 445, .external_lex_state = 76},
  [3696] = {.lex_state = 452, .external_lex_state = 35},
  [3697] = {.lex_state = 445, .external_lex_state = 76},
  [3698] = {.lex_state = 454, .external_lex_state = 78},
  [3699] = {.lex_state = 445, .external_lex_state = 76},
  [3700] = {.lex_state = 454, .external_lex_state = 78},
  [3701] = {.lex_state = 452, .external_lex_state = 35},
  [3702] = {.lex_state = 445, .external_lex_state = 76},
  [3703] = {.lex_state = 452, .external_lex_state = 35},
  [3704] = {.lex_state = 445, .external_lex_state = 76},
  [3705] = {.lex_state = 445, .external_lex_state = 76},
  [3706] = {.lex_state = 445, .external_lex_state = 76},
  [3707] = {.lex_state = 440, .external_lex_state = 77},
  [3708] = {.lex_state = 440, .external_lex_state = 77},
  [3709] = {.lex_state = 445, .external_lex_state = 76},
  [3710] = {.lex_state = 411, .external_lex_state = 82},
  [3711] = {.lex_state = 454, .external_lex_state = 78},
  [3712] = {.lex_state = 454, .external_lex_state = 78},
  [3713] = {.lex_state = 454, .external_lex_state = 83},
  [3714] = {.lex_state = 454, .external_lex_state = 78},
  [3715] = {.lex_state = 473, .external_lex_state = 84},
  [3716] = {.lex_state = 454, .external_lex_state = 78},
  [3717] = {.lex_state = 454, .external_lex_state = 78},
  [3718] = {.lex_state = 473, .external_lex_state = 84},
  [3719] = {.lex_state = 454, .external_lex_state = 78},
  [3720] = {.lex_state = 454, .external_lex_state = 78},
  [3721] = {.lex_state = 454, .external_lex_state = 78},
  [3722] = {.lex_state = 454, .external_lex_state = 78},
  [3723] = {.lex_state = 454, .external_lex_state = 78},
  [3724] = {.lex_state = 454, .external_lex_state = 78},
  [3725] = {.lex_state = 454, .external_lex_state = 78},
  [3726] = {.lex_state = 454, .external_lex_state = 78},
  [3727] = {.lex_state = 454, .external_lex_state = 78},
  [3728] = {.lex_state = 454, .external_lex_state = 83},
  [3729] = {.lex_state = 473, .external_lex_state = 84},
  [3730] = {.lex_state = 454, .external_lex_state = 78},
  [3731] = {.lex_state = 454, .external_lex_state = 78},
  [3732] = {.lex_state = 454, .external_lex_state = 78},
  [3733] = {.lex_state = 454, .external_lex_state = 78},
  [3734] = {.lex_state = 454, .external_lex_state = 78},
  [3735] = {.lex_state = 473, .external_lex_state = 84},
  [3736] = {.lex_state = 473, .external_lex_state = 84},
  [3737] = {.lex_state = 454, .external_lex_state = 78},
  [3738] = {.lex_state = 454, .external_lex_state = 78},
  [3739] = {.lex_state = 454, .external_lex_state = 78},
  [3740] = {.lex_state = 473, .external_lex_state = 84},
  [3741] = {.lex_state = 454, .external_lex_state = 78},
  [3742] = {.lex_state = 454, .external_lex_state = 78},
  [3743] = {.lex_state = 454, .external_lex_state = 83},
  [3744] = {.lex_state = 454, .external_lex_state = 78},
  [3745] = {.lex_state = 454, .external_lex_state = 78},
  [3746] = {.lex_state = 289, .external_lex_state = 75},
  [3747] = {.lex_state = 473, .external_lex_state = 84},
  [3748] = {.lex_state = 454, .external_lex_state = 78},
  [3749] = {.lex_state = 454, .external_lex_state = 78},
  [3750] = {.lex_state = 473, .external_lex_state = 84},
  [3751] = {.lex_state = 454, .external_lex_state = 78},
  [3752] = {.lex_state = 454, .external_lex_state = 78},
  [3753] = {.lex_state = 454, .external_lex_state = 78},
  [3754] = {.lex_state = 454, .external_lex_state = 78},
  [3755] = {.lex_state = 454, .external_lex_state = 78},
  [3756] = {.lex_state = 454, .external_lex_state = 78},
  [3757] = {.lex_state = 454, .external_lex_state = 78},
  [3758] = {.lex_state = 454, .external_lex_state = 78},
  [3759] = {.lex_state = 473, .external_lex_state = 84},
  [3760] = {.lex_state = 454, .external_lex_state = 78},
  [3761] = {.lex_state = 473, .external_lex_state = 84},
  [3762] = {.lex_state = 454, .external_lex_state = 78},
  [3763] = {.lex_state = 454, .external_lex_state = 78},
  [3764] = {.lex_state = 454, .external_lex_state = 78},
  [3765] = {.lex_state = 454, .external_lex_state = 78},
  [3766] = {.lex_state = 454, .external_lex_state = 78},
  [3767] = {.lex_state = 473, .external_lex_state = 84},
  [3768] = {.lex_state = 473, .external_lex_state = 84},
  [3769] = {.lex_state = 454, .external_lex_state = 78},
  [3770] = {.lex_state = 454, .external_lex_state = 78},
  [3771] = {.lex_state = 454, .external_lex_state = 78},
  [3772] = {.lex_state = 454, .external_lex_state = 83},
  [3773] = {.lex_state = 454, .external_lex_state = 78},
  [3774] = {.lex_state = 441, .external_lex_state = 81},
  [3775] = {.lex_state = 441, .external_lex_state = 81},
  [3776] = {.lex_state = 454, .external_lex_state = 78},
  [3777] = {.lex_state = 441, .external_lex_state = 81},
  [3778] = {.lex_state = 454, .external_lex_state = 78},
  [3779] = {.lex_state = 454, .external_lex_state = 78},
  [3780] = {.lex_state = 454, .external_lex_state = 78},
  [3781] = {.lex_state = 454, .external_lex_state = 78},
  [3782] = {.lex_state = 289, .external_lex_state = 75},
  [3783] = {.lex_state = 454, .external_lex_state = 78},
  [3784] = {.lex_state = 454, .external_lex_state = 78},
  [3785] = {.lex_state = 441, .external_lex_state = 81},
  [3786] = {.lex_state = 454, .external_lex_state = 78},
  [3787] = {.lex_state = 454, .external_lex_state = 78},
  [3788] = {.lex_state = 454, .external_lex_state = 78},
  [3789] = {.lex_state = 454, .external_lex_state = 83},
  [3790] = {.lex_state = 454, .external_lex_state = 83},
  [3791] = {.lex_state = 454, .external_lex_state = 78},
  [3792] = {.lex_state = 454, .external_lex_state = 78},
  [3793] = {.lex_state = 454, .external_lex_state = 78},
  [3794] = {.lex_state = 454, .external_lex_state = 78},
  [3795] = {.lex_state = 454, .external_lex_state = 83},
  [3796] = {.lex_state = 411, .external_lex_state = 82},
  [3797] = {.lex_state = 472, .external_lex_state = 85},
  [3798] = {.lex_state = 472, .external_lex_state = 85},
  [3799] = {.lex_state = 472, .external_lex_state = 85},
  [3800] = {.lex_state = 95, .external_lex_state = 86},
  [3801] = {.lex_state = 472, .external_lex_state = 85},
  [3802] = {.lex_state = 472, .external_lex_state = 85},
  [3803] = {.lex_state = 472, .external_lex_state = 85},
  [3804] = {.lex_state = 472, .external_lex_state = 85},
  [3805] = {.lex_state = 472, .external_lex_state = 85},
  [3806] = {.lex_state = 472, .external_lex_state = 85},
  [3807] = {.lex_state = 472, .external_lex_state = 85},
  [3808] = {.lex_state = 472, .external_lex_state = 85},
  [3809] = {.lex_state = 472, .external_lex_state = 85},
  [3810] = {.lex_state = 472, .external_lex_state = 85},
  [3811] = {.lex_state = 472, .external_lex_state = 85},
  [3812] = {.lex_state = 472, .external_lex_state = 85},
  [3813] = {.lex_state = 472, .external_lex_state = 85},
  [3814] = {.lex_state = 472, .external_lex_state = 85},
  [3815] = {.lex_state = 472, .external_lex_state = 85},
  [3816] = {.lex_state = 472, .external_lex_state = 85},
  [3817] = {.lex_state = 472, .external_lex_state = 85},
  [3818] = {.lex_state = 472, .external_lex_state = 85},
  [3819] = {.lex_state = 472, .external_lex_state = 85},
  [3820] = {.lex_state = 472, .external_lex_state = 85},
  [3821] = {.lex_state = 472, .external_lex_state = 85},
  [3822] = {.lex_state = 472, .external_lex_state = 85},
  [3823] = {.lex_state = 472, .external_lex_state = 85},
  [3824] = {.lex_state = 472, .external_lex_state = 85},
  [3825] = {.lex_state = 472, .external_lex_state = 85},
  [3826] = {.lex_state = 472, .external_lex_state = 85},
  [3827] = {.lex_state = 472, .external_lex_state = 85},
  [3828] = {.lex_state = 472, .external_lex_state = 85},
  [3829] = {.lex_state = 472, .external_lex_state = 85},
  [3830] = {.lex_state = 472, .external_lex_state = 85},
  [3831] = {.lex_state = 472, .external_lex_state = 85},
  [3832] = {.lex_state = 472, .external_lex_state = 85},
  [3833] = {.lex_state = 472, .external_lex_state = 85},
  [3834] = {.lex_state = 472, .external_lex_state = 85},
  [3835] = {.lex_state = 472, .external_lex_state = 85},
  [3836] = {.lex_state = 472, .external_lex_state = 85},
  [3837] = {.lex_state = 472, .external_lex_state = 85},
  [3838] = {.lex_state = 472, .external_lex_state = 85},
  [3839] = {.lex_state = 472, .external_lex_state = 85},
  [3840] = {.lex_state = 472, .external_lex_state = 85},
  [3841] = {.lex_state = 454, .external_lex_state = 78},
  [3842] = {.lex_state = 472, .external_lex_state = 85},
  [3843] = {.lex_state = 472, .external_lex_state = 85},
  [3844] = {.lex_state = 454, .external_lex_state = 78},
  [3845] = {.lex_state = 472, .external_lex_state = 85},
  [3846] = {.lex_state = 472, .external_lex_state = 85},
  [3847] = {.lex_state = 472, .external_lex_state = 85},
  [3848] = {.lex_state = 472, .external_lex_state = 85},
  [3849] = {.lex_state = 472, .external_lex_state = 85},
  [3850] = {.lex_state = 472, .external_lex_state = 85},
  [3851] = {.lex_state = 454, .external_lex_state = 78},
  [3852] = {.lex_state = 472, .external_lex_state = 85},
  [3853] = {.lex_state = 472, .external_lex_state = 85},
  [3854] = {.lex_state = 472, .external_lex_state = 85},
  [3855] = {.lex_state = 93, .external_lex_state = 87},
  [3856] = {.lex_state = 472, .external_lex_state = 85},
  [3857] = {.lex_state = 454, .external_lex_state = 78},
  [3858] = {.lex_state = 454, .external_lex_state = 78},
  [3859] = {.lex_state = 454, .external_lex_state = 78},
  [3860] = {.lex_state = 454, .external_lex_state = 78},
  [3861] = {.lex_state = 454, .external_lex_state = 78},
  [3862] = {.lex_state = 472, .external_lex_state = 85},
  [3863] = {.lex_state = 472, .external_lex_state = 85},
  [3864] = {.lex_state = 454, .external_lex_state = 78},
  [3865] = {.lex_state = 472, .external_lex_state = 85},
  [3866] = {.lex_state = 472, .external_lex_state = 85},
  [3867] = {.lex_state = 472, .external_lex_state = 85},
  [3868] = {.lex_state = 472, .external_lex_state = 85},
  [3869] = {.lex_state = 472, .external_lex_state = 85},
  [3870] = {.lex_state = 472, .external_lex_state = 85},
  [3871] = {.lex_state = 472, .external_lex_state = 85},
  [3872] = {.lex_state = 454, .external_lex_state = 78},
  [3873] = {.lex_state = 454, .external_lex_state = 78},
  [3874] = {.lex_state = 454, .external_lex_state = 78},
  [3875] = {.lex_state = 454, .external_lex_state = 78},
  [3876] = {.lex_state = 454, .external_lex_state = 78},
  [3877] = {.lex_state = 454, .external_lex_state = 78},
  [3878] = {.lex_state = 472, .external_lex_state = 85},
  [3879] = {.lex_state = 472, .external_lex_state = 85},
  [3880] = {.lex_state = 472, .external_lex_state = 85},
  [3881] = {.lex_state = 472, .external_lex_state = 85},
  [3882] = {.lex_state = 472, .external_lex_state = 85},
  [3883] = {.lex_state = 454, .external_lex_state = 78},
  [3884] = {.lex_state = 472, .external_lex_state = 85},
  [3885] = {.lex_state = 454, .external_lex_state = 78},
  [3886] = {.lex_state = 454, .external_lex_state = 78},
  [3887] = {.lex_state = 454, .external_lex_state = 78},
  [3888] = {.lex_state = 454, .external_lex_state = 78},
  [3889] = {.lex_state = 472, .external_lex_state = 85},
  [3890] = {.lex_state = 472, .external_lex_state = 85},
  [3891] = {.lex_state = 472, .external_lex_state = 85},
  [3892] = {.lex_state = 472, .external_lex_state = 85},
  [3893] = {.lex_state = 454, .external_lex_state = 78},
  [3894] = {.lex_state = 454, .external_lex_state = 78},
  [3895] = {.lex_state = 454, .external_lex_state = 78},
  [3896] = {.lex_state = 454, .external_lex_state = 78},
  [3897] = {.lex_state = 454, .external_lex_state = 78},
  [3898] = {.lex_state = 472, .external_lex_state = 85},
  [3899] = {.lex_state = 454, .external_lex_state = 78},
  [3900] = {.lex_state = 472, .external_lex_state = 85},
  [3901] = {.lex_state = 472, .external_lex_state = 85},
  [3902] = {.lex_state = 472, .external_lex_state = 85},
  [3903] = {.lex_state = 472, .external_lex_state = 85},
  [3904] = {.lex_state = 95, .external_lex_state = 86},
  [3905] = {.lex_state = 95, .external_lex_state = 86},
  [3906] = {.lex_state = 472, .external_lex_state = 85},
  [3907] = {.lex_state = 454, .external_lex_state = 78},
  [3908] = {.lex_state = 454, .external_lex_state = 78},
  [3909] = {.lex_state = 472, .external_lex_state = 85},
  [3910] = {.lex_state = 472, .external_lex_state = 85},
  [3911] = {.lex_state = 472, .external_lex_state = 85},
  [3912] = {.lex_state = 472, .external_lex_state = 85},
  [3913] = {.lex_state = 454, .external_lex_state = 78},
  [3914] = {.lex_state = 472, .external_lex_state = 85},
  [3915] = {.lex_state = 472, .external_lex_state = 85},
  [3916] = {.lex_state = 472, .external_lex_state = 85},
  [3917] = {.lex_state = 472, .external_lex_state = 85},
  [3918] = {.lex_state = 472, .external_lex_state = 85},
  [3919] = {.lex_state = 454, .external_lex_state = 78},
  [3920] = {.lex_state = 472, .external_lex_state = 85},
  [3921] = {.lex_state = 454, .external_lex_state = 78},
  [3922] = {.lex_state = 472, .external_lex_state = 85},
  [3923] = {.lex_state = 472, .external_lex_state = 85},
  [3924] = {.lex_state = 472, .external_lex_state = 85},
  [3925] = {.lex_state = 472, .external_lex_state = 85},
  [3926] = {.lex_state = 472, .external_lex_state = 85},
  [3927] = {.lex_state = 472, .external_lex_state = 85},
  [3928] = {.lex_state = 472, .external_lex_state = 85},
  [3929] = {.lex_state = 472, .external_lex_state = 85},
  [3930] = {.lex_state = 454, .external_lex_state = 78},
  [3931] = {.lex_state = 472, .external_lex_state = 85},
  [3932] = {.lex_state = 472, .external_lex_state = 85},
  [3933] = {.lex_state = 454, .external_lex_state = 78},
  [3934] = {.lex_state = 472, .external_lex_state = 85},
  [3935] = {.lex_state = 472, .external_lex_state = 85},
  [3936] = {.lex_state = 472, .external_lex_state = 85},
  [3937] = {.lex_state = 472, .external_lex_state = 85},
  [3938] = {.lex_state = 472, .external_lex_state = 85},
  [3939] = {.lex_state = 472, .external_lex_state = 85},
  [3940] = {.lex_state = 454, .external_lex_state = 78},
  [3941] = {.lex_state = 472, .external_lex_state = 85},
  [3942] = {.lex_state = 454, .external_lex_state = 78},
  [3943] = {.lex_state = 472, .external_lex_state = 85},
  [3944] = {.lex_state = 472, .external_lex_state = 85},
  [3945] = {.lex_state = 472, .external_lex_state = 85},
  [3946] = {.lex_state = 472, .external_lex_state = 85},
  [3947] = {.lex_state = 472, .external_lex_state = 85},
  [3948] = {.lex_state = 472, .external_lex_state = 85},
  [3949] = {.lex_state = 472, .external_lex_state = 85},
  [3950] = {.lex_state = 472, .external_lex_state = 85},
  [3951] = {.lex_state = 472, .external_lex_state = 85},
  [3952] = {.lex_state = 472, .external_lex_state = 85},
  [3953] = {.lex_state = 454, .external_lex_state = 78},
  [3954] = {.lex_state = 475, .external_lex_state = 88},
  [3955] = {.lex_state = 454, .external_lex_state = 78},
  [3956] = {.lex_state = 472, .external_lex_state = 85},
  [3957] = {.lex_state = 472, .external_lex_state = 85},
  [3958] = {.lex_state = 472, .external_lex_state = 85},
  [3959] = {.lex_state = 472, .external_lex_state = 85},
  [3960] = {.lex_state = 472, .external_lex_state = 85},
  [3961] = {.lex_state = 472, .external_lex_state = 85},
  [3962] = {.lex_state = 454, .external_lex_state = 78},
  [3963] = {.lex_state = 472, .external_lex_state = 85},
  [3964] = {.lex_state = 454, .external_lex_state = 78},
  [3965] = {.lex_state = 472, .external_lex_state = 85},
  [3966] = {.lex_state = 472, .external_lex_state = 85},
  [3967] = {.lex_state = 472, .external_lex_state = 85},
  [3968] = {.lex_state = 454, .external_lex_state = 78},
  [3969] = {.lex_state = 472, .external_lex_state = 85},
  [3970] = {.lex_state = 472, .external_lex_state = 85},
  [3971] = {.lex_state = 472, .external_lex_state = 85},
  [3972] = {.lex_state = 454, .external_lex_state = 78},
  [3973] = {.lex_state = 472, .external_lex_state = 85},
  [3974] = {.lex_state = 472, .external_lex_state = 85},
  [3975] = {.lex_state = 454, .external_lex_state = 78},
  [3976] = {.lex_state = 472, .external_lex_state = 85},
  [3977] = {.lex_state = 472, .external_lex_state = 85},
  [3978] = {.lex_state = 472, .external_lex_state = 85},
  [3979] = {.lex_state = 472, .external_lex_state = 85},
  [3980] = {.lex_state = 472, .external_lex_state = 85},
  [3981] = {.lex_state = 472, .external_lex_state = 85},
  [3982] = {.lex_state = 454, .external_lex_state = 78},
  [3983] = {.lex_state = 472, .external_lex_state = 85},
  [3984] = {.lex_state = 454, .external_lex_state = 78},
  [3985] = {.lex_state = 472, .external_lex_state = 85},
  [3986] = {.lex_state = 472, .external_lex_state = 85},
  [3987] = {.lex_state = 472, .external_lex_state = 85},
  [3988] = {.lex_state = 472, .external_lex_state = 85},
  [3989] = {.lex_state = 472, .external_lex_state = 85},
  [3990] = {.lex_state = 472, .external_lex_state = 85},
  [3991] = {.lex_state = 472, .external_lex_state = 85},
  [3992] = {.lex_state = 454, .external_lex_state = 78},
  [3993] = {.lex_state = 454, .external_lex_state = 78},
  [3994] = {.lex_state = 472, .external_lex_state = 85},
  [3995] = {.lex_state = 472, .external_lex_state = 85},
  [3996] = {.lex_state = 472, .external_lex_state = 85},
  [3997] = {.lex_state = 472, .external_lex_state = 85},
  [3998] = {.lex_state = 454, .external_lex_state = 78},
  [3999] = {.lex_state = 472, .external_lex_state = 85},
  [4000] = {.lex_state = 472, .external_lex_state = 85},
  [4001] = {.lex_state = 454, .external_lex_state = 78},
  [4002] = {.lex_state = 96, .external_lex_state = 89},
  [4003] = {.lex_state = 472, .external_lex_state = 85},
  [4004] = {.lex_state = 472, .external_lex_state = 85},
  [4005] = {.lex_state = 472, .external_lex_state = 85},
  [4006] = {.lex_state = 472, .external_lex_state = 85},
  [4007] = {.lex_state = 472, .external_lex_state = 85},
  [4008] = {.lex_state = 454, .external_lex_state = 78},
  [4009] = {.lex_state = 454, .external_lex_state = 78},
  [4010] = {.lex_state = 472, .external_lex_state = 85},
  [4011] = {.lex_state = 472, .external_lex_state = 85},
  [4012] = {.lex_state = 472, .external_lex_state = 85},
  [4013] = {.lex_state = 454, .external_lex_state = 78},
  [4014] = {.lex_state = 95, .external_lex_state = 86},
  [4015] = {.lex_state = 454, .external_lex_state = 78},
  [4016] = {.lex_state = 472, .external_lex_state = 85},
  [4017] = {.lex_state = 472, .external_lex_state = 85},
  [4018] = {.lex_state = 454, .external_lex_state = 78},
  [4019] = {.lex_state = 472, .external_lex_state = 85},
  [4020] = {.lex_state = 472, .external_lex_state = 85},
  [4021] = {.lex_state = 472, .external_lex_state = 85},
  [4022] = {.lex_state = 454, .external_lex_state = 78},
  [4023] = {.lex_state = 472, .external_lex_state = 85},
  [4024] = {.lex_state = 472, .external_lex_state = 85},
  [4025] = {.lex_state = 95, .external_lex_state = 90},
  [4026] = {.lex_state = 454, .external_lex_state = 78},
  [4027] = {.lex_state = 472, .external_lex_state = 85},
  [4028] = {.lex_state = 454, .external_lex_state = 78},
  [4029] = {.lex_state = 472, .external_lex_state = 85},
  [4030] = {.lex_state = 472, .external_lex_state = 85},
  [4031] = {.lex_state = 472, .external_lex_state = 85},
  [4032] = {.lex_state = 454, .external_lex_state = 78},
  [4033] = {.lex_state = 472, .external_lex_state = 85},
  [4034] = {.lex_state = 454, .external_lex_state = 78},
  [4035] = {.lex_state = 472, .external_lex_state = 85},
  [4036] = {.lex_state = 472, .external_lex_state = 85},
  [4037] = {.lex_state = 472, .external_lex_state = 85},
  [4038] = {.lex_state = 472, .external_lex_state = 85},
  [4039] = {.lex_state = 472, .external_lex_state = 85},
  [4040] = {.lex_state = 472, .external_lex_state = 85},
  [4041] = {.lex_state = 472, .external_lex_state = 85},
  [4042] = {.lex_state = 472, .external_lex_state = 85},
  [4043] = {.lex_state = 472, .external_lex_state = 85},
  [4044] = {.lex_state = 472, .external_lex_state = 85},
  [4045] = {.lex_state = 472, .external_lex_state = 85},
  [4046] = {.lex_state = 472, .external_lex_state = 85},
  [4047] = {.lex_state = 472, .external_lex_state = 85},
  [4048] = {.lex_state = 472, .external_lex_state = 85},
  [4049] = {.lex_state = 454, .external_lex_state = 78},
  [4050] = {.lex_state = 472, .external_lex_state = 85},
  [4051] = {.lex_state = 472, .external_lex_state = 85},
  [4052] = {.lex_state = 472, .external_lex_state = 85},
  [4053] = {.lex_state = 472, .external_lex_state = 85},
  [4054] = {.lex_state = 472, .external_lex_state = 85},
  [4055] = {.lex_state = 472, .external_lex_state = 85},
  [4056] = {.lex_state = 472, .external_lex_state = 85},
  [4057] = {.lex_state = 472, .external_lex_state = 85},
  [4058] = {.lex_state = 472, .external_lex_state = 85},
  [4059] = {.lex_state = 454, .external_lex_state = 78},
  [4060] = {.lex_state = 472, .external_lex_state = 85},
  [4061] = {.lex_state = 472, .external_lex_state = 85},
  [4062] = {.lex_state = 472, .external_lex_state = 85},
  [4063] = {.lex_state = 472, .external_lex_state = 85},
  [4064] = {.lex_state = 472, .external_lex_state = 85},
  [4065] = {.lex_state = 472, .external_lex_state = 85},
  [4066] = {.lex_state = 472, .external_lex_state = 85},
  [4067] = {.lex_state = 472, .external_lex_state = 85},
  [4068] = {.lex_state = 454, .external_lex_state = 78},
  [4069] = {.lex_state = 93, .external_lex_state = 87},
  [4070] = {.lex_state = 472, .external_lex_state = 85},
  [4071] = {.lex_state = 472, .external_lex_state = 85},
  [4072] = {.lex_state = 472, .external_lex_state = 85},
  [4073] = {.lex_state = 472, .external_lex_state = 85},
  [4074] = {.lex_state = 472, .external_lex_state = 85},
  [4075] = {.lex_state = 472, .external_lex_state = 85},
  [4076] = {.lex_state = 472, .external_lex_state = 85},
  [4077] = {.lex_state = 472, .external_lex_state = 85},
  [4078] = {.lex_state = 472, .external_lex_state = 85},
  [4079] = {.lex_state = 472, .external_lex_state = 85},
  [4080] = {.lex_state = 472, .external_lex_state = 85},
  [4081] = {.lex_state = 472, .external_lex_state = 85},
  [4082] = {.lex_state = 472, .external_lex_state = 85},
  [4083] = {.lex_state = 472, .external_lex_state = 85},
  [4084] = {.lex_state = 472, .external_lex_state = 85},
  [4085] = {.lex_state = 472, .external_lex_state = 85},
  [4086] = {.lex_state = 472, .external_lex_state = 85},
  [4087] = {.lex_state = 472, .external_lex_state = 85},
  [4088] = {.lex_state = 472, .external_lex_state = 85},
  [4089] = {.lex_state = 472, .external_lex_state = 85},
  [4090] = {.lex_state = 454, .external_lex_state = 78},
  [4091] = {.lex_state = 472, .external_lex_state = 85},
  [4092] = {.lex_state = 454, .external_lex_state = 78},
  [4093] = {.lex_state = 472, .external_lex_state = 85},
  [4094] = {.lex_state = 454, .external_lex_state = 78},
  [4095] = {.lex_state = 454, .external_lex_state = 78},
  [4096] = {.lex_state = 472, .external_lex_state = 85},
  [4097] = {.lex_state = 472, .external_lex_state = 85},
  [4098] = {.lex_state = 454, .external_lex_state = 78},
  [4099] = {.lex_state = 93, .external_lex_state = 87},
  [4100] = {.lex_state = 472, .external_lex_state = 85},
  [4101] = {.lex_state = 472, .external_lex_state = 85},
  [4102] = {.lex_state = 472, .external_lex_state = 85},
  [4103] = {.lex_state = 472, .external_lex_state = 85},
  [4104] = {.lex_state = 472, .external_lex_state = 85},
  [4105] = {.lex_state = 454, .external_lex_state = 78},
  [4106] = {.lex_state = 472, .external_lex_state = 85},
  [4107] = {.lex_state = 472, .external_lex_state = 85},
  [4108] = {.lex_state = 472, .external_lex_state = 85},
  [4109] = {.lex_state = 472, .external_lex_state = 85},
  [4110] = {.lex_state = 472, .external_lex_state = 85},
  [4111] = {.lex_state = 454, .external_lex_state = 78},
  [4112] = {.lex_state = 472, .external_lex_state = 85},
  [4113] = {.lex_state = 472, .external_lex_state = 85},
  [4114] = {.lex_state = 472, .external_lex_state = 85},
  [4115] = {.lex_state = 472, .external_lex_state = 85},
  [4116] = {.lex_state = 472, .external_lex_state = 85},
  [4117] = {.lex_state = 472, .external_lex_state = 85},
  [4118] = {.lex_state = 472, .external_lex_state = 85},
  [4119] = {.lex_state = 454, .external_lex_state = 78},
  [4120] = {.lex_state = 472, .external_lex_state = 85},
  [4121] = {.lex_state = 454, .external_lex_state = 78},
  [4122] = {.lex_state = 472, .external_lex_state = 85},
  [4123] = {.lex_state = 472, .external_lex_state = 85},
  [4124] = {.lex_state = 454, .external_lex_state = 78},
  [4125] = {.lex_state = 454, .external_lex_state = 78},
  [4126] = {.lex_state = 454, .external_lex_state = 78},
  [4127] = {.lex_state = 93, .external_lex_state = 87},
  [4128] = {.lex_state = 472, .external_lex_state = 85},
  [4129] = {.lex_state = 472, .external_lex_state = 85},
  [4130] = {.lex_state = 472, .external_lex_state = 85},
  [4131] = {.lex_state = 472, .external_lex_state = 85},
  [4132] = {.lex_state = 454, .external_lex_state = 78},
  [4133] = {.lex_state = 95, .external_lex_state = 90},
  [4134] = {.lex_state = 95, .external_lex_state = 91},
  [4135] = {.lex_state = 95, .external_lex_state = 90},
  [4136] = {.lex_state = 96, .external_lex_state = 89},
  [4137] = {.lex_state = 96, .external_lex_state = 89},
  [4138] = {.lex_state = 95, .external_lex_state = 90},
  [4139] = {.lex_state = 96, .external_lex_state = 64},
  [4140] = {.lex_state = 95, .external_lex_state = 92},
  [4141] = {.lex_state = 95, .external_lex_state = 86},
  [4142] = {.lex_state = 95, .external_lex_state = 90},
  [4143] = {.lex_state = 96, .external_lex_state = 89},
  [4144] = {.lex_state = 96, .external_lex_state = 93},
  [4145] = {.lex_state = 513, .external_lex_state = 91},
  [4146] = {.lex_state = 95, .external_lex_state = 92},
  [4147] = {.lex_state = 95, .external_lex_state = 90},
  [4148] = {.lex_state = 96, .external_lex_state = 89},
  [4149] = {.lex_state = 93, .external_lex_state = 87},
  [4150] = {.lex_state = 95, .external_lex_state = 92},
  [4151] = {.lex_state = 93, .external_lex_state = 87},
  [4152] = {.lex_state = 95, .external_lex_state = 86},
  [4153] = {.lex_state = 95, .external_lex_state = 92},
  [4154] = {.lex_state = 93, .external_lex_state = 87},
  [4155] = {.lex_state = 96, .external_lex_state = 90},
  [4156] = {.lex_state = 515, .external_lex_state = 93},
  [4157] = {.lex_state = 95, .external_lex_state = 90},
  [4158] = {.lex_state = 95, .external_lex_state = 90},
  [4159] = {.lex_state = 96, .external_lex_state = 64},
  [4160] = {.lex_state = 267, .external_lex_state = 94},
  [4161] = {.lex_state = 95, .external_lex_state = 90},
  [4162] = {.lex_state = 95, .external_lex_state = 90},
  [4163] = {.lex_state = 96, .external_lex_state = 89},
  [4164] = {.lex_state = 267, .external_lex_state = 94},
  [4165] = {.lex_state = 95, .external_lex_state = 90},
  [4166] = {.lex_state = 95, .external_lex_state = 90},
  [4167] = {.lex_state = 96, .external_lex_state = 89},
  [4168] = {.lex_state = 96, .external_lex_state = 90},
  [4169] = {.lex_state = 515, .external_lex_state = 93},
  [4170] = {.lex_state = 95, .external_lex_state = 90},
  [4171] = {.lex_state = 96, .external_lex_state = 89},
  [4172] = {.lex_state = 513, .external_lex_state = 92},
  [4173] = {.lex_state = 513, .external_lex_state = 91},
  [4174] = {.lex_state = 96, .external_lex_state = 67},
  [4175] = {.lex_state = 95, .external_lex_state = 86},
  [4176] = {.lex_state = 513, .external_lex_state = 91},
  [4177] = {.lex_state = 513, .external_lex_state = 91},
  [4178] = {.lex_state = 96, .external_lex_state = 89},
  [4179] = {.lex_state = 96, .external_lex_state = 90},
  [4180] = {.lex_state = 96, .external_lex_state = 86},
  [4181] = {.lex_state = 96, .external_lex_state = 64},
  [4182] = {.lex_state = 96, .external_lex_state = 86},
  [4183] = {.lex_state = 513, .external_lex_state = 91},
  [4184] = {.lex_state = 475, .external_lex_state = 95},
  [4185] = {.lex_state = 513, .external_lex_state = 91},
  [4186] = {.lex_state = 95, .external_lex_state = 86},
  [4187] = {.lex_state = 515, .external_lex_state = 93},
  [4188] = {.lex_state = 513, .external_lex_state = 91},
  [4189] = {.lex_state = 95, .external_lex_state = 90},
  [4190] = {.lex_state = 513, .external_lex_state = 91},
  [4191] = {.lex_state = 513, .external_lex_state = 91},
  [4192] = {.lex_state = 513, .external_lex_state = 91},
  [4193] = {.lex_state = 95, .external_lex_state = 91},
  [4194] = {.lex_state = 96, .external_lex_state = 90},
  [4195] = {.lex_state = 513, .external_lex_state = 91},
  [4196] = {.lex_state = 95, .external_lex_state = 90},
  [4197] = {.lex_state = 96, .external_lex_state = 89},
  [4198] = {.lex_state = 95, .external_lex_state = 86},
  [4199] = {.lex_state = 96, .external_lex_state = 89},
  [4200] = {.lex_state = 96, .external_lex_state = 89},
  [4201] = {.lex_state = 515, .external_lex_state = 93},
  [4202] = {.lex_state = 513, .external_lex_state = 92},
  [4203] = {.lex_state = 96, .external_lex_state = 89},
  [4204] = {.lex_state = 96, .external_lex_state = 90},
  [4205] = {.lex_state = 96, .external_lex_state = 67},
  [4206] = {.lex_state = 95, .external_lex_state = 90},
  [4207] = {.lex_state = 513, .external_lex_state = 91},
  [4208] = {.lex_state = 513, .external_lex_state = 91},
  [4209] = {.lex_state = 513, .external_lex_state = 91},
  [4210] = {.lex_state = 95, .external_lex_state = 91},
  [4211] = {.lex_state = 514, .external_lex_state = 92},
  [4212] = {.lex_state = 96, .external_lex_state = 93},
  [4213] = {.lex_state = 514, .external_lex_state = 92},
  [4214] = {.lex_state = 515, .external_lex_state = 91},
  [4215] = {.lex_state = 475, .external_lex_state = 95},
  [4216] = {.lex_state = 95, .external_lex_state = 90},
  [4217] = {.lex_state = 95, .external_lex_state = 92},
  [4218] = {.lex_state = 513, .external_lex_state = 91},
  [4219] = {.lex_state = 515, .external_lex_state = 93},
  [4220] = {.lex_state = 515, .external_lex_state = 93},
  [4221] = {.lex_state = 96, .external_lex_state = 90},
  [4222] = {.lex_state = 96, .external_lex_state = 93},
  [4223] = {.lex_state = 516, .external_lex_state = 67},
  [4224] = {.lex_state = 96, .external_lex_state = 89},
  [4225] = {.lex_state = 513, .external_lex_state = 92},
  [4226] = {.lex_state = 95, .external_lex_state = 90},
  [4227] = {.lex_state = 513, .external_lex_state = 91},
  [4228] = {.lex_state = 515, .external_lex_state = 93},
  [4229] = {.lex_state = 513, .external_lex_state = 91},
  [4230] = {.lex_state = 96, .external_lex_state = 91},
  [4231] = {.lex_state = 515, .external_lex_state = 93},
  [4232] = {.lex_state = 95, .external_lex_state = 90},
  [4233] = {.lex_state = 96, .external_lex_state = 86},
  [4234] = {.lex_state = 95, .external_lex_state = 91},
  [4235] = {.lex_state = 96, .external_lex_state = 90},
  [4236] = {.lex_state = 514, .external_lex_state = 92},
  [4237] = {.lex_state = 96, .external_lex_state = 93},
  [4238] = {.lex_state = 96, .external_lex_state = 86},
  [4239] = {.lex_state = 95, .external_lex_state = 91},
  [4240] = {.lex_state = 95, .external_lex_state = 90},
  [4241] = {.lex_state = 96, .external_lex_state = 89},
  [4242] = {.lex_state = 96, .external_lex_state = 89},
  [4243] = {.lex_state = 515, .external_lex_state = 93},
  [4244] = {.lex_state = 96, .external_lex_state = 93},
  [4245] = {.lex_state = 95, .external_lex_state = 86},
  [4246] = {.lex_state = 95, .external_lex_state = 92},
  [4247] = {.lex_state = 95, .external_lex_state = 91},
  [4248] = {.lex_state = 95, .external_lex_state = 90},
  [4249] = {.lex_state = 515, .external_lex_state = 93},
  [4250] = {.lex_state = 96, .external_lex_state = 89},
  [4251] = {.lex_state = 95, .external_lex_state = 91},
  [4252] = {.lex_state = 95, .external_lex_state = 90},
  [4253] = {.lex_state = 95, .external_lex_state = 86},
  [4254] = {.lex_state = 95, .external_lex_state = 91},
  [4255] = {.lex_state = 513, .external_lex_state = 91},
  [4256] = {.lex_state = 96, .external_lex_state = 90},
  [4257] = {.lex_state = 95, .external_lex_state = 90},
  [4258] = {.lex_state = 96, .external_lex_state = 90},
  [4259] = {.lex_state = 96, .external_lex_state = 89},
  [4260] = {.lex_state = 514, .external_lex_state = 92},
  [4261] = {.lex_state = 515, .external_lex_state = 93},
  [4262] = {.lex_state = 95, .external_lex_state = 91},
  [4263] = {.lex_state = 513, .external_lex_state = 91},
  [4264] = {.lex_state = 96, .external_lex_state = 89},
  [4265] = {.lex_state = 514, .external_lex_state = 92},
  [4266] = {.lex_state = 515, .external_lex_state = 93},
  [4267] = {.lex_state = 515, .external_lex_state = 93},
  [4268] = {.lex_state = 96, .external_lex_state = 90},
  [4269] = {.lex_state = 96, .external_lex_state = 86},
  [4270] = {.lex_state = 515, .external_lex_state = 93},
  [4271] = {.lex_state = 515, .external_lex_state = 93},
  [4272] = {.lex_state = 513, .external_lex_state = 92},
  [4273] = {.lex_state = 96, .external_lex_state = 89},
  [4274] = {.lex_state = 475, .external_lex_state = 95},
  [4275] = {.lex_state = 475, .external_lex_state = 95},
  [4276] = {.lex_state = 95, .external_lex_state = 90},
  [4277] = {.lex_state = 515, .external_lex_state = 93},
  [4278] = {.lex_state = 96, .external_lex_state = 89},
  [4279] = {.lex_state = 513, .external_lex_state = 92},
  [4280] = {.lex_state = 515, .external_lex_state = 93},
  [4281] = {.lex_state = 96, .external_lex_state = 93},
  [4282] = {.lex_state = 515, .external_lex_state = 93},
  [4283] = {.lex_state = 515, .external_lex_state = 93},
  [4284] = {.lex_state = 513, .external_lex_state = 91},
  [4285] = {.lex_state = 513, .external_lex_state = 92},
  [4286] = {.lex_state = 95, .external_lex_state = 86},
  [4287] = {.lex_state = 514, .external_lex_state = 92},
  [4288] = {.lex_state = 95, .external_lex_state = 86},
  [4289] = {.lex_state = 515, .external_lex_state = 93},
  [4290] = {.lex_state = 513, .external_lex_state = 91},
  [4291] = {.lex_state = 95, .external_lex_state = 86},
  [4292] = {.lex_state = 95, .external_lex_state = 91},
  [4293] = {.lex_state = 96, .external_lex_state = 86},
  [4294] = {.lex_state = 516, .external_lex_state = 67},
  [4295] = {.lex_state = 95, .external_lex_state = 90},
  [4296] = {.lex_state = 96, .external_lex_state = 89},
  [4297] = {.lex_state = 95, .external_lex_state = 91},
  [4298] = {.lex_state = 95, .external_lex_state = 90},
  [4299] = {.lex_state = 513, .external_lex_state = 91},
  [4300] = {.lex_state = 95, .external_lex_state = 91},
  [4301] = {.lex_state = 95, .external_lex_state = 90},
  [4302] = {.lex_state = 513, .external_lex_state = 91},
  [4303] = {.lex_state = 515, .external_lex_state = 93},
  [4304] = {.lex_state = 95, .external_lex_state = 90},
  [4305] = {.lex_state = 514, .external_lex_state = 92},
  [4306] = {.lex_state = 95, .external_lex_state = 90},
  [4307] = {.lex_state = 514, .external_lex_state = 92},
  [4308] = {.lex_state = 96, .external_lex_state = 89},
  [4309] = {.lex_state = 515, .external_lex_state = 93},
  [4310] = {.lex_state = 513, .external_lex_state = 92},
  [4311] = {.lex_state = 96, .external_lex_state = 90},
  [4312] = {.lex_state = 96, .external_lex_state = 89},
  [4313] = {.lex_state = 513, .external_lex_state = 92},
  [4314] = {.lex_state = 95, .external_lex_state = 90},
  [4315] = {.lex_state = 96, .external_lex_state = 90},
  [4316] = {.lex_state = 515, .external_lex_state = 93},
  [4317] = {.lex_state = 96, .external_lex_state = 64},
  [4318] = {.lex_state = 514, .external_lex_state = 92},
  [4319] = {.lex_state = 96, .external_lex_state = 89},
  [4320] = {.lex_state = 95, .external_lex_state = 90},
  [4321] = {.lex_state = 513, .external_lex_state = 92},
  [4322] = {.lex_state = 513, .external_lex_state = 91},
  [4323] = {.lex_state = 513, .external_lex_state = 91},
  [4324] = {.lex_state = 96, .external_lex_state = 91},
  [4325] = {.lex_state = 96, .external_lex_state = 91},
  [4326] = {.lex_state = 96, .external_lex_state = 91},
  [4327] = {.lex_state = 96, .external_lex_state = 90},
  [4328] = {.lex_state = 96, .external_lex_state = 90},
  [4329] = {.lex_state = 513, .external_lex_state = 91},
  [4330] = {.lex_state = 95, .external_lex_state = 92},
  [4331] = {.lex_state = 96, .external_lex_state = 91},
  [4332] = {.lex_state = 96, .external_lex_state = 90},
  [4333] = {.lex_state = 513, .external_lex_state = 92},
  [4334] = {.lex_state = 515, .external_lex_state = 67},
  [4335] = {.lex_state = 513, .external_lex_state = 92},
  [4336] = {.lex_state = 95, .external_lex_state = 92},
  [4337] = {.lex_state = 513, .external_lex_state = 92},
  [4338] = {.lex_state = 95, .external_lex_state = 91},
  [4339] = {.lex_state = 95, .external_lex_state = 91},
  [4340] = {.lex_state = 96, .external_lex_state = 91},
  [4341] = {.lex_state = 515, .external_lex_state = 67},
  [4342] = {.lex_state = 513, .external_lex_state = 91},
  [4343] = {.lex_state = 96, .external_lex_state = 91},
  [4344] = {.lex_state = 515, .external_lex_state = 93},
  [4345] = {.lex_state = 515, .external_lex_state = 93},
  [4346] = {.lex_state = 96, .external_lex_state = 86},
  [4347] = {.lex_state = 95, .external_lex_state = 92},
  [4348] = {.lex_state = 516, .external_lex_state = 92},
  [4349] = {.lex_state = 515, .external_lex_state = 91},
  [4350] = {.lex_state = 95, .external_lex_state = 92},
  [4351] = {.lex_state = 515, .external_lex_state = 91},
  [4352] = {.lex_state = 515, .external_lex_state = 91},
  [4353] = {.lex_state = 516, .external_lex_state = 92},
  [4354] = {.lex_state = 96, .external_lex_state = 91},
  [4355] = {.lex_state = 95, .external_lex_state = 91},
  [4356] = {.lex_state = 96, .external_lex_state = 86},
  [4357] = {.lex_state = 515, .external_lex_state = 91},
  [4358] = {.lex_state = 96, .external_lex_state = 92},
  [4359] = {.lex_state = 515, .external_lex_state = 91},
  [4360] = {.lex_state = 96, .external_lex_state = 93},
  [4361] = {.lex_state = 96, .external_lex_state = 92},
  [4362] = {.lex_state = 96, .external_lex_state = 93},
  [4363] = {.lex_state = 514, .external_lex_state = 92},
  [4364] = {.lex_state = 515, .external_lex_state = 91},
  [4365] = {.lex_state = 513, .external_lex_state = 92},
  [4366] = {.lex_state = 95, .external_lex_state = 91},
  [4367] = {.lex_state = 515, .external_lex_state = 91},
  [4368] = {.lex_state = 516, .external_lex_state = 92},
  [4369] = {.lex_state = 515, .external_lex_state = 91},
  [4370] = {.lex_state = 513, .external_lex_state = 91},
  [4371] = {.lex_state = 516, .external_lex_state = 92},
  [4372] = {.lex_state = 95, .external_lex_state = 91},
  [4373] = {.lex_state = 515, .external_lex_state = 93},
  [4374] = {.lex_state = 513, .external_lex_state = 91},
  [4375] = {.lex_state = 515, .external_lex_state = 93},
  [4376] = {.lex_state = 516, .external_lex_state = 92},
  [4377] = {.lex_state = 95, .external_lex_state = 91},
  [4378] = {.lex_state = 515, .external_lex_state = 93},
  [4379] = {.lex_state = 513, .external_lex_state = 92},
  [4380] = {.lex_state = 96, .external_lex_state = 93},
  [4381] = {.lex_state = 96, .external_lex_state = 90},
  [4382] = {.lex_state = 513, .external_lex_state = 91},
  [4383] = {.lex_state = 96, .external_lex_state = 90},
  [4384] = {.lex_state = 95, .external_lex_state = 91},
  [4385] = {.lex_state = 95, .external_lex_state = 91},
  [4386] = {.lex_state = 96, .external_lex_state = 90},
  [4387] = {.lex_state = 96, .external_lex_state = 92},
  [4388] = {.lex_state = 96, .external_lex_state = 92},
  [4389] = {.lex_state = 96, .external_lex_state = 90},
  [4390] = {.lex_state = 96, .external_lex_state = 92},
  [4391] = {.lex_state = 96, .external_lex_state = 93},
  [4392] = {.lex_state = 515, .external_lex_state = 91},
  [4393] = {.lex_state = 96, .external_lex_state = 93},
  [4394] = {.lex_state = 515, .external_lex_state = 91},
  [4395] = {.lex_state = 515, .external_lex_state = 91},
  [4396] = {.lex_state = 514, .external_lex_state = 92},
  [4397] = {.lex_state = 96, .external_lex_state = 90},
  [4398] = {.lex_state = 515, .external_lex_state = 91},
  [4399] = {.lex_state = 96, .external_lex_state = 90},
  [4400] = {.lex_state = 95, .external_lex_state = 92},
  [4401] = {.lex_state = 96, .external_lex_state = 93},
  [4402] = {.lex_state = 515, .external_lex_state = 91},
  [4403] = {.lex_state = 95, .external_lex_state = 91},
  [4404] = {.lex_state = 96, .external_lex_state = 91},
  [4405] = {.lex_state = 96, .external_lex_state = 86},
  [4406] = {.lex_state = 515, .external_lex_state = 91},
  [4407] = {.lex_state = 96, .external_lex_state = 67},
  [4408] = {.lex_state = 515, .external_lex_state = 91},
  [4409] = {.lex_state = 514, .external_lex_state = 92},
  [4410] = {.lex_state = 96, .external_lex_state = 90},
  [4411] = {.lex_state = 515, .external_lex_state = 91},
  [4412] = {.lex_state = 96, .external_lex_state = 92},
  [4413] = {.lex_state = 96, .external_lex_state = 93},
  [4414] = {.lex_state = 96, .external_lex_state = 91},
  [4415] = {.lex_state = 515, .external_lex_state = 91},
  [4416] = {.lex_state = 96, .external_lex_state = 90},
  [4417] = {.lex_state = 95, .external_lex_state = 91},
  [4418] = {.lex_state = 95, .external_lex_state = 91},
  [4419] = {.lex_state = 96, .external_lex_state = 86},
  [4420] = {.lex_state = 95, .external_lex_state = 92},
  [4421] = {.lex_state = 515, .external_lex_state = 91},
  [4422] = {.lex_state = 515, .external_lex_state = 93},
  [4423] = {.lex_state = 96, .external_lex_state = 93},
  [4424] = {.lex_state = 515, .external_lex_state = 91},
  [4425] = {.lex_state = 515, .external_lex_state = 91},
  [4426] = {.lex_state = 515, .external_lex_state = 91},
  [4427] = {.lex_state = 96, .external_lex_state = 90},
  [4428] = {.lex_state = 96, .external_lex_state = 93},
  [4429] = {.lex_state = 96, .external_lex_state = 86},
  [4430] = {.lex_state = 515, .external_lex_state = 91},
  [4431] = {.lex_state = 513, .external_lex_state = 91},
  [4432] = {.lex_state = 513, .external_lex_state = 91},
  [4433] = {.lex_state = 96, .external_lex_state = 90},
  [4434] = {.lex_state = 96, .external_lex_state = 93},
  [4435] = {.lex_state = 96, .external_lex_state = 93},
  [4436] = {.lex_state = 515, .external_lex_state = 67},
  [4437] = {.lex_state = 513, .external_lex_state = 92},
  [4438] = {.lex_state = 515, .external_lex_state = 67},
  [4439] = {.lex_state = 513, .external_lex_state = 92},
  [4440] = {.lex_state = 513, .external_lex_state = 91},
  [4441] = {.lex_state = 513, .external_lex_state = 91},
  [4442] = {.lex_state = 96, .external_lex_state = 67},
  [4443] = {.lex_state = 95, .external_lex_state = 91},
  [4444] = {.lex_state = 95, .external_lex_state = 91},
  [4445] = {.lex_state = 95, .external_lex_state = 91},
  [4446] = {.lex_state = 95, .external_lex_state = 91},
  [4447] = {.lex_state = 95, .external_lex_state = 91},
  [4448] = {.lex_state = 96, .external_lex_state = 93},
  [4449] = {.lex_state = 96, .external_lex_state = 93},
  [4450] = {.lex_state = 96, .external_lex_state = 93},
  [4451] = {.lex_state = 96, .external_lex_state = 93},
  [4452] = {.lex_state = 95, .external_lex_state = 92},
  [4453] = {.lex_state = 513, .external_lex_state = 91},
  [4454] = {.lex_state = 513, .external_lex_state = 91},
  [4455] = {.lex_state = 513, .external_lex_state = 91},
  [4456] = {.lex_state = 513, .external_lex_state = 91},
  [4457] = {.lex_state = 96, .external_lex_state = 93},
  [4458] = {.lex_state = 513, .external_lex_state = 91},
  [4459] = {.lex_state = 513, .external_lex_state = 91},
  [4460] = {.lex_state = 513, .external_lex_state = 91},
  [4461] = {.lex_state = 513, .external_lex_state = 91},
  [4462] = {.lex_state = 95, .external_lex_state = 91},
  [4463] = {.lex_state = 95, .external_lex_state = 91},
  [4464] = {.lex_state = 95, .external_lex_state = 91},
  [4465] = {.lex_state = 95, .external_lex_state = 86},
  [4466] = {.lex_state = 96, .external_lex_state = 90},
  [4467] = {.lex_state = 96, .external_lex_state = 90},
  [4468] = {.lex_state = 96, .external_lex_state = 90},
  [4469] = {.lex_state = 96, .external_lex_state = 90},
  [4470] = {.lex_state = 96, .external_lex_state = 93},
  [4471] = {.lex_state = 96, .external_lex_state = 93},
  [4472] = {.lex_state = 96, .external_lex_state = 93},
  [4473] = {.lex_state = 475, .external_lex_state = 72},
  [4474] = {.lex_state = 475, .external_lex_state = 72},
  [4475] = {.lex_state = 513, .external_lex_state = 91},
  [4476] = {.lex_state = 513, .external_lex_state = 91},
  [4477] = {.lex_state = 515, .external_lex_state = 93},
  [4478] = {.lex_state = 95, .external_lex_state = 92},
  [4479] = {.lex_state = 515, .external_lex_state = 93},
  [4480] = {.lex_state = 475, .external_lex_state = 72},
  [4481] = {.lex_state = 475, .external_lex_state = 72},
  [4482] = {.lex_state = 513, .external_lex_state = 91},
  [4483] = {.lex_state = 96, .external_lex_state = 90},
  [4484] = {.lex_state = 96, .external_lex_state = 90},
  [4485] = {.lex_state = 513, .external_lex_state = 92},
  [4486] = {.lex_state = 96, .external_lex_state = 64},
  [4487] = {.lex_state = 96, .external_lex_state = 91},
  [4488] = {.lex_state = 515, .external_lex_state = 93},
  [4489] = {.lex_state = 96, .external_lex_state = 91},
  [4490] = {.lex_state = 515, .external_lex_state = 93},
  [4491] = {.lex_state = 513, .external_lex_state = 91},
  [4492] = {.lex_state = 516, .external_lex_state = 67},
  [4493] = {.lex_state = 516, .external_lex_state = 67},
  [4494] = {.lex_state = 513, .external_lex_state = 91},
  [4495] = {.lex_state = 513, .external_lex_state = 91},
  [4496] = {.lex_state = 513, .external_lex_state = 91},
  [4497] = {.lex_state = 513, .external_lex_state = 91},
  [4498] = {.lex_state = 513, .external_lex_state = 91},
  [4499] = {.lex_state = 513, .external_lex_state = 91},
  [4500] = {.lex_state = 513, .external_lex_state = 91},
  [4501] = {.lex_state = 513, .external_lex_state = 91},
  [4502] = {.lex_state = 515, .external_lex_state = 93},
  [4503] = {.lex_state = 515, .external_lex_state = 93},
  [4504] = {.lex_state = 513, .external_lex_state = 92},
  [4505] = {.lex_state = 516, .external_lex_state = 67},
  [4506] = {.lex_state = 515, .external_lex_state = 93},
  [4507] = {.lex_state = 515, .external_lex_state = 91},
  [4508] = {.lex_state = 468, .external_lex_state = 96},
  [4509] = {.lex_state = 514, .external_lex_state = 92},
  [4510] = {.lex_state = 96, .external_lex_state = 91},
  [4511] = {.lex_state = 96, .external_lex_state = 91},
  [4512] = {.lex_state = 96, .external_lex_state = 91},
  [4513] = {.lex_state = 516, .external_lex_state = 92},
  [4514] = {.lex_state = 95, .external_lex_state = 86},
  [4515] = {.lex_state = 516, .external_lex_state = 67},
  [4516] = {.lex_state = 515, .external_lex_state = 92},
  [4517] = {.lex_state = 515, .external_lex_state = 93},
  [4518] = {.lex_state = 514, .external_lex_state = 92},
  [4519] = {.lex_state = 514, .external_lex_state = 92},
  [4520] = {.lex_state = 468, .external_lex_state = 96},
  [4521] = {.lex_state = 515, .external_lex_state = 91},
  [4522] = {.lex_state = 514, .external_lex_state = 92},
  [4523] = {.lex_state = 515, .external_lex_state = 91},
  [4524] = {.lex_state = 514, .external_lex_state = 92},
  [4525] = {.lex_state = 96, .external_lex_state = 86},
  [4526] = {.lex_state = 515, .external_lex_state = 92},
  [4527] = {.lex_state = 515, .external_lex_state = 91},
  [4528] = {.lex_state = 514, .external_lex_state = 92},
  [4529] = {.lex_state = 513, .external_lex_state = 92},
  [4530] = {.lex_state = 515, .external_lex_state = 91},
  [4531] = {.lex_state = 513, .external_lex_state = 92},
  [4532] = {.lex_state = 96, .external_lex_state = 64},
  [4533] = {.lex_state = 515, .external_lex_state = 92},
  [4534] = {.lex_state = 513, .external_lex_state = 92},
  [4535] = {.lex_state = 515, .external_lex_state = 91},
  [4536] = {.lex_state = 95, .external_lex_state = 86},
  [4537] = {.lex_state = 513, .external_lex_state = 92},
  [4538] = {.lex_state = 96, .external_lex_state = 91},
  [4539] = {.lex_state = 96, .external_lex_state = 91},
  [4540] = {.lex_state = 96, .external_lex_state = 91},
  [4541] = {.lex_state = 95, .external_lex_state = 86},
  [4542] = {.lex_state = 96, .external_lex_state = 91},
  [4543] = {.lex_state = 95, .external_lex_state = 86},
  [4544] = {.lex_state = 514, .external_lex_state = 92},
  [4545] = {.lex_state = 96, .external_lex_state = 91},
  [4546] = {.lex_state = 96, .external_lex_state = 86},
  [4547] = {.lex_state = 96, .external_lex_state = 67},
  [4548] = {.lex_state = 96, .external_lex_state = 86},
  [4549] = {.lex_state = 514, .external_lex_state = 92},
  [4550] = {.lex_state = 514, .external_lex_state = 92},
  [4551] = {.lex_state = 514, .external_lex_state = 92},
  [4552] = {.lex_state = 95, .external_lex_state = 86},
  [4553] = {.lex_state = 515, .external_lex_state = 92},
  [4554] = {.lex_state = 513, .external_lex_state = 92},
  [4555] = {.lex_state = 515, .external_lex_state = 92},
  [4556] = {.lex_state = 513, .external_lex_state = 92},
  [4557] = {.lex_state = 514, .external_lex_state = 92},
  [4558] = {.lex_state = 96, .external_lex_state = 91},
  [4559] = {.lex_state = 96, .external_lex_state = 91},
  [4560] = {.lex_state = 96, .external_lex_state = 91},
  [4561] = {.lex_state = 514, .external_lex_state = 92},
  [4562] = {.lex_state = 516, .external_lex_state = 92},
  [4563] = {.lex_state = 468, .external_lex_state = 96},
  [4564] = {.lex_state = 95, .external_lex_state = 86},
  [4565] = {.lex_state = 96, .external_lex_state = 91},
  [4566] = {.lex_state = 96, .external_lex_state = 91},
  [4567] = {.lex_state = 515, .external_lex_state = 91},
  [4568] = {.lex_state = 515, .external_lex_state = 91},
  [4569] = {.lex_state = 515, .external_lex_state = 91},
  [4570] = {.lex_state = 515, .external_lex_state = 91},
  [4571] = {.lex_state = 515, .external_lex_state = 91},
  [4572] = {.lex_state = 515, .external_lex_state = 91},
  [4573] = {.lex_state = 515, .external_lex_state = 91},
  [4574] = {.lex_state = 515, .external_lex_state = 91},
  [4575] = {.lex_state = 95, .external_lex_state = 86},
  [4576] = {.lex_state = 514, .external_lex_state = 92},
  [4577] = {.lex_state = 297, .external_lex_state = 97},
  [4578] = {.lex_state = 96, .external_lex_state = 91},
  [4579] = {.lex_state = 95, .external_lex_state = 86},
  [4580] = {.lex_state = 95, .external_lex_state = 86},
  [4581] = {.lex_state = 96, .external_lex_state = 86},
  [4582] = {.lex_state = 297, .external_lex_state = 97},
  [4583] = {.lex_state = 96, .external_lex_state = 91},
  [4584] = {.lex_state = 516, .external_lex_state = 92},
  [4585] = {.lex_state = 514, .external_lex_state = 92},
  [4586] = {.lex_state = 514, .external_lex_state = 92},
  [4587] = {.lex_state = 515, .external_lex_state = 92},
  [4588] = {.lex_state = 513, .external_lex_state = 92},
  [4589] = {.lex_state = 515, .external_lex_state = 92},
  [4590] = {.lex_state = 516, .external_lex_state = 92},
  [4591] = {.lex_state = 297, .external_lex_state = 97},
  [4592] = {.lex_state = 516, .external_lex_state = 92},
  [4593] = {.lex_state = 514, .external_lex_state = 92},
  [4594] = {.lex_state = 516, .external_lex_state = 92},
  [4595] = {.lex_state = 96, .external_lex_state = 91},
  [4596] = {.lex_state = 96, .external_lex_state = 92},
  [4597] = {.lex_state = 515, .external_lex_state = 92},
  [4598] = {.lex_state = 96, .external_lex_state = 92},
  [4599] = {.lex_state = 513, .external_lex_state = 92},
  [4600] = {.lex_state = 468, .external_lex_state = 96},
  [4601] = {.lex_state = 516, .external_lex_state = 92},
  [4602] = {.lex_state = 515, .external_lex_state = 93},
  [4603] = {.lex_state = 515, .external_lex_state = 93},
  [4604] = {.lex_state = 96, .external_lex_state = 64},
  [4605] = {.lex_state = 515, .external_lex_state = 67},
  [4606] = {.lex_state = 515, .external_lex_state = 67},
  [4607] = {.lex_state = 96, .external_lex_state = 92},
  [4608] = {.lex_state = 516, .external_lex_state = 67},
  [4609] = {.lex_state = 514, .external_lex_state = 92},
  [4610] = {.lex_state = 297, .external_lex_state = 97},
  [4611] = {.lex_state = 96, .external_lex_state = 86},
  [4612] = {.lex_state = 516, .external_lex_state = 92},
  [4613] = {.lex_state = 514, .external_lex_state = 92},
  [4614] = {.lex_state = 297, .external_lex_state = 97},
  [4615] = {.lex_state = 96, .external_lex_state = 86},
  [4616] = {.lex_state = 95, .external_lex_state = 86},
  [4617] = {.lex_state = 515, .external_lex_state = 92},
  [4618] = {.lex_state = 515, .external_lex_state = 91},
  [4619] = {.lex_state = 513, .external_lex_state = 91},
  [4620] = {.lex_state = 513, .external_lex_state = 91},
  [4621] = {.lex_state = 96, .external_lex_state = 64},
  [4622] = {.lex_state = 95, .external_lex_state = 86},
  [4623] = {.lex_state = 468, .external_lex_state = 96},
  [4624] = {.lex_state = 513, .external_lex_state = 91},
  [4625] = {.lex_state = 513, .external_lex_state = 91},
  [4626] = {.lex_state = 513, .external_lex_state = 91},
  [4627] = {.lex_state = 513, .external_lex_state = 91},
  [4628] = {.lex_state = 95, .external_lex_state = 86},
  [4629] = {.lex_state = 513, .external_lex_state = 91},
  [4630] = {.lex_state = 513, .external_lex_state = 91},
  [4631] = {.lex_state = 513, .external_lex_state = 91},
  [4632] = {.lex_state = 513, .external_lex_state = 91},
  [4633] = {.lex_state = 515, .external_lex_state = 91},
  [4634] = {.lex_state = 95, .external_lex_state = 86},
  [4635] = {.lex_state = 515, .external_lex_state = 91},
  [4636] = {.lex_state = 515, .external_lex_state = 91},
  [4637] = {.lex_state = 515, .external_lex_state = 91},
  [4638] = {.lex_state = 514, .external_lex_state = 92},
  [4639] = {.lex_state = 95, .external_lex_state = 86},
  [4640] = {.lex_state = 96, .external_lex_state = 92},
  [4641] = {.lex_state = 515, .external_lex_state = 91},
  [4642] = {.lex_state = 96, .external_lex_state = 91},
  [4643] = {.lex_state = 95, .external_lex_state = 86},
  [4644] = {.lex_state = 468, .external_lex_state = 96},
  [4645] = {.lex_state = 515, .external_lex_state = 92},
  [4646] = {.lex_state = 515, .external_lex_state = 91},
  [4647] = {.lex_state = 96, .external_lex_state = 91},
  [4648] = {.lex_state = 514, .external_lex_state = 92},
  [4649] = {.lex_state = 515, .external_lex_state = 91},
  [4650] = {.lex_state = 515, .external_lex_state = 91},
  [4651] = {.lex_state = 515, .external_lex_state = 91},
  [4652] = {.lex_state = 515, .external_lex_state = 91},
  [4653] = {.lex_state = 515, .external_lex_state = 91},
  [4654] = {.lex_state = 515, .external_lex_state = 91},
  [4655] = {.lex_state = 515, .external_lex_state = 91},
  [4656] = {.lex_state = 515, .external_lex_state = 91},
  [4657] = {.lex_state = 95, .external_lex_state = 86},
  [4658] = {.lex_state = 95, .external_lex_state = 86},
  [4659] = {.lex_state = 96, .external_lex_state = 91},
  [4660] = {.lex_state = 468, .external_lex_state = 96},
  [4661] = {.lex_state = 297, .external_lex_state = 97},
  [4662] = {.lex_state = 96, .external_lex_state = 92},
  [4663] = {.lex_state = 95, .external_lex_state = 86},
  [4664] = {.lex_state = 95, .external_lex_state = 92},
  [4665] = {.lex_state = 514, .external_lex_state = 92},
  [4666] = {.lex_state = 515, .external_lex_state = 92},
  [4667] = {.lex_state = 515, .external_lex_state = 91},
  [4668] = {.lex_state = 516, .external_lex_state = 67},
  [4669] = {.lex_state = 515, .external_lex_state = 92},
  [4670] = {.lex_state = 515, .external_lex_state = 93},
  [4671] = {.lex_state = 468, .external_lex_state = 96},
  [4672] = {.lex_state = 515, .external_lex_state = 91},
  [4673] = {.lex_state = 468, .external_lex_state = 96},
  [4674] = {.lex_state = 96, .external_lex_state = 86},
  [4675] = {.lex_state = 468, .external_lex_state = 96},
  [4676] = {.lex_state = 450, .external_lex_state = 98},
  [4677] = {.lex_state = 297, .external_lex_state = 97},
  [4678] = {.lex_state = 516, .external_lex_state = 92},
  [4679] = {.lex_state = 450, .external_lex_state = 98},
  [4680] = {.lex_state = 516, .external_lex_state = 92},
  [4681] = {.lex_state = 516, .external_lex_state = 92},
  [4682] = {.lex_state = 96, .external_lex_state = 86},
  [4683] = {.lex_state = 96, .external_lex_state = 86},
  [4684] = {.lex_state = 450, .external_lex_state = 98},
  [4685] = {.lex_state = 516, .external_lex_state = 92},
  [4686] = {.lex_state = 450, .external_lex_state = 98},
  [4687] = {.lex_state = 516, .external_lex_state = 92},
  [4688] = {.lex_state = 297, .external_lex_state = 97},
  [4689] = {.lex_state = 450, .external_lex_state = 98},
  [4690] = {.lex_state = 516, .external_lex_state = 92},
  [4691] = {.lex_state = 450, .external_lex_state = 98},
  [4692] = {.lex_state = 450, .external_lex_state = 98},
  [4693] = {.lex_state = 516, .external_lex_state = 92},
  [4694] = {.lex_state = 96, .external_lex_state = 92},
  [4695] = {.lex_state = 450, .external_lex_state = 98},
  [4696] = {.lex_state = 96, .external_lex_state = 86},
  [4697] = {.lex_state = 450, .external_lex_state = 98},
  [4698] = {.lex_state = 468, .external_lex_state = 96},
  [4699] = {.lex_state = 450, .external_lex_state = 98},
  [4700] = {.lex_state = 96, .external_lex_state = 67},
  [4701] = {.lex_state = 450, .external_lex_state = 98},
  [4702] = {.lex_state = 516, .external_lex_state = 92},
  [4703] = {.lex_state = 450, .external_lex_state = 98},
  [4704] = {.lex_state = 96, .external_lex_state = 86},
  [4705] = {.lex_state = 96, .external_lex_state = 86},
  [4706] = {.lex_state = 450, .external_lex_state = 98},
  [4707] = {.lex_state = 95, .external_lex_state = 92},
  [4708] = {.lex_state = 96, .external_lex_state = 86},
  [4709] = {.lex_state = 516, .external_lex_state = 92},
  [4710] = {.lex_state = 96, .external_lex_state = 92},
  [4711] = {.lex_state = 450, .external_lex_state = 98},
  [4712] = {.lex_state = 450, .external_lex_state = 98},
  [4713] = {.lex_state = 516, .external_lex_state = 92},
  [4714] = {.lex_state = 96, .external_lex_state = 86},
  [4715] = {.lex_state = 516, .external_lex_state = 92},
  [4716] = {.lex_state = 96, .external_lex_state = 92},
  [4717] = {.lex_state = 516, .external_lex_state = 92},
  [4718] = {.lex_state = 96, .external_lex_state = 67},
  [4719] = {.lex_state = 95, .external_lex_state = 92},
  [4720] = {.lex_state = 96, .external_lex_state = 86},
  [4721] = {.lex_state = 450, .external_lex_state = 98},
  [4722] = {.lex_state = 450, .external_lex_state = 98},
  [4723] = {.lex_state = 96, .external_lex_state = 86},
  [4724] = {.lex_state = 516, .external_lex_state = 92},
  [4725] = {.lex_state = 516, .external_lex_state = 92},
  [4726] = {.lex_state = 516, .external_lex_state = 92},
  [4727] = {.lex_state = 450, .external_lex_state = 98},
  [4728] = {.lex_state = 516, .external_lex_state = 92},
  [4729] = {.lex_state = 450, .external_lex_state = 98},
  [4730] = {.lex_state = 516, .external_lex_state = 92},
  [4731] = {.lex_state = 515, .external_lex_state = 92},
  [4732] = {.lex_state = 96, .external_lex_state = 86},
  [4733] = {.lex_state = 513, .external_lex_state = 92},
  [4734] = {.lex_state = 516, .external_lex_state = 92},
  [4735] = {.lex_state = 516, .external_lex_state = 92},
  [4736] = {.lex_state = 515, .external_lex_state = 92},
  [4737] = {.lex_state = 96, .external_lex_state = 86},
  [4738] = {.lex_state = 450, .external_lex_state = 98},
  [4739] = {.lex_state = 515, .external_lex_state = 92},
  [4740] = {.lex_state = 297, .external_lex_state = 97},
  [4741] = {.lex_state = 515, .external_lex_state = 92},
  [4742] = {.lex_state = 513, .external_lex_state = 92},
  [4743] = {.lex_state = 95, .external_lex_state = 92},
  [4744] = {.lex_state = 513, .external_lex_state = 92},
  [4745] = {.lex_state = 297, .external_lex_state = 97},
  [4746] = {.lex_state = 516, .external_lex_state = 92},
  [4747] = {.lex_state = 297, .external_lex_state = 97},
  [4748] = {.lex_state = 96, .external_lex_state = 86},
  [4749] = {.lex_state = 516, .external_lex_state = 92},
  [4750] = {.lex_state = 516, .external_lex_state = 92},
  [4751] = {.lex_state = 450, .external_lex_state = 98},
  [4752] = {.lex_state = 96, .external_lex_state = 86},
  [4753] = {.lex_state = 297, .external_lex_state = 97},
  [4754] = {.lex_state = 450, .external_lex_state = 98},
  [4755] = {.lex_state = 450, .external_lex_state = 98},
  [4756] = {.lex_state = 468, .external_lex_state = 96},
  [4757] = {.lex_state = 450, .external_lex_state = 98},
  [4758] = {.lex_state = 468, .external_lex_state = 96},
  [4759] = {.lex_state = 297, .external_lex_state = 97},
  [4760] = {.lex_state = 450, .external_lex_state = 98},
  [4761] = {.lex_state = 516, .external_lex_state = 92},
  [4762] = {.lex_state = 516, .external_lex_state = 92},
  [4763] = {.lex_state = 516, .external_lex_state = 92},
  [4764] = {.lex_state = 297, .external_lex_state = 97},
  [4765] = {.lex_state = 297, .external_lex_state = 97},
  [4766] = {.lex_state = 96, .external_lex_state = 86},
  [4767] = {.lex_state = 96, .external_lex_state = 86},
  [4768] = {.lex_state = 297, .external_lex_state = 97},
  [4769] = {.lex_state = 516, .external_lex_state = 92},
  [4770] = {.lex_state = 95, .external_lex_state = 92},
  [4771] = {.lex_state = 96, .external_lex_state = 86},
  [4772] = {.lex_state = 516, .external_lex_state = 92},
  [4773] = {.lex_state = 96, .external_lex_state = 86},
  [4774] = {.lex_state = 96, .external_lex_state = 86},
  [4775] = {.lex_state = 297, .external_lex_state = 97},
  [4776] = {.lex_state = 516, .external_lex_state = 92},
  [4777] = {.lex_state = 96, .external_lex_state = 86},
  [4778] = {.lex_state = 96, .external_lex_state = 86},
  [4779] = {.lex_state = 450, .external_lex_state = 98},
  [4780] = {.lex_state = 96, .external_lex_state = 86},
  [4781] = {.lex_state = 450, .external_lex_state = 98},
  [4782] = {.lex_state = 516, .external_lex_state = 92},
  [4783] = {.lex_state = 516, .external_lex_state = 92},
  [4784] = {.lex_state = 516, .external_lex_state = 92},
  [4785] = {.lex_state = 96, .external_lex_state = 86},
  [4786] = {.lex_state = 516, .external_lex_state = 92},
  [4787] = {.lex_state = 450, .external_lex_state = 98},
  [4788] = {.lex_state = 96, .external_lex_state = 86},
  [4789] = {.lex_state = 96, .external_lex_state = 86},
  [4790] = {.lex_state = 450, .external_lex_state = 98},
  [4791] = {.lex_state = 468, .external_lex_state = 96},
  [4792] = {.lex_state = 516, .external_lex_state = 92},
  [4793] = {.lex_state = 450, .external_lex_state = 98},
  [4794] = {.lex_state = 468, .external_lex_state = 96},
  [4795] = {.lex_state = 96, .external_lex_state = 86},
  [4796] = {.lex_state = 450, .external_lex_state = 98},
  [4797] = {.lex_state = 96, .external_lex_state = 86},
  [4798] = {.lex_state = 515, .external_lex_state = 92},
  [4799] = {.lex_state = 450, .external_lex_state = 98},
  [4800] = {.lex_state = 96, .external_lex_state = 86},
  [4801] = {.lex_state = 96, .external_lex_state = 86},
  [4802] = {.lex_state = 95, .external_lex_state = 92},
  [4803] = {.lex_state = 450, .external_lex_state = 98},
  [4804] = {.lex_state = 450, .external_lex_state = 98},
  [4805] = {.lex_state = 96, .external_lex_state = 86},
  [4806] = {.lex_state = 468, .external_lex_state = 96},
  [4807] = {.lex_state = 450, .external_lex_state = 98},
  [4808] = {.lex_state = 96, .external_lex_state = 92},
  [4809] = {.lex_state = 450, .external_lex_state = 98},
  [4810] = {.lex_state = 450, .external_lex_state = 98},
  [4811] = {.lex_state = 96, .external_lex_state = 92},
  [4812] = {.lex_state = 96, .external_lex_state = 86},
  [4813] = {.lex_state = 96, .external_lex_state = 86},
  [4814] = {.lex_state = 450, .external_lex_state = 98},
  [4815] = {.lex_state = 96, .external_lex_state = 86},
  [4816] = {.lex_state = 450, .external_lex_state = 98},
  [4817] = {.lex_state = 516, .external_lex_state = 92},
  [4818] = {.lex_state = 516, .external_lex_state = 92},
  [4819] = {.lex_state = 96, .external_lex_state = 86},
  [4820] = {.lex_state = 96, .external_lex_state = 86},
  [4821] = {.lex_state = 96, .external_lex_state = 92},
  [4822] = {.lex_state = 450, .external_lex_state = 98},
  [4823] = {.lex_state = 297, .external_lex_state = 97},
  [4824] = {.lex_state = 297, .external_lex_state = 97},
  [4825] = {.lex_state = 297, .external_lex_state = 97},
  [4826] = {.lex_state = 450, .external_lex_state = 98},
  [4827] = {.lex_state = 96, .external_lex_state = 86},
  [4828] = {.lex_state = 96, .external_lex_state = 86},
  [4829] = {.lex_state = 516, .external_lex_state = 92},
  [4830] = {.lex_state = 450, .external_lex_state = 98},
  [4831] = {.lex_state = 96, .external_lex_state = 86},
  [4832] = {.lex_state = 450, .external_lex_state = 98},
  [4833] = {.lex_state = 95, .external_lex_state = 92},
  [4834] = {.lex_state = 450, .external_lex_state = 98},
  [4835] = {.lex_state = 95, .external_lex_state = 92},
  [4836] = {.lex_state = 450, .external_lex_state = 98},
  [4837] = {.lex_state = 96, .external_lex_state = 86},
  [4838] = {.lex_state = 95, .external_lex_state = 92},
  [4839] = {.lex_state = 516, .external_lex_state = 92},
  [4840] = {.lex_state = 516, .external_lex_state = 92},
  [4841] = {.lex_state = 95, .external_lex_state = 92},
  [4842] = {.lex_state = 516, .external_lex_state = 92},
  [4843] = {.lex_state = 516, .external_lex_state = 92},
  [4844] = {.lex_state = 468, .external_lex_state = 96},
  [4845] = {.lex_state = 450, .external_lex_state = 98},
  [4846] = {.lex_state = 95, .external_lex_state = 92},
  [4847] = {.lex_state = 450, .external_lex_state = 98},
  [4848] = {.lex_state = 95, .external_lex_state = 92},
  [4849] = {.lex_state = 516, .external_lex_state = 92},
  [4850] = {.lex_state = 450, .external_lex_state = 98},
  [4851] = {.lex_state = 468, .external_lex_state = 96},
  [4852] = {.lex_state = 96, .external_lex_state = 86},
  [4853] = {.lex_state = 95, .external_lex_state = 92},
  [4854] = {.lex_state = 450, .external_lex_state = 98},
  [4855] = {.lex_state = 450, .external_lex_state = 98},
  [4856] = {.lex_state = 96, .external_lex_state = 86},
  [4857] = {.lex_state = 450, .external_lex_state = 98},
  [4858] = {.lex_state = 96, .external_lex_state = 86},
  [4859] = {.lex_state = 96, .external_lex_state = 86},
  [4860] = {.lex_state = 516, .external_lex_state = 92},
  [4861] = {.lex_state = 96, .external_lex_state = 86},
  [4862] = {.lex_state = 96, .external_lex_state = 86},
  [4863] = {.lex_state = 450, .external_lex_state = 98},
  [4864] = {.lex_state = 450, .external_lex_state = 98},
  [4865] = {.lex_state = 450, .external_lex_state = 98},
  [4866] = {.lex_state = 515, .external_lex_state = 91},
  [4867] = {.lex_state = 515, .external_lex_state = 91},
  [4868] = {.lex_state = 450, .external_lex_state = 98},
  [4869] = {.lex_state = 96, .external_lex_state = 86},
  [4870] = {.lex_state = 450, .external_lex_state = 98},
  [4871] = {.lex_state = 96, .external_lex_state = 86},
  [4872] = {.lex_state = 450, .external_lex_state = 98},
  [4873] = {.lex_state = 96, .external_lex_state = 86},
  [4874] = {.lex_state = 297, .external_lex_state = 97},
  [4875] = {.lex_state = 515, .external_lex_state = 91},
  [4876] = {.lex_state = 515, .external_lex_state = 91},
  [4877] = {.lex_state = 515, .external_lex_state = 91},
  [4878] = {.lex_state = 515, .external_lex_state = 91},
  [4879] = {.lex_state = 515, .external_lex_state = 91},
  [4880] = {.lex_state = 515, .external_lex_state = 91},
  [4881] = {.lex_state = 515, .external_lex_state = 91},
  [4882] = {.lex_state = 515, .external_lex_state = 91},
  [4883] = {.lex_state = 450, .external_lex_state = 98},
  [4884] = {.lex_state = 450, .external_lex_state = 98},
  [4885] = {.lex_state = 516, .external_lex_state = 92},
  [4886] = {.lex_state = 95, .external_lex_state = 92},
  [4887] = {.lex_state = 95, .external_lex_state = 92},
  [4888] = {.lex_state = 516, .external_lex_state = 92},
  [4889] = {.lex_state = 450, .external_lex_state = 98},
  [4890] = {.lex_state = 450, .external_lex_state = 98},
  [4891] = {.lex_state = 95, .external_lex_state = 92},
  [4892] = {.lex_state = 450, .external_lex_state = 98},
  [4893] = {.lex_state = 96, .external_lex_state = 86},
  [4894] = {.lex_state = 515, .external_lex_state = 92},
  [4895] = {.lex_state = 450, .external_lex_state = 98},
  [4896] = {.lex_state = 297, .external_lex_state = 97},
  [4897] = {.lex_state = 95, .external_lex_state = 92},
  [4898] = {.lex_state = 297, .external_lex_state = 97},
  [4899] = {.lex_state = 515, .external_lex_state = 92},
  [4900] = {.lex_state = 450, .external_lex_state = 98},
  [4901] = {.lex_state = 516, .external_lex_state = 92},
  [4902] = {.lex_state = 516, .external_lex_state = 92},
  [4903] = {.lex_state = 450, .external_lex_state = 98},
  [4904] = {.lex_state = 450, .external_lex_state = 98},
  [4905] = {.lex_state = 450, .external_lex_state = 98},
  [4906] = {.lex_state = 96, .external_lex_state = 86},
  [4907] = {.lex_state = 96, .external_lex_state = 86},
  [4908] = {.lex_state = 96, .external_lex_state = 86},
  [4909] = {.lex_state = 450, .external_lex_state = 98},
  [4910] = {.lex_state = 96, .external_lex_state = 86},
  [4911] = {.lex_state = 450, .external_lex_state = 98},
  [4912] = {.lex_state = 96, .external_lex_state = 86},
  [4913] = {.lex_state = 450, .external_lex_state = 98},
  [4914] = {.lex_state = 95, .external_lex_state = 92},
  [4915] = {.lex_state = 95, .external_lex_state = 92},
  [4916] = {.lex_state = 515, .external_lex_state = 92},
  [4917] = {.lex_state = 297, .external_lex_state = 97},
  [4918] = {.lex_state = 516, .external_lex_state = 92},
  [4919] = {.lex_state = 516, .external_lex_state = 92},
  [4920] = {.lex_state = 516, .external_lex_state = 92},
  [4921] = {.lex_state = 96, .external_lex_state = 67},
  [4922] = {.lex_state = 516, .external_lex_state = 92},
  [4923] = {.lex_state = 297, .external_lex_state = 97},
  [4924] = {.lex_state = 450, .external_lex_state = 98},
  [4925] = {.lex_state = 450, .external_lex_state = 98},
  [4926] = {.lex_state = 450, .external_lex_state = 98},
  [4927] = {.lex_state = 516, .external_lex_state = 92},
  [4928] = {.lex_state = 516, .external_lex_state = 92},
  [4929] = {.lex_state = 450, .external_lex_state = 98},
  [4930] = {.lex_state = 516, .external_lex_state = 92},
  [4931] = {.lex_state = 450, .external_lex_state = 98},
  [4932] = {.lex_state = 516, .external_lex_state = 92},
  [4933] = {.lex_state = 516, .external_lex_state = 92},
  [4934] = {.lex_state = 516, .external_lex_state = 92},
  [4935] = {.lex_state = 96, .external_lex_state = 86},
  [4936] = {.lex_state = 96, .external_lex_state = 86},
  [4937] = {.lex_state = 516, .external_lex_state = 92},
  [4938] = {.lex_state = 96, .external_lex_state = 86},
  [4939] = {.lex_state = 450, .external_lex_state = 98},
  [4940] = {.lex_state = 450, .external_lex_state = 98},
  [4941] = {.lex_state = 96, .external_lex_state = 92},
  [4942] = {.lex_state = 96, .external_lex_state = 92},
  [4943] = {.lex_state = 296, .external_lex_state = 71},
  [4944] = {.lex_state = 96, .external_lex_state = 92},
  [4945] = {.lex_state = 515, .external_lex_state = 92},
  [4946] = {.lex_state = 96, .external_lex_state = 92},
  [4947] = {.lex_state = 95, .external_lex_state = 92},
  [4948] = {.lex_state = 96, .external_lex_state = 92},
  [4949] = {.lex_state = 96, .external_lex_state = 92},
  [4950] = {.lex_state = 96, .external_lex_state = 92},
  [4951] = {.lex_state = 96, .external_lex_state = 92},
  [4952] = {.lex_state = 515, .external_lex_state = 92},
  [4953] = {.lex_state = 96, .external_lex_state = 92},
  [4954] = {.lex_state = 96, .external_lex_state = 92},
  [4955] = {.lex_state = 96, .external_lex_state = 92},
  [4956] = {.lex_state = 96, .external_lex_state = 92},
  [4957] = {.lex_state = 515, .external_lex_state = 92},
  [4958] = {.lex_state = 96, .external_lex_state = 92},
  [4959] = {.lex_state = 96, .external_lex_state = 92},
  [4960] = {.lex_state = 96, .external_lex_state = 92},
  [4961] = {.lex_state = 96, .external_lex_state = 92},
  [4962] = {.lex_state = 96, .external_lex_state = 92},
  [4963] = {.lex_state = 96, .external_lex_state = 92},
  [4964] = {.lex_state = 96, .external_lex_state = 92},
  [4965] = {.lex_state = 515, .external_lex_state = 92},
  [4966] = {.lex_state = 96, .external_lex_state = 92},
  [4967] = {.lex_state = 96, .external_lex_state = 92},
  [4968] = {.lex_state = 96, .external_lex_state = 92},
  [4969] = {.lex_state = 96, .external_lex_state = 92},
  [4970] = {.lex_state = 96, .external_lex_state = 92},
  [4971] = {.lex_state = 516, .external_lex_state = 92},
  [4972] = {.lex_state = 96, .external_lex_state = 92},
  [4973] = {.lex_state = 96, .external_lex_state = 92},
  [4974] = {.lex_state = 516, .external_lex_state = 92},
  [4975] = {.lex_state = 96, .external_lex_state = 92},
  [4976] = {.lex_state = 96, .external_lex_state = 92},
  [4977] = {.lex_state = 96, .external_lex_state = 92},
  [4978] = {.lex_state = 96, .external_lex_state = 92},
  [4979] = {.lex_state = 96, .external_lex_state = 92},
  [4980] = {.lex_state = 515, .external_lex_state = 92},
  [4981] = {.lex_state = 96, .external_lex_state = 92},
  [4982] = {.lex_state = 296, .external_lex_state = 71},
  [4983] = {.lex_state = 96, .external_lex_state = 92},
  [4984] = {.lex_state = 96, .external_lex_state = 92},
  [4985] = {.lex_state = 96, .external_lex_state = 92},
  [4986] = {.lex_state = 96, .external_lex_state = 92},
  [4987] = {.lex_state = 96, .external_lex_state = 92},
  [4988] = {.lex_state = 95, .external_lex_state = 91},
  [4989] = {.lex_state = 96, .external_lex_state = 92},
  [4990] = {.lex_state = 96, .external_lex_state = 92},
  [4991] = {.lex_state = 96, .external_lex_state = 92},
  [4992] = {.lex_state = 516, .external_lex_state = 92},
  [4993] = {.lex_state = 96, .external_lex_state = 92},
  [4994] = {.lex_state = 96, .external_lex_state = 92},
  [4995] = {.lex_state = 96, .external_lex_state = 92},
  [4996] = {.lex_state = 96, .external_lex_state = 92},
  [4997] = {.lex_state = 96, .external_lex_state = 92},
  [4998] = {.lex_state = 96, .external_lex_state = 92},
  [4999] = {.lex_state = 95, .external_lex_state = 92},
  [5000] = {.lex_state = 96, .external_lex_state = 93},
  [5001] = {.lex_state = 96, .external_lex_state = 92},
  [5002] = {.lex_state = 96, .external_lex_state = 92},
  [5003] = {.lex_state = 96, .external_lex_state = 92},
  [5004] = {.lex_state = 96, .external_lex_state = 92},
  [5005] = {.lex_state = 96, .external_lex_state = 92},
  [5006] = {.lex_state = 516, .external_lex_state = 92},
  [5007] = {.lex_state = 480, .external_lex_state = 99},
  [5008] = {.lex_state = 515, .external_lex_state = 92},
  [5009] = {.lex_state = 515, .external_lex_state = 92},
  [5010] = {.lex_state = 96, .external_lex_state = 92},
  [5011] = {.lex_state = 96, .external_lex_state = 92},
  [5012] = {.lex_state = 515, .external_lex_state = 92},
  [5013] = {.lex_state = 96, .external_lex_state = 92},
  [5014] = {.lex_state = 95, .external_lex_state = 92},
  [5015] = {.lex_state = 96, .external_lex_state = 92},
  [5016] = {.lex_state = 96, .external_lex_state = 92},
  [5017] = {.lex_state = 95, .external_lex_state = 92},
  [5018] = {.lex_state = 96, .external_lex_state = 92},
  [5019] = {.lex_state = 96, .external_lex_state = 91},
  [5020] = {.lex_state = 457, .external_lex_state = 100},
  [5021] = {.lex_state = 457, .external_lex_state = 100},
  [5022] = {.lex_state = 468, .external_lex_state = 96},
  [5023] = {.lex_state = 468, .external_lex_state = 96},
  [5024] = {.lex_state = 468, .external_lex_state = 96},
  [5025] = {.lex_state = 468, .external_lex_state = 96},
  [5026] = {.lex_state = 468, .external_lex_state = 96},
  [5027] = {.lex_state = 468, .external_lex_state = 96},
  [5028] = {.lex_state = 468, .external_lex_state = 96},
  [5029] = {.lex_state = 468, .external_lex_state = 96},
  [5030] = {.lex_state = 468, .external_lex_state = 96},
  [5031] = {.lex_state = 468, .external_lex_state = 96},
  [5032] = {.lex_state = 468, .external_lex_state = 96},
  [5033] = {.lex_state = 468, .external_lex_state = 96},
  [5034] = {.lex_state = 480, .external_lex_state = 99},
  [5035] = {.lex_state = 480, .external_lex_state = 99},
  [5036] = {.lex_state = 480, .external_lex_state = 99},
  [5037] = {.lex_state = 480, .external_lex_state = 99},
  [5038] = {.lex_state = 445, .external_lex_state = 101},
  [5039] = {.lex_state = 457, .external_lex_state = 100},
  [5040] = {.lex_state = 457, .external_lex_state = 100},
  [5041] = {.lex_state = 457, .external_lex_state = 100},
  [5042] = {.lex_state = 284, .external_lex_state = 97},
  [5043] = {.lex_state = 284, .external_lex_state = 97},
  [5044] = {.lex_state = 480, .external_lex_state = 99},
  [5045] = {.lex_state = 480, .external_lex_state = 99},
  [5046] = {.lex_state = 457, .external_lex_state = 100},
  [5047] = {.lex_state = 480, .external_lex_state = 99},
  [5048] = {.lex_state = 480, .external_lex_state = 99},
  [5049] = {.lex_state = 445, .external_lex_state = 101},
  [5050] = {.lex_state = 296, .external_lex_state = 71},
  [5051] = {.lex_state = 515, .external_lex_state = 92},
  [5052] = {.lex_state = 468, .external_lex_state = 96},
  [5053] = {.lex_state = 284, .external_lex_state = 97},
  [5054] = {.lex_state = 284, .external_lex_state = 97},
  [5055] = {.lex_state = 284, .external_lex_state = 97},
  [5056] = {.lex_state = 468, .external_lex_state = 96},
  [5057] = {.lex_state = 95, .external_lex_state = 92},
  [5058] = {.lex_state = 95, .external_lex_state = 92},
  [5059] = {.lex_state = 468, .external_lex_state = 96},
  [5060] = {.lex_state = 468, .external_lex_state = 96},
  [5061] = {.lex_state = 445, .external_lex_state = 102},
  [5062] = {.lex_state = 468, .external_lex_state = 96},
  [5063] = {.lex_state = 468, .external_lex_state = 96},
  [5064] = {.lex_state = 468, .external_lex_state = 96},
  [5065] = {.lex_state = 468, .external_lex_state = 96},
  [5066] = {.lex_state = 468, .external_lex_state = 96},
  [5067] = {.lex_state = 95, .external_lex_state = 91},
  [5068] = {.lex_state = 480, .external_lex_state = 99},
  [5069] = {.lex_state = 480, .external_lex_state = 99},
  [5070] = {.lex_state = 468, .external_lex_state = 96},
  [5071] = {.lex_state = 468, .external_lex_state = 96},
  [5072] = {.lex_state = 480, .external_lex_state = 99},
  [5073] = {.lex_state = 468, .external_lex_state = 96},
  [5074] = {.lex_state = 468, .external_lex_state = 96},
  [5075] = {.lex_state = 468, .external_lex_state = 96},
  [5076] = {.lex_state = 96, .external_lex_state = 93},
  [5077] = {.lex_state = 96, .external_lex_state = 93},
  [5078] = {.lex_state = 95, .external_lex_state = 91},
  [5079] = {.lex_state = 95, .external_lex_state = 91},
  [5080] = {.lex_state = 468, .external_lex_state = 96},
  [5081] = {.lex_state = 468, .external_lex_state = 96},
  [5082] = {.lex_state = 468, .external_lex_state = 96},
  [5083] = {.lex_state = 468, .external_lex_state = 96},
  [5084] = {.lex_state = 468, .external_lex_state = 96},
  [5085] = {.lex_state = 468, .external_lex_state = 96},
  [5086] = {.lex_state = 468, .external_lex_state = 96},
  [5087] = {.lex_state = 468, .external_lex_state = 96},
  [5088] = {.lex_state = 468, .external_lex_state = 96},
  [5089] = {.lex_state = 468, .external_lex_state = 96},
  [5090] = {.lex_state = 468, .external_lex_state = 96},
  [5091] = {.lex_state = 515, .external_lex_state = 92},
  [5092] = {.lex_state = 468, .external_lex_state = 96},
  [5093] = {.lex_state = 477, .external_lex_state = 103},
  [5094] = {.lex_state = 445, .external_lex_state = 102},
  [5095] = {.lex_state = 515, .external_lex_state = 92},
  [5096] = {.lex_state = 515, .external_lex_state = 92},
  [5097] = {.lex_state = 468, .external_lex_state = 96},
  [5098] = {.lex_state = 515, .external_lex_state = 92},
  [5099] = {.lex_state = 515, .external_lex_state = 92},
  [5100] = {.lex_state = 478, .external_lex_state = 104},
  [5101] = {.lex_state = 445, .external_lex_state = 102},
  [5102] = {.lex_state = 469, .external_lex_state = 105},
  [5103] = {.lex_state = 96, .external_lex_state = 93},
  [5104] = {.lex_state = 96, .external_lex_state = 93},
  [5105] = {.lex_state = 96, .external_lex_state = 67},
  [5106] = {.lex_state = 96, .external_lex_state = 67},
  [5107] = {.lex_state = 95, .external_lex_state = 91},
  [5108] = {.lex_state = 95, .external_lex_state = 91},
  [5109] = {.lex_state = 95, .external_lex_state = 91},
  [5110] = {.lex_state = 95, .external_lex_state = 91},
  [5111] = {.lex_state = 95, .external_lex_state = 91},
  [5112] = {.lex_state = 95, .external_lex_state = 91},
  [5113] = {.lex_state = 95, .external_lex_state = 91},
  [5114] = {.lex_state = 481, .external_lex_state = 99},
  [5115] = {.lex_state = 96, .external_lex_state = 92},
  [5116] = {.lex_state = 466, .external_lex_state = 69},
  [5117] = {.lex_state = 481, .external_lex_state = 99},
  [5118] = {.lex_state = 481, .external_lex_state = 99},
  [5119] = {.lex_state = 94, .external_lex_state = 106},
  [5120] = {.lex_state = 466, .external_lex_state = 69},
  [5121] = {.lex_state = 481, .external_lex_state = 99},
  [5122] = {.lex_state = 481, .external_lex_state = 99},
  [5123] = {.lex_state = 477, .external_lex_state = 103},
  [5124] = {.lex_state = 477, .external_lex_state = 103},
  [5125] = {.lex_state = 457, .external_lex_state = 100},
  [5126] = {.lex_state = 457, .external_lex_state = 100},
  [5127] = {.lex_state = 457, .external_lex_state = 100},
  [5128] = {.lex_state = 466, .external_lex_state = 69},
  [5129] = {.lex_state = 457, .external_lex_state = 100},
  [5130] = {.lex_state = 457, .external_lex_state = 100},
  [5131] = {.lex_state = 468, .external_lex_state = 101},
  [5132] = {.lex_state = 457, .external_lex_state = 100},
  [5133] = {.lex_state = 457, .external_lex_state = 100},
  [5134] = {.lex_state = 445, .external_lex_state = 101},
  [5135] = {.lex_state = 468, .external_lex_state = 81},
  [5136] = {.lex_state = 466, .external_lex_state = 69},
  [5137] = {.lex_state = 445, .external_lex_state = 101},
  [5138] = {.lex_state = 481, .external_lex_state = 99},
  [5139] = {.lex_state = 481, .external_lex_state = 99},
  [5140] = {.lex_state = 480, .external_lex_state = 104},
  [5141] = {.lex_state = 480, .external_lex_state = 104},
  [5142] = {.lex_state = 457, .external_lex_state = 100},
  [5143] = {.lex_state = 457, .external_lex_state = 100},
  [5144] = {.lex_state = 457, .external_lex_state = 100},
  [5145] = {.lex_state = 457, .external_lex_state = 100},
  [5146] = {.lex_state = 457, .external_lex_state = 100},
  [5147] = {.lex_state = 480, .external_lex_state = 104},
  [5148] = {.lex_state = 480, .external_lex_state = 104},
  [5149] = {.lex_state = 457, .external_lex_state = 100},
  [5150] = {.lex_state = 457, .external_lex_state = 100},
  [5151] = {.lex_state = 466, .external_lex_state = 69},
  [5152] = {.lex_state = 457, .external_lex_state = 100},
  [5153] = {.lex_state = 457, .external_lex_state = 100},
  [5154] = {.lex_state = 457, .external_lex_state = 100},
  [5155] = {.lex_state = 457, .external_lex_state = 100},
  [5156] = {.lex_state = 457, .external_lex_state = 100},
  [5157] = {.lex_state = 94, .external_lex_state = 106},
  [5158] = {.lex_state = 481, .external_lex_state = 99},
  [5159] = {.lex_state = 481, .external_lex_state = 99},
  [5160] = {.lex_state = 94, .external_lex_state = 106},
  [5161] = {.lex_state = 481, .external_lex_state = 99},
  [5162] = {.lex_state = 466, .external_lex_state = 69},
  [5163] = {.lex_state = 96, .external_lex_state = 92},
  [5164] = {.lex_state = 95, .external_lex_state = 92},
  [5165] = {.lex_state = 96, .external_lex_state = 92},
  [5166] = {.lex_state = 96, .external_lex_state = 92},
  [5167] = {.lex_state = 96, .external_lex_state = 92},
  [5168] = {.lex_state = 95, .external_lex_state = 92},
  [5169] = {.lex_state = 95, .external_lex_state = 92},
  [5170] = {.lex_state = 96, .external_lex_state = 92},
  [5171] = {.lex_state = 468, .external_lex_state = 101},
  [5172] = {.lex_state = 481, .external_lex_state = 99},
  [5173] = {.lex_state = 468, .external_lex_state = 81},
  [5174] = {.lex_state = 481, .external_lex_state = 99},
  [5175] = {.lex_state = 468, .external_lex_state = 101},
  [5176] = {.lex_state = 480, .external_lex_state = 99},
  [5177] = {.lex_state = 466, .external_lex_state = 69},
  [5178] = {.lex_state = 480, .external_lex_state = 99},
  [5179] = {.lex_state = 480, .external_lex_state = 99},
  [5180] = {.lex_state = 480, .external_lex_state = 99},
  [5181] = {.lex_state = 96, .external_lex_state = 91},
  [5182] = {.lex_state = 96, .external_lex_state = 91},
  [5183] = {.lex_state = 480, .external_lex_state = 99},
  [5184] = {.lex_state = 466, .external_lex_state = 69},
  [5185] = {.lex_state = 466, .external_lex_state = 69},
  [5186] = {.lex_state = 466, .external_lex_state = 69},
  [5187] = {.lex_state = 445, .external_lex_state = 101},
  [5188] = {.lex_state = 480, .external_lex_state = 99},
  [5189] = {.lex_state = 466, .external_lex_state = 69},
  [5190] = {.lex_state = 477, .external_lex_state = 103},
  [5191] = {.lex_state = 468, .external_lex_state = 101},
  [5192] = {.lex_state = 477, .external_lex_state = 103},
  [5193] = {.lex_state = 445, .external_lex_state = 101},
  [5194] = {.lex_state = 477, .external_lex_state = 103},
  [5195] = {.lex_state = 466, .external_lex_state = 69},
  [5196] = {.lex_state = 480, .external_lex_state = 104},
  [5197] = {.lex_state = 480, .external_lex_state = 104},
  [5198] = {.lex_state = 466, .external_lex_state = 69},
  [5199] = {.lex_state = 468, .external_lex_state = 101},
  [5200] = {.lex_state = 480, .external_lex_state = 104},
  [5201] = {.lex_state = 480, .external_lex_state = 99},
  [5202] = {.lex_state = 480, .external_lex_state = 104},
  [5203] = {.lex_state = 480, .external_lex_state = 99},
  [5204] = {.lex_state = 480, .external_lex_state = 99},
  [5205] = {.lex_state = 466, .external_lex_state = 69},
  [5206] = {.lex_state = 480, .external_lex_state = 99},
  [5207] = {.lex_state = 480, .external_lex_state = 99},
  [5208] = {.lex_state = 480, .external_lex_state = 99},
  [5209] = {.lex_state = 480, .external_lex_state = 99},
  [5210] = {.lex_state = 480, .external_lex_state = 99},
  [5211] = {.lex_state = 480, .external_lex_state = 99},
  [5212] = {.lex_state = 468, .external_lex_state = 101},
  [5213] = {.lex_state = 466, .external_lex_state = 69},
  [5214] = {.lex_state = 480, .external_lex_state = 99},
  [5215] = {.lex_state = 480, .external_lex_state = 99},
  [5216] = {.lex_state = 480, .external_lex_state = 99},
  [5217] = {.lex_state = 477, .external_lex_state = 104},
  [5218] = {.lex_state = 480, .external_lex_state = 104},
  [5219] = {.lex_state = 480, .external_lex_state = 104},
  [5220] = {.lex_state = 480, .external_lex_state = 104},
  [5221] = {.lex_state = 468, .external_lex_state = 101},
  [5222] = {.lex_state = 445, .external_lex_state = 102},
  [5223] = {.lex_state = 466, .external_lex_state = 69},
  [5224] = {.lex_state = 468, .external_lex_state = 101},
  [5225] = {.lex_state = 445, .external_lex_state = 101},
  [5226] = {.lex_state = 466, .external_lex_state = 69},
  [5227] = {.lex_state = 466, .external_lex_state = 69},
  [5228] = {.lex_state = 468, .external_lex_state = 101},
  [5229] = {.lex_state = 466, .external_lex_state = 69},
  [5230] = {.lex_state = 466, .external_lex_state = 69},
  [5231] = {.lex_state = 466, .external_lex_state = 69},
  [5232] = {.lex_state = 466, .external_lex_state = 69},
  [5233] = {.lex_state = 466, .external_lex_state = 69},
  [5234] = {.lex_state = 468, .external_lex_state = 101},
  [5235] = {.lex_state = 445, .external_lex_state = 102},
  [5236] = {.lex_state = 96, .external_lex_state = 91},
  [5237] = {.lex_state = 96, .external_lex_state = 91},
  [5238] = {.lex_state = 96, .external_lex_state = 91},
  [5239] = {.lex_state = 96, .external_lex_state = 91},
  [5240] = {.lex_state = 96, .external_lex_state = 91},
  [5241] = {.lex_state = 96, .external_lex_state = 91},
  [5242] = {.lex_state = 96, .external_lex_state = 91},
  [5243] = {.lex_state = 96, .external_lex_state = 91},
  [5244] = {.lex_state = 466, .external_lex_state = 69},
  [5245] = {.lex_state = 480, .external_lex_state = 99},
  [5246] = {.lex_state = 477, .external_lex_state = 103},
  [5247] = {.lex_state = 468, .external_lex_state = 101},
  [5248] = {.lex_state = 454, .external_lex_state = 48},
  [5249] = {.lex_state = 480, .external_lex_state = 104},
  [5250] = {.lex_state = 454, .external_lex_state = 48},
  [5251] = {.lex_state = 454, .external_lex_state = 48},
  [5252] = {.lex_state = 477, .external_lex_state = 104},
  [5253] = {.lex_state = 477, .external_lex_state = 104},
  [5254] = {.lex_state = 454, .external_lex_state = 48},
  [5255] = {.lex_state = 454, .external_lex_state = 48},
  [5256] = {.lex_state = 480, .external_lex_state = 104},
  [5257] = {.lex_state = 454, .external_lex_state = 48},
  [5258] = {.lex_state = 454, .external_lex_state = 48},
  [5259] = {.lex_state = 454, .external_lex_state = 48},
  [5260] = {.lex_state = 480, .external_lex_state = 104},
  [5261] = {.lex_state = 478, .external_lex_state = 102},
  [5262] = {.lex_state = 454, .external_lex_state = 48},
  [5263] = {.lex_state = 468, .external_lex_state = 101},
  [5264] = {.lex_state = 454, .external_lex_state = 48},
  [5265] = {.lex_state = 454, .external_lex_state = 48},
  [5266] = {.lex_state = 468, .external_lex_state = 101},
  [5267] = {.lex_state = 454, .external_lex_state = 48},
  [5268] = {.lex_state = 454, .external_lex_state = 48},
  [5269] = {.lex_state = 454, .external_lex_state = 48},
  [5270] = {.lex_state = 477, .external_lex_state = 104},
  [5271] = {.lex_state = 477, .external_lex_state = 104},
  [5272] = {.lex_state = 454, .external_lex_state = 48},
  [5273] = {.lex_state = 454, .external_lex_state = 48},
  [5274] = {.lex_state = 454, .external_lex_state = 48},
  [5275] = {.lex_state = 477, .external_lex_state = 103},
  [5276] = {.lex_state = 468, .external_lex_state = 101},
  [5277] = {.lex_state = 454, .external_lex_state = 48},
  [5278] = {.lex_state = 445, .external_lex_state = 101},
  [5279] = {.lex_state = 478, .external_lex_state = 102},
  [5280] = {.lex_state = 477, .external_lex_state = 103},
  [5281] = {.lex_state = 477, .external_lex_state = 103},
  [5282] = {.lex_state = 454, .external_lex_state = 48},
  [5283] = {.lex_state = 454, .external_lex_state = 48},
  [5284] = {.lex_state = 477, .external_lex_state = 103},
  [5285] = {.lex_state = 477, .external_lex_state = 103},
  [5286] = {.lex_state = 481, .external_lex_state = 99},
  [5287] = {.lex_state = 477, .external_lex_state = 81},
  [5288] = {.lex_state = 454, .external_lex_state = 48},
  [5289] = {.lex_state = 481, .external_lex_state = 99},
  [5290] = {.lex_state = 481, .external_lex_state = 99},
  [5291] = {.lex_state = 481, .external_lex_state = 99},
  [5292] = {.lex_state = 445, .external_lex_state = 102},
  [5293] = {.lex_state = 454, .external_lex_state = 48},
  [5294] = {.lex_state = 481, .external_lex_state = 99},
  [5295] = {.lex_state = 480, .external_lex_state = 104},
  [5296] = {.lex_state = 454, .external_lex_state = 48},
  [5297] = {.lex_state = 481, .external_lex_state = 99},
  [5298] = {.lex_state = 481, .external_lex_state = 99},
  [5299] = {.lex_state = 478, .external_lex_state = 102},
  [5300] = {.lex_state = 454, .external_lex_state = 48},
  [5301] = {.lex_state = 454, .external_lex_state = 48},
  [5302] = {.lex_state = 481, .external_lex_state = 99},
  [5303] = {.lex_state = 477, .external_lex_state = 81},
  [5304] = {.lex_state = 480, .external_lex_state = 104},
  [5305] = {.lex_state = 477, .external_lex_state = 103},
  [5306] = {.lex_state = 468, .external_lex_state = 102},
  [5307] = {.lex_state = 481, .external_lex_state = 99},
  [5308] = {.lex_state = 477, .external_lex_state = 103},
  [5309] = {.lex_state = 480, .external_lex_state = 104},
  [5310] = {.lex_state = 445, .external_lex_state = 102},
  [5311] = {.lex_state = 454, .external_lex_state = 48},
  [5312] = {.lex_state = 478, .external_lex_state = 102},
  [5313] = {.lex_state = 454, .external_lex_state = 48},
  [5314] = {.lex_state = 454, .external_lex_state = 48},
  [5315] = {.lex_state = 454, .external_lex_state = 48},
  [5316] = {.lex_state = 454, .external_lex_state = 48},
  [5317] = {.lex_state = 454, .external_lex_state = 48},
  [5318] = {.lex_state = 481, .external_lex_state = 99},
  [5319] = {.lex_state = 481, .external_lex_state = 99},
  [5320] = {.lex_state = 481, .external_lex_state = 99},
  [5321] = {.lex_state = 481, .external_lex_state = 99},
  [5322] = {.lex_state = 454, .external_lex_state = 48},
  [5323] = {.lex_state = 454, .external_lex_state = 48},
  [5324] = {.lex_state = 469, .external_lex_state = 107},
  [5325] = {.lex_state = 445, .external_lex_state = 102},
  [5326] = {.lex_state = 454, .external_lex_state = 48},
  [5327] = {.lex_state = 481, .external_lex_state = 99},
  [5328] = {.lex_state = 481, .external_lex_state = 99},
  [5329] = {.lex_state = 477, .external_lex_state = 104},
  [5330] = {.lex_state = 480, .external_lex_state = 104},
  [5331] = {.lex_state = 477, .external_lex_state = 104},
  [5332] = {.lex_state = 477, .external_lex_state = 104},
  [5333] = {.lex_state = 454, .external_lex_state = 48},
  [5334] = {.lex_state = 480, .external_lex_state = 104},
  [5335] = {.lex_state = 454, .external_lex_state = 48},
  [5336] = {.lex_state = 454, .external_lex_state = 48},
  [5337] = {.lex_state = 477, .external_lex_state = 103},
  [5338] = {.lex_state = 257, .external_lex_state = 71},
  [5339] = {.lex_state = 454, .external_lex_state = 48},
  [5340] = {.lex_state = 477, .external_lex_state = 103},
  [5341] = {.lex_state = 480, .external_lex_state = 104},
  [5342] = {.lex_state = 480, .external_lex_state = 104},
  [5343] = {.lex_state = 481, .external_lex_state = 99},
  [5344] = {.lex_state = 454, .external_lex_state = 48},
  [5345] = {.lex_state = 477, .external_lex_state = 103},
  [5346] = {.lex_state = 477, .external_lex_state = 103},
  [5347] = {.lex_state = 480, .external_lex_state = 104},
  [5348] = {.lex_state = 477, .external_lex_state = 104},
  [5349] = {.lex_state = 480, .external_lex_state = 104},
  [5350] = {.lex_state = 477, .external_lex_state = 104},
  [5351] = {.lex_state = 480, .external_lex_state = 104},
  [5352] = {.lex_state = 480, .external_lex_state = 104},
  [5353] = {.lex_state = 94, .external_lex_state = 106},
  [5354] = {.lex_state = 454, .external_lex_state = 48},
  [5355] = {.lex_state = 480, .external_lex_state = 104},
  [5356] = {.lex_state = 454, .external_lex_state = 48},
  [5357] = {.lex_state = 477, .external_lex_state = 103},
  [5358] = {.lex_state = 477, .external_lex_state = 103},
  [5359] = {.lex_state = 478, .external_lex_state = 102},
  [5360] = {.lex_state = 481, .external_lex_state = 99},
  [5361] = {.lex_state = 454, .external_lex_state = 48},
  [5362] = {.lex_state = 454, .external_lex_state = 48},
  [5363] = {.lex_state = 454, .external_lex_state = 48},
  [5364] = {.lex_state = 454, .external_lex_state = 48},
  [5365] = {.lex_state = 477, .external_lex_state = 103},
  [5366] = {.lex_state = 454, .external_lex_state = 48},
  [5367] = {.lex_state = 477, .external_lex_state = 103},
  [5368] = {.lex_state = 454, .external_lex_state = 48},
  [5369] = {.lex_state = 454, .external_lex_state = 48},
  [5370] = {.lex_state = 477, .external_lex_state = 103},
  [5371] = {.lex_state = 468, .external_lex_state = 102},
  [5372] = {.lex_state = 454, .external_lex_state = 48},
  [5373] = {.lex_state = 468, .external_lex_state = 102},
  [5374] = {.lex_state = 454, .external_lex_state = 48},
  [5375] = {.lex_state = 480, .external_lex_state = 104},
  [5376] = {.lex_state = 454, .external_lex_state = 48},
  [5377] = {.lex_state = 480, .external_lex_state = 104},
  [5378] = {.lex_state = 454, .external_lex_state = 48},
  [5379] = {.lex_state = 454, .external_lex_state = 48},
  [5380] = {.lex_state = 454, .external_lex_state = 48},
  [5381] = {.lex_state = 468, .external_lex_state = 102},
  [5382] = {.lex_state = 477, .external_lex_state = 103},
  [5383] = {.lex_state = 454, .external_lex_state = 48},
  [5384] = {.lex_state = 477, .external_lex_state = 103},
  [5385] = {.lex_state = 454, .external_lex_state = 48},
  [5386] = {.lex_state = 480, .external_lex_state = 104},
  [5387] = {.lex_state = 454, .external_lex_state = 48},
  [5388] = {.lex_state = 454, .external_lex_state = 78},
  [5389] = {.lex_state = 454, .external_lex_state = 48},
  [5390] = {.lex_state = 454, .external_lex_state = 78},
  [5391] = {.lex_state = 481, .external_lex_state = 99},
  [5392] = {.lex_state = 480, .external_lex_state = 104},
  [5393] = {.lex_state = 481, .external_lex_state = 99},
  [5394] = {.lex_state = 468, .external_lex_state = 101},
  [5395] = {.lex_state = 477, .external_lex_state = 104},
  [5396] = {.lex_state = 468, .external_lex_state = 102},
  [5397] = {.lex_state = 477, .external_lex_state = 104},
  [5398] = {.lex_state = 454, .external_lex_state = 48},
  [5399] = {.lex_state = 454, .external_lex_state = 48},
  [5400] = {.lex_state = 454, .external_lex_state = 48},
  [5401] = {.lex_state = 454, .external_lex_state = 48},
  [5402] = {.lex_state = 454, .external_lex_state = 48},
  [5403] = {.lex_state = 454, .external_lex_state = 48},
  [5404] = {.lex_state = 477, .external_lex_state = 104},
  [5405] = {.lex_state = 477, .external_lex_state = 102},
  [5406] = {.lex_state = 477, .external_lex_state = 104},
  [5407] = {.lex_state = 445, .external_lex_state = 101},
  [5408] = {.lex_state = 445, .external_lex_state = 101},
  [5409] = {.lex_state = 454, .external_lex_state = 78},
  [5410] = {.lex_state = 94, .external_lex_state = 108},
  [5411] = {.lex_state = 477, .external_lex_state = 81},
  [5412] = {.lex_state = 96, .external_lex_state = 92},
  [5413] = {.lex_state = 477, .external_lex_state = 102},
  [5414] = {.lex_state = 97, .external_lex_state = 109},
  [5415] = {.lex_state = 445, .external_lex_state = 101},
  [5416] = {.lex_state = 96, .external_lex_state = 92},
  [5417] = {.lex_state = 94, .external_lex_state = 108},
  [5418] = {.lex_state = 94, .external_lex_state = 108},
  [5419] = {.lex_state = 477, .external_lex_state = 104},
  [5420] = {.lex_state = 477, .external_lex_state = 104},
  [5421] = {.lex_state = 94, .external_lex_state = 108},
  [5422] = {.lex_state = 477, .external_lex_state = 104},
  [5423] = {.lex_state = 477, .external_lex_state = 104},
  [5424] = {.lex_state = 477, .external_lex_state = 104},
  [5425] = {.lex_state = 477, .external_lex_state = 104},
  [5426] = {.lex_state = 94, .external_lex_state = 108},
  [5427] = {.lex_state = 468, .external_lex_state = 101},
  [5428] = {.lex_state = 477, .external_lex_state = 104},
  [5429] = {.lex_state = 477, .external_lex_state = 104},
  [5430] = {.lex_state = 477, .external_lex_state = 104},
  [5431] = {.lex_state = 477, .external_lex_state = 102},
  [5432] = {.lex_state = 94, .external_lex_state = 106},
  [5433] = {.lex_state = 445, .external_lex_state = 101},
  [5434] = {.lex_state = 477, .external_lex_state = 102},
  [5435] = {.lex_state = 94, .external_lex_state = 108},
  [5436] = {.lex_state = 94, .external_lex_state = 108},
  [5437] = {.lex_state = 477, .external_lex_state = 104},
  [5438] = {.lex_state = 478, .external_lex_state = 102},
  [5439] = {.lex_state = 477, .external_lex_state = 104},
  [5440] = {.lex_state = 477, .external_lex_state = 104},
  [5441] = {.lex_state = 96, .external_lex_state = 92},
  [5442] = {.lex_state = 477, .external_lex_state = 104},
  [5443] = {.lex_state = 96, .external_lex_state = 92},
  [5444] = {.lex_state = 477, .external_lex_state = 102},
  [5445] = {.lex_state = 94, .external_lex_state = 108},
  [5446] = {.lex_state = 94, .external_lex_state = 108},
  [5447] = {.lex_state = 257, .external_lex_state = 71},
  [5448] = {.lex_state = 477, .external_lex_state = 104},
  [5449] = {.lex_state = 477, .external_lex_state = 104},
  [5450] = {.lex_state = 477, .external_lex_state = 104},
  [5451] = {.lex_state = 94, .external_lex_state = 108},
  [5452] = {.lex_state = 94, .external_lex_state = 106},
  [5453] = {.lex_state = 477, .external_lex_state = 104},
  [5454] = {.lex_state = 94, .external_lex_state = 106},
  [5455] = {.lex_state = 468, .external_lex_state = 101},
  [5456] = {.lex_state = 445, .external_lex_state = 102},
  [5457] = {.lex_state = 94, .external_lex_state = 108},
  [5458] = {.lex_state = 468, .external_lex_state = 102},
  [5459] = {.lex_state = 468, .external_lex_state = 101},
  [5460] = {.lex_state = 468, .external_lex_state = 101},
  [5461] = {.lex_state = 468, .external_lex_state = 101},
  [5462] = {.lex_state = 97, .external_lex_state = 109},
  [5463] = {.lex_state = 445, .external_lex_state = 102},
  [5464] = {.lex_state = 468, .external_lex_state = 101},
  [5465] = {.lex_state = 468, .external_lex_state = 101},
  [5466] = {.lex_state = 468, .external_lex_state = 101},
  [5467] = {.lex_state = 468, .external_lex_state = 101},
  [5468] = {.lex_state = 468, .external_lex_state = 101},
  [5469] = {.lex_state = 468, .external_lex_state = 101},
  [5470] = {.lex_state = 468, .external_lex_state = 101},
  [5471] = {.lex_state = 468, .external_lex_state = 101},
  [5472] = {.lex_state = 468, .external_lex_state = 101},
  [5473] = {.lex_state = 468, .external_lex_state = 101},
  [5474] = {.lex_state = 445, .external_lex_state = 102},
  [5475] = {.lex_state = 468, .external_lex_state = 101},
  [5476] = {.lex_state = 468, .external_lex_state = 101},
  [5477] = {.lex_state = 468, .external_lex_state = 101},
  [5478] = {.lex_state = 468, .external_lex_state = 101},
  [5479] = {.lex_state = 468, .external_lex_state = 101},
  [5480] = {.lex_state = 468, .external_lex_state = 101},
  [5481] = {.lex_state = 468, .external_lex_state = 101},
  [5482] = {.lex_state = 445, .external_lex_state = 102},
  [5483] = {.lex_state = 97, .external_lex_state = 109},
  [5484] = {.lex_state = 445, .external_lex_state = 102},
  [5485] = {.lex_state = 445, .external_lex_state = 102},
  [5486] = {.lex_state = 97, .external_lex_state = 109},
  [5487] = {.lex_state = 468, .external_lex_state = 101},
  [5488] = {.lex_state = 468, .external_lex_state = 101},
  [5489] = {.lex_state = 97, .external_lex_state = 109},
  [5490] = {.lex_state = 445, .external_lex_state = 76},
  [5491] = {.lex_state = 468, .external_lex_state = 102},
  [5492] = {.lex_state = 477, .external_lex_state = 102},
  [5493] = {.lex_state = 445, .external_lex_state = 102},
  [5494] = {.lex_state = 270, .external_lex_state = 110},
  [5495] = {.lex_state = 468, .external_lex_state = 81},
  [5496] = {.lex_state = 97, .external_lex_state = 109},
  [5497] = {.lex_state = 445, .external_lex_state = 102},
  [5498] = {.lex_state = 97, .external_lex_state = 109},
  [5499] = {.lex_state = 270, .external_lex_state = 110},
  [5500] = {.lex_state = 468, .external_lex_state = 102},
  [5501] = {.lex_state = 468, .external_lex_state = 102},
  [5502] = {.lex_state = 468, .external_lex_state = 101},
  [5503] = {.lex_state = 97, .external_lex_state = 109},
  [5504] = {.lex_state = 445, .external_lex_state = 102},
  [5505] = {.lex_state = 468, .external_lex_state = 101},
  [5506] = {.lex_state = 445, .external_lex_state = 102},
  [5507] = {.lex_state = 468, .external_lex_state = 81},
  [5508] = {.lex_state = 445, .external_lex_state = 102},
  [5509] = {.lex_state = 468, .external_lex_state = 102},
  [5510] = {.lex_state = 468, .external_lex_state = 102},
  [5511] = {.lex_state = 445, .external_lex_state = 102},
  [5512] = {.lex_state = 468, .external_lex_state = 102},
  [5513] = {.lex_state = 97, .external_lex_state = 109},
  [5514] = {.lex_state = 445, .external_lex_state = 102},
  [5515] = {.lex_state = 445, .external_lex_state = 102},
  [5516] = {.lex_state = 468, .external_lex_state = 102},
  [5517] = {.lex_state = 468, .external_lex_state = 102},
  [5518] = {.lex_state = 468, .external_lex_state = 102},
  [5519] = {.lex_state = 468, .external_lex_state = 102},
  [5520] = {.lex_state = 468, .external_lex_state = 102},
  [5521] = {.lex_state = 445, .external_lex_state = 102},
  [5522] = {.lex_state = 468, .external_lex_state = 81},
  [5523] = {.lex_state = 445, .external_lex_state = 102},
  [5524] = {.lex_state = 97, .external_lex_state = 109},
  [5525] = {.lex_state = 97, .external_lex_state = 109},
  [5526] = {.lex_state = 445, .external_lex_state = 102},
  [5527] = {.lex_state = 97, .external_lex_state = 109},
  [5528] = {.lex_state = 445, .external_lex_state = 102},
  [5529] = {.lex_state = 97, .external_lex_state = 109},
  [5530] = {.lex_state = 468, .external_lex_state = 102},
  [5531] = {.lex_state = 97, .external_lex_state = 109},
  [5532] = {.lex_state = 97, .external_lex_state = 109},
  [5533] = {.lex_state = 468, .external_lex_state = 102},
  [5534] = {.lex_state = 97, .external_lex_state = 109},
  [5535] = {.lex_state = 468, .external_lex_state = 102},
  [5536] = {.lex_state = 468, .external_lex_state = 102},
  [5537] = {.lex_state = 468, .external_lex_state = 102},
  [5538] = {.lex_state = 468, .external_lex_state = 102},
  [5539] = {.lex_state = 468, .external_lex_state = 102},
  [5540] = {.lex_state = 468, .external_lex_state = 102},
  [5541] = {.lex_state = 97, .external_lex_state = 109},
  [5542] = {.lex_state = 468, .external_lex_state = 102},
  [5543] = {.lex_state = 468, .external_lex_state = 102},
  [5544] = {.lex_state = 468, .external_lex_state = 102},
  [5545] = {.lex_state = 97, .external_lex_state = 109},
  [5546] = {.lex_state = 97, .external_lex_state = 109},
  [5547] = {.lex_state = 468, .external_lex_state = 102},
  [5548] = {.lex_state = 468, .external_lex_state = 102},
  [5549] = {.lex_state = 468, .external_lex_state = 102},
  [5550] = {.lex_state = 468, .external_lex_state = 102},
  [5551] = {.lex_state = 468, .external_lex_state = 102},
  [5552] = {.lex_state = 97, .external_lex_state = 108},
  [5553] = {.lex_state = 468, .external_lex_state = 102},
  [5554] = {.lex_state = 468, .external_lex_state = 102},
  [5555] = {.lex_state = 97, .external_lex_state = 109},
  [5556] = {.lex_state = 97, .external_lex_state = 109},
  [5557] = {.lex_state = 97, .external_lex_state = 109},
  [5558] = {.lex_state = 97, .external_lex_state = 108},
  [5559] = {.lex_state = 97, .external_lex_state = 109},
  [5560] = {.lex_state = 468, .external_lex_state = 102},
  [5561] = {.lex_state = 97, .external_lex_state = 109},
  [5562] = {.lex_state = 468, .external_lex_state = 102},
  [5563] = {.lex_state = 468, .external_lex_state = 102},
  [5564] = {.lex_state = 468, .external_lex_state = 102},
  [5565] = {.lex_state = 468, .external_lex_state = 102},
  [5566] = {.lex_state = 468, .external_lex_state = 102},
  [5567] = {.lex_state = 468, .external_lex_state = 102},
  [5568] = {.lex_state = 468, .external_lex_state = 102},
  [5569] = {.lex_state = 468, .external_lex_state = 102},
  [5570] = {.lex_state = 468, .external_lex_state = 102},
  [5571] = {.lex_state = 97, .external_lex_state = 109},
  [5572] = {.lex_state = 97, .external_lex_state = 109},
  [5573] = {.lex_state = 468, .external_lex_state = 102},
  [5574] = {.lex_state = 468, .external_lex_state = 102},
  [5575] = {.lex_state = 468, .external_lex_state = 102},
  [5576] = {.lex_state = 468, .external_lex_state = 102},
  [5577] = {.lex_state = 468, .external_lex_state = 102},
  [5578] = {.lex_state = 468, .external_lex_state = 102},
  [5579] = {.lex_state = 468, .external_lex_state = 102},
  [5580] = {.lex_state = 468, .external_lex_state = 102},
  [5581] = {.lex_state = 468, .external_lex_state = 102},
  [5582] = {.lex_state = 468, .external_lex_state = 102},
  [5583] = {.lex_state = 468, .external_lex_state = 102},
  [5584] = {.lex_state = 468, .external_lex_state = 102},
  [5585] = {.lex_state = 468, .external_lex_state = 102},
  [5586] = {.lex_state = 468, .external_lex_state = 102},
  [5587] = {.lex_state = 468, .external_lex_state = 102},
  [5588] = {.lex_state = 468, .external_lex_state = 102},
  [5589] = {.lex_state = 468, .external_lex_state = 102},
  [5590] = {.lex_state = 468, .external_lex_state = 102},
  [5591] = {.lex_state = 468, .external_lex_state = 102},
  [5592] = {.lex_state = 468, .external_lex_state = 102},
  [5593] = {.lex_state = 468, .external_lex_state = 102},
  [5594] = {.lex_state = 468, .external_lex_state = 102},
  [5595] = {.lex_state = 97, .external_lex_state = 108},
  [5596] = {.lex_state = 97, .external_lex_state = 108},
  [5597] = {.lex_state = 468, .external_lex_state = 102},
  [5598] = {.lex_state = 97, .external_lex_state = 109},
  [5599] = {.lex_state = 468, .external_lex_state = 102},
  [5600] = {.lex_state = 97, .external_lex_state = 108},
  [5601] = {.lex_state = 468, .external_lex_state = 102},
  [5602] = {.lex_state = 468, .external_lex_state = 102},
  [5603] = {.lex_state = 97, .external_lex_state = 109},
  [5604] = {.lex_state = 468, .external_lex_state = 102},
  [5605] = {.lex_state = 468, .external_lex_state = 102},
  [5606] = {.lex_state = 97, .external_lex_state = 109},
  [5607] = {.lex_state = 97, .external_lex_state = 109},
  [5608] = {.lex_state = 468, .external_lex_state = 102},
  [5609] = {.lex_state = 97, .external_lex_state = 109},
  [5610] = {.lex_state = 97, .external_lex_state = 108},
  [5611] = {.lex_state = 94, .external_lex_state = 108},
  [5612] = {.lex_state = 94, .external_lex_state = 108},
  [5613] = {.lex_state = 94, .external_lex_state = 108},
  [5614] = {.lex_state = 94, .external_lex_state = 108},
  [5615] = {.lex_state = 442, .external_lex_state = 111},
  [5616] = {.lex_state = 449, .external_lex_state = 111},
  [5617] = {.lex_state = 442, .external_lex_state = 111},
  [5618] = {.lex_state = 449, .external_lex_state = 111},
  [5619] = {.lex_state = 474},
  [5620] = {.lex_state = 474},
  [5621] = {.lex_state = 474},
  [5622] = {.lex_state = 474},
  [5623] = {.lex_state = 474},
  [5624] = {.lex_state = 474},
  [5625] = {.lex_state = 474},
  [5626] = {.lex_state = 474},
  [5627] = {.lex_state = 474},
  [5628] = {.lex_state = 474},
  [5629] = {.lex_state = 474},
  [5630] = {.lex_state = 474},
  [5631] = {.lex_state = 474},
  [5632] = {.lex_state = 474},
  [5633] = {.lex_state = 474},
  [5634] = {.lex_state = 474},
  [5635] = {.lex_state = 474},
  [5636] = {.lex_state = 474},
  [5637] = {.lex_state = 474},
  [5638] = {.lex_state = 474},
  [5639] = {.lex_state = 474},
  [5640] = {.lex_state = 474},
  [5641] = {.lex_state = 474},
  [5642] = {.lex_state = 474},
  [5643] = {.lex_state = 474},
  [5644] = {.lex_state = 474},
  [5645] = {.lex_state = 474},
  [5646] = {.lex_state = 474},
  [5647] = {.lex_state = 474},
  [5648] = {.lex_state = 474},
  [5649] = {.lex_state = 474},
  [5650] = {.lex_state = 474},
  [5651] = {.lex_state = 474},
  [5652] = {.lex_state = 474},
  [5653] = {.lex_state = 474},
  [5654] = {.lex_state = 474},
  [5655] = {.lex_state = 474},
  [5656] = {.lex_state = 474},
  [5657] = {.lex_state = 474},
  [5658] = {.lex_state = 474},
  [5659] = {.lex_state = 474},
  [5660] = {.lex_state = 474},
  [5661] = {.lex_state = 474},
  [5662] = {.lex_state = 474},
  [5663] = {.lex_state = 474},
  [5664] = {.lex_state = 474},
  [5665] = {.lex_state = 474},
  [5666] = {.lex_state = 474},
  [5667] = {.lex_state = 474},
  [5668] = {.lex_state = 474},
  [5669] = {.lex_state = 474},
  [5670] = {.lex_state = 474},
  [5671] = {.lex_state = 474},
  [5672] = {.lex_state = 474},
  [5673] = {.lex_state = 474},
  [5674] = {.lex_state = 474},
  [5675] = {.lex_state = 474},
  [5676] = {.lex_state = 474},
  [5677] = {.lex_state = 474},
  [5678] = {.lex_state = 474},
  [5679] = {.lex_state = 474},
  [5680] = {.lex_state = 474},
  [5681] = {.lex_state = 474},
  [5682] = {.lex_state = 474},
  [5683] = {.lex_state = 474},
  [5684] = {.lex_state = 474},
  [5685] = {.lex_state = 474},
  [5686] = {.lex_state = 474},
  [5687] = {.lex_state = 474},
  [5688] = {.lex_state = 474},
  [5689] = {.lex_state = 474},
  [5690] = {.lex_state = 474},
  [5691] = {.lex_state = 474},
  [5692] = {.lex_state = 474},
  [5693] = {.lex_state = 474},
  [5694] = {.lex_state = 474},
  [5695] = {.lex_state = 474},
  [5696] = {.lex_state = 474},
  [5697] = {.lex_state = 474},
  [5698] = {.lex_state = 474},
  [5699] = {.lex_state = 474},
  [5700] = {.lex_state = 474},
  [5701] = {.lex_state = 474},
  [5702] = {.lex_state = 474},
  [5703] = {.lex_state = 474},
  [5704] = {.lex_state = 474},
  [5705] = {.lex_state = 474},
  [5706] = {.lex_state = 474},
  [5707] = {.lex_state = 474},
  [5708] = {.lex_state = 474},
  [5709] = {.lex_state = 474},
  [5710] = {.lex_state = 474},
  [5711] = {.lex_state = 474},
  [5712] = {.lex_state = 474},
  [5713] = {.lex_state = 474},
  [5714] = {.lex_state = 474},
  [5715] = {.lex_state = 474},
  [5716] = {.lex_state = 474},
  [5717] = {.lex_state = 474},
  [5718] = {.lex_state = 474},
  [5719] = {.lex_state = 474},
  [5720] = {.lex_state = 474},
  [5721] = {.lex_state = 474},
  [5722] = {.lex_state = 474},
  [5723] = {.lex_state = 474},
  [5724] = {.lex_state = 474},
  [5725] = {.lex_state = 474},
  [5726] = {.lex_state = 474},
  [5727] = {.lex_state = 474},
  [5728] = {.lex_state = 474},
  [5729] = {.lex_state = 474},
  [5730] = {.lex_state = 474},
  [5731] = {.lex_state = 474},
  [5732] = {.lex_state = 474},
  [5733] = {.lex_state = 474},
  [5734] = {.lex_state = 474},
  [5735] = {.lex_state = 474},
  [5736] = {.lex_state = 474},
  [5737] = {.lex_state = 474},
  [5738] = {.lex_state = 474},
  [5739] = {.lex_state = 474},
  [5740] = {.lex_state = 474},
  [5741] = {.lex_state = 474},
  [5742] = {.lex_state = 474},
  [5743] = {.lex_state = 474},
  [5744] = {.lex_state = 474},
  [5745] = {.lex_state = 474},
  [5746] = {.lex_state = 474},
  [5747] = {.lex_state = 474},
  [5748] = {.lex_state = 474},
  [5749] = {.lex_state = 474},
  [5750] = {.lex_state = 474},
  [5751] = {.lex_state = 474},
  [5752] = {.lex_state = 474},
  [5753] = {.lex_state = 474},
  [5754] = {.lex_state = 474},
  [5755] = {.lex_state = 474},
  [5756] = {.lex_state = 474},
  [5757] = {.lex_state = 474},
  [5758] = {.lex_state = 474},
  [5759] = {.lex_state = 474},
  [5760] = {.lex_state = 474},
  [5761] = {.lex_state = 474},
  [5762] = {.lex_state = 474},
  [5763] = {.lex_state = 474},
  [5764] = {.lex_state = 474},
  [5765] = {.lex_state = 474},
  [5766] = {.lex_state = 474},
  [5767] = {.lex_state = 474},
  [5768] = {.lex_state = 474},
  [5769] = {.lex_state = 474},
  [5770] = {.lex_state = 474},
  [5771] = {.lex_state = 474},
  [5772] = {.lex_state = 474},
  [5773] = {.lex_state = 474},
  [5774] = {.lex_state = 443, .external_lex_state = 111},
  [5775] = {.lex_state = 443, .external_lex_state = 111},
  [5776] = {.lex_state = 443, .external_lex_state = 111},
  [5777] = {.lex_state = 444, .external_lex_state = 111},
  [5778] = {.lex_state = 445, .external_lex_state = 112},
  [5779] = {.lex_state = 443, .external_lex_state = 111},
  [5780] = {.lex_state = 443, .external_lex_state = 111},
  [5781] = {.lex_state = 444, .external_lex_state = 111},
  [5782] = {.lex_state = 443, .external_lex_state = 111},
  [5783] = {.lex_state = 443, .external_lex_state = 111},
  [5784] = {.lex_state = 443, .external_lex_state = 111},
  [5785] = {.lex_state = 445, .external_lex_state = 112},
  [5786] = {.lex_state = 443, .external_lex_state = 111},
  [5787] = {.lex_state = 443, .external_lex_state = 111},
  [5788] = {.lex_state = 444, .external_lex_state = 111},
  [5789] = {.lex_state = 443, .external_lex_state = 111},
  [5790] = {.lex_state = 443, .external_lex_state = 111},
  [5791] = {.lex_state = 443, .external_lex_state = 111},
  [5792] = {.lex_state = 443, .external_lex_state = 111},
  [5793] = {.lex_state = 444, .external_lex_state = 111},
  [5794] = {.lex_state = 443, .external_lex_state = 111},
  [5795] = {.lex_state = 443, .external_lex_state = 111},
  [5796] = {.lex_state = 443, .external_lex_state = 111},
  [5797] = {.lex_state = 445, .external_lex_state = 112},
  [5798] = {.lex_state = 443, .external_lex_state = 111},
  [5799] = {.lex_state = 444, .external_lex_state = 111},
  [5800] = {.lex_state = 443, .external_lex_state = 111},
  [5801] = {.lex_state = 444, .external_lex_state = 111},
  [5802] = {.lex_state = 443, .external_lex_state = 111},
  [5803] = {.lex_state = 443, .external_lex_state = 111},
  [5804] = {.lex_state = 444, .external_lex_state = 111},
  [5805] = {.lex_state = 443, .external_lex_state = 111},
  [5806] = {.lex_state = 443, .external_lex_state = 111},
  [5807] = {.lex_state = 444, .external_lex_state = 111},
  [5808] = {.lex_state = 443, .external_lex_state = 111},
  [5809] = {.lex_state = 443, .external_lex_state = 111},
  [5810] = {.lex_state = 443, .external_lex_state = 111},
  [5811] = {.lex_state = 443, .external_lex_state = 111},
  [5812] = {.lex_state = 444, .external_lex_state = 111},
  [5813] = {.lex_state = 443, .external_lex_state = 111},
  [5814] = {.lex_state = 443, .external_lex_state = 111},
  [5815] = {.lex_state = 444, .external_lex_state = 111},
  [5816] = {.lex_state = 443, .external_lex_state = 111},
  [5817] = {.lex_state = 443, .external_lex_state = 111},
  [5818] = {.lex_state = 443, .external_lex_state = 111},
  [5819] = {.lex_state = 443, .external_lex_state = 111},
  [5820] = {.lex_state = 444, .external_lex_state = 111},
  [5821] = {.lex_state = 443, .external_lex_state = 111},
  [5822] = {.lex_state = 443, .external_lex_state = 111},
  [5823] = {.lex_state = 443, .external_lex_state = 111},
  [5824] = {.lex_state = 443, .external_lex_state = 111},
  [5825] = {.lex_state = 443, .external_lex_state = 111},
  [5826] = {.lex_state = 444, .external_lex_state = 111},
  [5827] = {.lex_state = 443, .external_lex_state = 111},
  [5828] = {.lex_state = 443, .external_lex_state = 111},
  [5829] = {.lex_state = 443, .external_lex_state = 111},
  [5830] = {.lex_state = 444, .external_lex_state = 111},
  [5831] = {.lex_state = 444, .external_lex_state = 111},
  [5832] = {.lex_state = 443, .external_lex_state = 111},
  [5833] = {.lex_state = 443, .external_lex_state = 111},
  [5834] = {.lex_state = 443, .external_lex_state = 111},
  [5835] = {.lex_state = 443, .external_lex_state = 111},
  [5836] = {.lex_state = 444, .external_lex_state = 111},
  [5837] = {.lex_state = 443, .external_lex_state = 111},
  [5838] = {.lex_state = 443, .external_lex_state = 111},
  [5839] = {.lex_state = 444, .external_lex_state = 111},
  [5840] = {.lex_state = 443, .external_lex_state = 111},
  [5841] = {.lex_state = 444, .external_lex_state = 111},
  [5842] = {.lex_state = 444, .external_lex_state = 111},
  [5843] = {.lex_state = 443, .external_lex_state = 111},
  [5844] = {.lex_state = 443, .external_lex_state = 111},
  [5845] = {.lex_state = 443, .external_lex_state = 111},
  [5846] = {.lex_state = 444, .external_lex_state = 111},
  [5847] = {.lex_state = 443, .external_lex_state = 111},
  [5848] = {.lex_state = 443, .external_lex_state = 111},
  [5849] = {.lex_state = 443, .external_lex_state = 111},
  [5850] = {.lex_state = 444, .external_lex_state = 111},
  [5851] = {.lex_state = 444, .external_lex_state = 111},
  [5852] = {.lex_state = 443, .external_lex_state = 111},
  [5853] = {.lex_state = 443, .external_lex_state = 111},
  [5854] = {.lex_state = 445, .external_lex_state = 112},
  [5855] = {.lex_state = 443, .external_lex_state = 111},
  [5856] = {.lex_state = 443, .external_lex_state = 111},
  [5857] = {.lex_state = 443, .external_lex_state = 111},
  [5858] = {.lex_state = 444, .external_lex_state = 111},
  [5859] = {.lex_state = 444, .external_lex_state = 111},
  [5860] = {.lex_state = 443, .external_lex_state = 111},
  [5861] = {.lex_state = 443, .external_lex_state = 111},
  [5862] = {.lex_state = 443, .external_lex_state = 111},
  [5863] = {.lex_state = 443, .external_lex_state = 111},
  [5864] = {.lex_state = 443, .external_lex_state = 111},
  [5865] = {.lex_state = 443, .external_lex_state = 111},
  [5866] = {.lex_state = 444, .external_lex_state = 111},
  [5867] = {.lex_state = 444, .external_lex_state = 111},
  [5868] = {.lex_state = 443, .external_lex_state = 111},
  [5869] = {.lex_state = 443, .external_lex_state = 111},
  [5870] = {.lex_state = 443, .external_lex_state = 111},
  [5871] = {.lex_state = 443, .external_lex_state = 111},
  [5872] = {.lex_state = 443, .external_lex_state = 111},
  [5873] = {.lex_state = 444, .external_lex_state = 111},
  [5874] = {.lex_state = 443, .external_lex_state = 111},
  [5875] = {.lex_state = 443, .external_lex_state = 111},
  [5876] = {.lex_state = 443, .external_lex_state = 111},
  [5877] = {.lex_state = 444, .external_lex_state = 111},
  [5878] = {.lex_state = 443, .external_lex_state = 111},
  [5879] = {.lex_state = 443, .external_lex_state = 111},
  [5880] = {.lex_state = 444, .external_lex_state = 111},
  [5881] = {.lex_state = 443, .external_lex_state = 111},
  [5882] = {.lex_state = 443, .external_lex_state = 111},
  [5883] = {.lex_state = 444, .external_lex_state = 111},
  [5884] = {.lex_state = 443, .external_lex_state = 111},
  [5885] = {.lex_state = 443, .external_lex_state = 111},
  [5886] = {.lex_state = 443, .external_lex_state = 111},
  [5887] = {.lex_state = 444, .external_lex_state = 111},
  [5888] = {.lex_state = 443, .external_lex_state = 111},
  [5889] = {.lex_state = 443, .external_lex_state = 111},
  [5890] = {.lex_state = 443, .external_lex_state = 111},
  [5891] = {.lex_state = 443, .external_lex_state = 111},
  [5892] = {.lex_state = 443, .external_lex_state = 111},
  [5893] = {.lex_state = 444, .external_lex_state = 111},
  [5894] = {.lex_state = 443, .external_lex_state = 111},
  [5895] = {.lex_state = 444, .external_lex_state = 111},
  [5896] = {.lex_state = 443, .external_lex_state = 111},
  [5897] = {.lex_state = 443, .external_lex_state = 111},
  [5898] = {.lex_state = 443, .external_lex_state = 111},
  [5899] = {.lex_state = 443, .external_lex_state = 111},
  [5900] = {.lex_state = 444, .external_lex_state = 111},
  [5901] = {.lex_state = 444, .external_lex_state = 111},
  [5902] = {.lex_state = 443, .external_lex_state = 111},
  [5903] = {.lex_state = 445, .external_lex_state = 112},
  [5904] = {.lex_state = 443, .external_lex_state = 111},
  [5905] = {.lex_state = 443, .external_lex_state = 111},
  [5906] = {.lex_state = 444, .external_lex_state = 111},
  [5907] = {.lex_state = 443, .external_lex_state = 111},
  [5908] = {.lex_state = 443, .external_lex_state = 111},
  [5909] = {.lex_state = 443, .external_lex_state = 111},
  [5910] = {.lex_state = 443, .external_lex_state = 111},
  [5911] = {.lex_state = 443, .external_lex_state = 111},
  [5912] = {.lex_state = 444, .external_lex_state = 111},
  [5913] = {.lex_state = 443, .external_lex_state = 111},
  [5914] = {.lex_state = 443, .external_lex_state = 111},
  [5915] = {.lex_state = 443, .external_lex_state = 111},
  [5916] = {.lex_state = 443, .external_lex_state = 111},
  [5917] = {.lex_state = 444, .external_lex_state = 111},
  [5918] = {.lex_state = 443, .external_lex_state = 111},
  [5919] = {.lex_state = 443, .external_lex_state = 111},
  [5920] = {.lex_state = 443, .external_lex_state = 111},
  [5921] = {.lex_state = 444, .external_lex_state = 111},
  [5922] = {.lex_state = 443, .external_lex_state = 111},
  [5923] = {.lex_state = 443, .external_lex_state = 111},
  [5924] = {.lex_state = 443, .external_lex_state = 111},
  [5925] = {.lex_state = 444, .external_lex_state = 111},
  [5926] = {.lex_state = 443, .external_lex_state = 111},
  [5927] = {.lex_state = 443, .external_lex_state = 111},
  [5928] = {.lex_state = 444, .external_lex_state = 111},
  [5929] = {.lex_state = 444, .external_lex_state = 111},
  [5930] = {.lex_state = 444, .external_lex_state = 111},
  [5931] = {.lex_state = 443, .external_lex_state = 111},
  [5932] = {.lex_state = 443, .external_lex_state = 111},
  [5933] = {.lex_state = 445, .external_lex_state = 112},
  [5934] = {.lex_state = 443, .external_lex_state = 111},
  [5935] = {.lex_state = 444, .external_lex_state = 111},
  [5936] = {.lex_state = 443, .external_lex_state = 111},
  [5937] = {.lex_state = 443, .external_lex_state = 111},
  [5938] = {.lex_state = 443, .external_lex_state = 111},
  [5939] = {.lex_state = 443, .external_lex_state = 111},
  [5940] = {.lex_state = 444, .external_lex_state = 111},
  [5941] = {.lex_state = 443, .external_lex_state = 111},
  [5942] = {.lex_state = 443, .external_lex_state = 111},
  [5943] = {.lex_state = 443, .external_lex_state = 111},
  [5944] = {.lex_state = 444, .external_lex_state = 111},
  [5945] = {.lex_state = 443, .external_lex_state = 111},
  [5946] = {.lex_state = 443, .external_lex_state = 111},
  [5947] = {.lex_state = 443, .external_lex_state = 111},
  [5948] = {.lex_state = 444, .external_lex_state = 111},
  [5949] = {.lex_state = 444, .external_lex_state = 111},
  [5950] = {.lex_state = 443, .external_lex_state = 111},
  [5951] = {.lex_state = 444, .external_lex_state = 111},
  [5952] = {.lex_state = 443, .external_lex_state = 111},
  [5953] = {.lex_state = 443, .external_lex_state = 111},
  [5954] = {.lex_state = 443, .external_lex_state = 111},
  [5955] = {.lex_state = 443, .external_lex_state = 111},
  [5956] = {.lex_state = 444, .external_lex_state = 111},
  [5957] = {.lex_state = 444, .external_lex_state = 111},
  [5958] = {.lex_state = 443, .external_lex_state = 111},
  [5959] = {.lex_state = 443, .external_lex_state = 111},
  [5960] = {.lex_state = 443, .external_lex_state = 111},
  [5961] = {.lex_state = 443, .external_lex_state = 111},
  [5962] = {.lex_state = 444, .external_lex_state = 111},
  [5963] = {.lex_state = 443, .external_lex_state = 111},
  [5964] = {.lex_state = 445, .external_lex_state = 112},
  [5965] = {.lex_state = 443, .external_lex_state = 111},
  [5966] = {.lex_state = 443, .external_lex_state = 111},
  [5967] = {.lex_state = 443, .external_lex_state = 111},
  [5968] = {.lex_state = 444, .external_lex_state = 111},
  [5969] = {.lex_state = 443, .external_lex_state = 111},
  [5970] = {.lex_state = 444, .external_lex_state = 111},
  [5971] = {.lex_state = 443, .external_lex_state = 111},
  [5972] = {.lex_state = 444, .external_lex_state = 111},
  [5973] = {.lex_state = 444, .external_lex_state = 111},
  [5974] = {.lex_state = 443, .external_lex_state = 111},
  [5975] = {.lex_state = 444, .external_lex_state = 111},
  [5976] = {.lex_state = 444, .external_lex_state = 111},
  [5977] = {.lex_state = 443, .external_lex_state = 111},
  [5978] = {.lex_state = 443, .external_lex_state = 111},
  [5979] = {.lex_state = 443, .external_lex_state = 111},
  [5980] = {.lex_state = 445, .external_lex_state = 112},
  [5981] = {.lex_state = 443, .external_lex_state = 111},
  [5982] = {.lex_state = 443, .external_lex_state = 111},
  [5983] = {.lex_state = 443, .external_lex_state = 111},
  [5984] = {.lex_state = 443, .external_lex_state = 111},
  [5985] = {.lex_state = 444, .external_lex_state = 111},
  [5986] = {.lex_state = 444, .external_lex_state = 111},
  [5987] = {.lex_state = 443, .external_lex_state = 111},
  [5988] = {.lex_state = 444, .external_lex_state = 111},
  [5989] = {.lex_state = 443, .external_lex_state = 111},
  [5990] = {.lex_state = 444, .external_lex_state = 111},
  [5991] = {.lex_state = 443, .external_lex_state = 111},
  [5992] = {.lex_state = 443, .external_lex_state = 111},
  [5993] = {.lex_state = 443, .external_lex_state = 111},
  [5994] = {.lex_state = 444, .external_lex_state = 111},
  [5995] = {.lex_state = 444, .external_lex_state = 111},
  [5996] = {.lex_state = 443, .external_lex_state = 111},
  [5997] = {.lex_state = 443, .external_lex_state = 111},
  [5998] = {.lex_state = 444, .external_lex_state = 111},
  [5999] = {.lex_state = 443, .external_lex_state = 111},
  [6000] = {.lex_state = 468, .external_lex_state = 112},
  [6001] = {.lex_state = 468, .external_lex_state = 112},
  [6002] = {.lex_state = 468, .external_lex_state = 112},
  [6003] = {.lex_state = 468, .external_lex_state = 112},
  [6004] = {.lex_state = 94, .external_lex_state = 106},
  [6005] = {.lex_state = 94, .external_lex_state = 106},
  [6006] = {.lex_state = 468, .external_lex_state = 112},
  [6007] = {.lex_state = 468, .external_lex_state = 112},
  [6008] = {.lex_state = 468, .external_lex_state = 112},
  [6009] = {.lex_state = 468, .external_lex_state = 112},
  [6010] = {.lex_state = 446, .external_lex_state = 111},
  [6011] = {.lex_state = 468, .external_lex_state = 112},
  [6012] = {.lex_state = 479},
  [6013] = {.lex_state = 427, .external_lex_state = 113},
  [6014] = {.lex_state = 479},
  [6015] = {.lex_state = 469, .external_lex_state = 114},
  [6016] = {.lex_state = 447, .external_lex_state = 111},
  [6017] = {.lex_state = 479},
  [6018] = {.lex_state = 479},
  [6019] = {.lex_state = 447, .external_lex_state = 111},
  [6020] = {.lex_state = 479},
  [6021] = {.lex_state = 479},
  [6022] = {.lex_state = 479},
  [6023] = {.lex_state = 427, .external_lex_state = 113},
  [6024] = {.lex_state = 447, .external_lex_state = 111},
  [6025] = {.lex_state = 479},
  [6026] = {.lex_state = 479},
  [6027] = {.lex_state = 479},
  [6028] = {.lex_state = 447, .external_lex_state = 111},
  [6029] = {.lex_state = 479},
  [6030] = {.lex_state = 447, .external_lex_state = 111},
  [6031] = {.lex_state = 427, .external_lex_state = 113},
  [6032] = {.lex_state = 447, .external_lex_state = 111},
  [6033] = {.lex_state = 479},
  [6034] = {.lex_state = 479},
  [6035] = {.lex_state = 479},
  [6036] = {.lex_state = 479},
  [6037] = {.lex_state = 479},
  [6038] = {.lex_state = 479},
  [6039] = {.lex_state = 479},
  [6040] = {.lex_state = 479},
  [6041] = {.lex_state = 447, .external_lex_state = 111},
  [6042] = {.lex_state = 479},
  [6043] = {.lex_state = 479},
  [6044] = {.lex_state = 479},
  [6045] = {.lex_state = 447, .external_lex_state = 111},
  [6046] = {.lex_state = 479},
  [6047] = {.lex_state = 479},
  [6048] = {.lex_state = 479},
  [6049] = {.lex_state = 479},
  [6050] = {.lex_state = 447, .external_lex_state = 111},
  [6051] = {.lex_state = 479},
  [6052] = {.lex_state = 479, .external_lex_state = 96},
  [6053] = {.lex_state = 479, .external_lex_state = 96},
  [6054] = {.lex_state = 479, .external_lex_state = 96},
  [6055] = {.lex_state = 474, .external_lex_state = 115},
  [6056] = {.lex_state = 474, .external_lex_state = 115},
  [6057] = {.lex_state = 479, .external_lex_state = 96},
  [6058] = {.lex_state = 479, .external_lex_state = 96},
  [6059] = {.lex_state = 479, .external_lex_state = 96},
  [6060] = {.lex_state = 474, .external_lex_state = 115},
  [6061] = {.lex_state = 479, .external_lex_state = 96},
  [6062] = {.lex_state = 479, .external_lex_state = 96},
  [6063] = {.lex_state = 474, .external_lex_state = 115},
  [6064] = {.lex_state = 479, .external_lex_state = 96},
  [6065] = {.lex_state = 479, .external_lex_state = 96},
  [6066] = {.lex_state = 479, .external_lex_state = 96},
  [6067] = {.lex_state = 479, .external_lex_state = 96},
  [6068] = {.lex_state = 479, .external_lex_state = 96},
  [6069] = {.lex_state = 474, .external_lex_state = 115},
  [6070] = {.lex_state = 474, .external_lex_state = 115},
  [6071] = {.lex_state = 479, .external_lex_state = 96},
  [6072] = {.lex_state = 479, .external_lex_state = 96},
  [6073] = {.lex_state = 479, .external_lex_state = 96},
  [6074] = {.lex_state = 479, .external_lex_state = 96},
  [6075] = {.lex_state = 474, .external_lex_state = 115},
  [6076] = {.lex_state = 469},
  [6077] = {.lex_state = 474, .external_lex_state = 115},
  [6078] = {.lex_state = 479, .external_lex_state = 96},
  [6079] = {.lex_state = 479, .external_lex_state = 96},
  [6080] = {.lex_state = 474, .external_lex_state = 115},
  [6081] = {.lex_state = 479, .external_lex_state = 96},
  [6082] = {.lex_state = 474, .external_lex_state = 115},
  [6083] = {.lex_state = 474, .external_lex_state = 115},
  [6084] = {.lex_state = 479, .external_lex_state = 96},
  [6085] = {.lex_state = 480},
  [6086] = {.lex_state = 479, .external_lex_state = 96},
  [6087] = {.lex_state = 479, .external_lex_state = 96},
  [6088] = {.lex_state = 479, .external_lex_state = 96},
  [6089] = {.lex_state = 474},
  [6090] = {.lex_state = 98, .external_lex_state = 116},
  [6091] = {.lex_state = 470, .external_lex_state = 117},
  [6092] = {.lex_state = 474},
  [6093] = {.lex_state = 98, .external_lex_state = 116},
  [6094] = {.lex_state = 471, .external_lex_state = 118},
  [6095] = {.lex_state = 477},
  [6096] = {.lex_state = 98, .external_lex_state = 116},
  [6097] = {.lex_state = 471, .external_lex_state = 118},
  [6098] = {.lex_state = 98, .external_lex_state = 116},
  [6099] = {.lex_state = 98, .external_lex_state = 116},
  [6100] = {.lex_state = 471, .external_lex_state = 118},
  [6101] = {.lex_state = 98, .external_lex_state = 116},
  [6102] = {.lex_state = 98, .external_lex_state = 116},
  [6103] = {.lex_state = 98, .external_lex_state = 116},
  [6104] = {.lex_state = 477},
  [6105] = {.lex_state = 98, .external_lex_state = 116},
  [6106] = {.lex_state = 98, .external_lex_state = 116},
  [6107] = {.lex_state = 98, .external_lex_state = 116},
  [6108] = {.lex_state = 98, .external_lex_state = 116},
  [6109] = {.lex_state = 470, .external_lex_state = 114},
  [6110] = {.lex_state = 98, .external_lex_state = 116},
  [6111] = {.lex_state = 427, .external_lex_state = 113},
  [6112] = {.lex_state = 98, .external_lex_state = 119},
  [6113] = {.lex_state = 98, .external_lex_state = 116},
  [6114] = {.lex_state = 470, .external_lex_state = 114},
  [6115] = {.lex_state = 470, .external_lex_state = 114},
  [6116] = {.lex_state = 470, .external_lex_state = 114},
  [6117] = {.lex_state = 98, .external_lex_state = 119},
  [6118] = {.lex_state = 427, .external_lex_state = 113},
  [6119] = {.lex_state = 427, .external_lex_state = 113},
  [6120] = {.lex_state = 427, .external_lex_state = 113},
  [6121] = {.lex_state = 98, .external_lex_state = 119},
  [6122] = {.lex_state = 98, .external_lex_state = 116},
  [6123] = {.lex_state = 98, .external_lex_state = 116},
  [6124] = {.lex_state = 98, .external_lex_state = 116},
  [6125] = {.lex_state = 98, .external_lex_state = 116},
  [6126] = {.lex_state = 98, .external_lex_state = 116},
  [6127] = {.lex_state = 98, .external_lex_state = 116},
  [6128] = {.lex_state = 470, .external_lex_state = 114},
  [6129] = {.lex_state = 470, .external_lex_state = 114},
  [6130] = {.lex_state = 470, .external_lex_state = 114},
  [6131] = {.lex_state = 98, .external_lex_state = 116},
  [6132] = {.lex_state = 98, .external_lex_state = 116},
  [6133] = {.lex_state = 98, .external_lex_state = 119},
  [6134] = {.lex_state = 98, .external_lex_state = 116},
  [6135] = {.lex_state = 470, .external_lex_state = 114},
  [6136] = {.lex_state = 98, .external_lex_state = 119},
  [6137] = {.lex_state = 98, .external_lex_state = 116},
  [6138] = {.lex_state = 98, .external_lex_state = 116},
  [6139] = {.lex_state = 470, .external_lex_state = 114},
  [6140] = {.lex_state = 470, .external_lex_state = 114},
  [6141] = {.lex_state = 98, .external_lex_state = 116},
  [6142] = {.lex_state = 98, .external_lex_state = 116},
  [6143] = {.lex_state = 98, .external_lex_state = 116},
  [6144] = {.lex_state = 427, .external_lex_state = 113},
  [6145] = {.lex_state = 98, .external_lex_state = 116},
  [6146] = {.lex_state = 98, .external_lex_state = 116},
  [6147] = {.lex_state = 470, .external_lex_state = 114},
  [6148] = {.lex_state = 427, .external_lex_state = 113},
  [6149] = {.lex_state = 98, .external_lex_state = 116},
  [6150] = {.lex_state = 427, .external_lex_state = 113},
  [6151] = {.lex_state = 470, .external_lex_state = 114},
  [6152] = {.lex_state = 453, .external_lex_state = 115},
  [6153] = {.lex_state = 453, .external_lex_state = 115},
  [6154] = {.lex_state = 427},
  [6155] = {.lex_state = 427},
  [6156] = {.lex_state = 427},
  [6157] = {.lex_state = 470, .external_lex_state = 114},
  [6158] = {.lex_state = 427},
  [6159] = {.lex_state = 470, .external_lex_state = 114},
  [6160] = {.lex_state = 427},
  [6161] = {.lex_state = 470, .external_lex_state = 114},
  [6162] = {.lex_state = 427},
  [6163] = {.lex_state = 427},
  [6164] = {.lex_state = 427},
  [6165] = {.lex_state = 470, .external_lex_state = 114},
  [6166] = {.lex_state = 427},
  [6167] = {.lex_state = 427},
  [6168] = {.lex_state = 93, .external_lex_state = 119},
  [6169] = {.lex_state = 427},
  [6170] = {.lex_state = 427},
  [6171] = {.lex_state = 470, .external_lex_state = 114},
  [6172] = {.lex_state = 427},
  [6173] = {.lex_state = 470, .external_lex_state = 114},
  [6174] = {.lex_state = 470, .external_lex_state = 114},
  [6175] = {.lex_state = 470, .external_lex_state = 114},
  [6176] = {.lex_state = 479},
  [6177] = {.lex_state = 480},
  [6178] = {.lex_state = 93, .external_lex_state = 119},
  [6179] = {.lex_state = 427},
  [6180] = {.lex_state = 427},
  [6181] = {.lex_state = 480},
  [6182] = {.lex_state = 427},
  [6183] = {.lex_state = 427},
  [6184] = {.lex_state = 427},
  [6185] = {.lex_state = 427},
  [6186] = {.lex_state = 427},
  [6187] = {.lex_state = 427},
  [6188] = {.lex_state = 93, .external_lex_state = 119},
  [6189] = {.lex_state = 427},
  [6190] = {.lex_state = 453, .external_lex_state = 115},
  [6191] = {.lex_state = 470, .external_lex_state = 114},
  [6192] = {.lex_state = 427},
  [6193] = {.lex_state = 427},
  [6194] = {.lex_state = 479},
  [6195] = {.lex_state = 427},
  [6196] = {.lex_state = 427},
  [6197] = {.lex_state = 482, .external_lex_state = 120},
  [6198] = {.lex_state = 453, .external_lex_state = 115},
  [6199] = {.lex_state = 453, .external_lex_state = 115},
  [6200] = {.lex_state = 480},
  [6201] = {.lex_state = 427},
  [6202] = {.lex_state = 427},
  [6203] = {.lex_state = 427},
  [6204] = {.lex_state = 453, .external_lex_state = 115},
  [6205] = {.lex_state = 470, .external_lex_state = 114},
  [6206] = {.lex_state = 93, .external_lex_state = 119},
  [6207] = {.lex_state = 427},
  [6208] = {.lex_state = 470, .external_lex_state = 114},
  [6209] = {.lex_state = 427},
  [6210] = {.lex_state = 427},
  [6211] = {.lex_state = 427},
  [6212] = {.lex_state = 427},
  [6213] = {.lex_state = 427},
  [6214] = {.lex_state = 427},
  [6215] = {.lex_state = 427},
  [6216] = {.lex_state = 470, .external_lex_state = 114},
  [6217] = {.lex_state = 427},
  [6218] = {.lex_state = 479},
  [6219] = {.lex_state = 480},
  [6220] = {.lex_state = 427},
  [6221] = {.lex_state = 427},
  [6222] = {.lex_state = 480},
  [6223] = {.lex_state = 453, .external_lex_state = 115},
  [6224] = {.lex_state = 482, .external_lex_state = 120},
  [6225] = {.lex_state = 471, .external_lex_state = 118},
  [6226] = {.lex_state = 427},
  [6227] = {.lex_state = 93, .external_lex_state = 119},
  [6228] = {.lex_state = 427},
  [6229] = {.lex_state = 480},
  [6230] = {.lex_state = 427},
  [6231] = {.lex_state = 427},
  [6232] = {.lex_state = 482, .external_lex_state = 120},
  [6233] = {.lex_state = 98, .external_lex_state = 119},
  [6234] = {.lex_state = 427},
  [6235] = {.lex_state = 427},
  [6236] = {.lex_state = 427},
  [6237] = {.lex_state = 427},
  [6238] = {.lex_state = 427},
  [6239] = {.lex_state = 470, .external_lex_state = 114},
  [6240] = {.lex_state = 93, .external_lex_state = 119},
  [6241] = {.lex_state = 427},
  [6242] = {.lex_state = 93, .external_lex_state = 119},
  [6243] = {.lex_state = 427},
  [6244] = {.lex_state = 427},
  [6245] = {.lex_state = 471, .external_lex_state = 118},
  [6246] = {.lex_state = 453, .external_lex_state = 115},
  [6247] = {.lex_state = 480},
  [6248] = {.lex_state = 453, .external_lex_state = 115},
  [6249] = {.lex_state = 470, .external_lex_state = 114},
  [6250] = {.lex_state = 427},
  [6251] = {.lex_state = 427},
  [6252] = {.lex_state = 427},
  [6253] = {.lex_state = 470, .external_lex_state = 114},
  [6254] = {.lex_state = 427},
  [6255] = {.lex_state = 427},
  [6256] = {.lex_state = 471, .external_lex_state = 118},
  [6257] = {.lex_state = 427},
  [6258] = {.lex_state = 427},
  [6259] = {.lex_state = 427},
  [6260] = {.lex_state = 427},
  [6261] = {.lex_state = 479},
  [6262] = {.lex_state = 427},
  [6263] = {.lex_state = 427},
  [6264] = {.lex_state = 427},
  [6265] = {.lex_state = 470, .external_lex_state = 114},
  [6266] = {.lex_state = 427},
  [6267] = {.lex_state = 93, .external_lex_state = 119},
  [6268] = {.lex_state = 427},
  [6269] = {.lex_state = 427},
  [6270] = {.lex_state = 480},
  [6271] = {.lex_state = 427},
  [6272] = {.lex_state = 471, .external_lex_state = 118},
  [6273] = {.lex_state = 427},
  [6274] = {.lex_state = 427},
  [6275] = {.lex_state = 482, .external_lex_state = 121},
  [6276] = {.lex_state = 434, .external_lex_state = 122},
  [6277] = {.lex_state = 434, .external_lex_state = 123},
  [6278] = {.lex_state = 452},
  [6279] = {.lex_state = 540, .external_lex_state = 124},
  [6280] = {.lex_state = 540, .external_lex_state = 124},
  [6281] = {.lex_state = 540, .external_lex_state = 124},
  [6282] = {.lex_state = 540, .external_lex_state = 124},
  [6283] = {.lex_state = 540, .external_lex_state = 124},
  [6284] = {.lex_state = 540, .external_lex_state = 124},
  [6285] = {.lex_state = 540, .external_lex_state = 124},
  [6286] = {.lex_state = 540, .external_lex_state = 124},
  [6287] = {.lex_state = 540, .external_lex_state = 124},
  [6288] = {.lex_state = 540, .external_lex_state = 124},
  [6289] = {.lex_state = 540, .external_lex_state = 124},
  [6290] = {.lex_state = 540, .external_lex_state = 124},
  [6291] = {.lex_state = 540, .external_lex_state = 124},
  [6292] = {.lex_state = 482, .external_lex_state = 121},
  [6293] = {.lex_state = 540, .external_lex_state = 124},
  [6294] = {.lex_state = 434, .external_lex_state = 123},
  [6295] = {.lex_state = 434, .external_lex_state = 123},
  [6296] = {.lex_state = 434, .external_lex_state = 123},
  [6297] = {.lex_state = 540, .external_lex_state = 124},
  [6298] = {.lex_state = 540, .external_lex_state = 124},
  [6299] = {.lex_state = 540, .external_lex_state = 124},
  [6300] = {.lex_state = 479},
  [6301] = {.lex_state = 98, .external_lex_state = 119},
  [6302] = {.lex_state = 540, .external_lex_state = 124},
  [6303] = {.lex_state = 453, .external_lex_state = 115},
  [6304] = {.lex_state = 482, .external_lex_state = 120},
  [6305] = {.lex_state = 434, .external_lex_state = 123},
  [6306] = {.lex_state = 434, .external_lex_state = 122},
  [6307] = {.lex_state = 452},
  [6308] = {.lex_state = 479},
  [6309] = {.lex_state = 482, .external_lex_state = 121},
  [6310] = {.lex_state = 482, .external_lex_state = 121},
  [6311] = {.lex_state = 434, .external_lex_state = 123},
  [6312] = {.lex_state = 482, .external_lex_state = 121},
  [6313] = {.lex_state = 453, .external_lex_state = 115},
  [6314] = {.lex_state = 482, .external_lex_state = 121},
  [6315] = {.lex_state = 482, .external_lex_state = 121},
  [6316] = {.lex_state = 482, .external_lex_state = 120},
  [6317] = {.lex_state = 434, .external_lex_state = 123},
  [6318] = {.lex_state = 434, .external_lex_state = 123},
  [6319] = {.lex_state = 540, .external_lex_state = 124},
  [6320] = {.lex_state = 98, .external_lex_state = 119},
  [6321] = {.lex_state = 540, .external_lex_state = 124},
  [6322] = {.lex_state = 540, .external_lex_state = 124},
  [6323] = {.lex_state = 478},
  [6324] = {.lex_state = 453, .external_lex_state = 115},
  [6325] = {.lex_state = 482, .external_lex_state = 120},
  [6326] = {.lex_state = 479},
  [6327] = {.lex_state = 98, .external_lex_state = 119},
  [6328] = {.lex_state = 540, .external_lex_state = 124},
  [6329] = {.lex_state = 540, .external_lex_state = 124},
  [6330] = {.lex_state = 540, .external_lex_state = 124},
  [6331] = {.lex_state = 98, .external_lex_state = 119},
  [6332] = {.lex_state = 540, .external_lex_state = 124},
  [6333] = {.lex_state = 540, .external_lex_state = 124},
  [6334] = {.lex_state = 434, .external_lex_state = 122},
  [6335] = {.lex_state = 480},
  [6336] = {.lex_state = 540, .external_lex_state = 124},
  [6337] = {.lex_state = 540, .external_lex_state = 124},
  [6338] = {.lex_state = 540, .external_lex_state = 124},
  [6339] = {.lex_state = 540, .external_lex_state = 124},
  [6340] = {.lex_state = 540, .external_lex_state = 124},
  [6341] = {.lex_state = 434, .external_lex_state = 123},
  [6342] = {.lex_state = 540, .external_lex_state = 124},
  [6343] = {.lex_state = 540, .external_lex_state = 124},
  [6344] = {.lex_state = 540, .external_lex_state = 124},
  [6345] = {.lex_state = 434, .external_lex_state = 123},
  [6346] = {.lex_state = 479},
  [6347] = {.lex_state = 452},
  [6348] = {.lex_state = 540, .external_lex_state = 124},
  [6349] = {.lex_state = 434, .external_lex_state = 123},
  [6350] = {.lex_state = 540, .external_lex_state = 124},
  [6351] = {.lex_state = 540, .external_lex_state = 124},
  [6352] = {.lex_state = 540, .external_lex_state = 124},
  [6353] = {.lex_state = 540, .external_lex_state = 124},
  [6354] = {.lex_state = 540, .external_lex_state = 124},
  [6355] = {.lex_state = 540, .external_lex_state = 124},
  [6356] = {.lex_state = 452},
  [6357] = {.lex_state = 540, .external_lex_state = 124},
  [6358] = {.lex_state = 540, .external_lex_state = 124},
  [6359] = {.lex_state = 98, .external_lex_state = 119},
  [6360] = {.lex_state = 540, .external_lex_state = 124},
  [6361] = {.lex_state = 93, .external_lex_state = 119},
  [6362] = {.lex_state = 540, .external_lex_state = 124},
  [6363] = {.lex_state = 540, .external_lex_state = 124},
  [6364] = {.lex_state = 98, .external_lex_state = 119},
  [6365] = {.lex_state = 540, .external_lex_state = 124},
  [6366] = {.lex_state = 540, .external_lex_state = 124},
  [6367] = {.lex_state = 540, .external_lex_state = 124},
  [6368] = {.lex_state = 540, .external_lex_state = 124},
  [6369] = {.lex_state = 540, .external_lex_state = 124},
  [6370] = {.lex_state = 540, .external_lex_state = 124},
  [6371] = {.lex_state = 482, .external_lex_state = 121},
  [6372] = {.lex_state = 540, .external_lex_state = 124},
  [6373] = {.lex_state = 98, .external_lex_state = 119},
  [6374] = {.lex_state = 434, .external_lex_state = 122},
  [6375] = {.lex_state = 98, .external_lex_state = 119},
  [6376] = {.lex_state = 540, .external_lex_state = 124},
  [6377] = {.lex_state = 434, .external_lex_state = 123},
  [6378] = {.lex_state = 540, .external_lex_state = 124},
  [6379] = {.lex_state = 434, .external_lex_state = 123},
  [6380] = {.lex_state = 540, .external_lex_state = 124},
  [6381] = {.lex_state = 540, .external_lex_state = 124},
  [6382] = {.lex_state = 453, .external_lex_state = 115},
  [6383] = {.lex_state = 453, .external_lex_state = 115},
  [6384] = {.lex_state = 540, .external_lex_state = 124},
  [6385] = {.lex_state = 540, .external_lex_state = 124},
  [6386] = {.lex_state = 540, .external_lex_state = 124},
  [6387] = {.lex_state = 453, .external_lex_state = 115},
  [6388] = {.lex_state = 453, .external_lex_state = 115},
  [6389] = {.lex_state = 453, .external_lex_state = 115},
  [6390] = {.lex_state = 453, .external_lex_state = 115},
  [6391] = {.lex_state = 434, .external_lex_state = 123},
  [6392] = {.lex_state = 434, .external_lex_state = 123},
  [6393] = {.lex_state = 434, .external_lex_state = 123},
  [6394] = {.lex_state = 452},
  [6395] = {.lex_state = 93, .external_lex_state = 119},
  [6396] = {.lex_state = 434, .external_lex_state = 123},
  [6397] = {.lex_state = 427, .external_lex_state = 125},
  [6398] = {.lex_state = 470, .external_lex_state = 114},
  [6399] = {.lex_state = 434, .external_lex_state = 123},
  [6400] = {.lex_state = 434, .external_lex_state = 123},
  [6401] = {.lex_state = 453, .external_lex_state = 115},
  [6402] = {.lex_state = 453, .external_lex_state = 115},
  [6403] = {.lex_state = 453, .external_lex_state = 115},
  [6404] = {.lex_state = 453, .external_lex_state = 115},
  [6405] = {.lex_state = 453, .external_lex_state = 115},
  [6406] = {.lex_state = 453, .external_lex_state = 115},
  [6407] = {.lex_state = 453, .external_lex_state = 115},
  [6408] = {.lex_state = 453, .external_lex_state = 115},
  [6409] = {.lex_state = 427, .external_lex_state = 125},
  [6410] = {.lex_state = 453, .external_lex_state = 115},
  [6411] = {.lex_state = 453, .external_lex_state = 115},
  [6412] = {.lex_state = 453, .external_lex_state = 115},
  [6413] = {.lex_state = 452},
  [6414] = {.lex_state = 427, .external_lex_state = 125},
  [6415] = {.lex_state = 453, .external_lex_state = 115},
  [6416] = {.lex_state = 427, .external_lex_state = 125},
  [6417] = {.lex_state = 427, .external_lex_state = 125},
  [6418] = {.lex_state = 434, .external_lex_state = 123},
  [6419] = {.lex_state = 470, .external_lex_state = 114},
  [6420] = {.lex_state = 470, .external_lex_state = 114},
  [6421] = {.lex_state = 482, .external_lex_state = 121},
  [6422] = {.lex_state = 482, .external_lex_state = 121},
  [6423] = {.lex_state = 427, .external_lex_state = 125},
  [6424] = {.lex_state = 482, .external_lex_state = 121},
  [6425] = {.lex_state = 482, .external_lex_state = 121},
  [6426] = {.lex_state = 482, .external_lex_state = 121},
  [6427] = {.lex_state = 482, .external_lex_state = 121},
  [6428] = {.lex_state = 482, .external_lex_state = 121},
  [6429] = {.lex_state = 93, .external_lex_state = 119},
  [6430] = {.lex_state = 482, .external_lex_state = 121},
  [6431] = {.lex_state = 482, .external_lex_state = 121},
  [6432] = {.lex_state = 482, .external_lex_state = 121},
  [6433] = {.lex_state = 470, .external_lex_state = 114},
  [6434] = {.lex_state = 482, .external_lex_state = 121},
  [6435] = {.lex_state = 482, .external_lex_state = 121},
  [6436] = {.lex_state = 434, .external_lex_state = 123},
  [6437] = {.lex_state = 434, .external_lex_state = 121},
  [6438] = {.lex_state = 482, .external_lex_state = 121},
  [6439] = {.lex_state = 93, .external_lex_state = 119},
  [6440] = {.lex_state = 427, .external_lex_state = 125},
  [6441] = {.lex_state = 427, .external_lex_state = 125},
  [6442] = {.lex_state = 427, .external_lex_state = 125},
  [6443] = {.lex_state = 427, .external_lex_state = 125},
  [6444] = {.lex_state = 427, .external_lex_state = 125},
  [6445] = {.lex_state = 453, .external_lex_state = 115},
  [6446] = {.lex_state = 453, .external_lex_state = 115},
  [6447] = {.lex_state = 453, .external_lex_state = 115},
  [6448] = {.lex_state = 427, .external_lex_state = 125},
  [6449] = {.lex_state = 482, .external_lex_state = 121},
  [6450] = {.lex_state = 429},
  [6451] = {.lex_state = 429},
  [6452] = {.lex_state = 429},
  [6453] = {.lex_state = 540},
  [6454] = {.lex_state = 429},
  [6455] = {.lex_state = 540},
  [6456] = {.lex_state = 540},
  [6457] = {.lex_state = 482},
  [6458] = {.lex_state = 540},
  [6459] = {.lex_state = 429},
  [6460] = {.lex_state = 482},
  [6461] = {.lex_state = 429},
  [6462] = {.lex_state = 413},
  [6463] = {.lex_state = 482},
  [6464] = {.lex_state = 429},
  [6465] = {.lex_state = 482},
  [6466] = {.lex_state = 429},
  [6467] = {.lex_state = 429},
  [6468] = {.lex_state = 429},
  [6469] = {.lex_state = 482},
  [6470] = {.lex_state = 482},
  [6471] = {.lex_state = 429},
  [6472] = {.lex_state = 429},
  [6473] = {.lex_state = 540},
  [6474] = {.lex_state = 482},
  [6475] = {.lex_state = 429},
  [6476] = {.lex_state = 482},
  [6477] = {.lex_state = 429},
  [6478] = {.lex_state = 429},
  [6479] = {.lex_state = 470, .external_lex_state = 114},
  [6480] = {.lex_state = 482},
  [6481] = {.lex_state = 482},
  [6482] = {.lex_state = 429},
  [6483] = {.lex_state = 429},
  [6484] = {.lex_state = 452},
  [6485] = {.lex_state = 470, .external_lex_state = 114},
  [6486] = {.lex_state = 482},
  [6487] = {.lex_state = 429},
  [6488] = {.lex_state = 540},
  [6489] = {.lex_state = 482},
  [6490] = {.lex_state = 540},
  [6491] = {.lex_state = 482},
  [6492] = {.lex_state = 470, .external_lex_state = 114},
  [6493] = {.lex_state = 540},
  [6494] = {.lex_state = 429},
  [6495] = {.lex_state = 482},
  [6496] = {.lex_state = 482},
  [6497] = {.lex_state = 429},
  [6498] = {.lex_state = 540},
  [6499] = {.lex_state = 427},
  [6500] = {.lex_state = 540},
  [6501] = {.lex_state = 540},
  [6502] = {.lex_state = 540},
  [6503] = {.lex_state = 429},
  [6504] = {.lex_state = 427},
  [6505] = {.lex_state = 429},
  [6506] = {.lex_state = 429},
  [6507] = {.lex_state = 429},
  [6508] = {.lex_state = 429},
  [6509] = {.lex_state = 429},
  [6510] = {.lex_state = 427},
  [6511] = {.lex_state = 540},
  [6512] = {.lex_state = 429},
  [6513] = {.lex_state = 540},
  [6514] = {.lex_state = 429},
  [6515] = {.lex_state = 429},
  [6516] = {.lex_state = 429},
  [6517] = {.lex_state = 429},
  [6518] = {.lex_state = 540},
  [6519] = {.lex_state = 429},
  [6520] = {.lex_state = 413},
  [6521] = {.lex_state = 429},
  [6522] = {.lex_state = 429},
  [6523] = {.lex_state = 429},
  [6524] = {.lex_state = 468, .external_lex_state = 115},
  [6525] = {.lex_state = 468, .external_lex_state = 115},
  [6526] = {.lex_state = 429},
  [6527] = {.lex_state = 429},
  [6528] = {.lex_state = 470, .external_lex_state = 117},
  [6529] = {.lex_state = 429},
  [6530] = {.lex_state = 429},
  [6531] = {.lex_state = 429},
  [6532] = {.lex_state = 429},
  [6533] = {.lex_state = 470, .external_lex_state = 117},
  [6534] = {.lex_state = 427},
  [6535] = {.lex_state = 470, .external_lex_state = 117},
  [6536] = {.lex_state = 429},
  [6537] = {.lex_state = 427},
  [6538] = {.lex_state = 540, .external_lex_state = 126},
  [6539] = {.lex_state = 427},
  [6540] = {.lex_state = 429},
  [6541] = {.lex_state = 540},
  [6542] = {.lex_state = 429},
  [6543] = {.lex_state = 470, .external_lex_state = 117},
  [6544] = {.lex_state = 429},
  [6545] = {.lex_state = 540},
  [6546] = {.lex_state = 540},
  [6547] = {.lex_state = 429},
  [6548] = {.lex_state = 429},
  [6549] = {.lex_state = 429},
  [6550] = {.lex_state = 429},
  [6551] = {.lex_state = 429},
  [6552] = {.lex_state = 429},
  [6553] = {.lex_state = 429},
  [6554] = {.lex_state = 429},
  [6555] = {.lex_state = 413},
  [6556] = {.lex_state = 482},
  [6557] = {.lex_state = 429},
  [6558] = {.lex_state = 429},
  [6559] = {.lex_state = 482},
  [6560] = {.lex_state = 429},
  [6561] = {.lex_state = 540},
  [6562] = {.lex_state = 427},
  [6563] = {.lex_state = 429},
  [6564] = {.lex_state = 429},
  [6565] = {.lex_state = 429},
  [6566] = {.lex_state = 429},
  [6567] = {.lex_state = 399, .external_lex_state = 115},
  [6568] = {.lex_state = 429},
  [6569] = {.lex_state = 540, .external_lex_state = 126},
  [6570] = {.lex_state = 540, .external_lex_state = 126},
  [6571] = {.lex_state = 540},
  [6572] = {.lex_state = 429},
  [6573] = {.lex_state = 413},
  [6574] = {.lex_state = 540, .external_lex_state = 126},
  [6575] = {.lex_state = 540},
  [6576] = {.lex_state = 540, .external_lex_state = 126},
  [6577] = {.lex_state = 540, .external_lex_state = 126},
  [6578] = {.lex_state = 429},
  [6579] = {.lex_state = 429},
  [6580] = {.lex_state = 429},
  [6581] = {.lex_state = 429},
  [6582] = {.lex_state = 429},
  [6583] = {.lex_state = 413},
  [6584] = {.lex_state = 429},
  [6585] = {.lex_state = 429},
  [6586] = {.lex_state = 429},
  [6587] = {.lex_state = 482},
  [6588] = {.lex_state = 482},
  [6589] = {.lex_state = 540},
  [6590] = {.lex_state = 540},
  [6591] = {.lex_state = 540, .external_lex_state = 126},
  [6592] = {.lex_state = 413},
  [6593] = {.lex_state = 540, .external_lex_state = 126},
  [6594] = {.lex_state = 540, .external_lex_state = 126},
  [6595] = {.lex_state = 482},
  [6596] = {.lex_state = 429},
  [6597] = {.lex_state = 429},
  [6598] = {.lex_state = 429},
  [6599] = {.lex_state = 540},
  [6600] = {.lex_state = 429},
  [6601] = {.lex_state = 429},
  [6602] = {.lex_state = 540},
  [6603] = {.lex_state = 429},
  [6604] = {.lex_state = 413},
  [6605] = {.lex_state = 429},
  [6606] = {.lex_state = 429},
  [6607] = {.lex_state = 482},
  [6608] = {.lex_state = 482},
  [6609] = {.lex_state = 540},
  [6610] = {.lex_state = 468, .external_lex_state = 115},
  [6611] = {.lex_state = 540},
  [6612] = {.lex_state = 429},
  [6613] = {.lex_state = 429},
  [6614] = {.lex_state = 540},
  [6615] = {.lex_state = 540},
  [6616] = {.lex_state = 429},
  [6617] = {.lex_state = 540},
  [6618] = {.lex_state = 413},
  [6619] = {.lex_state = 540},
  [6620] = {.lex_state = 540},
  [6621] = {.lex_state = 429},
  [6622] = {.lex_state = 540},
  [6623] = {.lex_state = 468, .external_lex_state = 115},
  [6624] = {.lex_state = 482},
  [6625] = {.lex_state = 429},
  [6626] = {.lex_state = 429},
  [6627] = {.lex_state = 429},
  [6628] = {.lex_state = 427},
  [6629] = {.lex_state = 434, .external_lex_state = 118},
  [6630] = {.lex_state = 480},
  [6631] = {.lex_state = 468},
  [6632] = {.lex_state = 480},
  [6633] = {.lex_state = 468},
  [6634] = {.lex_state = 468},
  [6635] = {.lex_state = 414, .external_lex_state = 127},
  [6636] = {.lex_state = 468},
  [6637] = {.lex_state = 468},
  [6638] = {.lex_state = 470, .external_lex_state = 114},
  [6639] = {.lex_state = 414, .external_lex_state = 127},
  [6640] = {.lex_state = 470, .external_lex_state = 114},
  [6641] = {.lex_state = 468},
  [6642] = {.lex_state = 470, .external_lex_state = 114},
  [6643] = {.lex_state = 468},
  [6644] = {.lex_state = 480},
  [6645] = {.lex_state = 470, .external_lex_state = 114},
  [6646] = {.lex_state = 429},
  [6647] = {.lex_state = 414, .external_lex_state = 127},
  [6648] = {.lex_state = 470, .external_lex_state = 114},
  [6649] = {.lex_state = 414, .external_lex_state = 127},
  [6650] = {.lex_state = 468},
  [6651] = {.lex_state = 468},
  [6652] = {.lex_state = 468},
  [6653] = {.lex_state = 429},
  [6654] = {.lex_state = 480},
  [6655] = {.lex_state = 468},
  [6656] = {.lex_state = 468},
  [6657] = {.lex_state = 468},
  [6658] = {.lex_state = 470, .external_lex_state = 114},
  [6659] = {.lex_state = 427},
  [6660] = {.lex_state = 540},
  [6661] = {.lex_state = 434, .external_lex_state = 114},
  [6662] = {.lex_state = 414, .external_lex_state = 127},
  [6663] = {.lex_state = 414, .external_lex_state = 127},
  [6664] = {.lex_state = 468},
  [6665] = {.lex_state = 470, .external_lex_state = 114},
  [6666] = {.lex_state = 414, .external_lex_state = 127},
  [6667] = {.lex_state = 414, .external_lex_state = 127},
  [6668] = {.lex_state = 414, .external_lex_state = 127},
  [6669] = {.lex_state = 468},
  [6670] = {.lex_state = 470, .external_lex_state = 114},
  [6671] = {.lex_state = 470, .external_lex_state = 114},
  [6672] = {.lex_state = 468},
  [6673] = {.lex_state = 468},
  [6674] = {.lex_state = 470, .external_lex_state = 114},
  [6675] = {.lex_state = 468},
  [6676] = {.lex_state = 480},
  [6677] = {.lex_state = 470, .external_lex_state = 114},
  [6678] = {.lex_state = 434, .external_lex_state = 114},
  [6679] = {.lex_state = 468},
  [6680] = {.lex_state = 480},
  [6681] = {.lex_state = 468},
  [6682] = {.lex_state = 429},
  [6683] = {.lex_state = 470, .external_lex_state = 114},
  [6684] = {.lex_state = 429},
  [6685] = {.lex_state = 429},
  [6686] = {.lex_state = 429},
  [6687] = {.lex_state = 414, .external_lex_state = 127},
  [6688] = {.lex_state = 540},
  [6689] = {.lex_state = 480},
  [6690] = {.lex_state = 429},
  [6691] = {.lex_state = 470, .external_lex_state = 114},
  [6692] = {.lex_state = 427},
  [6693] = {.lex_state = 468},
  [6694] = {.lex_state = 470, .external_lex_state = 114},
  [6695] = {.lex_state = 468},
  [6696] = {.lex_state = 470, .external_lex_state = 114},
  [6697] = {.lex_state = 468},
  [6698] = {.lex_state = 480},
  [6699] = {.lex_state = 468},
  [6700] = {.lex_state = 470, .external_lex_state = 114},
  [6701] = {.lex_state = 468},
  [6702] = {.lex_state = 468},
  [6703] = {.lex_state = 468},
  [6704] = {.lex_state = 434, .external_lex_state = 114},
  [6705] = {.lex_state = 540},
  [6706] = {.lex_state = 540},
  [6707] = {.lex_state = 434, .external_lex_state = 114},
  [6708] = {.lex_state = 434, .external_lex_state = 114},
  [6709] = {.lex_state = 540},
  [6710] = {.lex_state = 427},
  [6711] = {.lex_state = 540},
  [6712] = {.lex_state = 413},
  [6713] = {.lex_state = 434, .external_lex_state = 114},
  [6714] = {.lex_state = 540},
  [6715] = {.lex_state = 434, .external_lex_state = 114},
  [6716] = {.lex_state = 434, .external_lex_state = 114},
  [6717] = {.lex_state = 434, .external_lex_state = 114},
  [6718] = {.lex_state = 540},
  [6719] = {.lex_state = 427},
  [6720] = {.lex_state = 434, .external_lex_state = 114},
  [6721] = {.lex_state = 540},
  [6722] = {.lex_state = 434, .external_lex_state = 114},
  [6723] = {.lex_state = 540},
  [6724] = {.lex_state = 434, .external_lex_state = 114},
  [6725] = {.lex_state = 540},
  [6726] = {.lex_state = 540},
  [6727] = {.lex_state = 540},
  [6728] = {.lex_state = 427},
  [6729] = {.lex_state = 156, .external_lex_state = 119},
  [6730] = {.lex_state = 540},
  [6731] = {.lex_state = 540},
  [6732] = {.lex_state = 435},
  [6733] = {.lex_state = 540},
  [6734] = {.lex_state = 480},
  [6735] = {.lex_state = 435},
  [6736] = {.lex_state = 434, .external_lex_state = 114},
  [6737] = {.lex_state = 427},
  [6738] = {.lex_state = 540},
  [6739] = {.lex_state = 540},
  [6740] = {.lex_state = 540},
  [6741] = {.lex_state = 434, .external_lex_state = 114},
  [6742] = {.lex_state = 540},
  [6743] = {.lex_state = 435},
  [6744] = {.lex_state = 540},
  [6745] = {.lex_state = 540},
  [6746] = {.lex_state = 427},
  [6747] = {.lex_state = 540},
  [6748] = {.lex_state = 540},
  [6749] = {.lex_state = 434, .external_lex_state = 114},
  [6750] = {.lex_state = 435},
  [6751] = {.lex_state = 540},
  [6752] = {.lex_state = 434, .external_lex_state = 114},
  [6753] = {.lex_state = 540},
  [6754] = {.lex_state = 540},
  [6755] = {.lex_state = 427},
  [6756] = {.lex_state = 434, .external_lex_state = 114},
  [6757] = {.lex_state = 540},
  [6758] = {.lex_state = 540},
  [6759] = {.lex_state = 156, .external_lex_state = 119},
  [6760] = {.lex_state = 540},
  [6761] = {.lex_state = 540},
  [6762] = {.lex_state = 540},
  [6763] = {.lex_state = 427, .external_lex_state = 125},
  [6764] = {.lex_state = 427},
  [6765] = {.lex_state = 435},
  [6766] = {.lex_state = 434, .external_lex_state = 114},
  [6767] = {.lex_state = 540},
  [6768] = {.lex_state = 434, .external_lex_state = 114},
  [6769] = {.lex_state = 427, .external_lex_state = 125},
  [6770] = {.lex_state = 434, .external_lex_state = 114},
  [6771] = {.lex_state = 435},
  [6772] = {.lex_state = 434, .external_lex_state = 114},
  [6773] = {.lex_state = 427},
  [6774] = {.lex_state = 435},
  [6775] = {.lex_state = 540},
  [6776] = {.lex_state = 414, .external_lex_state = 128},
  [6777] = {.lex_state = 414, .external_lex_state = 128},
  [6778] = {.lex_state = 435},
  [6779] = {.lex_state = 480},
  [6780] = {.lex_state = 427},
  [6781] = {.lex_state = 434, .external_lex_state = 114},
  [6782] = {.lex_state = 540},
  [6783] = {.lex_state = 435},
  [6784] = {.lex_state = 434, .external_lex_state = 114},
  [6785] = {.lex_state = 480},
  [6786] = {.lex_state = 540},
  [6787] = {.lex_state = 427},
  [6788] = {.lex_state = 434, .external_lex_state = 114},
  [6789] = {.lex_state = 427, .external_lex_state = 125},
  [6790] = {.lex_state = 434, .external_lex_state = 114},
  [6791] = {.lex_state = 540},
  [6792] = {.lex_state = 427, .external_lex_state = 125},
  [6793] = {.lex_state = 540},
  [6794] = {.lex_state = 427},
  [6795] = {.lex_state = 540},
  [6796] = {.lex_state = 540},
  [6797] = {.lex_state = 434, .external_lex_state = 114},
  [6798] = {.lex_state = 435},
  [6799] = {.lex_state = 434, .external_lex_state = 114},
  [6800] = {.lex_state = 435},
  [6801] = {.lex_state = 427},
  [6802] = {.lex_state = 434, .external_lex_state = 114},
  [6803] = {.lex_state = 480},
  [6804] = {.lex_state = 434, .external_lex_state = 114},
  [6805] = {.lex_state = 427, .external_lex_state = 125},
  [6806] = {.lex_state = 540},
  [6807] = {.lex_state = 427, .external_lex_state = 125},
  [6808] = {.lex_state = 427},
  [6809] = {.lex_state = 540},
  [6810] = {.lex_state = 434, .external_lex_state = 114},
  [6811] = {.lex_state = 434, .external_lex_state = 114},
  [6812] = {.lex_state = 403},
  [6813] = {.lex_state = 540, .external_lex_state = 129},
  [6814] = {.lex_state = 540, .external_lex_state = 129},
  [6815] = {.lex_state = 427},
  [6816] = {.lex_state = 540},
  [6817] = {.lex_state = 403},
  [6818] = {.lex_state = 540},
  [6819] = {.lex_state = 434, .external_lex_state = 114},
  [6820] = {.lex_state = 480},
  [6821] = {.lex_state = 427, .external_lex_state = 125},
  [6822] = {.lex_state = 427},
  [6823] = {.lex_state = 427, .external_lex_state = 125},
  [6824] = {.lex_state = 540},
  [6825] = {.lex_state = 434, .external_lex_state = 114},
  [6826] = {.lex_state = 540},
  [6827] = {.lex_state = 540},
  [6828] = {.lex_state = 540},
  [6829] = {.lex_state = 427},
  [6830] = {.lex_state = 427, .external_lex_state = 125},
  [6831] = {.lex_state = 427, .external_lex_state = 125},
  [6832] = {.lex_state = 540},
  [6833] = {.lex_state = 540},
  [6834] = {.lex_state = 435},
  [6835] = {.lex_state = 540},
  [6836] = {.lex_state = 427},
  [6837] = {.lex_state = 540},
  [6838] = {.lex_state = 540},
  [6839] = {.lex_state = 540},
  [6840] = {.lex_state = 540},
  [6841] = {.lex_state = 540},
  [6842] = {.lex_state = 540},
  [6843] = {.lex_state = 427},
  [6844] = {.lex_state = 435},
  [6845] = {.lex_state = 540},
  [6846] = {.lex_state = 434, .external_lex_state = 114},
  [6847] = {.lex_state = 434, .external_lex_state = 114},
  [6848] = {.lex_state = 540},
  [6849] = {.lex_state = 435},
  [6850] = {.lex_state = 427},
  [6851] = {.lex_state = 540},
  [6852] = {.lex_state = 540},
  [6853] = {.lex_state = 435},
  [6854] = {.lex_state = 540},
  [6855] = {.lex_state = 540},
  [6856] = {.lex_state = 540},
  [6857] = {.lex_state = 427},
  [6858] = {.lex_state = 435},
  [6859] = {.lex_state = 540},
  [6860] = {.lex_state = 427},
  [6861] = {.lex_state = 413},
  [6862] = {.lex_state = 427},
  [6863] = {.lex_state = 434, .external_lex_state = 114},
  [6864] = {.lex_state = 427},
  [6865] = {.lex_state = 434, .external_lex_state = 114},
  [6866] = {.lex_state = 540},
  [6867] = {.lex_state = 540},
  [6868] = {.lex_state = 434, .external_lex_state = 114},
  [6869] = {.lex_state = 540},
  [6870] = {.lex_state = 427},
  [6871] = {.lex_state = 427},
  [6872] = {.lex_state = 540},
  [6873] = {.lex_state = 434, .external_lex_state = 114},
  [6874] = {.lex_state = 540},
  [6875] = {.lex_state = 540},
  [6876] = {.lex_state = 540},
  [6877] = {.lex_state = 540},
  [6878] = {.lex_state = 427},
  [6879] = {.lex_state = 540},
  [6880] = {.lex_state = 427, .external_lex_state = 125},
  [6881] = {.lex_state = 540},
  [6882] = {.lex_state = 540},
  [6883] = {.lex_state = 540},
  [6884] = {.lex_state = 540},
  [6885] = {.lex_state = 427},
  [6886] = {.lex_state = 540},
  [6887] = {.lex_state = 435},
  [6888] = {.lex_state = 156, .external_lex_state = 119},
  [6889] = {.lex_state = 540},
  [6890] = {.lex_state = 540},
  [6891] = {.lex_state = 540, .external_lex_state = 129},
  [6892] = {.lex_state = 427},
  [6893] = {.lex_state = 540},
  [6894] = {.lex_state = 435},
  [6895] = {.lex_state = 156, .external_lex_state = 119},
  [6896] = {.lex_state = 540},
  [6897] = {.lex_state = 434, .external_lex_state = 114},
  [6898] = {.lex_state = 434, .external_lex_state = 114},
  [6899] = {.lex_state = 427},
  [6900] = {.lex_state = 540},
  [6901] = {.lex_state = 434, .external_lex_state = 114},
  [6902] = {.lex_state = 540},
  [6903] = {.lex_state = 540},
  [6904] = {.lex_state = 540},
  [6905] = {.lex_state = 540},
  [6906] = {.lex_state = 427},
  [6907] = {.lex_state = 540},
  [6908] = {.lex_state = 435},
  [6909] = {.lex_state = 435},
  [6910] = {.lex_state = 540},
  [6911] = {.lex_state = 435},
  [6912] = {.lex_state = 435},
  [6913] = {.lex_state = 427},
  [6914] = {.lex_state = 540},
  [6915] = {.lex_state = 434, .external_lex_state = 114},
  [6916] = {.lex_state = 540},
  [6917] = {.lex_state = 434, .external_lex_state = 114},
  [6918] = {.lex_state = 540},
  [6919] = {.lex_state = 403},
  [6920] = {.lex_state = 427},
  [6921] = {.lex_state = 156, .external_lex_state = 119},
  [6922] = {.lex_state = 540},
  [6923] = {.lex_state = 540},
  [6924] = {.lex_state = 434, .external_lex_state = 114},
  [6925] = {.lex_state = 156, .external_lex_state = 119},
  [6926] = {.lex_state = 540},
  [6927] = {.lex_state = 427},
  [6928] = {.lex_state = 540, .external_lex_state = 130},
  [6929] = {.lex_state = 540},
  [6930] = {.lex_state = 540},
  [6931] = {.lex_state = 540},
  [6932] = {.lex_state = 540, .external_lex_state = 129},
  [6933] = {.lex_state = 540},
  [6934] = {.lex_state = 427},
  [6935] = {.lex_state = 435},
  [6936] = {.lex_state = 540},
  [6937] = {.lex_state = 403},
  [6938] = {.lex_state = 434, .external_lex_state = 114},
  [6939] = {.lex_state = 434, .external_lex_state = 114},
  [6940] = {.lex_state = 540},
  [6941] = {.lex_state = 427},
  [6942] = {.lex_state = 435},
  [6943] = {.lex_state = 540},
  [6944] = {.lex_state = 434, .external_lex_state = 114},
  [6945] = {.lex_state = 540},
  [6946] = {.lex_state = 434, .external_lex_state = 114},
  [6947] = {.lex_state = 540},
  [6948] = {.lex_state = 427},
  [6949] = {.lex_state = 540},
  [6950] = {.lex_state = 540},
  [6951] = {.lex_state = 434},
  [6952] = {.lex_state = 156, .external_lex_state = 119},
  [6953] = {.lex_state = 156, .external_lex_state = 119},
  [6954] = {.lex_state = 434, .external_lex_state = 114},
  [6955] = {.lex_state = 427},
  [6956] = {.lex_state = 540},
  [6957] = {.lex_state = 434, .external_lex_state = 114},
  [6958] = {.lex_state = 540},
  [6959] = {.lex_state = 540},
  [6960] = {.lex_state = 156, .external_lex_state = 119},
  [6961] = {.lex_state = 540},
  [6962] = {.lex_state = 427},
  [6963] = {.lex_state = 540},
  [6964] = {.lex_state = 540},
  [6965] = {.lex_state = 156, .external_lex_state = 119},
  [6966] = {.lex_state = 540},
  [6967] = {.lex_state = 540},
  [6968] = {.lex_state = 540},
  [6969] = {.lex_state = 427},
  [6970] = {.lex_state = 434, .external_lex_state = 114},
  [6971] = {.lex_state = 540},
  [6972] = {.lex_state = 435},
  [6973] = {.lex_state = 435},
  [6974] = {.lex_state = 540},
  [6975] = {.lex_state = 434, .external_lex_state = 114},
  [6976] = {.lex_state = 427},
  [6977] = {.lex_state = 434, .external_lex_state = 114},
  [6978] = {.lex_state = 435},
  [6979] = {.lex_state = 540},
  [6980] = {.lex_state = 434, .external_lex_state = 114},
  [6981] = {.lex_state = 540},
  [6982] = {.lex_state = 540},
  [6983] = {.lex_state = 427},
  [6984] = {.lex_state = 434, .external_lex_state = 114},
  [6985] = {.lex_state = 540},
  [6986] = {.lex_state = 540},
  [6987] = {.lex_state = 414, .external_lex_state = 128},
  [6988] = {.lex_state = 414, .external_lex_state = 128},
  [6989] = {.lex_state = 435},
  [6990] = {.lex_state = 427},
  [6991] = {.lex_state = 156, .external_lex_state = 119},
  [6992] = {.lex_state = 434, .external_lex_state = 114},
  [6993] = {.lex_state = 540},
  [6994] = {.lex_state = 540},
  [6995] = {.lex_state = 540},
  [6996] = {.lex_state = 480},
  [6997] = {.lex_state = 427},
  [6998] = {.lex_state = 540},
  [6999] = {.lex_state = 540},
  [7000] = {.lex_state = 427, .external_lex_state = 125},
  [7001] = {.lex_state = 434, .external_lex_state = 114},
  [7002] = {.lex_state = 427},
  [7003] = {.lex_state = 427, .external_lex_state = 125},
  [7004] = {.lex_state = 427},
  [7005] = {.lex_state = 540},
  [7006] = {.lex_state = 435},
  [7007] = {.lex_state = 540},
  [7008] = {.lex_state = 540},
  [7009] = {.lex_state = 413},
  [7010] = {.lex_state = 434, .external_lex_state = 114},
  [7011] = {.lex_state = 427},
  [7012] = {.lex_state = 435},
  [7013] = {.lex_state = 434, .external_lex_state = 114},
  [7014] = {.lex_state = 480},
  [7015] = {.lex_state = 435},
  [7016] = {.lex_state = 427, .external_lex_state = 125},
  [7017] = {.lex_state = 540},
  [7018] = {.lex_state = 427},
  [7019] = {.lex_state = 427, .external_lex_state = 125},
  [7020] = {.lex_state = 540},
  [7021] = {.lex_state = 435},
  [7022] = {.lex_state = 540},
  [7023] = {.lex_state = 540, .external_lex_state = 129},
  [7024] = {.lex_state = 540, .external_lex_state = 129},
  [7025] = {.lex_state = 427},
  [7026] = {.lex_state = 434, .external_lex_state = 114},
  [7027] = {.lex_state = 540},
  [7028] = {.lex_state = 434, .external_lex_state = 114},
  [7029] = {.lex_state = 540},
  [7030] = {.lex_state = 480},
  [7031] = {.lex_state = 427, .external_lex_state = 125},
  [7032] = {.lex_state = 427},
  [7033] = {.lex_state = 427, .external_lex_state = 125},
  [7034] = {.lex_state = 540},
  [7035] = {.lex_state = 540},
  [7036] = {.lex_state = 434, .external_lex_state = 114},
  [7037] = {.lex_state = 434, .external_lex_state = 114},
  [7038] = {.lex_state = 435},
  [7039] = {.lex_state = 427},
  [7040] = {.lex_state = 427, .external_lex_state = 125},
  [7041] = {.lex_state = 427, .external_lex_state = 125},
  [7042] = {.lex_state = 540},
  [7043] = {.lex_state = 434, .external_lex_state = 114},
  [7044] = {.lex_state = 540},
  [7045] = {.lex_state = 434, .external_lex_state = 114},
  [7046] = {.lex_state = 427},
  [7047] = {.lex_state = 434, .external_lex_state = 114},
  [7048] = {.lex_state = 540},
  [7049] = {.lex_state = 540},
  [7050] = {.lex_state = 427},
  [7051] = {.lex_state = 540},
  [7052] = {.lex_state = 540},
  [7053] = {.lex_state = 427},
  [7054] = {.lex_state = 434, .external_lex_state = 114},
  [7055] = {.lex_state = 540},
  [7056] = {.lex_state = 540},
  [7057] = {.lex_state = 540},
  [7058] = {.lex_state = 540},
  [7059] = {.lex_state = 427},
  [7060] = {.lex_state = 427},
  [7061] = {.lex_state = 540},
  [7062] = {.lex_state = 540},
  [7063] = {.lex_state = 540},
  [7064] = {.lex_state = 540},
  [7065] = {.lex_state = 435},
  [7066] = {.lex_state = 427, .external_lex_state = 125},
  [7067] = {.lex_state = 427},
  [7068] = {.lex_state = 435},
  [7069] = {.lex_state = 435},
  [7070] = {.lex_state = 435},
  [7071] = {.lex_state = 434, .external_lex_state = 114},
  [7072] = {.lex_state = 540},
  [7073] = {.lex_state = 434, .external_lex_state = 114},
  [7074] = {.lex_state = 427},
  [7075] = {.lex_state = 540},
  [7076] = {.lex_state = 434, .external_lex_state = 114},
  [7077] = {.lex_state = 540},
  [7078] = {.lex_state = 540},
  [7079] = {.lex_state = 540},
  [7080] = {.lex_state = 540},
  [7081] = {.lex_state = 427},
  [7082] = {.lex_state = 540},
  [7083] = {.lex_state = 540},
  [7084] = {.lex_state = 540},
  [7085] = {.lex_state = 540},
  [7086] = {.lex_state = 434, .external_lex_state = 114},
  [7087] = {.lex_state = 540},
  [7088] = {.lex_state = 427},
  [7089] = {.lex_state = 435},
  [7090] = {.lex_state = 434, .external_lex_state = 114},
  [7091] = {.lex_state = 540},
  [7092] = {.lex_state = 434, .external_lex_state = 114},
  [7093] = {.lex_state = 540},
  [7094] = {.lex_state = 540},
  [7095] = {.lex_state = 540},
  [7096] = {.lex_state = 540},
  [7097] = {.lex_state = 427},
  [7098] = {.lex_state = 540},
  [7099] = {.lex_state = 540},
  [7100] = {.lex_state = 540},
  [7101] = {.lex_state = 540},
  [7102] = {.lex_state = 434, .external_lex_state = 114},
  [7103] = {.lex_state = 540},
  [7104] = {.lex_state = 434, .external_lex_state = 114},
  [7105] = {.lex_state = 434, .external_lex_state = 114},
  [7106] = {.lex_state = 435},
  [7107] = {.lex_state = 434, .external_lex_state = 114},
  [7108] = {.lex_state = 540},
  [7109] = {.lex_state = 540},
  [7110] = {.lex_state = 540},
  [7111] = {.lex_state = 540},
  [7112] = {.lex_state = 403},
  [7113] = {.lex_state = 540},
  [7114] = {.lex_state = 540},
  [7115] = {.lex_state = 156, .external_lex_state = 119},
  [7116] = {.lex_state = 156, .external_lex_state = 119},
  [7117] = {.lex_state = 434, .external_lex_state = 114},
  [7118] = {.lex_state = 434, .external_lex_state = 114},
  [7119] = {.lex_state = 540},
  [7120] = {.lex_state = 434, .external_lex_state = 114},
  [7121] = {.lex_state = 540},
  [7122] = {.lex_state = 540},
  [7123] = {.lex_state = 540},
  [7124] = {.lex_state = 434, .external_lex_state = 114},
  [7125] = {.lex_state = 540},
  [7126] = {.lex_state = 435},
  [7127] = {.lex_state = 540},
  [7128] = {.lex_state = 540},
  [7129] = {.lex_state = 434, .external_lex_state = 114},
  [7130] = {.lex_state = 434, .external_lex_state = 114},
  [7131] = {.lex_state = 435},
  [7132] = {.lex_state = 434, .external_lex_state = 114},
  [7133] = {.lex_state = 156, .external_lex_state = 119},
  [7134] = {.lex_state = 434, .external_lex_state = 114},
  [7135] = {.lex_state = 434, .external_lex_state = 114},
  [7136] = {.lex_state = 156, .external_lex_state = 119},
  [7137] = {.lex_state = 429},
  [7138] = {.lex_state = 540},
  [7139] = {.lex_state = 435},
  [7140] = {.lex_state = 480},
  [7141] = {.lex_state = 427},
  [7142] = {.lex_state = 540},
  [7143] = {.lex_state = 434, .external_lex_state = 114},
  [7144] = {.lex_state = 540},
  [7145] = {.lex_state = 540, .external_lex_state = 130},
  [7146] = {.lex_state = 156, .external_lex_state = 119},
  [7147] = {.lex_state = 540},
  [7148] = {.lex_state = 434, .external_lex_state = 114},
  [7149] = {.lex_state = 540},
  [7150] = {.lex_state = 540, .external_lex_state = 130},
  [7151] = {.lex_state = 434, .external_lex_state = 114},
  [7152] = {.lex_state = 540},
  [7153] = {.lex_state = 414, .external_lex_state = 128},
  [7154] = {.lex_state = 414, .external_lex_state = 128},
  [7155] = {.lex_state = 435},
  [7156] = {.lex_state = 540},
  [7157] = {.lex_state = 540},
  [7158] = {.lex_state = 434, .external_lex_state = 114},
  [7159] = {.lex_state = 480},
  [7160] = {.lex_state = 156, .external_lex_state = 119},
  [7161] = {.lex_state = 434, .external_lex_state = 114},
  [7162] = {.lex_state = 427, .external_lex_state = 125},
  [7163] = {.lex_state = 434, .external_lex_state = 114},
  [7164] = {.lex_state = 435},
  [7165] = {.lex_state = 427, .external_lex_state = 125},
  [7166] = {.lex_state = 434, .external_lex_state = 114},
  [7167] = {.lex_state = 540},
  [7168] = {.lex_state = 434, .external_lex_state = 114},
  [7169] = {.lex_state = 540},
  [7170] = {.lex_state = 540},
  [7171] = {.lex_state = 540},
  [7172] = {.lex_state = 434, .external_lex_state = 114},
  [7173] = {.lex_state = 480},
  [7174] = {.lex_state = 540},
  [7175] = {.lex_state = 427, .external_lex_state = 125},
  [7176] = {.lex_state = 434, .external_lex_state = 114},
  [7177] = {.lex_state = 427, .external_lex_state = 125},
  [7178] = {.lex_state = 540},
  [7179] = {.lex_state = 434, .external_lex_state = 114},
  [7180] = {.lex_state = 540, .external_lex_state = 129},
  [7181] = {.lex_state = 540, .external_lex_state = 129},
  [7182] = {.lex_state = 434, .external_lex_state = 114},
  [7183] = {.lex_state = 540},
  [7184] = {.lex_state = 434, .external_lex_state = 114},
  [7185] = {.lex_state = 540},
  [7186] = {.lex_state = 540},
  [7187] = {.lex_state = 480},
  [7188] = {.lex_state = 427, .external_lex_state = 125},
  [7189] = {.lex_state = 427, .external_lex_state = 125},
  [7190] = {.lex_state = 540},
  [7191] = {.lex_state = 540},
  [7192] = {.lex_state = 540},
  [7193] = {.lex_state = 540},
  [7194] = {.lex_state = 540},
  [7195] = {.lex_state = 427, .external_lex_state = 125},
  [7196] = {.lex_state = 427, .external_lex_state = 125},
  [7197] = {.lex_state = 540},
  [7198] = {.lex_state = 540},
  [7199] = {.lex_state = 434, .external_lex_state = 114},
  [7200] = {.lex_state = 540},
  [7201] = {.lex_state = 540},
  [7202] = {.lex_state = 540},
  [7203] = {.lex_state = 540},
  [7204] = {.lex_state = 540},
  [7205] = {.lex_state = 156, .external_lex_state = 119},
  [7206] = {.lex_state = 540},
  [7207] = {.lex_state = 540},
  [7208] = {.lex_state = 435},
  [7209] = {.lex_state = 540},
  [7210] = {.lex_state = 435},
  [7211] = {.lex_state = 435},
  [7212] = {.lex_state = 540},
  [7213] = {.lex_state = 434, .external_lex_state = 114},
  [7214] = {.lex_state = 434, .external_lex_state = 114},
  [7215] = {.lex_state = 540},
  [7216] = {.lex_state = 434, .external_lex_state = 114},
  [7217] = {.lex_state = 540},
  [7218] = {.lex_state = 540},
  [7219] = {.lex_state = 434, .external_lex_state = 114},
  [7220] = {.lex_state = 435},
  [7221] = {.lex_state = 434, .external_lex_state = 114},
  [7222] = {.lex_state = 414, .external_lex_state = 128},
  [7223] = {.lex_state = 540},
  [7224] = {.lex_state = 434, .external_lex_state = 114},
  [7225] = {.lex_state = 540},
  [7226] = {.lex_state = 540},
  [7227] = {.lex_state = 540},
  [7228] = {.lex_state = 434, .external_lex_state = 114},
  [7229] = {.lex_state = 434, .external_lex_state = 114},
  [7230] = {.lex_state = 540},
  [7231] = {.lex_state = 480},
  [7232] = {.lex_state = 403},
  [7233] = {.lex_state = 540},
  [7234] = {.lex_state = 540},
  [7235] = {.lex_state = 540},
  [7236] = {.lex_state = 540},
  [7237] = {.lex_state = 434, .external_lex_state = 114},
  [7238] = {.lex_state = 434, .external_lex_state = 114},
  [7239] = {.lex_state = 540},
  [7240] = {.lex_state = 540},
  [7241] = {.lex_state = 540},
  [7242] = {.lex_state = 540},
  [7243] = {.lex_state = 540},
  [7244] = {.lex_state = 540},
  [7245] = {.lex_state = 434, .external_lex_state = 114},
  [7246] = {.lex_state = 434, .external_lex_state = 114},
  [7247] = {.lex_state = 540},
  [7248] = {.lex_state = 156, .external_lex_state = 119},
  [7249] = {.lex_state = 434, .external_lex_state = 114},
  [7250] = {.lex_state = 540},
  [7251] = {.lex_state = 434, .external_lex_state = 114},
  [7252] = {.lex_state = 540},
  [7253] = {.lex_state = 156, .external_lex_state = 119},
  [7254] = {.lex_state = 540},
  [7255] = {.lex_state = 434, .external_lex_state = 114},
  [7256] = {.lex_state = 540},
  [7257] = {.lex_state = 435},
  [7258] = {.lex_state = 435},
  [7259] = {.lex_state = 427},
  [7260] = {.lex_state = 414, .external_lex_state = 128},
  [7261] = {.lex_state = 414, .external_lex_state = 128},
  [7262] = {.lex_state = 435},
  [7263] = {.lex_state = 540},
  [7264] = {.lex_state = 540},
  [7265] = {.lex_state = 435},
  [7266] = {.lex_state = 540, .external_lex_state = 129},
  [7267] = {.lex_state = 540, .external_lex_state = 129},
  [7268] = {.lex_state = 434, .external_lex_state = 114},
  [7269] = {.lex_state = 435},
  [7270] = {.lex_state = 540},
  [7271] = {.lex_state = 434, .external_lex_state = 114},
  [7272] = {.lex_state = 540},
  [7273] = {.lex_state = 540},
  [7274] = {.lex_state = 434, .external_lex_state = 114},
  [7275] = {.lex_state = 540},
  [7276] = {.lex_state = 540},
  [7277] = {.lex_state = 156, .external_lex_state = 119},
  [7278] = {.lex_state = 429},
  [7279] = {.lex_state = 540},
  [7280] = {.lex_state = 540},
  [7281] = {.lex_state = 480},
  [7282] = {.lex_state = 427},
  [7283] = {.lex_state = 540},
  [7284] = {.lex_state = 540},
  [7285] = {.lex_state = 540},
  [7286] = {.lex_state = 540, .external_lex_state = 130},
  [7287] = {.lex_state = 540},
  [7288] = {.lex_state = 540},
  [7289] = {.lex_state = 540},
  [7290] = {.lex_state = 540, .external_lex_state = 130},
  [7291] = {.lex_state = 540},
  [7292] = {.lex_state = 435},
  [7293] = {.lex_state = 434, .external_lex_state = 114},
  [7294] = {.lex_state = 540},
  [7295] = {.lex_state = 434, .external_lex_state = 114},
  [7296] = {.lex_state = 540},
  [7297] = {.lex_state = 540},
  [7298] = {.lex_state = 156, .external_lex_state = 119},
  [7299] = {.lex_state = 540},
  [7300] = {.lex_state = 434, .external_lex_state = 114},
  [7301] = {.lex_state = 540},
  [7302] = {.lex_state = 540},
  [7303] = {.lex_state = 540},
  [7304] = {.lex_state = 540},
  [7305] = {.lex_state = 540},
  [7306] = {.lex_state = 540},
  [7307] = {.lex_state = 540},
  [7308] = {.lex_state = 427},
  [7309] = {.lex_state = 156, .external_lex_state = 119},
  [7310] = {.lex_state = 540},
  [7311] = {.lex_state = 435},
  [7312] = {.lex_state = 480},
  [7313] = {.lex_state = 434, .external_lex_state = 114},
  [7314] = {.lex_state = 540},
  [7315] = {.lex_state = 434, .external_lex_state = 114},
  [7316] = {.lex_state = 540},
  [7317] = {.lex_state = 427},
  [7318] = {.lex_state = 480},
  [7319] = {.lex_state = 403},
  [7320] = {.lex_state = 540},
  [7321] = {.lex_state = 427},
  [7322] = {.lex_state = 540},
  [7323] = {.lex_state = 540},
  [7324] = {.lex_state = 540},
  [7325] = {.lex_state = 540},
  [7326] = {.lex_state = 434, .external_lex_state = 114},
  [7327] = {.lex_state = 540},
  [7328] = {.lex_state = 540},
  [7329] = {.lex_state = 540},
  [7330] = {.lex_state = 540},
  [7331] = {.lex_state = 540},
  [7332] = {.lex_state = 540},
  [7333] = {.lex_state = 540},
  [7334] = {.lex_state = 540},
  [7335] = {.lex_state = 540},
  [7336] = {.lex_state = 540},
  [7337] = {.lex_state = 434, .external_lex_state = 114},
  [7338] = {.lex_state = 540},
  [7339] = {.lex_state = 540},
  [7340] = {.lex_state = 427, .external_lex_state = 125},
  [7341] = {.lex_state = 540},
  [7342] = {.lex_state = 156, .external_lex_state = 119},
  [7343] = {.lex_state = 540},
  [7344] = {.lex_state = 434, .external_lex_state = 114},
  [7345] = {.lex_state = 435},
  [7346] = {.lex_state = 434, .external_lex_state = 114},
  [7347] = {.lex_state = 414, .external_lex_state = 128},
  [7348] = {.lex_state = 414, .external_lex_state = 128},
  [7349] = {.lex_state = 435},
  [7350] = {.lex_state = 540},
  [7351] = {.lex_state = 540},
  [7352] = {.lex_state = 540},
  [7353] = {.lex_state = 540},
  [7354] = {.lex_state = 540},
  [7355] = {.lex_state = 427},
  [7356] = {.lex_state = 540},
  [7357] = {.lex_state = 540},
  [7358] = {.lex_state = 427},
  [7359] = {.lex_state = 434, .external_lex_state = 114},
  [7360] = {.lex_state = 413},
  [7361] = {.lex_state = 540},
  [7362] = {.lex_state = 427},
  [7363] = {.lex_state = 427},
  [7364] = {.lex_state = 435},
  [7365] = {.lex_state = 434, .external_lex_state = 114},
  [7366] = {.lex_state = 427, .external_lex_state = 125},
  [7367] = {.lex_state = 540},
  [7368] = {.lex_state = 540},
  [7369] = {.lex_state = 429},
  [7370] = {.lex_state = 540},
  [7371] = {.lex_state = 434, .external_lex_state = 114},
  [7372] = {.lex_state = 403},
  [7373] = {.lex_state = 434, .external_lex_state = 114},
  [7374] = {.lex_state = 434, .external_lex_state = 114},
  [7375] = {.lex_state = 540},
  [7376] = {.lex_state = 540},
  [7377] = {.lex_state = 540},
  [7378] = {.lex_state = 540},
  [7379] = {.lex_state = 427},
  [7380] = {.lex_state = 429},
  [7381] = {.lex_state = 427},
  [7382] = {.lex_state = 540},
  [7383] = {.lex_state = 480},
  [7384] = {.lex_state = 427},
  [7385] = {.lex_state = 540},
  [7386] = {.lex_state = 435},
  [7387] = {.lex_state = 540},
  [7388] = {.lex_state = 540, .external_lex_state = 130},
  [7389] = {.lex_state = 434, .external_lex_state = 114},
  [7390] = {.lex_state = 540},
  [7391] = {.lex_state = 427},
  [7392] = {.lex_state = 540, .external_lex_state = 130},
  [7393] = {.lex_state = 540},
  [7394] = {.lex_state = 540},
  [7395] = {.lex_state = 540},
  [7396] = {.lex_state = 156, .external_lex_state = 119},
  [7397] = {.lex_state = 156, .external_lex_state = 119},
  [7398] = {.lex_state = 540},
  [7399] = {.lex_state = 540},
  [7400] = {.lex_state = 540},
  [7401] = {.lex_state = 427},
  [7402] = {.lex_state = 540},
  [7403] = {.lex_state = 403},
  [7404] = {.lex_state = 435},
  [7405] = {.lex_state = 434, .external_lex_state = 114},
  [7406] = {.lex_state = 540},
  [7407] = {.lex_state = 156, .external_lex_state = 119},
  [7408] = {.lex_state = 540},
  [7409] = {.lex_state = 156, .external_lex_state = 119},
  [7410] = {.lex_state = 480},
  [7411] = {.lex_state = 427},
  [7412] = {.lex_state = 540},
  [7413] = {.lex_state = 540, .external_lex_state = 130},
  [7414] = {.lex_state = 434, .external_lex_state = 114},
  [7415] = {.lex_state = 435},
  [7416] = {.lex_state = 540, .external_lex_state = 130},
  [7417] = {.lex_state = 156, .external_lex_state = 119},
  [7418] = {.lex_state = 540},
  [7419] = {.lex_state = 434, .external_lex_state = 114},
  [7420] = {.lex_state = 156, .external_lex_state = 119},
  [7421] = {.lex_state = 427},
  [7422] = {.lex_state = 540, .external_lex_state = 130},
  [7423] = {.lex_state = 434, .external_lex_state = 114},
  [7424] = {.lex_state = 540},
  [7425] = {.lex_state = 434, .external_lex_state = 114},
  [7426] = {.lex_state = 434, .external_lex_state = 114},
  [7427] = {.lex_state = 434, .external_lex_state = 114},
  [7428] = {.lex_state = 435},
  [7429] = {.lex_state = 435},
  [7430] = {.lex_state = 480},
  [7431] = {.lex_state = 435},
  [7432] = {.lex_state = 434, .external_lex_state = 114},
  [7433] = {.lex_state = 434, .external_lex_state = 114},
  [7434] = {.lex_state = 427},
  [7435] = {.lex_state = 427},
  [7436] = {.lex_state = 427},
  [7437] = {.lex_state = 427},
  [7438] = {.lex_state = 427},
  [7439] = {.lex_state = 427},
  [7440] = {.lex_state = 427},
  [7441] = {.lex_state = 427},
  [7442] = {.lex_state = 427},
  [7443] = {.lex_state = 427},
  [7444] = {.lex_state = 427},
  [7445] = {.lex_state = 427},
  [7446] = {.lex_state = 427},
  [7447] = {.lex_state = 427},
  [7448] = {.lex_state = 427},
  [7449] = {.lex_state = 427},
  [7450] = {.lex_state = 427},
  [7451] = {.lex_state = 427},
  [7452] = {.lex_state = 427},
  [7453] = {.lex_state = 427},
  [7454] = {.lex_state = 427},
  [7455] = {.lex_state = 427},
  [7456] = {.lex_state = 427},
  [7457] = {.lex_state = 427},
  [7458] = {.lex_state = 427},
  [7459] = {.lex_state = 427},
  [7460] = {.lex_state = 427},
  [7461] = {.lex_state = 427},
  [7462] = {.lex_state = 427},
  [7463] = {.lex_state = 427},
  [7464] = {.lex_state = 427},
  [7465] = {.lex_state = 427},
  [7466] = {.lex_state = 427},
  [7467] = {.lex_state = 427},
  [7468] = {.lex_state = 427},
  [7469] = {.lex_state = 427},
  [7470] = {.lex_state = 427},
  [7471] = {.lex_state = 427},
  [7472] = {.lex_state = 427},
  [7473] = {.lex_state = 427},
  [7474] = {.lex_state = 427},
  [7475] = {.lex_state = 427},
  [7476] = {.lex_state = 427},
  [7477] = {.lex_state = 427},
  [7478] = {.lex_state = 427},
  [7479] = {.lex_state = 427},
  [7480] = {.lex_state = 427},
  [7481] = {.lex_state = 427},
  [7482] = {.lex_state = 427},
  [7483] = {.lex_state = 427},
  [7484] = {.lex_state = 427},
  [7485] = {.lex_state = 427},
  [7486] = {.lex_state = 427},
  [7487] = {.lex_state = 427},
  [7488] = {.lex_state = 427},
  [7489] = {.lex_state = 427},
  [7490] = {.lex_state = 427},
  [7491] = {.lex_state = 427},
  [7492] = {.lex_state = 427},
  [7493] = {.lex_state = 427},
  [7494] = {.lex_state = 540},
  [7495] = {.lex_state = 540},
  [7496] = {.lex_state = 427, .external_lex_state = 125},
  [7497] = {.lex_state = 540},
  [7498] = {.lex_state = 540},
  [7499] = {.lex_state = 480},
  [7500] = {.lex_state = 414, .external_lex_state = 128},
  [7501] = {.lex_state = 540},
  [7502] = {.lex_state = 427},
  [7503] = {.lex_state = 427},
  [7504] = {.lex_state = 434, .external_lex_state = 114},
  [7505] = {.lex_state = 427, .external_lex_state = 125},
  [7506] = {.lex_state = 540},
  [7507] = {.lex_state = 434, .external_lex_state = 114},
  [7508] = {.lex_state = 540},
  [7509] = {.lex_state = 427},
  [7510] = {.lex_state = 427},
  [7511] = {.lex_state = 427},
  [7512] = {.lex_state = 427},
  [7513] = {.lex_state = 427},
  [7514] = {.lex_state = 427},
  [7515] = {.lex_state = 427},
  [7516] = {.lex_state = 427},
  [7517] = {.lex_state = 427},
  [7518] = {.lex_state = 427},
  [7519] = {.lex_state = 427},
  [7520] = {.lex_state = 427},
  [7521] = {.lex_state = 427},
  [7522] = {.lex_state = 427},
  [7523] = {.lex_state = 427},
  [7524] = {.lex_state = 427},
  [7525] = {.lex_state = 427},
  [7526] = {.lex_state = 427},
  [7527] = {.lex_state = 427},
  [7528] = {.lex_state = 427},
  [7529] = {.lex_state = 427},
  [7530] = {.lex_state = 427},
  [7531] = {.lex_state = 427},
  [7532] = {.lex_state = 427},
  [7533] = {.lex_state = 427},
  [7534] = {.lex_state = 427},
  [7535] = {.lex_state = 427},
  [7536] = {.lex_state = 427},
  [7537] = {.lex_state = 427},
  [7538] = {.lex_state = 427},
  [7539] = {.lex_state = 427},
  [7540] = {.lex_state = 427},
  [7541] = {.lex_state = 427},
  [7542] = {.lex_state = 427},
  [7543] = {.lex_state = 427},
  [7544] = {.lex_state = 427},
  [7545] = {.lex_state = 427},
  [7546] = {.lex_state = 427},
  [7547] = {.lex_state = 427},
  [7548] = {.lex_state = 427},
  [7549] = {.lex_state = 427},
  [7550] = {.lex_state = 427},
  [7551] = {.lex_state = 427},
  [7552] = {.lex_state = 427},
  [7553] = {.lex_state = 427},
  [7554] = {.lex_state = 427},
  [7555] = {.lex_state = 427},
  [7556] = {.lex_state = 427},
  [7557] = {.lex_state = 427},
  [7558] = {.lex_state = 427},
  [7559] = {.lex_state = 427},
  [7560] = {.lex_state = 427},
  [7561] = {.lex_state = 427},
  [7562] = {.lex_state = 427},
  [7563] = {.lex_state = 427},
  [7564] = {.lex_state = 427},
  [7565] = {.lex_state = 427},
  [7566] = {.lex_state = 427},
  [7567] = {.lex_state = 427},
  [7568] = {.lex_state = 427},
  [7569] = {.lex_state = 427},
  [7570] = {.lex_state = 434, .external_lex_state = 114},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_word] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_select] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_until] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_done] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_fi] = ACTIONS(1),
    [anon_sym_elif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_esac] = ACTIONS(1),
    [anon_sym_SEMI_SEMI] = ACTIONS(1),
    [anon_sym_SEMI_AMP] = ACTIONS(1),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_PIPE_AMP] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1),
    [anon_sym_declare] = ACTIONS(1),
    [anon_sym_typeset] = ACTIONS(1),
    [anon_sym_export] = ACTIONS(1),
    [anon_sym_readonly] = ACTIONS(1),
    [anon_sym_local] = ACTIONS(1),
    [anon_sym_unset] = ACTIONS(1),
    [anon_sym_unsetenv] = ACTIONS(1),
    [anon_sym_AMP_GT] = ACTIONS(1),
    [anon_sym_AMP_GT_GT] = ACTIONS(1),
    [anon_sym_LT_AMP] = ACTIONS(1),
    [anon_sym_GT_AMP] = ACTIONS(1),
    [anon_sym_GT_PIPE] = ACTIONS(1),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1),
    [anon_sym_LT_LT_DASH] = ACTIONS(1),
    [anon_sym_LT_LT_LT] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_DASH2] = ACTIONS(1),
    [anon_sym_PLUS2] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1),
    [aux_sym_brace_expression_token1] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_RBRACE2] = ACTIONS(1),
    [aux_sym_concatenation_token1] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [sym__special_character] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_raw_string] = ACTIONS(1),
    [sym_ansi_c_string] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE3] = ACTIONS(1),
    [anon_sym_BANG2] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_STAR2] = ACTIONS(1),
    [anon_sym_POUND2] = ACTIONS(1),
    [anon_sym_EQ2] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_DASH3] = ACTIONS(1),
    [anon_sym_COLON_DASH] = ACTIONS(1),
    [anon_sym_PLUS3] = ACTIONS(1),
    [anon_sym_COLON_PLUS] = ACTIONS(1),
    [anon_sym_QMARK2] = ACTIONS(1),
    [anon_sym_COLON_QMARK] = ACTIONS(1),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(1),
    [anon_sym_SLASH_POUND] = ACTIONS(1),
    [anon_sym_SLASH_PERCENT] = ACTIONS(1),
    [anon_sym_COMMA_COMMA] = ACTIONS(1),
    [anon_sym_CARET_CARET] = ACTIONS(1),
    [anon_sym_U] = ACTIONS(1),
    [anon_sym_u] = ACTIONS(1),
    [anon_sym_L] = ACTIONS(1),
    [anon_sym_Q] = ACTIONS(1),
    [anon_sym_E] = ACTIONS(1),
    [anon_sym_P] = ACTIONS(1),
    [anon_sym_A] = ACTIONS(1),
    [anon_sym_K] = ACTIONS(1),
    [anon_sym_a] = ACTIONS(1),
    [anon_sym_k] = ACTIONS(1),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1),
    [anon_sym_BQUOTE] = ACTIONS(1),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1),
    [anon_sym_LT_LPAREN] = ACTIONS(1),
    [anon_sym_GT_LPAREN] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym__comment_word] = ACTIONS(1),
    [anon_sym_AT2] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [sym_heredoc_start] = ACTIONS(1),
    [sym_simple_heredoc_body] = ACTIONS(1),
    [sym__heredoc_body_beginning] = ACTIONS(1),
    [sym_heredoc_content] = ACTIONS(1),
    [sym_heredoc_end] = ACTIONS(1),
    [sym_file_descriptor] = ACTIONS(1),
    [sym__empty_value] = ACTIONS(1),
    [sym__concat] = ACTIONS(1),
    [sym_variable_name] = ACTIONS(1),
    [sym_test_operator] = ACTIONS(1),
    [sym_regex] = ACTIONS(1),
    [sym__regex_no_slash] = ACTIONS(1),
    [sym__regex_no_space] = ACTIONS(1),
    [sym__expansion_word] = ACTIONS(1),
    [sym_extglob_pattern] = ACTIONS(1),
    [sym__bare_dollar] = ACTIONS(1),
    [sym__brace_start] = ACTIONS(1),
    [sym__immediate_double_hash] = ACTIONS(1),
    [sym__external_expansion_sym_hash] = ACTIONS(1),
    [sym__external_expansion_sym_bang] = ACTIONS(1),
    [sym__external_expansion_sym_equal] = ACTIONS(1),
    [sym___error_recovery] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_program] = STATE(6879),
    [sym__statements] = STATE(7212),
    [sym__statement_not_pipeline] = STATE(6618),
    [sym_redirected_statement] = STATE(4555),
    [sym_for_statement] = STATE(4555),
    [sym_c_style_for_statement] = STATE(4555),
    [sym_while_statement] = STATE(4225),
    [sym_if_statement] = STATE(4225),
    [sym_case_statement] = STATE(4555),
    [sym_function_definition] = STATE(4555),
    [sym_compound_statement] = STATE(4555),
    [sym_subshell] = STATE(4555),
    [sym_pipeline] = STATE(4952),
    [sym_list] = STATE(4555),
    [sym_negated_command] = STATE(4555),
    [sym_test_command] = STATE(4555),
    [sym_declaration_command] = STATE(4555),
    [sym_unset_command] = STATE(4555),
    [sym_command] = STATE(4555),
    [sym_command_name] = STATE(528),
    [sym_variable_assignment] = STATE(868),
    [sym_variable_assignments] = STATE(4555),
    [sym_subscript] = STATE(6655),
    [sym_file_redirect] = STATE(2125),
    [sym_herestring_redirect] = STATE(2207),
    [sym_arithmetic_expansion] = STATE(944),
    [sym_brace_expression] = STATE(944),
    [sym_concatenation] = STATE(1431),
    [sym_string] = STATE(944),
    [sym_translated_string] = STATE(944),
    [sym_number] = STATE(944),
    [sym_simple_expansion] = STATE(944),
    [sym_expansion] = STATE(944),
    [sym_command_substitution] = STATE(944),
    [sym_process_substitution] = STATE(944),
    [aux_sym__statements_repeat1] = STATE(425),
    [aux_sym_redirected_statement_repeat2] = STATE(4333),
    [aux_sym_command_repeat1] = STATE(937),
    [aux_sym__literal_repeat1] = STATE(1181),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_word] = ACTIONS(7),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(15),
    [anon_sym_GT] = ACTIONS(15),
    [anon_sym_GT_GT] = ACTIONS(17),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(27),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(31),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(37),
    [anon_sym_typeset] = ACTIONS(37),
    [anon_sym_export] = ACTIONS(37),
    [anon_sym_readonly] = ACTIONS(37),
    [anon_sym_local] = ACTIONS(37),
    [anon_sym_unset] = ACTIONS(39),
    [anon_sym_unsetenv] = ACTIONS(39),
    [anon_sym_AMP_GT] = ACTIONS(15),
    [anon_sym_AMP_GT_GT] = ACTIONS(17),
    [anon_sym_LT_AMP] = ACTIONS(15),
    [anon_sym_GT_AMP] = ACTIONS(15),
    [anon_sym_GT_PIPE] = ACTIONS(17),
    [anon_sym_LT_AMP_DASH] = ACTIONS(41),
    [anon_sym_GT_AMP_DASH] = ACTIONS(41),
    [anon_sym_LT_LT_LT] = ACTIONS(43),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(45),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(47),
    [anon_sym_DOLLAR] = ACTIONS(49),
    [sym__special_character] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [sym_raw_string] = ACTIONS(55),
    [sym_ansi_c_string] = ACTIONS(55),
    [aux_sym_number_token1] = ACTIONS(57),
    [aux_sym_number_token2] = ACTIONS(59),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(61),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(63),
    [anon_sym_BQUOTE] = ACTIONS(65),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(67),
    [anon_sym_LT_LPAREN] = ACTIONS(69),
    [anon_sym_GT_LPAREN] = ACTIONS(69),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(73),
    [sym_variable_name] = ACTIONS(75),
    [sym_test_operator] = ACTIONS(77),
    [sym__brace_start] = ACTIONS(79),
  },
  [STATE(2)] = {
    [sym__statements] = STATE(7341),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym__expression] = STATE(2995),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(467),
    [sym_brace_expression] = STATE(467),
    [sym_concatenation] = STATE(490),
    [sym_string] = STATE(467),
    [sym_translated_string] = STATE(467),
    [sym_number] = STATE(467),
    [sym_simple_expansion] = STATE(467),
    [sym_expansion] = STATE(467),
    [sym_command_substitution] = STATE(467),
    [sym_process_substitution] = STATE(467),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(489),
    [sym_word] = ACTIONS(81),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(91),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_PLUS_PLUS2] = ACTIONS(101),
    [anon_sym_DASH_DASH2] = ACTIONS(101),
    [anon_sym_DASH2] = ACTIONS(103),
    [anon_sym_PLUS2] = ACTIONS(103),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(107),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(109),
    [anon_sym_DOLLAR] = ACTIONS(111),
    [sym__special_character] = ACTIONS(113),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_raw_string] = ACTIONS(117),
    [sym_ansi_c_string] = ACTIONS(117),
    [aux_sym_number_token1] = ACTIONS(119),
    [aux_sym_number_token2] = ACTIONS(121),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(123),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(125),
    [anon_sym_BQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(129),
    [anon_sym_LT_LPAREN] = ACTIONS(131),
    [anon_sym_GT_LPAREN] = ACTIONS(131),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(137),
    [sym__brace_start] = ACTIONS(139),
  },
  [STATE(3)] = {
    [sym__statements] = STATE(6767),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym__expression] = STATE(2948),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(467),
    [sym_brace_expression] = STATE(467),
    [sym_concatenation] = STATE(490),
    [sym_string] = STATE(467),
    [sym_translated_string] = STATE(467),
    [sym_number] = STATE(467),
    [sym_simple_expansion] = STATE(467),
    [sym_expansion] = STATE(467),
    [sym_command_substitution] = STATE(467),
    [sym_process_substitution] = STATE(467),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(489),
    [sym_word] = ACTIONS(81),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(91),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_PLUS_PLUS2] = ACTIONS(101),
    [anon_sym_DASH_DASH2] = ACTIONS(101),
    [anon_sym_DASH2] = ACTIONS(103),
    [anon_sym_PLUS2] = ACTIONS(103),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(107),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(109),
    [anon_sym_DOLLAR] = ACTIONS(111),
    [sym__special_character] = ACTIONS(113),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_raw_string] = ACTIONS(117),
    [sym_ansi_c_string] = ACTIONS(117),
    [aux_sym_number_token1] = ACTIONS(119),
    [aux_sym_number_token2] = ACTIONS(121),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(123),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(125),
    [anon_sym_BQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(129),
    [anon_sym_LT_LPAREN] = ACTIONS(131),
    [anon_sym_GT_LPAREN] = ACTIONS(131),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(137),
    [sym__brace_start] = ACTIONS(139),
  },
  [STATE(4)] = {
    [sym__statements] = STATE(6922),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym__expression] = STATE(2948),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(467),
    [sym_brace_expression] = STATE(467),
    [sym_concatenation] = STATE(490),
    [sym_string] = STATE(467),
    [sym_translated_string] = STATE(467),
    [sym_number] = STATE(467),
    [sym_simple_expansion] = STATE(467),
    [sym_expansion] = STATE(467),
    [sym_command_substitution] = STATE(467),
    [sym_process_substitution] = STATE(467),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(489),
    [sym_word] = ACTIONS(81),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(91),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_PLUS_PLUS2] = ACTIONS(101),
    [anon_sym_DASH_DASH2] = ACTIONS(101),
    [anon_sym_DASH2] = ACTIONS(103),
    [anon_sym_PLUS2] = ACTIONS(103),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(107),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(109),
    [anon_sym_DOLLAR] = ACTIONS(111),
    [sym__special_character] = ACTIONS(113),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_raw_string] = ACTIONS(117),
    [sym_ansi_c_string] = ACTIONS(117),
    [aux_sym_number_token1] = ACTIONS(119),
    [aux_sym_number_token2] = ACTIONS(121),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(123),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(125),
    [anon_sym_BQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(129),
    [anon_sym_LT_LPAREN] = ACTIONS(131),
    [anon_sym_GT_LPAREN] = ACTIONS(131),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(137),
    [sym__brace_start] = ACTIONS(139),
  },
  [STATE(5)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5224),
    [sym_for_statement] = STATE(5306),
    [sym_c_style_for_statement] = STATE(5306),
    [sym_while_statement] = STATE(5094),
    [sym_if_statement] = STATE(5094),
    [sym_case_statement] = STATE(5306),
    [sym_function_definition] = STATE(5306),
    [sym_compound_statement] = STATE(5306),
    [sym_subshell] = STATE(5306),
    [sym_pipeline] = STATE(5517),
    [sym_list] = STATE(5306),
    [sym_negated_command] = STATE(5306),
    [sym_test_command] = STATE(5306),
    [sym_declaration_command] = STATE(5306),
    [sym_unset_command] = STATE(5306),
    [sym_command] = STATE(5306),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1744),
    [sym_variable_assignments] = STATE(5306),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2603),
    [sym_herestring_redirect] = STATE(2604),
    [sym__expression] = STATE(2805),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_redirected_statement_repeat2] = STATE(5038),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(149),
    [anon_sym_GT_GT] = ACTIONS(151),
    [anon_sym_LPAREN] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_RBRACK] = ACTIONS(169),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(149),
    [anon_sym_AMP_GT_GT] = ACTIONS(151),
    [anon_sym_LT_AMP] = ACTIONS(149),
    [anon_sym_GT_AMP] = ACTIONS(149),
    [anon_sym_GT_PIPE] = ACTIONS(151),
    [anon_sym_LT_AMP_DASH] = ACTIONS(177),
    [anon_sym_GT_AMP_DASH] = ACTIONS(177),
    [anon_sym_LT_LT_LT] = ACTIONS(179),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(213),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
  [STATE(6)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5191),
    [sym_for_statement] = STATE(5306),
    [sym_c_style_for_statement] = STATE(5306),
    [sym_while_statement] = STATE(5094),
    [sym_if_statement] = STATE(5094),
    [sym_case_statement] = STATE(5306),
    [sym_function_definition] = STATE(5306),
    [sym_compound_statement] = STATE(5306),
    [sym_subshell] = STATE(5306),
    [sym_pipeline] = STATE(5517),
    [sym_list] = STATE(5306),
    [sym_negated_command] = STATE(5306),
    [sym_test_command] = STATE(5306),
    [sym_declaration_command] = STATE(5306),
    [sym_unset_command] = STATE(5306),
    [sym_command] = STATE(5306),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1744),
    [sym_variable_assignments] = STATE(5306),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2603),
    [sym_herestring_redirect] = STATE(2604),
    [sym__expression] = STATE(2943),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_redirected_statement_repeat2] = STATE(5038),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(149),
    [anon_sym_GT_GT] = ACTIONS(151),
    [anon_sym_LPAREN] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_RBRACK] = ACTIONS(221),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(149),
    [anon_sym_AMP_GT_GT] = ACTIONS(151),
    [anon_sym_LT_AMP] = ACTIONS(149),
    [anon_sym_GT_AMP] = ACTIONS(149),
    [anon_sym_GT_PIPE] = ACTIONS(151),
    [anon_sym_LT_AMP_DASH] = ACTIONS(177),
    [anon_sym_GT_AMP_DASH] = ACTIONS(177),
    [anon_sym_LT_LT_LT] = ACTIONS(179),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(213),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
  [STATE(7)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5212),
    [sym_for_statement] = STATE(5306),
    [sym_c_style_for_statement] = STATE(5306),
    [sym_while_statement] = STATE(5094),
    [sym_if_statement] = STATE(5094),
    [sym_case_statement] = STATE(5306),
    [sym_function_definition] = STATE(5306),
    [sym_compound_statement] = STATE(5306),
    [sym_subshell] = STATE(5306),
    [sym_pipeline] = STATE(5517),
    [sym_list] = STATE(5306),
    [sym_negated_command] = STATE(5306),
    [sym_test_command] = STATE(5306),
    [sym_declaration_command] = STATE(5306),
    [sym_unset_command] = STATE(5306),
    [sym_command] = STATE(5306),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1744),
    [sym_variable_assignments] = STATE(5306),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2603),
    [sym_herestring_redirect] = STATE(2604),
    [sym__expression] = STATE(2982),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_redirected_statement_repeat2] = STATE(5038),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(149),
    [anon_sym_GT_GT] = ACTIONS(151),
    [anon_sym_LPAREN] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_RBRACK] = ACTIONS(223),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(149),
    [anon_sym_AMP_GT_GT] = ACTIONS(151),
    [anon_sym_LT_AMP] = ACTIONS(149),
    [anon_sym_GT_AMP] = ACTIONS(149),
    [anon_sym_GT_PIPE] = ACTIONS(151),
    [anon_sym_LT_AMP_DASH] = ACTIONS(177),
    [anon_sym_GT_AMP_DASH] = ACTIONS(177),
    [anon_sym_LT_LT_LT] = ACTIONS(179),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(213),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
  [STATE(8)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5221),
    [sym_for_statement] = STATE(5306),
    [sym_c_style_for_statement] = STATE(5306),
    [sym_while_statement] = STATE(5094),
    [sym_if_statement] = STATE(5094),
    [sym_case_statement] = STATE(5306),
    [sym_function_definition] = STATE(5306),
    [sym_compound_statement] = STATE(5306),
    [sym_subshell] = STATE(5306),
    [sym_pipeline] = STATE(5517),
    [sym_list] = STATE(5306),
    [sym_negated_command] = STATE(5306),
    [sym_test_command] = STATE(5306),
    [sym_declaration_command] = STATE(5306),
    [sym_unset_command] = STATE(5306),
    [sym_command] = STATE(5306),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1744),
    [sym_variable_assignments] = STATE(5306),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2603),
    [sym_herestring_redirect] = STATE(2604),
    [sym__expression] = STATE(2998),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_redirected_statement_repeat2] = STATE(5038),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(149),
    [anon_sym_GT_GT] = ACTIONS(151),
    [anon_sym_LPAREN] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_RBRACK] = ACTIONS(225),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(149),
    [anon_sym_AMP_GT_GT] = ACTIONS(151),
    [anon_sym_LT_AMP] = ACTIONS(149),
    [anon_sym_GT_AMP] = ACTIONS(149),
    [anon_sym_GT_PIPE] = ACTIONS(151),
    [anon_sym_LT_AMP_DASH] = ACTIONS(177),
    [anon_sym_GT_AMP_DASH] = ACTIONS(177),
    [anon_sym_LT_LT_LT] = ACTIONS(179),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(213),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
  [STATE(9)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5199),
    [sym_for_statement] = STATE(5306),
    [sym_c_style_for_statement] = STATE(5306),
    [sym_while_statement] = STATE(5094),
    [sym_if_statement] = STATE(5094),
    [sym_case_statement] = STATE(5306),
    [sym_function_definition] = STATE(5306),
    [sym_compound_statement] = STATE(5306),
    [sym_subshell] = STATE(5306),
    [sym_pipeline] = STATE(5517),
    [sym_list] = STATE(5306),
    [sym_negated_command] = STATE(5306),
    [sym_test_command] = STATE(5306),
    [sym_declaration_command] = STATE(5306),
    [sym_unset_command] = STATE(5306),
    [sym_command] = STATE(5306),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1744),
    [sym_variable_assignments] = STATE(5306),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2603),
    [sym_herestring_redirect] = STATE(2604),
    [sym__expression] = STATE(2845),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_redirected_statement_repeat2] = STATE(5038),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(149),
    [anon_sym_GT_GT] = ACTIONS(151),
    [anon_sym_LPAREN] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_RBRACK] = ACTIONS(227),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(149),
    [anon_sym_AMP_GT_GT] = ACTIONS(151),
    [anon_sym_LT_AMP] = ACTIONS(149),
    [anon_sym_GT_AMP] = ACTIONS(149),
    [anon_sym_GT_PIPE] = ACTIONS(151),
    [anon_sym_LT_AMP_DASH] = ACTIONS(177),
    [anon_sym_GT_AMP_DASH] = ACTIONS(177),
    [anon_sym_LT_LT_LT] = ACTIONS(179),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(213),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
  [STATE(10)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5228),
    [sym_for_statement] = STATE(5306),
    [sym_c_style_for_statement] = STATE(5306),
    [sym_while_statement] = STATE(5094),
    [sym_if_statement] = STATE(5094),
    [sym_case_statement] = STATE(5306),
    [sym_function_definition] = STATE(5306),
    [sym_compound_statement] = STATE(5306),
    [sym_subshell] = STATE(5306),
    [sym_pipeline] = STATE(5517),
    [sym_list] = STATE(5306),
    [sym_negated_command] = STATE(5306),
    [sym_test_command] = STATE(5306),
    [sym_declaration_command] = STATE(5306),
    [sym_unset_command] = STATE(5306),
    [sym_command] = STATE(5306),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1744),
    [sym_variable_assignments] = STATE(5306),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2603),
    [sym_herestring_redirect] = STATE(2604),
    [sym__expression] = STATE(2811),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_redirected_statement_repeat2] = STATE(5038),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(149),
    [anon_sym_GT_GT] = ACTIONS(151),
    [anon_sym_LPAREN] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_RBRACK] = ACTIONS(229),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(149),
    [anon_sym_AMP_GT_GT] = ACTIONS(151),
    [anon_sym_LT_AMP] = ACTIONS(149),
    [anon_sym_GT_AMP] = ACTIONS(149),
    [anon_sym_GT_PIPE] = ACTIONS(151),
    [anon_sym_LT_AMP_DASH] = ACTIONS(177),
    [anon_sym_GT_AMP_DASH] = ACTIONS(177),
    [anon_sym_LT_LT_LT] = ACTIONS(179),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(213),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
  [STATE(11)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5175),
    [sym_for_statement] = STATE(5306),
    [sym_c_style_for_statement] = STATE(5306),
    [sym_while_statement] = STATE(5094),
    [sym_if_statement] = STATE(5094),
    [sym_case_statement] = STATE(5306),
    [sym_function_definition] = STATE(5306),
    [sym_compound_statement] = STATE(5306),
    [sym_subshell] = STATE(5306),
    [sym_pipeline] = STATE(5517),
    [sym_list] = STATE(5306),
    [sym_negated_command] = STATE(5306),
    [sym_test_command] = STATE(5306),
    [sym_declaration_command] = STATE(5306),
    [sym_unset_command] = STATE(5306),
    [sym_command] = STATE(5306),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1744),
    [sym_variable_assignments] = STATE(5306),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2603),
    [sym_herestring_redirect] = STATE(2604),
    [sym__expression] = STATE(2824),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_redirected_statement_repeat2] = STATE(5038),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(149),
    [anon_sym_GT_GT] = ACTIONS(151),
    [anon_sym_LPAREN] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_RBRACK] = ACTIONS(231),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(149),
    [anon_sym_AMP_GT_GT] = ACTIONS(151),
    [anon_sym_LT_AMP] = ACTIONS(149),
    [anon_sym_GT_AMP] = ACTIONS(149),
    [anon_sym_GT_PIPE] = ACTIONS(151),
    [anon_sym_LT_AMP_DASH] = ACTIONS(177),
    [anon_sym_GT_AMP_DASH] = ACTIONS(177),
    [anon_sym_LT_LT_LT] = ACTIONS(179),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(213),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
  [STATE(12)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5234),
    [sym_for_statement] = STATE(5306),
    [sym_c_style_for_statement] = STATE(5306),
    [sym_while_statement] = STATE(5094),
    [sym_if_statement] = STATE(5094),
    [sym_case_statement] = STATE(5306),
    [sym_function_definition] = STATE(5306),
    [sym_compound_statement] = STATE(5306),
    [sym_subshell] = STATE(5306),
    [sym_pipeline] = STATE(5517),
    [sym_list] = STATE(5306),
    [sym_negated_command] = STATE(5306),
    [sym_test_command] = STATE(5306),
    [sym_declaration_command] = STATE(5306),
    [sym_unset_command] = STATE(5306),
    [sym_command] = STATE(5306),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1744),
    [sym_variable_assignments] = STATE(5306),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2603),
    [sym_herestring_redirect] = STATE(2604),
    [sym__expression] = STATE(2818),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_redirected_statement_repeat2] = STATE(5038),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(149),
    [anon_sym_GT_GT] = ACTIONS(151),
    [anon_sym_LPAREN] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_RBRACK] = ACTIONS(233),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(149),
    [anon_sym_AMP_GT_GT] = ACTIONS(151),
    [anon_sym_LT_AMP] = ACTIONS(149),
    [anon_sym_GT_AMP] = ACTIONS(149),
    [anon_sym_GT_PIPE] = ACTIONS(151),
    [anon_sym_LT_AMP_DASH] = ACTIONS(177),
    [anon_sym_GT_AMP_DASH] = ACTIONS(177),
    [anon_sym_LT_LT_LT] = ACTIONS(179),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(213),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
  [STATE(13)] = {
    [sym__expression] = STATE(2956),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(2344),
    [sym_brace_expression] = STATE(2344),
    [sym_concatenation] = STATE(2518),
    [sym_string] = STATE(2344),
    [sym_translated_string] = STATE(2344),
    [sym_number] = STATE(2344),
    [sym_simple_expansion] = STATE(2344),
    [sym_expansion] = STATE(2344),
    [sym_command_substitution] = STATE(2344),
    [sym_process_substitution] = STATE(2344),
    [aux_sym__literal_repeat1] = STATE(2312),
    [aux_sym_concatenation_repeat1] = STATE(466),
    [sym_word] = ACTIONS(235),
    [anon_sym_SEMI] = ACTIONS(237),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_GT_EQ] = ACTIONS(239),
    [anon_sym_AMP_EQ] = ACTIONS(239),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(239),
    [anon_sym_PIPE_PIPE] = ACTIONS(241),
    [anon_sym_AMP_AMP] = ACTIONS(241),
    [anon_sym_PIPE] = ACTIONS(241),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(241),
    [anon_sym_EQ_EQ] = ACTIONS(241),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_EQ] = ACTIONS(239),
    [anon_sym_LT_LT] = ACTIONS(241),
    [anon_sym_GT_GT] = ACTIONS(241),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(244),
    [anon_sym_RPAREN] = ACTIONS(241),
    [anon_sym_SEMI_SEMI] = ACTIONS(237),
    [anon_sym_PIPE_AMP] = ACTIONS(237),
    [anon_sym_BANG] = ACTIONS(246),
    [anon_sym_EQ_TILDE] = ACTIONS(241),
    [anon_sym_AMP_GT] = ACTIONS(237),
    [anon_sym_AMP_GT_GT] = ACTIONS(237),
    [anon_sym_LT_AMP] = ACTIONS(237),
    [anon_sym_GT_AMP] = ACTIONS(237),
    [anon_sym_GT_PIPE] = ACTIONS(237),
    [anon_sym_LT_AMP_DASH] = ACTIONS(237),
    [anon_sym_GT_AMP_DASH] = ACTIONS(237),
    [anon_sym_LT_LT_DASH] = ACTIONS(237),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(237),
    [anon_sym_LT_LT_LT] = ACTIONS(237),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(248),
    [anon_sym_DASH_DASH2] = ACTIONS(248),
    [anon_sym_DASH2] = ACTIONS(103),
    [anon_sym_PLUS2] = ACTIONS(103),
    [anon_sym_TILDE] = ACTIONS(103),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(250),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(252),
    [aux_sym_concatenation_token1] = ACTIONS(254),
    [anon_sym_DOLLAR] = ACTIONS(256),
    [sym__special_character] = ACTIONS(258),
    [anon_sym_DQUOTE] = ACTIONS(260),
    [sym_raw_string] = ACTIONS(235),
    [sym_ansi_c_string] = ACTIONS(235),
    [aux_sym_number_token1] = ACTIONS(262),
    [aux_sym_number_token2] = ACTIONS(264),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(266),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(268),
    [anon_sym_BQUOTE] = ACTIONS(270),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(272),
    [anon_sym_LT_LPAREN] = ACTIONS(274),
    [anon_sym_GT_LPAREN] = ACTIONS(274),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(276),
    [sym__concat] = ACTIONS(278),
    [sym_test_operator] = ACTIONS(280),
    [sym__bare_dollar] = ACTIONS(276),
    [sym__brace_start] = ACTIONS(282),
  },
  [STATE(14)] = {
    [aux_sym__terminated_statement] = STATE(21),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_elif_clause] = STATE(6177),
    [sym_else_clause] = STATE(7159),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_if_statement_repeat1] = STATE(6177),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(290),
    [anon_sym_elif] = ACTIONS(292),
    [anon_sym_else] = ACTIONS(294),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(15)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_elif_clause] = STATE(6229),
    [sym_else_clause] = STATE(7430),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_if_statement_repeat1] = STATE(6229),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(342),
    [anon_sym_elif] = ACTIONS(292),
    [anon_sym_else] = ACTIONS(294),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(16)] = {
    [aux_sym__terminated_statement] = STATE(18),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_elif_clause] = STATE(6219),
    [sym_else_clause] = STATE(6785),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_if_statement_repeat1] = STATE(6219),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(344),
    [anon_sym_elif] = ACTIONS(292),
    [anon_sym_else] = ACTIONS(294),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(17)] = {
    [aux_sym__terminated_statement] = STATE(15),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_elif_clause] = STATE(6200),
    [sym_else_clause] = STATE(7231),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_if_statement_repeat1] = STATE(6200),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(346),
    [anon_sym_elif] = ACTIONS(292),
    [anon_sym_else] = ACTIONS(294),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(18)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_elif_clause] = STATE(6270),
    [sym_else_clause] = STATE(6803),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_if_statement_repeat1] = STATE(6270),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(348),
    [anon_sym_elif] = ACTIONS(292),
    [anon_sym_else] = ACTIONS(294),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(19)] = {
    [aux_sym__terminated_statement] = STATE(20),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_elif_clause] = STATE(6222),
    [sym_else_clause] = STATE(6996),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_if_statement_repeat1] = STATE(6222),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(350),
    [anon_sym_elif] = ACTIONS(292),
    [anon_sym_else] = ACTIONS(294),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(20)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_elif_clause] = STATE(6247),
    [sym_else_clause] = STATE(7014),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_if_statement_repeat1] = STATE(6247),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(352),
    [anon_sym_elif] = ACTIONS(292),
    [anon_sym_else] = ACTIONS(294),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(21)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_elif_clause] = STATE(6181),
    [sym_else_clause] = STATE(7173),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_if_statement_repeat1] = STATE(6181),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(354),
    [anon_sym_elif] = ACTIONS(292),
    [anon_sym_else] = ACTIONS(294),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(22)] = {
    [sym__expression] = STATE(2994),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(2309),
    [sym_brace_expression] = STATE(2309),
    [sym_concatenation] = STATE(2847),
    [sym_string] = STATE(2309),
    [sym_translated_string] = STATE(2309),
    [sym_number] = STATE(2309),
    [sym_simple_expansion] = STATE(2309),
    [sym_expansion] = STATE(2309),
    [sym_command_substitution] = STATE(2309),
    [sym_process_substitution] = STATE(2309),
    [aux_sym__literal_repeat1] = STATE(2549),
    [aux_sym_concatenation_repeat1] = STATE(492),
    [sym_word] = ACTIONS(356),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(360),
    [anon_sym_AMP_AMP] = ACTIONS(360),
    [anon_sym_PIPE] = ACTIONS(241),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(241),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(241),
    [anon_sym_GT_GT] = ACTIONS(241),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(363),
    [anon_sym_PIPE_AMP] = ACTIONS(276),
    [anon_sym_BANG] = ACTIONS(365),
    [anon_sym_RBRACK] = ACTIONS(358),
    [anon_sym_EQ_TILDE] = ACTIONS(241),
    [anon_sym_AMP_GT] = ACTIONS(237),
    [anon_sym_AMP_GT_GT] = ACTIONS(276),
    [anon_sym_LT_AMP] = ACTIONS(237),
    [anon_sym_GT_AMP] = ACTIONS(237),
    [anon_sym_GT_PIPE] = ACTIONS(276),
    [anon_sym_LT_AMP_DASH] = ACTIONS(276),
    [anon_sym_GT_AMP_DASH] = ACTIONS(276),
    [anon_sym_LT_LT_DASH] = ACTIONS(276),
    [anon_sym_LT_LT_LT] = ACTIONS(276),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(371),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(379),
    [sym_ansi_c_string] = ACTIONS(379),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(276),
    [sym__concat] = ACTIONS(371),
    [sym_test_operator] = ACTIONS(395),
    [sym__bare_dollar] = ACTIONS(276),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(23)] = {
    [sym__statements] = STATE(6423),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(419),
    [anon_sym_SEMI_SEMI] = ACTIONS(421),
    [anon_sym_SEMI_AMP] = ACTIONS(423),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(425),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(24)] = {
    [sym__statements] = STATE(6414),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(479),
    [anon_sym_SEMI_SEMI] = ACTIONS(481),
    [anon_sym_SEMI_AMP] = ACTIONS(483),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(483),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(25)] = {
    [sym__statements] = STATE(6417),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(485),
    [anon_sym_SEMI_SEMI] = ACTIONS(487),
    [anon_sym_SEMI_AMP] = ACTIONS(489),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(491),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(26)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(493),
    [anon_sym_for] = ACTIONS(496),
    [anon_sym_select] = ACTIONS(499),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(502),
    [anon_sym_LT] = ACTIONS(505),
    [anon_sym_GT] = ACTIONS(505),
    [anon_sym_GT_GT] = ACTIONS(508),
    [anon_sym_LPAREN] = ACTIONS(511),
    [anon_sym_while] = ACTIONS(514),
    [anon_sym_until] = ACTIONS(514),
    [anon_sym_do] = ACTIONS(517),
    [anon_sym_if] = ACTIONS(519),
    [anon_sym_then] = ACTIONS(517),
    [anon_sym_fi] = ACTIONS(517),
    [anon_sym_elif] = ACTIONS(517),
    [anon_sym_else] = ACTIONS(517),
    [anon_sym_case] = ACTIONS(522),
    [anon_sym_function] = ACTIONS(525),
    [anon_sym_LBRACE] = ACTIONS(528),
    [anon_sym_BANG] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(537),
    [anon_sym_declare] = ACTIONS(540),
    [anon_sym_typeset] = ACTIONS(540),
    [anon_sym_export] = ACTIONS(540),
    [anon_sym_readonly] = ACTIONS(540),
    [anon_sym_local] = ACTIONS(540),
    [anon_sym_unset] = ACTIONS(543),
    [anon_sym_unsetenv] = ACTIONS(543),
    [anon_sym_AMP_GT] = ACTIONS(505),
    [anon_sym_AMP_GT_GT] = ACTIONS(508),
    [anon_sym_LT_AMP] = ACTIONS(505),
    [anon_sym_GT_AMP] = ACTIONS(505),
    [anon_sym_GT_PIPE] = ACTIONS(508),
    [anon_sym_LT_AMP_DASH] = ACTIONS(546),
    [anon_sym_GT_AMP_DASH] = ACTIONS(546),
    [anon_sym_LT_LT_LT] = ACTIONS(549),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(552),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(555),
    [anon_sym_DOLLAR] = ACTIONS(558),
    [sym__special_character] = ACTIONS(561),
    [anon_sym_DQUOTE] = ACTIONS(564),
    [sym_raw_string] = ACTIONS(567),
    [sym_ansi_c_string] = ACTIONS(567),
    [aux_sym_number_token1] = ACTIONS(570),
    [aux_sym_number_token2] = ACTIONS(573),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(576),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(579),
    [anon_sym_BQUOTE] = ACTIONS(582),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(585),
    [anon_sym_LT_LPAREN] = ACTIONS(588),
    [anon_sym_GT_LPAREN] = ACTIONS(588),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(591),
    [sym_variable_name] = ACTIONS(594),
    [sym_test_operator] = ACTIONS(597),
    [sym__brace_start] = ACTIONS(600),
  },
  [STATE(27)] = {
    [sym__statements] = STATE(6416),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(603),
    [anon_sym_SEMI_SEMI] = ACTIONS(605),
    [anon_sym_SEMI_AMP] = ACTIONS(607),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(28)] = {
    [sym__statements] = STATE(6441),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(609),
    [anon_sym_SEMI_SEMI] = ACTIONS(611),
    [anon_sym_SEMI_AMP] = ACTIONS(613),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(613),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(29)] = {
    [sym__statements] = STATE(6440),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(615),
    [anon_sym_SEMI_SEMI] = ACTIONS(617),
    [anon_sym_SEMI_AMP] = ACTIONS(619),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(621),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(30)] = {
    [sym__statements] = STATE(6442),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(623),
    [anon_sym_SEMI_SEMI] = ACTIONS(625),
    [anon_sym_SEMI_AMP] = ACTIONS(627),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(627),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(31)] = {
    [sym__statements] = STATE(6443),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(629),
    [anon_sym_SEMI_SEMI] = ACTIONS(631),
    [anon_sym_SEMI_AMP] = ACTIONS(633),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(635),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(32)] = {
    [sym__statements] = STATE(6444),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(629),
    [anon_sym_SEMI_SEMI] = ACTIONS(637),
    [anon_sym_SEMI_AMP] = ACTIONS(639),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(33)] = {
    [sym__statements] = STATE(6448),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(615),
    [anon_sym_SEMI_SEMI] = ACTIONS(643),
    [anon_sym_SEMI_AMP] = ACTIONS(645),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(647),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(34)] = {
    [sym__statements] = STATE(6397),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(419),
    [anon_sym_SEMI_SEMI] = ACTIONS(649),
    [anon_sym_SEMI_AMP] = ACTIONS(651),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(35)] = {
    [sym__statements] = STATE(6409),
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4293),
    [sym_for_statement] = STATE(4293),
    [sym_c_style_for_statement] = STATE(4293),
    [sym_while_statement] = STATE(4014),
    [sym_if_statement] = STATE(4014),
    [sym_case_statement] = STATE(4293),
    [sym_function_definition] = STATE(4293),
    [sym_compound_statement] = STATE(4293),
    [sym_subshell] = STATE(4293),
    [sym_pipeline] = STATE(4611),
    [sym_list] = STATE(4293),
    [sym_negated_command] = STATE(4293),
    [sym_test_command] = STATE(4293),
    [sym_declaration_command] = STATE(4293),
    [sym_unset_command] = STATE(4293),
    [sym_command] = STATE(4293),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(793),
    [sym_variable_assignments] = STATE(4293),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(423),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_esac] = ACTIONS(485),
    [anon_sym_SEMI_SEMI] = ACTIONS(655),
    [anon_sym_SEMI_AMP] = ACTIONS(657),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(659),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(36)] = {
    [sym__statements] = STATE(6541),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(681),
    [anon_sym_SEMI_AMP] = ACTIONS(633),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(635),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(37)] = {
    [sym__statements] = STATE(6561),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(735),
    [anon_sym_SEMI_AMP] = ACTIONS(483),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(483),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(38)] = {
    [sym__statements] = STATE(6590),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(737),
    [anon_sym_SEMI_AMP] = ACTIONS(613),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(613),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(39)] = {
    [sym__statements] = STATE(6589),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(739),
    [anon_sym_SEMI_AMP] = ACTIONS(619),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(621),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(40)] = {
    [sym__statements] = STATE(6619),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(741),
    [anon_sym_SEMI_AMP] = ACTIONS(627),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(627),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(41)] = {
    [sym__statements] = STATE(6473),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(743),
    [anon_sym_SEMI_AMP] = ACTIONS(607),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(42)] = {
    [sym__statements] = STATE(6545),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(745),
    [anon_sym_SEMI_AMP] = ACTIONS(639),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(43)] = {
    [sym__statements] = STATE(6546),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(747),
    [anon_sym_SEMI_AMP] = ACTIONS(645),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(647),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(44)] = {
    [sym__statements] = STATE(6571),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(749),
    [anon_sym_SEMI_AMP] = ACTIONS(651),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(45)] = {
    [sym__statements] = STATE(6602),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(751),
    [anon_sym_SEMI_AMP] = ACTIONS(657),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(659),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(46)] = {
    [sym__statements] = STATE(6620),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(753),
    [anon_sym_SEMI_AMP] = ACTIONS(489),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(491),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(47)] = {
    [sym__statements] = STATE(6455),
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4412),
    [sym_for_statement] = STATE(4412),
    [sym_c_style_for_statement] = STATE(4412),
    [sym_while_statement] = STATE(4150),
    [sym_if_statement] = STATE(4150),
    [sym_case_statement] = STATE(4412),
    [sym_function_definition] = STATE(4412),
    [sym_compound_statement] = STATE(4412),
    [sym_subshell] = STATE(4412),
    [sym_pipeline] = STATE(4811),
    [sym_list] = STATE(4412),
    [sym_negated_command] = STATE(4412),
    [sym_test_command] = STATE(4412),
    [sym_declaration_command] = STATE(4412),
    [sym_unset_command] = STATE(4412),
    [sym_command] = STATE(4412),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(855),
    [sym_variable_assignments] = STATE(4412),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(424),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_SEMI_SEMI] = ACTIONS(755),
    [anon_sym_SEMI_AMP] = ACTIONS(423),
    [anon_sym_SEMI_SEMI_AMP] = ACTIONS(425),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(48)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(757),
    [anon_sym_elif] = ACTIONS(757),
    [anon_sym_else] = ACTIONS(757),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(49)] = {
    [aux_sym__terminated_statement] = STATE(48),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(759),
    [anon_sym_elif] = ACTIONS(759),
    [anon_sym_else] = ACTIONS(759),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(50)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_do_group] = STATE(4564),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_do] = ACTIONS(761),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(51)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_do_group] = STATE(5515),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_do] = ACTIONS(763),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(52)] = {
    [sym__statements] = STATE(7103),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_RPAREN] = ACTIONS(767),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(53)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_do_group] = STATE(4719),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_do] = ACTIONS(777),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(54)] = {
    [sym__statements] = STATE(7103),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_RPAREN] = ACTIONS(779),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(55)] = {
    [sym__statements] = STATE(7225),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_RPAREN] = ACTIONS(781),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(56)] = {
    [sym__statements] = STATE(7367),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_RPAREN] = ACTIONS(783),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(57)] = {
    [sym__statements] = STATE(6775),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_RPAREN] = ACTIONS(785),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(58)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_do_group] = STATE(4613),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_do] = ACTIONS(787),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(59)] = {
    [sym__statements] = STATE(7103),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_RPAREN] = ACTIONS(789),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(60)] = {
    [sym__statements] = STATE(7103),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_RPAREN] = ACTIONS(791),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(61)] = {
    [sym__statements] = STATE(7103),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_RPAREN] = ACTIONS(793),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(62)] = {
    [sym__statements] = STATE(7494),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(1939),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(63)] = {
    [sym__statements] = STATE(7334),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(64)] = {
    [aux_sym__terminated_statement] = STATE(66),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(795),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(65)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_then] = ACTIONS(797),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(66)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(67)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(493),
    [anon_sym_for] = ACTIONS(496),
    [anon_sym_select] = ACTIONS(499),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(502),
    [anon_sym_LT] = ACTIONS(505),
    [anon_sym_GT] = ACTIONS(505),
    [anon_sym_GT_GT] = ACTIONS(508),
    [anon_sym_LPAREN] = ACTIONS(511),
    [anon_sym_while] = ACTIONS(514),
    [anon_sym_until] = ACTIONS(514),
    [anon_sym_if] = ACTIONS(519),
    [anon_sym_case] = ACTIONS(522),
    [anon_sym_function] = ACTIONS(525),
    [anon_sym_LBRACE] = ACTIONS(528),
    [anon_sym_RBRACE] = ACTIONS(801),
    [anon_sym_BANG] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(537),
    [anon_sym_declare] = ACTIONS(540),
    [anon_sym_typeset] = ACTIONS(540),
    [anon_sym_export] = ACTIONS(540),
    [anon_sym_readonly] = ACTIONS(540),
    [anon_sym_local] = ACTIONS(540),
    [anon_sym_unset] = ACTIONS(543),
    [anon_sym_unsetenv] = ACTIONS(543),
    [anon_sym_AMP_GT] = ACTIONS(505),
    [anon_sym_AMP_GT_GT] = ACTIONS(508),
    [anon_sym_LT_AMP] = ACTIONS(505),
    [anon_sym_GT_AMP] = ACTIONS(505),
    [anon_sym_GT_PIPE] = ACTIONS(508),
    [anon_sym_LT_AMP_DASH] = ACTIONS(546),
    [anon_sym_GT_AMP_DASH] = ACTIONS(546),
    [anon_sym_LT_LT_LT] = ACTIONS(549),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(552),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(555),
    [anon_sym_DOLLAR] = ACTIONS(558),
    [sym__special_character] = ACTIONS(561),
    [anon_sym_DQUOTE] = ACTIONS(564),
    [sym_raw_string] = ACTIONS(567),
    [sym_ansi_c_string] = ACTIONS(567),
    [aux_sym_number_token1] = ACTIONS(570),
    [aux_sym_number_token2] = ACTIONS(573),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(576),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(579),
    [anon_sym_BQUOTE] = ACTIONS(582),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(585),
    [anon_sym_LT_LPAREN] = ACTIONS(588),
    [anon_sym_GT_LPAREN] = ACTIONS(588),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(591),
    [sym_variable_name] = ACTIONS(594),
    [sym_test_operator] = ACTIONS(597),
    [sym__brace_start] = ACTIONS(600),
  },
  [STATE(68)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(493),
    [anon_sym_for] = ACTIONS(496),
    [anon_sym_select] = ACTIONS(499),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(502),
    [anon_sym_LT] = ACTIONS(505),
    [anon_sym_GT] = ACTIONS(505),
    [anon_sym_GT_GT] = ACTIONS(508),
    [anon_sym_LPAREN] = ACTIONS(511),
    [anon_sym_while] = ACTIONS(514),
    [anon_sym_until] = ACTIONS(514),
    [anon_sym_done] = ACTIONS(517),
    [anon_sym_if] = ACTIONS(519),
    [anon_sym_case] = ACTIONS(522),
    [anon_sym_function] = ACTIONS(525),
    [anon_sym_LBRACE] = ACTIONS(528),
    [anon_sym_BANG] = ACTIONS(531),
    [anon_sym_LBRACK] = ACTIONS(534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(537),
    [anon_sym_declare] = ACTIONS(540),
    [anon_sym_typeset] = ACTIONS(540),
    [anon_sym_export] = ACTIONS(540),
    [anon_sym_readonly] = ACTIONS(540),
    [anon_sym_local] = ACTIONS(540),
    [anon_sym_unset] = ACTIONS(543),
    [anon_sym_unsetenv] = ACTIONS(543),
    [anon_sym_AMP_GT] = ACTIONS(505),
    [anon_sym_AMP_GT_GT] = ACTIONS(508),
    [anon_sym_LT_AMP] = ACTIONS(505),
    [anon_sym_GT_AMP] = ACTIONS(505),
    [anon_sym_GT_PIPE] = ACTIONS(508),
    [anon_sym_LT_AMP_DASH] = ACTIONS(546),
    [anon_sym_GT_AMP_DASH] = ACTIONS(546),
    [anon_sym_LT_LT_LT] = ACTIONS(549),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(552),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(555),
    [anon_sym_DOLLAR] = ACTIONS(558),
    [sym__special_character] = ACTIONS(561),
    [anon_sym_DQUOTE] = ACTIONS(564),
    [sym_raw_string] = ACTIONS(567),
    [sym_ansi_c_string] = ACTIONS(567),
    [aux_sym_number_token1] = ACTIONS(570),
    [aux_sym_number_token2] = ACTIONS(573),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(576),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(579),
    [anon_sym_BQUOTE] = ACTIONS(582),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(585),
    [anon_sym_LT_LPAREN] = ACTIONS(588),
    [anon_sym_GT_LPAREN] = ACTIONS(588),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(591),
    [sym_variable_name] = ACTIONS(594),
    [sym_test_operator] = ACTIONS(597),
    [sym__brace_start] = ACTIONS(600),
  },
  [STATE(69)] = {
    [aux_sym__terminated_statement] = STATE(71),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(803),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(70)] = {
    [aux_sym__terminated_statement] = STATE(83),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(805),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(71)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(807),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(72)] = {
    [aux_sym__terminated_statement] = STATE(73),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(73)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(811),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(74)] = {
    [aux_sym__terminated_statement] = STATE(75),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(813),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(75)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(815),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(76)] = {
    [aux_sym__terminated_statement] = STATE(77),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(817),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(77)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(819),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(78)] = {
    [aux_sym__terminated_statement] = STATE(79),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(821),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(79)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(823),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(80)] = {
    [aux_sym__terminated_statement] = STATE(81),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(825),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(81)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(827),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(82)] = {
    [aux_sym__terminated_statement] = STATE(84),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(829),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(83)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(831),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(84)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(85)] = {
    [aux_sym__terminated_statement] = STATE(413),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(835),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(86)] = {
    [aux_sym__terminated_statement] = STATE(87),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(837),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(87)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(839),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(88)] = {
    [aux_sym__terminated_statement] = STATE(89),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(841),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(89)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(843),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(90)] = {
    [aux_sym__terminated_statement] = STATE(92),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(91)] = {
    [aux_sym__terminated_statement] = STATE(410),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(847),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(92)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(93)] = {
    [aux_sym__terminated_statement] = STATE(94),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(851),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(94)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(853),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(95)] = {
    [aux_sym__terminated_statement] = STATE(97),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(96)] = {
    [sym__statements] = STATE(7304),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(1999),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(97)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(98)] = {
    [aux_sym__terminated_statement] = STATE(99),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(859),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(99)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(861),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(100)] = {
    [aux_sym__terminated_statement] = STATE(101),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(863),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(101)] = {
    [aux_sym__terminated_statement] = STATE(67),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4894),
    [sym_for_statement] = STATE(4894),
    [sym_c_style_for_statement] = STATE(4894),
    [sym_while_statement] = STATE(4485),
    [sym_if_statement] = STATE(4485),
    [sym_case_statement] = STATE(4894),
    [sym_function_definition] = STATE(4894),
    [sym_compound_statement] = STATE(4894),
    [sym_subshell] = STATE(4894),
    [sym_pipeline] = STATE(5091),
    [sym_list] = STATE(4894),
    [sym_negated_command] = STATE(4894),
    [sym_test_command] = STATE(4894),
    [sym_declaration_command] = STATE(4894),
    [sym_unset_command] = STATE(4894),
    [sym_command] = STATE(4894),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1047),
    [sym_variable_assignments] = STATE(4894),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_RBRACE] = ACTIONS(865),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(102)] = {
    [sym__statements] = STATE(7341),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(103)] = {
    [sym__statements] = STATE(6767),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(104)] = {
    [sym__statements] = STATE(7192),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(105)] = {
    [sym__statements] = STATE(6705),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(106)] = {
    [sym__statements] = STATE(6706),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(107)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_then] = ACTIONS(877),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(108)] = {
    [sym__statements] = STATE(7103),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(109)] = {
    [sym__statements] = STATE(6945),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2016),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(110)] = {
    [sym__statements] = STATE(6947),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(111)] = {
    [sym__statements] = STATE(6949),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(112)] = {
    [sym__statements] = STATE(6950),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(113)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_then] = ACTIONS(879),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(114)] = {
    [sym__statements] = STATE(7225),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(115)] = {
    [sym__statements] = STATE(7119),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2035),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(116)] = {
    [sym__statements] = STATE(7121),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(117)] = {
    [sym__statements] = STATE(7122),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(118)] = {
    [sym__statements] = STATE(7123),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(119)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_then] = ACTIONS(881),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(120)] = {
    [sym__statements] = STATE(7314),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(121)] = {
    [sym__statements] = STATE(7239),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2049),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(122)] = {
    [sym__statements] = STATE(7241),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(123)] = {
    [sym__statements] = STATE(7242),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(124)] = {
    [sym__statements] = STATE(7243),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(125)] = {
    [sym__statements] = STATE(7506),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(126)] = {
    [sym__statements] = STATE(7327),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2057),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(127)] = {
    [sym__statements] = STATE(7329),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(128)] = {
    [sym__statements] = STATE(7330),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(129)] = {
    [sym__statements] = STATE(7331),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(130)] = {
    [sym__statements] = STATE(7367),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(131)] = {
    [sym__statements] = STATE(7390),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2061),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(132)] = {
    [sym__statements] = STATE(7393),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(133)] = {
    [sym__statements] = STATE(7394),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(134)] = {
    [sym__statements] = STATE(7395),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(135)] = {
    [sym__statements] = STATE(6775),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(136)] = {
    [sym__statements] = STATE(7167),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2068),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(137)] = {
    [sym__statements] = STATE(7280),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(138)] = {
    [sym__statements] = STATE(7291),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(139)] = {
    [sym__statements] = STATE(6747),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(140)] = {
    [sym__statements] = STATE(6867),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2070),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(141)] = {
    [sym__statements] = STATE(6986),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(142)] = {
    [sym__statements] = STATE(7017),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(143)] = {
    [sym__statements] = STATE(7020),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(144)] = {
    [sym__statements] = STATE(6782),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2073),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(145)] = {
    [sym__statements] = STATE(7064),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(146)] = {
    [sym__statements] = STATE(7424),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(147)] = {
    [sym__statements] = STATE(6709),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(148)] = {
    [sym__statements] = STATE(6903),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(1907),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(149)] = {
    [sym__statements] = STATE(6914),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(150)] = {
    [sym__statements] = STATE(6974),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(151)] = {
    [sym__statements] = STATE(6982),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(152)] = {
    [sym__statements] = STATE(7233),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2216),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(153)] = {
    [sym__statements] = STATE(7287),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(154)] = {
    [sym__statements] = STATE(7288),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(155)] = {
    [sym__statements] = STATE(7289),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(156)] = {
    [sym__statements] = STATE(6796),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2077),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(157)] = {
    [sym__statements] = STATE(6809),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(158)] = {
    [sym__statements] = STATE(6875),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(159)] = {
    [sym__statements] = STATE(6900),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(160)] = {
    [sym__statements] = STATE(6866),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2081),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(161)] = {
    [sym__statements] = STATE(6872),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(162)] = {
    [sym__statements] = STATE(6893),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(163)] = {
    [sym__statements] = STATE(6896),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(164)] = {
    [sym__statements] = STATE(7085),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2083),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(165)] = {
    [sym__statements] = STATE(7109),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(166)] = {
    [sym__statements] = STATE(7113),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(167)] = {
    [sym__statements] = STATE(7114),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(168)] = {
    [sym__statements] = STATE(7324),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2084),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(169)] = {
    [sym__statements] = STATE(7351),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(170)] = {
    [sym__statements] = STATE(7361),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(171)] = {
    [sym__statements] = STATE(7418),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(172)] = {
    [sym__statements] = STATE(7508),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2086),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(173)] = {
    [sym__statements] = STATE(6711),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(174)] = {
    [sym__statements] = STATE(6714),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(175)] = {
    [sym__statements] = STATE(6731),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(176)] = {
    [sym__statements] = STATE(7082),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2088),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(177)] = {
    [sym__statements] = STATE(7227),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(178)] = {
    [sym__statements] = STATE(7234),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(179)] = {
    [sym__statements] = STATE(7240),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(180)] = {
    [sym__statements] = STATE(6816),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2090),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(181)] = {
    [sym__statements] = STATE(6818),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(182)] = {
    [sym__statements] = STATE(6835),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(183)] = {
    [sym__statements] = STATE(6842),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(184)] = {
    [sym__statements] = STATE(6916),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2091),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(185)] = {
    [sym__statements] = STATE(6940),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(186)] = {
    [sym__statements] = STATE(6956),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(187)] = {
    [sym__statements] = STATE(6971),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(188)] = {
    [sym__statements] = STATE(7072),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2092),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(189)] = {
    [sym__statements] = STATE(7075),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(190)] = {
    [sym__statements] = STATE(7078),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(191)] = {
    [sym__statements] = STATE(7083),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(192)] = {
    [sym__statements] = STATE(7178),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2093),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(193)] = {
    [sym__statements] = STATE(7183),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(194)] = {
    [sym__statements] = STATE(7186),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(195)] = {
    [sym__statements] = STATE(7207),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(196)] = {
    [sym__statements] = STATE(7350),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2094),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(197)] = {
    [sym__statements] = STATE(7352),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(198)] = {
    [sym__statements] = STATE(7353),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(199)] = {
    [sym__statements] = STATE(7354),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(200)] = {
    [sym__statements] = STATE(7022),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2095),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(201)] = {
    [sym__statements] = STATE(7223),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(202)] = {
    [sym__statements] = STATE(7226),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(203)] = {
    [sym__statements] = STATE(7306),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(204)] = {
    [sym__statements] = STATE(7254),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2096),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(205)] = {
    [sym__statements] = STATE(7307),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(206)] = {
    [sym__statements] = STATE(7332),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(207)] = {
    [sym__statements] = STATE(7333),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(208)] = {
    [sym__statements] = STATE(6738),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2097),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(209)] = {
    [sym__statements] = STATE(6742),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(210)] = {
    [sym__statements] = STATE(6744),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(211)] = {
    [sym__statements] = STATE(6745),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(212)] = {
    [sym__statements] = STATE(6855),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2098),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(213)] = {
    [sym__statements] = STATE(6881),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(214)] = {
    [sym__statements] = STATE(6884),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(215)] = {
    [sym__statements] = STATE(6890),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(216)] = {
    [sym__statements] = STATE(7063),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2100),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(217)] = {
    [sym__statements] = STATE(7084),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(218)] = {
    [sym__statements] = STATE(7099),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(219)] = {
    [sym__statements] = STATE(7100),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(220)] = {
    [sym__statements] = STATE(7322),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2101),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(221)] = {
    [sym__statements] = STATE(7336),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(222)] = {
    [sym__statements] = STATE(7339),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(223)] = {
    [sym__statements] = STATE(7343),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(224)] = {
    [sym__statements] = STATE(6748),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2102),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(225)] = {
    [sym__statements] = STATE(6751),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(226)] = {
    [sym__statements] = STATE(6753),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(227)] = {
    [sym__statements] = STATE(6762),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(228)] = {
    [sym__statements] = STATE(6833),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2103),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(229)] = {
    [sym__statements] = STATE(6837),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(230)] = {
    [sym__statements] = STATE(6838),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(231)] = {
    [sym__statements] = STATE(6839),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(232)] = {
    [sym__statements] = STATE(6869),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2104),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(233)] = {
    [sym__statements] = STATE(6876),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(234)] = {
    [sym__statements] = STATE(6886),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(235)] = {
    [sym__statements] = STATE(6889),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(236)] = {
    [sym__statements] = STATE(6918),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2105),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(237)] = {
    [sym__statements] = STATE(6923),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(238)] = {
    [sym__statements] = STATE(6933),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(239)] = {
    [sym__statements] = STATE(6936),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(240)] = {
    [sym__statements] = STATE(6985),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2106),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(241)] = {
    [sym__statements] = STATE(6994),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(242)] = {
    [sym__statements] = STATE(7005),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(243)] = {
    [sym__statements] = STATE(7008),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(244)] = {
    [sym__statements] = STATE(7049),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2107),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(245)] = {
    [sym__statements] = STATE(7051),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(246)] = {
    [sym__statements] = STATE(7052),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(247)] = {
    [sym__statements] = STATE(7056),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(248)] = {
    [sym__statements] = STATE(7087),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2108),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(249)] = {
    [sym__statements] = STATE(7096),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(250)] = {
    [sym__statements] = STATE(7098),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(251)] = {
    [sym__statements] = STATE(7101),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(252)] = {
    [sym__statements] = STATE(7138),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2109),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(253)] = {
    [sym__statements] = STATE(7142),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(254)] = {
    [sym__statements] = STATE(7147),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(255)] = {
    [sym__statements] = STATE(7157),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(256)] = {
    [sym__statements] = STATE(7193),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2123),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(257)] = {
    [sym__statements] = STATE(7197),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(258)] = {
    [sym__statements] = STATE(7198),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(259)] = {
    [sym__statements] = STATE(7201),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(260)] = {
    [sym__statements] = STATE(7244),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2124),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(261)] = {
    [sym__statements] = STATE(7247),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(262)] = {
    [sym__statements] = STATE(7250),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(263)] = {
    [sym__statements] = STATE(7264),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(264)] = {
    [sym__statements] = STATE(7323),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2128),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(265)] = {
    [sym__statements] = STATE(7325),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(266)] = {
    [sym__statements] = STATE(7328),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(267)] = {
    [sym__statements] = STATE(7335),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(268)] = {
    [sym__statements] = STATE(7368),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2130),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(269)] = {
    [sym__statements] = STATE(7385),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(270)] = {
    [sym__statements] = STATE(7399),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(271)] = {
    [sym__statements] = STATE(7402),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(272)] = {
    [sym__statements] = STATE(7495),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2134),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(273)] = {
    [sym__statements] = STATE(7497),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(274)] = {
    [sym__statements] = STATE(7498),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(275)] = {
    [sym__statements] = STATE(7501),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(276)] = {
    [sym__statements] = STATE(6730),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2136),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(277)] = {
    [sym__statements] = STATE(6740),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(278)] = {
    [sym__statements] = STATE(6760),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(279)] = {
    [sym__statements] = STATE(7209),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(280)] = {
    [sym__statements] = STATE(6845),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2139),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(281)] = {
    [sym__statements] = STATE(6910),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(282)] = {
    [sym__statements] = STATE(6964),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(283)] = {
    [sym__statements] = STATE(7007),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(284)] = {
    [sym__statements] = STATE(7370),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2140),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(285)] = {
    [sym__statements] = STATE(7377),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(286)] = {
    [sym__statements] = STATE(7382),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(287)] = {
    [sym__statements] = STATE(7408),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(288)] = {
    [sym__statements] = STATE(6718),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2141),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(289)] = {
    [sym__statements] = STATE(6721),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(290)] = {
    [sym__statements] = STATE(6725),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(291)] = {
    [sym__statements] = STATE(6727),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(292)] = {
    [sym__statements] = STATE(6754),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2143),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(293)] = {
    [sym__statements] = STATE(6757),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(294)] = {
    [sym__statements] = STATE(6758),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(295)] = {
    [sym__statements] = STATE(6761),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(296)] = {
    [sym__statements] = STATE(6806),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2146),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(297)] = {
    [sym__statements] = STATE(6832),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(298)] = {
    [sym__statements] = STATE(6840),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(299)] = {
    [sym__statements] = STATE(6841),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(300)] = {
    [sym__statements] = STATE(6943),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2151),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(301)] = {
    [sym__statements] = STATE(6958),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(302)] = {
    [sym__statements] = STATE(6959),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(303)] = {
    [sym__statements] = STATE(6963),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(304)] = {
    [sym__statements] = STATE(7042),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2153),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(305)] = {
    [sym__statements] = STATE(7044),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(306)] = {
    [sym__statements] = STATE(7048),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(307)] = {
    [sym__statements] = STATE(7057),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(308)] = {
    [sym__statements] = STATE(7170),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2156),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(309)] = {
    [sym__statements] = STATE(7194),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(310)] = {
    [sym__statements] = STATE(7204),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(311)] = {
    [sym__statements] = STATE(7206),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(312)] = {
    [sym__statements] = STATE(7270),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2165),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(313)] = {
    [sym__statements] = STATE(7272),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(314)] = {
    [sym__statements] = STATE(7275),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(315)] = {
    [sym__statements] = STATE(7276),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(316)] = {
    [sym__statements] = STATE(7378),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2171),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(317)] = {
    [sym__statements] = STATE(7398),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(318)] = {
    [sym__statements] = STATE(7400),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(319)] = {
    [sym__statements] = STATE(7406),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(320)] = {
    [sym__statements] = STATE(6723),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2174),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(321)] = {
    [sym__statements] = STATE(6726),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(322)] = {
    [sym__statements] = STATE(6733),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(323)] = {
    [sym__statements] = STATE(6739),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(324)] = {
    [sym__statements] = STATE(6786),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2176),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(325)] = {
    [sym__statements] = STATE(6791),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(326)] = {
    [sym__statements] = STATE(6793),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(327)] = {
    [sym__statements] = STATE(6795),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(328)] = {
    [sym__statements] = STATE(6824),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2182),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(329)] = {
    [sym__statements] = STATE(6826),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(330)] = {
    [sym__statements] = STATE(6827),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(331)] = {
    [sym__statements] = STATE(6828),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(332)] = {
    [sym__statements] = STATE(6848),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2183),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(333)] = {
    [sym__statements] = STATE(6851),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(334)] = {
    [sym__statements] = STATE(6852),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(335)] = {
    [sym__statements] = STATE(6854),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(336)] = {
    [sym__statements] = STATE(6874),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2189),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(337)] = {
    [sym__statements] = STATE(6877),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(338)] = {
    [sym__statements] = STATE(6882),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(339)] = {
    [sym__statements] = STATE(6883),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(340)] = {
    [sym__statements] = STATE(6902),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2192),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(341)] = {
    [sym__statements] = STATE(6904),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(342)] = {
    [sym__statements] = STATE(6905),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(343)] = {
    [sym__statements] = STATE(6907),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(344)] = {
    [sym__statements] = STATE(6926),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2193),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(345)] = {
    [sym__statements] = STATE(6929),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(346)] = {
    [sym__statements] = STATE(6930),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(347)] = {
    [sym__statements] = STATE(6931),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(348)] = {
    [sym__statements] = STATE(6961),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2194),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(349)] = {
    [sym__statements] = STATE(6966),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(350)] = {
    [sym__statements] = STATE(6967),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(351)] = {
    [sym__statements] = STATE(6968),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(352)] = {
    [sym__statements] = STATE(6993),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2196),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(353)] = {
    [sym__statements] = STATE(6995),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(354)] = {
    [sym__statements] = STATE(6998),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(355)] = {
    [sym__statements] = STATE(6999),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(356)] = {
    [sym__statements] = STATE(7027),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2197),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(357)] = {
    [sym__statements] = STATE(7029),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(358)] = {
    [sym__statements] = STATE(7034),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(359)] = {
    [sym__statements] = STATE(7035),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(360)] = {
    [sym__statements] = STATE(7055),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2198),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(361)] = {
    [sym__statements] = STATE(7058),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(362)] = {
    [sym__statements] = STATE(7061),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(363)] = {
    [sym__statements] = STATE(7062),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(364)] = {
    [sym__statements] = STATE(7077),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2199),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(365)] = {
    [sym__statements] = STATE(7079),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(366)] = {
    [sym__statements] = STATE(7080),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(367)] = {
    [sym__statements] = STATE(7091),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2200),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(368)] = {
    [sym__statements] = STATE(7094),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(369)] = {
    [sym__statements] = STATE(7095),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(370)] = {
    [sym__statements] = STATE(7108),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2201),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(371)] = {
    [sym__statements] = STATE(7110),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(372)] = {
    [sym__statements] = STATE(7111),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(373)] = {
    [sym__statements] = STATE(7125),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2202),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(374)] = {
    [sym__statements] = STATE(7127),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(375)] = {
    [sym__statements] = STATE(7128),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(376)] = {
    [sym__statements] = STATE(7149),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2203),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(377)] = {
    [sym__statements] = STATE(7152),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(378)] = {
    [sym__statements] = STATE(7156),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(379)] = {
    [sym__statements] = STATE(7169),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2204),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(380)] = {
    [sym__statements] = STATE(7171),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(381)] = {
    [sym__statements] = STATE(7174),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(382)] = {
    [sym__statements] = STATE(7185),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2205),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(383)] = {
    [sym__statements] = STATE(7190),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(384)] = {
    [sym__statements] = STATE(7191),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(385)] = {
    [sym__statements] = STATE(7200),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2206),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(386)] = {
    [sym__statements] = STATE(7202),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(387)] = {
    [sym__statements] = STATE(7203),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(388)] = {
    [sym__statements] = STATE(7215),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2208),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(389)] = {
    [sym__statements] = STATE(7217),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(390)] = {
    [sym__statements] = STATE(7218),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(391)] = {
    [sym__statements] = STATE(7230),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2211),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(392)] = {
    [sym__statements] = STATE(7235),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(393)] = {
    [sym__statements] = STATE(7236),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(394)] = {
    [sym__statements] = STATE(7252),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2215),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(395)] = {
    [sym__statements] = STATE(7256),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(396)] = {
    [sym__statements] = STATE(7263),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(397)] = {
    [sym__statements] = STATE(7279),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2074),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(398)] = {
    [sym__statements] = STATE(7283),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(399)] = {
    [sym__statements] = STATE(7284),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(400)] = {
    [sym__statements] = STATE(7294),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2075),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(401)] = {
    [sym__statements] = STATE(7296),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(402)] = {
    [sym__statements] = STATE(7297),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(403)] = {
    [sym__statements] = STATE(7299),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(1908),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(404)] = {
    [sym__statements] = STATE(7301),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(405)] = {
    [sym__statements] = STATE(7302),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(406)] = {
    [sym__statements] = STATE(7303),
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4617),
    [sym_for_statement] = STATE(4617),
    [sym_c_style_for_statement] = STATE(4617),
    [sym_while_statement] = STATE(4279),
    [sym_if_statement] = STATE(4279),
    [sym_case_statement] = STATE(4617),
    [sym_function_definition] = STATE(4617),
    [sym_compound_statement] = STATE(4617),
    [sym_subshell] = STATE(4617),
    [sym_pipeline] = STATE(5008),
    [sym_list] = STATE(4617),
    [sym_negated_command] = STATE(4617),
    [sym_test_command] = STATE(4617),
    [sym_declaration_command] = STATE(4617),
    [sym_unset_command] = STATE(4617),
    [sym_command] = STATE(4617),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(958),
    [sym_variable_assignments] = STATE(4617),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(1909),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(418),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(407)] = {
    [sym__statements] = STATE(7305),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(408)] = {
    [sym__statements] = STATE(7310),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(409)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_then] = ACTIONS(883),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(410)] = {
    [aux_sym__terminated_statement] = STATE(26),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_fi] = ACTIONS(885),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(411)] = {
    [sym__statements] = STATE(7316),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(412)] = {
    [sym__statements] = STATE(7320),
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4592),
    [sym_for_statement] = STATE(4592),
    [sym_c_style_for_statement] = STATE(4592),
    [sym_while_statement] = STATE(4287),
    [sym_if_statement] = STATE(4287),
    [sym_case_statement] = STATE(4592),
    [sym_function_definition] = STATE(4592),
    [sym_compound_statement] = STATE(4592),
    [sym_subshell] = STATE(4592),
    [sym_pipeline] = STATE(4971),
    [sym_list] = STATE(4592),
    [sym_negated_command] = STATE(4592),
    [sym_test_command] = STATE(4592),
    [sym_declaration_command] = STATE(4592),
    [sym_unset_command] = STATE(4592),
    [sym_command] = STATE(4592),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1098),
    [sym_variable_assignments] = STATE(4592),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(422),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(413)] = {
    [aux_sym__terminated_statement] = STATE(68),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4798),
    [sym_for_statement] = STATE(4798),
    [sym_c_style_for_statement] = STATE(4798),
    [sym_while_statement] = STATE(4379),
    [sym_if_statement] = STATE(4379),
    [sym_case_statement] = STATE(4798),
    [sym_function_definition] = STATE(4798),
    [sym_compound_statement] = STATE(4798),
    [sym_subshell] = STATE(4798),
    [sym_pipeline] = STATE(5096),
    [sym_list] = STATE(4798),
    [sym_negated_command] = STATE(4798),
    [sym_test_command] = STATE(4798),
    [sym_declaration_command] = STATE(4798),
    [sym_unset_command] = STATE(4798),
    [sym_command] = STATE(4798),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1060),
    [sym_variable_assignments] = STATE(4798),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_done] = ACTIONS(887),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(414)] = {
    [aux_sym__terminated_statement] = STATE(65),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(415)] = {
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4916),
    [sym_for_statement] = STATE(4916),
    [sym_c_style_for_statement] = STATE(4916),
    [sym_while_statement] = STATE(4337),
    [sym_if_statement] = STATE(4337),
    [sym_case_statement] = STATE(4916),
    [sym_function_definition] = STATE(4916),
    [sym_compound_statement] = STATE(4916),
    [sym_subshell] = STATE(4916),
    [sym_pipeline] = STATE(5051),
    [sym_list] = STATE(4916),
    [sym_negated_command] = STATE(4916),
    [sym_test_command] = STATE(4916),
    [sym_declaration_command] = STATE(4916),
    [sym_unset_command] = STATE(4916),
    [sym_command] = STATE(4916),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1136),
    [sym_variable_assignments] = STATE(4916),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(415),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(889),
    [anon_sym_for] = ACTIONS(892),
    [anon_sym_select] = ACTIONS(895),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(898),
    [anon_sym_LT] = ACTIONS(901),
    [anon_sym_GT] = ACTIONS(901),
    [anon_sym_GT_GT] = ACTIONS(904),
    [anon_sym_LPAREN] = ACTIONS(907),
    [anon_sym_while] = ACTIONS(910),
    [anon_sym_until] = ACTIONS(910),
    [anon_sym_if] = ACTIONS(913),
    [anon_sym_case] = ACTIONS(916),
    [anon_sym_function] = ACTIONS(919),
    [anon_sym_LBRACE] = ACTIONS(922),
    [anon_sym_BANG] = ACTIONS(925),
    [anon_sym_LBRACK] = ACTIONS(928),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(931),
    [anon_sym_declare] = ACTIONS(934),
    [anon_sym_typeset] = ACTIONS(934),
    [anon_sym_export] = ACTIONS(934),
    [anon_sym_readonly] = ACTIONS(934),
    [anon_sym_local] = ACTIONS(934),
    [anon_sym_unset] = ACTIONS(937),
    [anon_sym_unsetenv] = ACTIONS(937),
    [anon_sym_AMP_GT] = ACTIONS(901),
    [anon_sym_AMP_GT_GT] = ACTIONS(904),
    [anon_sym_LT_AMP] = ACTIONS(901),
    [anon_sym_GT_AMP] = ACTIONS(901),
    [anon_sym_GT_PIPE] = ACTIONS(904),
    [anon_sym_LT_AMP_DASH] = ACTIONS(940),
    [anon_sym_GT_AMP_DASH] = ACTIONS(940),
    [anon_sym_LT_LT_LT] = ACTIONS(943),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(946),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(949),
    [anon_sym_DOLLAR] = ACTIONS(952),
    [sym__special_character] = ACTIONS(955),
    [anon_sym_DQUOTE] = ACTIONS(958),
    [sym_raw_string] = ACTIONS(961),
    [sym_ansi_c_string] = ACTIONS(961),
    [aux_sym_number_token1] = ACTIONS(964),
    [aux_sym_number_token2] = ACTIONS(967),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(970),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(973),
    [anon_sym_BQUOTE] = ACTIONS(976),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(979),
    [anon_sym_LT_LPAREN] = ACTIONS(982),
    [anon_sym_GT_LPAREN] = ACTIONS(982),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(985),
    [sym_variable_name] = ACTIONS(988),
    [sym_test_operator] = ACTIONS(991),
    [sym__brace_start] = ACTIONS(994),
  },
  [STATE(416)] = {
    [aux_sym__terminated_statement] = STATE(58),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(417)] = {
    [aux_sym__terminated_statement] = STATE(409),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(418)] = {
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4516),
    [sym_for_statement] = STATE(4516),
    [sym_c_style_for_statement] = STATE(4516),
    [sym_while_statement] = STATE(4202),
    [sym_if_statement] = STATE(4202),
    [sym_case_statement] = STATE(4516),
    [sym_function_definition] = STATE(4516),
    [sym_compound_statement] = STATE(4516),
    [sym_subshell] = STATE(4516),
    [sym_pipeline] = STATE(5012),
    [sym_list] = STATE(4516),
    [sym_negated_command] = STATE(4516),
    [sym_test_command] = STATE(4516),
    [sym_declaration_command] = STATE(4516),
    [sym_unset_command] = STATE(4516),
    [sym_command] = STATE(4516),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(969),
    [sym_variable_assignments] = STATE(4516),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym__statements_repeat1] = STATE(415),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(419)] = {
    [aux_sym__terminated_statement] = STATE(51),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(420)] = {
    [aux_sym__terminated_statement] = STATE(50),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(421)] = {
    [aux_sym__terminated_statement] = STATE(53),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(422)] = {
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4584),
    [sym_for_statement] = STATE(4584),
    [sym_c_style_for_statement] = STATE(4584),
    [sym_while_statement] = STATE(4307),
    [sym_if_statement] = STATE(4307),
    [sym_case_statement] = STATE(4584),
    [sym_function_definition] = STATE(4584),
    [sym_compound_statement] = STATE(4584),
    [sym_subshell] = STATE(4584),
    [sym_pipeline] = STATE(4974),
    [sym_list] = STATE(4584),
    [sym_negated_command] = STATE(4584),
    [sym_test_command] = STATE(4584),
    [sym_declaration_command] = STATE(4584),
    [sym_unset_command] = STATE(4584),
    [sym_command] = STATE(4584),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(993),
    [sym_variable_assignments] = STATE(4584),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym__statements_repeat1] = STATE(415),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(423)] = {
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4180),
    [sym_for_statement] = STATE(4180),
    [sym_c_style_for_statement] = STATE(4180),
    [sym_while_statement] = STATE(3905),
    [sym_if_statement] = STATE(3905),
    [sym_case_statement] = STATE(4180),
    [sym_function_definition] = STATE(4180),
    [sym_compound_statement] = STATE(4180),
    [sym_subshell] = STATE(4180),
    [sym_pipeline] = STATE(4548),
    [sym_list] = STATE(4180),
    [sym_negated_command] = STATE(4180),
    [sym_test_command] = STATE(4180),
    [sym_declaration_command] = STATE(4180),
    [sym_unset_command] = STATE(4180),
    [sym_command] = STATE(4180),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(785),
    [sym_variable_assignments] = STATE(4180),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym__statements_repeat1] = STATE(415),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(424)] = {
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4361),
    [sym_for_statement] = STATE(4361),
    [sym_c_style_for_statement] = STATE(4361),
    [sym_while_statement] = STATE(4140),
    [sym_if_statement] = STATE(4140),
    [sym_case_statement] = STATE(4361),
    [sym_function_definition] = STATE(4361),
    [sym_compound_statement] = STATE(4361),
    [sym_subshell] = STATE(4361),
    [sym_pipeline] = STATE(4710),
    [sym_list] = STATE(4361),
    [sym_negated_command] = STATE(4361),
    [sym_test_command] = STATE(4361),
    [sym_declaration_command] = STATE(4361),
    [sym_unset_command] = STATE(4361),
    [sym_command] = STATE(4361),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(814),
    [sym_variable_assignments] = STATE(4361),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym__statements_repeat1] = STATE(415),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(425)] = {
    [sym__statement_not_pipeline] = STATE(6618),
    [sym_redirected_statement] = STATE(4589),
    [sym_for_statement] = STATE(4589),
    [sym_c_style_for_statement] = STATE(4589),
    [sym_while_statement] = STATE(4310),
    [sym_if_statement] = STATE(4310),
    [sym_case_statement] = STATE(4589),
    [sym_function_definition] = STATE(4589),
    [sym_compound_statement] = STATE(4589),
    [sym_subshell] = STATE(4589),
    [sym_pipeline] = STATE(5009),
    [sym_list] = STATE(4589),
    [sym_negated_command] = STATE(4589),
    [sym_test_command] = STATE(4589),
    [sym_declaration_command] = STATE(4589),
    [sym_unset_command] = STATE(4589),
    [sym_command] = STATE(4589),
    [sym_command_name] = STATE(528),
    [sym_variable_assignment] = STATE(953),
    [sym_variable_assignments] = STATE(4589),
    [sym_subscript] = STATE(6655),
    [sym_file_redirect] = STATE(2125),
    [sym_herestring_redirect] = STATE(2207),
    [sym_arithmetic_expansion] = STATE(944),
    [sym_brace_expression] = STATE(944),
    [sym_concatenation] = STATE(1431),
    [sym_string] = STATE(944),
    [sym_translated_string] = STATE(944),
    [sym_number] = STATE(944),
    [sym_simple_expansion] = STATE(944),
    [sym_expansion] = STATE(944),
    [sym_command_substitution] = STATE(944),
    [sym_process_substitution] = STATE(944),
    [aux_sym__statements_repeat1] = STATE(415),
    [aux_sym_redirected_statement_repeat2] = STATE(4333),
    [aux_sym_command_repeat1] = STATE(937),
    [aux_sym__literal_repeat1] = STATE(1181),
    [sym_word] = ACTIONS(7),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(15),
    [anon_sym_GT] = ACTIONS(15),
    [anon_sym_GT_GT] = ACTIONS(17),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(27),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(31),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(37),
    [anon_sym_typeset] = ACTIONS(37),
    [anon_sym_export] = ACTIONS(37),
    [anon_sym_readonly] = ACTIONS(37),
    [anon_sym_local] = ACTIONS(37),
    [anon_sym_unset] = ACTIONS(39),
    [anon_sym_unsetenv] = ACTIONS(39),
    [anon_sym_AMP_GT] = ACTIONS(15),
    [anon_sym_AMP_GT_GT] = ACTIONS(17),
    [anon_sym_LT_AMP] = ACTIONS(15),
    [anon_sym_GT_AMP] = ACTIONS(15),
    [anon_sym_GT_PIPE] = ACTIONS(17),
    [anon_sym_LT_AMP_DASH] = ACTIONS(41),
    [anon_sym_GT_AMP_DASH] = ACTIONS(41),
    [anon_sym_LT_LT_LT] = ACTIONS(43),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(45),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(47),
    [anon_sym_DOLLAR] = ACTIONS(49),
    [sym__special_character] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [sym_raw_string] = ACTIONS(55),
    [sym_ansi_c_string] = ACTIONS(55),
    [aux_sym_number_token1] = ACTIONS(57),
    [aux_sym_number_token2] = ACTIONS(59),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(61),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(63),
    [anon_sym_BQUOTE] = ACTIONS(65),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(67),
    [anon_sym_LT_LPAREN] = ACTIONS(69),
    [anon_sym_GT_LPAREN] = ACTIONS(69),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(73),
    [sym_variable_name] = ACTIONS(75),
    [sym_test_operator] = ACTIONS(77),
    [sym__brace_start] = ACTIONS(79),
  },
  [STATE(426)] = {
    [aux_sym__terminated_statement] = STATE(107),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(427)] = {
    [aux_sym__terminated_statement] = STATE(113),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(428)] = {
    [aux_sym__terminated_statement] = STATE(119),
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4899),
    [sym_for_statement] = STATE(4899),
    [sym_c_style_for_statement] = STATE(4899),
    [sym_while_statement] = STATE(4335),
    [sym_if_statement] = STATE(4335),
    [sym_case_statement] = STATE(4899),
    [sym_function_definition] = STATE(4899),
    [sym_compound_statement] = STATE(4899),
    [sym_subshell] = STATE(4899),
    [sym_pipeline] = STATE(5095),
    [sym_list] = STATE(4899),
    [sym_negated_command] = STATE(4899),
    [sym_test_command] = STATE(4899),
    [sym_declaration_command] = STATE(4899),
    [sym_unset_command] = STATE(4899),
    [sym_command] = STATE(4899),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1097),
    [sym_variable_assignments] = STATE(4899),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(429)] = {
    [sym__statement_not_pipeline] = STATE(6604),
    [sym_redirected_statement] = STATE(5115),
    [sym_for_statement] = STATE(5115),
    [sym_c_style_for_statement] = STATE(5115),
    [sym_while_statement] = STATE(4947),
    [sym_if_statement] = STATE(4947),
    [sym_case_statement] = STATE(5115),
    [sym_function_definition] = STATE(5115),
    [sym_compound_statement] = STATE(5115),
    [sym_subshell] = STATE(5115),
    [sym_pipeline] = STATE(5416),
    [sym_list] = STATE(5115),
    [sym_negated_command] = STATE(5115),
    [sym_test_command] = STATE(5115),
    [sym_declaration_command] = STATE(5115),
    [sym_unset_command] = STATE(5115),
    [sym_command] = STATE(5115),
    [sym_command_name] = STATE(581),
    [sym_variable_assignment] = STATE(1602),
    [sym_variable_assignments] = STATE(5115),
    [sym_subscript] = STATE(6679),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1692),
    [sym_brace_expression] = STATE(1692),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1692),
    [sym_translated_string] = STATE(1692),
    [sym_number] = STATE(1692),
    [sym_simple_expansion] = STATE(1692),
    [sym_expansion] = STATE(1692),
    [sym_command_substitution] = STATE(1692),
    [sym_process_substitution] = STATE(1692),
    [aux_sym_redirected_statement_repeat2] = STATE(5057),
    [aux_sym_command_repeat1] = STATE(974),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(997),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(999),
    [anon_sym_GT] = ACTIONS(999),
    [anon_sym_GT_GT] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(1007),
    [anon_sym_typeset] = ACTIONS(1007),
    [anon_sym_export] = ACTIONS(1007),
    [anon_sym_readonly] = ACTIONS(1007),
    [anon_sym_local] = ACTIONS(1007),
    [anon_sym_unset] = ACTIONS(1009),
    [anon_sym_unsetenv] = ACTIONS(1009),
    [anon_sym_AMP_GT] = ACTIONS(999),
    [anon_sym_AMP_GT_GT] = ACTIONS(1001),
    [anon_sym_LT_AMP] = ACTIONS(999),
    [anon_sym_GT_AMP] = ACTIONS(999),
    [anon_sym_GT_PIPE] = ACTIONS(1001),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1011),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1011),
    [anon_sym_LT_LT_LT] = ACTIONS(1013),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(1015),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(1017),
    [sym_ansi_c_string] = ACTIONS(1017),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1019),
    [sym_variable_name] = ACTIONS(1021),
    [sym_test_operator] = ACTIONS(1023),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(430)] = {
    [sym__statement_not_pipeline] = STATE(6462),
    [sym_redirected_statement] = STATE(4666),
    [sym_for_statement] = STATE(4666),
    [sym_c_style_for_statement] = STATE(4666),
    [sym_while_statement] = STATE(4272),
    [sym_if_statement] = STATE(4272),
    [sym_case_statement] = STATE(4666),
    [sym_function_definition] = STATE(4666),
    [sym_compound_statement] = STATE(4666),
    [sym_subshell] = STATE(4666),
    [sym_pipeline] = STATE(4526),
    [sym_list] = STATE(4666),
    [sym_negated_command] = STATE(4666),
    [sym_test_command] = STATE(4666),
    [sym_declaration_command] = STATE(4666),
    [sym_unset_command] = STATE(4666),
    [sym_command] = STATE(4666),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(873),
    [sym_variable_assignments] = STATE(4666),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(431)] = {
    [sym__statement_not_pipeline] = STATE(6520),
    [sym_redirected_statement] = STATE(5371),
    [sym_for_statement] = STATE(5371),
    [sym_c_style_for_statement] = STATE(5371),
    [sym_while_statement] = STATE(5061),
    [sym_if_statement] = STATE(5061),
    [sym_case_statement] = STATE(5371),
    [sym_function_definition] = STATE(5371),
    [sym_compound_statement] = STATE(5371),
    [sym_subshell] = STATE(5371),
    [sym_pipeline] = STATE(5373),
    [sym_list] = STATE(5371),
    [sym_negated_command] = STATE(5371),
    [sym_test_command] = STATE(5371),
    [sym_declaration_command] = STATE(5371),
    [sym_unset_command] = STATE(5371),
    [sym_command] = STATE(5371),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1737),
    [sym_variable_assignments] = STATE(5371),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2929),
    [sym_herestring_redirect] = STATE(2930),
    [sym_arithmetic_expansion] = STATE(1879),
    [sym_brace_expression] = STATE(1879),
    [sym_concatenation] = STATE(2412),
    [sym_string] = STATE(1879),
    [sym_translated_string] = STATE(1879),
    [sym_number] = STATE(1879),
    [sym_simple_expansion] = STATE(1879),
    [sym_expansion] = STATE(1879),
    [sym_command_substitution] = STATE(1879),
    [sym_process_substitution] = STATE(1879),
    [aux_sym_redirected_statement_repeat2] = STATE(5222),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(2307),
    [sym_word] = ACTIONS(1025),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(1027),
    [anon_sym_GT] = ACTIONS(1027),
    [anon_sym_GT_GT] = ACTIONS(1029),
    [anon_sym_LPAREN] = ACTIONS(1031),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(1033),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(1027),
    [anon_sym_AMP_GT_GT] = ACTIONS(1029),
    [anon_sym_LT_AMP] = ACTIONS(1027),
    [anon_sym_GT_AMP] = ACTIONS(1027),
    [anon_sym_GT_PIPE] = ACTIONS(1029),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1035),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1035),
    [anon_sym_LT_LT_LT] = ACTIONS(1037),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1039),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1041),
    [anon_sym_DOLLAR] = ACTIONS(1043),
    [sym__special_character] = ACTIONS(1045),
    [anon_sym_DQUOTE] = ACTIONS(1047),
    [sym_raw_string] = ACTIONS(1049),
    [sym_ansi_c_string] = ACTIONS(1049),
    [aux_sym_number_token1] = ACTIONS(1051),
    [aux_sym_number_token2] = ACTIONS(1053),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1055),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1057),
    [anon_sym_BQUOTE] = ACTIONS(1059),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1061),
    [anon_sym_LT_LPAREN] = ACTIONS(1063),
    [anon_sym_GT_LPAREN] = ACTIONS(1063),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1065),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(1067),
    [sym__brace_start] = ACTIONS(1069),
  },
  [STATE(432)] = {
    [sym__statement_not_pipeline] = STATE(6604),
    [sym_redirected_statement] = STATE(5170),
    [sym_for_statement] = STATE(5170),
    [sym_c_style_for_statement] = STATE(5170),
    [sym_while_statement] = STATE(4999),
    [sym_if_statement] = STATE(4999),
    [sym_case_statement] = STATE(5170),
    [sym_function_definition] = STATE(5170),
    [sym_compound_statement] = STATE(5170),
    [sym_subshell] = STATE(5170),
    [sym_pipeline] = STATE(5412),
    [sym_list] = STATE(5170),
    [sym_negated_command] = STATE(5170),
    [sym_test_command] = STATE(5170),
    [sym_declaration_command] = STATE(5170),
    [sym_unset_command] = STATE(5170),
    [sym_command] = STATE(5170),
    [sym_command_name] = STATE(581),
    [sym_variable_assignment] = STATE(1601),
    [sym_variable_assignments] = STATE(5170),
    [sym_subscript] = STATE(6679),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1692),
    [sym_brace_expression] = STATE(1692),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1692),
    [sym_translated_string] = STATE(1692),
    [sym_number] = STATE(1692),
    [sym_simple_expansion] = STATE(1692),
    [sym_expansion] = STATE(1692),
    [sym_command_substitution] = STATE(1692),
    [sym_process_substitution] = STATE(1692),
    [aux_sym_redirected_statement_repeat2] = STATE(5057),
    [aux_sym_command_repeat1] = STATE(974),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(997),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(999),
    [anon_sym_GT] = ACTIONS(999),
    [anon_sym_GT_GT] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(1007),
    [anon_sym_typeset] = ACTIONS(1007),
    [anon_sym_export] = ACTIONS(1007),
    [anon_sym_readonly] = ACTIONS(1007),
    [anon_sym_local] = ACTIONS(1007),
    [anon_sym_unset] = ACTIONS(1009),
    [anon_sym_unsetenv] = ACTIONS(1009),
    [anon_sym_AMP_GT] = ACTIONS(999),
    [anon_sym_AMP_GT_GT] = ACTIONS(1001),
    [anon_sym_LT_AMP] = ACTIONS(999),
    [anon_sym_GT_AMP] = ACTIONS(999),
    [anon_sym_GT_PIPE] = ACTIONS(1001),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1011),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1011),
    [anon_sym_LT_LT_LT] = ACTIONS(1013),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(1015),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(1017),
    [sym_ansi_c_string] = ACTIONS(1017),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1019),
    [sym_variable_name] = ACTIONS(1021),
    [sym_test_operator] = ACTIONS(1023),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(433)] = {
    [sym__statement_not_pipeline] = STATE(5509),
    [sym_redirected_statement] = STATE(5509),
    [sym_for_statement] = STATE(5509),
    [sym_c_style_for_statement] = STATE(5509),
    [sym_while_statement] = STATE(5101),
    [sym_if_statement] = STATE(5101),
    [sym_case_statement] = STATE(5509),
    [sym_function_definition] = STATE(5509),
    [sym_compound_statement] = STATE(5509),
    [sym_subshell] = STATE(5509),
    [sym_pipeline] = STATE(5491),
    [sym_list] = STATE(5509),
    [sym_negated_command] = STATE(5509),
    [sym_test_command] = STATE(5509),
    [sym_declaration_command] = STATE(5509),
    [sym_unset_command] = STATE(5509),
    [sym_command] = STATE(5509),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(1751),
    [sym_variable_assignments] = STATE(5509),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(2929),
    [sym_herestring_redirect] = STATE(2930),
    [sym_arithmetic_expansion] = STATE(1879),
    [sym_brace_expression] = STATE(1879),
    [sym_concatenation] = STATE(2412),
    [sym_string] = STATE(1879),
    [sym_translated_string] = STATE(1879),
    [sym_number] = STATE(1879),
    [sym_simple_expansion] = STATE(1879),
    [sym_expansion] = STATE(1879),
    [sym_command_substitution] = STATE(1879),
    [sym_process_substitution] = STATE(1879),
    [aux_sym_redirected_statement_repeat2] = STATE(5222),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(2307),
    [sym_word] = ACTIONS(1025),
    [anon_sym_for] = ACTIONS(143),
    [anon_sym_select] = ACTIONS(145),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(147),
    [anon_sym_LT] = ACTIONS(1027),
    [anon_sym_GT] = ACTIONS(1027),
    [anon_sym_GT_GT] = ACTIONS(1029),
    [anon_sym_LPAREN] = ACTIONS(1031),
    [anon_sym_while] = ACTIONS(155),
    [anon_sym_until] = ACTIONS(155),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_case] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_LBRACE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(1033),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_declare] = ACTIONS(173),
    [anon_sym_typeset] = ACTIONS(173),
    [anon_sym_export] = ACTIONS(173),
    [anon_sym_readonly] = ACTIONS(173),
    [anon_sym_local] = ACTIONS(173),
    [anon_sym_unset] = ACTIONS(175),
    [anon_sym_unsetenv] = ACTIONS(175),
    [anon_sym_AMP_GT] = ACTIONS(1027),
    [anon_sym_AMP_GT_GT] = ACTIONS(1029),
    [anon_sym_LT_AMP] = ACTIONS(1027),
    [anon_sym_GT_AMP] = ACTIONS(1027),
    [anon_sym_GT_PIPE] = ACTIONS(1029),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1035),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1035),
    [anon_sym_LT_LT_LT] = ACTIONS(1037),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1039),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1041),
    [anon_sym_DOLLAR] = ACTIONS(1043),
    [sym__special_character] = ACTIONS(1045),
    [anon_sym_DQUOTE] = ACTIONS(1047),
    [sym_raw_string] = ACTIONS(1049),
    [sym_ansi_c_string] = ACTIONS(1049),
    [aux_sym_number_token1] = ACTIONS(1051),
    [aux_sym_number_token2] = ACTIONS(1053),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1055),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1057),
    [anon_sym_BQUOTE] = ACTIONS(1059),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1061),
    [anon_sym_LT_LPAREN] = ACTIONS(1063),
    [anon_sym_GT_LPAREN] = ACTIONS(1063),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1065),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(1067),
    [sym__brace_start] = ACTIONS(1069),
  },
  [STATE(434)] = {
    [sym__statement_not_pipeline] = STATE(4562),
    [sym_redirected_statement] = STATE(4562),
    [sym_for_statement] = STATE(4562),
    [sym_c_style_for_statement] = STATE(4562),
    [sym_while_statement] = STATE(4211),
    [sym_if_statement] = STATE(4211),
    [sym_case_statement] = STATE(4562),
    [sym_function_definition] = STATE(4562),
    [sym_compound_statement] = STATE(4562),
    [sym_subshell] = STATE(4562),
    [sym_pipeline] = STATE(5501),
    [sym_list] = STATE(4562),
    [sym_negated_command] = STATE(4562),
    [sym_test_command] = STATE(4562),
    [sym_declaration_command] = STATE(4562),
    [sym_unset_command] = STATE(4562),
    [sym_command] = STATE(4562),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1092),
    [sym_variable_assignments] = STATE(4562),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(435)] = {
    [sym__statement_not_pipeline] = STATE(6555),
    [sym_redirected_statement] = STATE(4590),
    [sym_for_statement] = STATE(4590),
    [sym_c_style_for_statement] = STATE(4590),
    [sym_while_statement] = STATE(4305),
    [sym_if_statement] = STATE(4305),
    [sym_case_statement] = STATE(4590),
    [sym_function_definition] = STATE(4590),
    [sym_compound_statement] = STATE(4590),
    [sym_subshell] = STATE(4590),
    [sym_pipeline] = STATE(4594),
    [sym_list] = STATE(4590),
    [sym_negated_command] = STATE(4590),
    [sym_test_command] = STATE(4590),
    [sym_declaration_command] = STATE(4590),
    [sym_unset_command] = STATE(4590),
    [sym_command] = STATE(4590),
    [sym_command_name] = STATE(538),
    [sym_variable_assignment] = STATE(1074),
    [sym_variable_assignments] = STATE(4590),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2268),
    [sym_herestring_redirect] = STATE(2269),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4363),
    [aux_sym_command_repeat1] = STATE(938),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(867),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(873),
    [anon_sym_typeset] = ACTIONS(873),
    [anon_sym_export] = ACTIONS(873),
    [anon_sym_readonly] = ACTIONS(873),
    [anon_sym_local] = ACTIONS(873),
    [anon_sym_unset] = ACTIONS(875),
    [anon_sym_unsetenv] = ACTIONS(875),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(436)] = {
    [sym__statement_not_pipeline] = STATE(4525),
    [sym_redirected_statement] = STATE(4525),
    [sym_for_statement] = STATE(4525),
    [sym_c_style_for_statement] = STATE(4525),
    [sym_while_statement] = STATE(3904),
    [sym_if_statement] = STATE(3904),
    [sym_case_statement] = STATE(4525),
    [sym_function_definition] = STATE(4525),
    [sym_compound_statement] = STATE(4525),
    [sym_subshell] = STATE(4525),
    [sym_pipeline] = STATE(5510),
    [sym_list] = STATE(4525),
    [sym_negated_command] = STATE(4525),
    [sym_test_command] = STATE(4525),
    [sym_declaration_command] = STATE(4525),
    [sym_unset_command] = STATE(4525),
    [sym_command] = STATE(4525),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(800),
    [sym_variable_assignments] = STATE(4525),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(437)] = {
    [sym__statement_not_pipeline] = STATE(6573),
    [sym_redirected_statement] = STATE(4238),
    [sym_for_statement] = STATE(4238),
    [sym_c_style_for_statement] = STATE(4238),
    [sym_while_statement] = STATE(3800),
    [sym_if_statement] = STATE(3800),
    [sym_case_statement] = STATE(4238),
    [sym_function_definition] = STATE(4238),
    [sym_compound_statement] = STATE(4238),
    [sym_subshell] = STATE(4238),
    [sym_pipeline] = STATE(4233),
    [sym_list] = STATE(4238),
    [sym_negated_command] = STATE(4238),
    [sym_test_command] = STATE(4238),
    [sym_declaration_command] = STATE(4238),
    [sym_unset_command] = STATE(4238),
    [sym_command] = STATE(4238),
    [sym_command_name] = STATE(524),
    [sym_variable_assignment] = STATE(782),
    [sym_variable_assignments] = STATE(4238),
    [sym_subscript] = STATE(6697),
    [sym_file_redirect] = STATE(1608),
    [sym_herestring_redirect] = STATE(1609),
    [sym_arithmetic_expansion] = STATE(781),
    [sym_brace_expression] = STATE(781),
    [sym_concatenation] = STATE(1056),
    [sym_string] = STATE(781),
    [sym_translated_string] = STATE(781),
    [sym_number] = STATE(781),
    [sym_simple_expansion] = STATE(781),
    [sym_expansion] = STATE(781),
    [sym_command_substitution] = STATE(781),
    [sym_process_substitution] = STATE(781),
    [aux_sym_redirected_statement_repeat2] = STATE(4152),
    [aux_sym_command_repeat1] = STATE(942),
    [aux_sym__literal_repeat1] = STATE(943),
    [sym_word] = ACTIONS(399),
    [anon_sym_for] = ACTIONS(401),
    [anon_sym_select] = ACTIONS(403),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_GT_GT] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(413),
    [anon_sym_until] = ACTIONS(413),
    [anon_sym_if] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(417),
    [anon_sym_function] = ACTIONS(427),
    [anon_sym_LBRACE] = ACTIONS(429),
    [anon_sym_BANG] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(435),
    [anon_sym_declare] = ACTIONS(437),
    [anon_sym_typeset] = ACTIONS(437),
    [anon_sym_export] = ACTIONS(437),
    [anon_sym_readonly] = ACTIONS(437),
    [anon_sym_local] = ACTIONS(437),
    [anon_sym_unset] = ACTIONS(439),
    [anon_sym_unsetenv] = ACTIONS(439),
    [anon_sym_AMP_GT] = ACTIONS(407),
    [anon_sym_AMP_GT_GT] = ACTIONS(409),
    [anon_sym_LT_AMP] = ACTIONS(407),
    [anon_sym_GT_AMP] = ACTIONS(407),
    [anon_sym_GT_PIPE] = ACTIONS(409),
    [anon_sym_LT_AMP_DASH] = ACTIONS(441),
    [anon_sym_GT_AMP_DASH] = ACTIONS(441),
    [anon_sym_LT_LT_LT] = ACTIONS(443),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(445),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(447),
    [anon_sym_DOLLAR] = ACTIONS(449),
    [sym__special_character] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(453),
    [sym_raw_string] = ACTIONS(455),
    [sym_ansi_c_string] = ACTIONS(455),
    [aux_sym_number_token1] = ACTIONS(457),
    [aux_sym_number_token2] = ACTIONS(459),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(461),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(463),
    [anon_sym_BQUOTE] = ACTIONS(465),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(467),
    [anon_sym_LT_LPAREN] = ACTIONS(469),
    [anon_sym_GT_LPAREN] = ACTIONS(469),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(471),
    [sym_variable_name] = ACTIONS(473),
    [sym_test_operator] = ACTIONS(475),
    [sym__brace_start] = ACTIONS(477),
  },
  [STATE(438)] = {
    [sym__statement_not_pipeline] = STATE(4808),
    [sym_redirected_statement] = STATE(4808),
    [sym_for_statement] = STATE(4808),
    [sym_c_style_for_statement] = STATE(4808),
    [sym_while_statement] = STATE(4153),
    [sym_if_statement] = STATE(4153),
    [sym_case_statement] = STATE(4808),
    [sym_function_definition] = STATE(4808),
    [sym_compound_statement] = STATE(4808),
    [sym_subshell] = STATE(4808),
    [sym_pipeline] = STATE(5519),
    [sym_list] = STATE(4808),
    [sym_negated_command] = STATE(4808),
    [sym_test_command] = STATE(4808),
    [sym_declaration_command] = STATE(4808),
    [sym_unset_command] = STATE(4808),
    [sym_command] = STATE(4808),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(860),
    [sym_variable_assignments] = STATE(4808),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(439)] = {
    [sym__statement_not_pipeline] = STATE(6592),
    [sym_redirected_statement] = STATE(4387),
    [sym_for_statement] = STATE(4387),
    [sym_c_style_for_statement] = STATE(4387),
    [sym_while_statement] = STATE(4146),
    [sym_if_statement] = STATE(4146),
    [sym_case_statement] = STATE(4387),
    [sym_function_definition] = STATE(4387),
    [sym_compound_statement] = STATE(4387),
    [sym_subshell] = STATE(4387),
    [sym_pipeline] = STATE(4390),
    [sym_list] = STATE(4387),
    [sym_negated_command] = STATE(4387),
    [sym_test_command] = STATE(4387),
    [sym_declaration_command] = STATE(4387),
    [sym_unset_command] = STATE(4387),
    [sym_command] = STATE(4387),
    [sym_command_name] = STATE(526),
    [sym_variable_assignment] = STATE(846),
    [sym_variable_assignments] = STATE(4387),
    [sym_subscript] = STATE(6673),
    [sym_file_redirect] = STATE(1823),
    [sym_herestring_redirect] = STATE(1824),
    [sym_arithmetic_expansion] = STATE(865),
    [sym_brace_expression] = STATE(865),
    [sym_concatenation] = STATE(1220),
    [sym_string] = STATE(865),
    [sym_translated_string] = STATE(865),
    [sym_number] = STATE(865),
    [sym_simple_expansion] = STATE(865),
    [sym_expansion] = STATE(865),
    [sym_command_substitution] = STATE(865),
    [sym_process_substitution] = STATE(865),
    [aux_sym_redirected_statement_repeat2] = STATE(4217),
    [aux_sym_command_repeat1] = STATE(949),
    [aux_sym__literal_repeat1] = STATE(1089),
    [sym_word] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(663),
    [anon_sym_select] = ACTIONS(665),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_GT] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(675),
    [anon_sym_until] = ACTIONS(675),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_case] = ACTIONS(679),
    [anon_sym_function] = ACTIONS(683),
    [anon_sym_LBRACE] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(689),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(691),
    [anon_sym_declare] = ACTIONS(693),
    [anon_sym_typeset] = ACTIONS(693),
    [anon_sym_export] = ACTIONS(693),
    [anon_sym_readonly] = ACTIONS(693),
    [anon_sym_local] = ACTIONS(693),
    [anon_sym_unset] = ACTIONS(695),
    [anon_sym_unsetenv] = ACTIONS(695),
    [anon_sym_AMP_GT] = ACTIONS(669),
    [anon_sym_AMP_GT_GT] = ACTIONS(671),
    [anon_sym_LT_AMP] = ACTIONS(669),
    [anon_sym_GT_AMP] = ACTIONS(669),
    [anon_sym_GT_PIPE] = ACTIONS(671),
    [anon_sym_LT_AMP_DASH] = ACTIONS(697),
    [anon_sym_GT_AMP_DASH] = ACTIONS(697),
    [anon_sym_LT_LT_LT] = ACTIONS(699),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(701),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [sym__special_character] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [sym_raw_string] = ACTIONS(711),
    [sym_ansi_c_string] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(713),
    [aux_sym_number_token2] = ACTIONS(715),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(717),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(719),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(723),
    [anon_sym_LT_LPAREN] = ACTIONS(725),
    [anon_sym_GT_LPAREN] = ACTIONS(725),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(727),
    [sym_variable_name] = ACTIONS(729),
    [sym_test_operator] = ACTIONS(731),
    [sym__brace_start] = ACTIONS(733),
  },
  [STATE(440)] = {
    [sym__statement_not_pipeline] = STATE(4562),
    [sym_redirected_statement] = STATE(4562),
    [sym_for_statement] = STATE(4562),
    [sym_c_style_for_statement] = STATE(4562),
    [sym_while_statement] = STATE(4285),
    [sym_if_statement] = STATE(4285),
    [sym_case_statement] = STATE(4562),
    [sym_function_definition] = STATE(4562),
    [sym_compound_statement] = STATE(4562),
    [sym_subshell] = STATE(4562),
    [sym_pipeline] = STATE(5520),
    [sym_list] = STATE(4562),
    [sym_negated_command] = STATE(4562),
    [sym_test_command] = STATE(4562),
    [sym_declaration_command] = STATE(4562),
    [sym_unset_command] = STATE(4562),
    [sym_command] = STATE(4562),
    [sym_command_name] = STATE(528),
    [sym_variable_assignment] = STATE(962),
    [sym_variable_assignments] = STATE(4562),
    [sym_subscript] = STATE(6655),
    [sym_file_redirect] = STATE(2125),
    [sym_herestring_redirect] = STATE(2207),
    [sym_arithmetic_expansion] = STATE(944),
    [sym_brace_expression] = STATE(944),
    [sym_concatenation] = STATE(1431),
    [sym_string] = STATE(944),
    [sym_translated_string] = STATE(944),
    [sym_number] = STATE(944),
    [sym_simple_expansion] = STATE(944),
    [sym_expansion] = STATE(944),
    [sym_command_substitution] = STATE(944),
    [sym_process_substitution] = STATE(944),
    [aux_sym_redirected_statement_repeat2] = STATE(4333),
    [aux_sym_command_repeat1] = STATE(937),
    [aux_sym__literal_repeat1] = STATE(1181),
    [sym_word] = ACTIONS(7),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(15),
    [anon_sym_GT] = ACTIONS(15),
    [anon_sym_GT_GT] = ACTIONS(17),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(27),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(31),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(37),
    [anon_sym_typeset] = ACTIONS(37),
    [anon_sym_export] = ACTIONS(37),
    [anon_sym_readonly] = ACTIONS(37),
    [anon_sym_local] = ACTIONS(37),
    [anon_sym_unset] = ACTIONS(39),
    [anon_sym_unsetenv] = ACTIONS(39),
    [anon_sym_AMP_GT] = ACTIONS(15),
    [anon_sym_AMP_GT_GT] = ACTIONS(17),
    [anon_sym_LT_AMP] = ACTIONS(15),
    [anon_sym_GT_AMP] = ACTIONS(15),
    [anon_sym_GT_PIPE] = ACTIONS(17),
    [anon_sym_LT_AMP_DASH] = ACTIONS(41),
    [anon_sym_GT_AMP_DASH] = ACTIONS(41),
    [anon_sym_LT_LT_LT] = ACTIONS(43),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(45),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(47),
    [anon_sym_DOLLAR] = ACTIONS(49),
    [sym__special_character] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [sym_raw_string] = ACTIONS(55),
    [sym_ansi_c_string] = ACTIONS(55),
    [aux_sym_number_token1] = ACTIONS(57),
    [aux_sym_number_token2] = ACTIONS(59),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(61),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(63),
    [anon_sym_BQUOTE] = ACTIONS(65),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(67),
    [anon_sym_LT_LPAREN] = ACTIONS(69),
    [anon_sym_GT_LPAREN] = ACTIONS(69),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(73),
    [sym_variable_name] = ACTIONS(75),
    [sym_test_operator] = ACTIONS(77),
    [sym__brace_start] = ACTIONS(79),
  },
  [STATE(441)] = {
    [sym__statement_not_pipeline] = STATE(6618),
    [sym_redirected_statement] = STATE(4587),
    [sym_for_statement] = STATE(4587),
    [sym_c_style_for_statement] = STATE(4587),
    [sym_while_statement] = STATE(4313),
    [sym_if_statement] = STATE(4313),
    [sym_case_statement] = STATE(4587),
    [sym_function_definition] = STATE(4587),
    [sym_compound_statement] = STATE(4587),
    [sym_subshell] = STATE(4587),
    [sym_pipeline] = STATE(4597),
    [sym_list] = STATE(4587),
    [sym_negated_command] = STATE(4587),
    [sym_test_command] = STATE(4587),
    [sym_declaration_command] = STATE(4587),
    [sym_unset_command] = STATE(4587),
    [sym_command] = STATE(4587),
    [sym_command_name] = STATE(528),
    [sym_variable_assignment] = STATE(939),
    [sym_variable_assignments] = STATE(4587),
    [sym_subscript] = STATE(6655),
    [sym_file_redirect] = STATE(2125),
    [sym_herestring_redirect] = STATE(2207),
    [sym_arithmetic_expansion] = STATE(944),
    [sym_brace_expression] = STATE(944),
    [sym_concatenation] = STATE(1431),
    [sym_string] = STATE(944),
    [sym_translated_string] = STATE(944),
    [sym_number] = STATE(944),
    [sym_simple_expansion] = STATE(944),
    [sym_expansion] = STATE(944),
    [sym_command_substitution] = STATE(944),
    [sym_process_substitution] = STATE(944),
    [aux_sym_redirected_statement_repeat2] = STATE(4333),
    [aux_sym_command_repeat1] = STATE(937),
    [aux_sym__literal_repeat1] = STATE(1181),
    [sym_word] = ACTIONS(7),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(15),
    [anon_sym_GT] = ACTIONS(15),
    [anon_sym_GT_GT] = ACTIONS(17),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(27),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(31),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(37),
    [anon_sym_typeset] = ACTIONS(37),
    [anon_sym_export] = ACTIONS(37),
    [anon_sym_readonly] = ACTIONS(37),
    [anon_sym_local] = ACTIONS(37),
    [anon_sym_unset] = ACTIONS(39),
    [anon_sym_unsetenv] = ACTIONS(39),
    [anon_sym_AMP_GT] = ACTIONS(15),
    [anon_sym_AMP_GT_GT] = ACTIONS(17),
    [anon_sym_LT_AMP] = ACTIONS(15),
    [anon_sym_GT_AMP] = ACTIONS(15),
    [anon_sym_GT_PIPE] = ACTIONS(17),
    [anon_sym_LT_AMP_DASH] = ACTIONS(41),
    [anon_sym_GT_AMP_DASH] = ACTIONS(41),
    [anon_sym_LT_LT_LT] = ACTIONS(43),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(45),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(47),
    [anon_sym_DOLLAR] = ACTIONS(49),
    [sym__special_character] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [sym_raw_string] = ACTIONS(55),
    [sym_ansi_c_string] = ACTIONS(55),
    [aux_sym_number_token1] = ACTIONS(57),
    [aux_sym_number_token2] = ACTIONS(59),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(61),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(63),
    [anon_sym_BQUOTE] = ACTIONS(65),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(67),
    [anon_sym_LT_LPAREN] = ACTIONS(69),
    [anon_sym_GT_LPAREN] = ACTIONS(69),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(73),
    [sym_variable_name] = ACTIONS(75),
    [sym_test_operator] = ACTIONS(77),
    [sym__brace_start] = ACTIONS(79),
  },
  [STATE(442)] = {
    [sym__statement_not_pipeline] = STATE(6583),
    [sym_redirected_statement] = STATE(4736),
    [sym_for_statement] = STATE(4736),
    [sym_c_style_for_statement] = STATE(4736),
    [sym_while_statement] = STATE(4437),
    [sym_if_statement] = STATE(4437),
    [sym_case_statement] = STATE(4736),
    [sym_function_definition] = STATE(4736),
    [sym_compound_statement] = STATE(4736),
    [sym_subshell] = STATE(4736),
    [sym_pipeline] = STATE(4739),
    [sym_list] = STATE(4736),
    [sym_negated_command] = STATE(4736),
    [sym_test_command] = STATE(4736),
    [sym_declaration_command] = STATE(4736),
    [sym_unset_command] = STATE(4736),
    [sym_command] = STATE(4736),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1128),
    [sym_variable_assignments] = STATE(4736),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(443)] = {
    [sym__statement_not_pipeline] = STATE(4562),
    [sym_redirected_statement] = STATE(4562),
    [sym_for_statement] = STATE(4562),
    [sym_c_style_for_statement] = STATE(4562),
    [sym_while_statement] = STATE(4439),
    [sym_if_statement] = STATE(4439),
    [sym_case_statement] = STATE(4562),
    [sym_function_definition] = STATE(4562),
    [sym_compound_statement] = STATE(4562),
    [sym_subshell] = STATE(4562),
    [sym_pipeline] = STATE(5512),
    [sym_list] = STATE(4562),
    [sym_negated_command] = STATE(4562),
    [sym_test_command] = STATE(4562),
    [sym_declaration_command] = STATE(4562),
    [sym_unset_command] = STATE(4562),
    [sym_command] = STATE(4562),
    [sym_command_name] = STATE(544),
    [sym_variable_assignment] = STATE(1130),
    [sym_variable_assignments] = STATE(4562),
    [sym_subscript] = STATE(6650),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1126),
    [sym_brace_expression] = STATE(1126),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1126),
    [sym_translated_string] = STATE(1126),
    [sym_number] = STATE(1126),
    [sym_simple_expansion] = STATE(1126),
    [sym_expansion] = STATE(1126),
    [sym_command_substitution] = STATE(1126),
    [sym_process_substitution] = STATE(1126),
    [aux_sym_redirected_statement_repeat2] = STATE(4529),
    [aux_sym_command_repeat1] = STATE(970),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(284),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_GT_GT] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(300),
    [anon_sym_typeset] = ACTIONS(300),
    [anon_sym_export] = ACTIONS(300),
    [anon_sym_readonly] = ACTIONS(300),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_unset] = ACTIONS(302),
    [anon_sym_unsetenv] = ACTIONS(302),
    [anon_sym_AMP_GT] = ACTIONS(286),
    [anon_sym_AMP_GT_GT] = ACTIONS(288),
    [anon_sym_LT_AMP] = ACTIONS(286),
    [anon_sym_GT_AMP] = ACTIONS(286),
    [anon_sym_GT_PIPE] = ACTIONS(288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(304),
    [anon_sym_LT_LT_LT] = ACTIONS(306),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(314),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(318),
    [sym_ansi_c_string] = ACTIONS(318),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(334),
    [sym_variable_name] = ACTIONS(336),
    [sym_test_operator] = ACTIONS(338),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(444)] = {
    [sym__statement_not_pipeline] = STATE(4562),
    [sym_redirected_statement] = STATE(4562),
    [sym_for_statement] = STATE(4562),
    [sym_c_style_for_statement] = STATE(4562),
    [sym_while_statement] = STATE(5017),
    [sym_if_statement] = STATE(5017),
    [sym_case_statement] = STATE(4562),
    [sym_function_definition] = STATE(4562),
    [sym_compound_statement] = STATE(4562),
    [sym_subshell] = STATE(4562),
    [sym_pipeline] = STATE(5500),
    [sym_list] = STATE(4562),
    [sym_negated_command] = STATE(4562),
    [sym_test_command] = STATE(4562),
    [sym_declaration_command] = STATE(4562),
    [sym_unset_command] = STATE(4562),
    [sym_command] = STATE(4562),
    [sym_command_name] = STATE(581),
    [sym_variable_assignment] = STATE(1698),
    [sym_variable_assignments] = STATE(4562),
    [sym_subscript] = STATE(6679),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1692),
    [sym_brace_expression] = STATE(1692),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1692),
    [sym_translated_string] = STATE(1692),
    [sym_number] = STATE(1692),
    [sym_simple_expansion] = STATE(1692),
    [sym_expansion] = STATE(1692),
    [sym_command_substitution] = STATE(1692),
    [sym_process_substitution] = STATE(1692),
    [aux_sym_redirected_statement_repeat2] = STATE(5057),
    [aux_sym_command_repeat1] = STATE(974),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(997),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(999),
    [anon_sym_GT] = ACTIONS(999),
    [anon_sym_GT_GT] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(1007),
    [anon_sym_typeset] = ACTIONS(1007),
    [anon_sym_export] = ACTIONS(1007),
    [anon_sym_readonly] = ACTIONS(1007),
    [anon_sym_local] = ACTIONS(1007),
    [anon_sym_unset] = ACTIONS(1009),
    [anon_sym_unsetenv] = ACTIONS(1009),
    [anon_sym_AMP_GT] = ACTIONS(999),
    [anon_sym_AMP_GT_GT] = ACTIONS(1001),
    [anon_sym_LT_AMP] = ACTIONS(999),
    [anon_sym_GT_AMP] = ACTIONS(999),
    [anon_sym_GT_PIPE] = ACTIONS(1001),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1011),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1011),
    [anon_sym_LT_LT_LT] = ACTIONS(1013),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(1015),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(1017),
    [sym_ansi_c_string] = ACTIONS(1017),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1019),
    [sym_variable_name] = ACTIONS(1021),
    [sym_test_operator] = ACTIONS(1023),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(445)] = {
    [sym__statement_not_pipeline] = STATE(6604),
    [sym_redirected_statement] = STATE(5165),
    [sym_for_statement] = STATE(5165),
    [sym_c_style_for_statement] = STATE(5165),
    [sym_while_statement] = STATE(5014),
    [sym_if_statement] = STATE(5014),
    [sym_case_statement] = STATE(5165),
    [sym_function_definition] = STATE(5165),
    [sym_compound_statement] = STATE(5165),
    [sym_subshell] = STATE(5165),
    [sym_pipeline] = STATE(5166),
    [sym_list] = STATE(5165),
    [sym_negated_command] = STATE(5165),
    [sym_test_command] = STATE(5165),
    [sym_declaration_command] = STATE(5165),
    [sym_unset_command] = STATE(5165),
    [sym_command] = STATE(5165),
    [sym_command_name] = STATE(581),
    [sym_variable_assignment] = STATE(1695),
    [sym_variable_assignments] = STATE(5165),
    [sym_subscript] = STATE(6679),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(1692),
    [sym_brace_expression] = STATE(1692),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(1692),
    [sym_translated_string] = STATE(1692),
    [sym_number] = STATE(1692),
    [sym_simple_expansion] = STATE(1692),
    [sym_expansion] = STATE(1692),
    [sym_command_substitution] = STATE(1692),
    [sym_process_substitution] = STATE(1692),
    [aux_sym_redirected_statement_repeat2] = STATE(5057),
    [aux_sym_command_repeat1] = STATE(974),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(997),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(999),
    [anon_sym_GT] = ACTIONS(999),
    [anon_sym_GT_GT] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(1003),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(1007),
    [anon_sym_typeset] = ACTIONS(1007),
    [anon_sym_export] = ACTIONS(1007),
    [anon_sym_readonly] = ACTIONS(1007),
    [anon_sym_local] = ACTIONS(1007),
    [anon_sym_unset] = ACTIONS(1009),
    [anon_sym_unsetenv] = ACTIONS(1009),
    [anon_sym_AMP_GT] = ACTIONS(999),
    [anon_sym_AMP_GT_GT] = ACTIONS(1001),
    [anon_sym_LT_AMP] = ACTIONS(999),
    [anon_sym_GT_AMP] = ACTIONS(999),
    [anon_sym_GT_PIPE] = ACTIONS(1001),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1011),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1011),
    [anon_sym_LT_LT_LT] = ACTIONS(1013),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(1015),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(1017),
    [sym_ansi_c_string] = ACTIONS(1017),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1019),
    [sym_variable_name] = ACTIONS(1021),
    [sym_test_operator] = ACTIONS(1023),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(446)] = {
    [sym__statement_not_pipeline] = STATE(4562),
    [sym_redirected_statement] = STATE(4562),
    [sym_for_statement] = STATE(4562),
    [sym_c_style_for_statement] = STATE(4562),
    [sym_while_statement] = STATE(4172),
    [sym_if_statement] = STATE(4172),
    [sym_case_statement] = STATE(4562),
    [sym_function_definition] = STATE(4562),
    [sym_compound_statement] = STATE(4562),
    [sym_subshell] = STATE(4562),
    [sym_pipeline] = STATE(5458),
    [sym_list] = STATE(4562),
    [sym_negated_command] = STATE(4562),
    [sym_test_command] = STATE(4562),
    [sym_declaration_command] = STATE(4562),
    [sym_unset_command] = STATE(4562),
    [sym_command] = STATE(4562),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(884),
    [sym_variable_assignments] = STATE(4562),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(2018),
    [sym_herestring_redirect] = STATE(2019),
    [sym_arithmetic_expansion] = STATE(956),
    [sym_brace_expression] = STATE(956),
    [sym_concatenation] = STATE(1350),
    [sym_string] = STATE(956),
    [sym_translated_string] = STATE(956),
    [sym_number] = STATE(956),
    [sym_simple_expansion] = STATE(956),
    [sym_expansion] = STATE(956),
    [sym_command_substitution] = STATE(956),
    [sym_process_substitution] = STATE(956),
    [aux_sym_redirected_statement_repeat2] = STATE(4321),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(1237),
    [sym_word] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_select] = ACTIONS(11),
    [anon_sym_LPAREN_LPAREN] = ACTIONS(13),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_GT] = ACTIONS(85),
    [anon_sym_LPAREN] = ACTIONS(19),
    [anon_sym_while] = ACTIONS(21),
    [anon_sym_until] = ACTIONS(21),
    [anon_sym_if] = ACTIONS(23),
    [anon_sym_case] = ACTIONS(25),
    [anon_sym_function] = ACTIONS(89),
    [anon_sym_LBRACE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(769),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_declare] = ACTIONS(93),
    [anon_sym_typeset] = ACTIONS(93),
    [anon_sym_export] = ACTIONS(93),
    [anon_sym_readonly] = ACTIONS(93),
    [anon_sym_local] = ACTIONS(93),
    [anon_sym_unset] = ACTIONS(95),
    [anon_sym_unsetenv] = ACTIONS(95),
    [anon_sym_AMP_GT] = ACTIONS(83),
    [anon_sym_AMP_GT_GT] = ACTIONS(85),
    [anon_sym_LT_AMP] = ACTIONS(83),
    [anon_sym_GT_AMP] = ACTIONS(83),
    [anon_sym_GT_PIPE] = ACTIONS(85),
    [anon_sym_LT_AMP_DASH] = ACTIONS(97),
    [anon_sym_GT_AMP_DASH] = ACTIONS(97),
    [anon_sym_LT_LT_LT] = ACTIONS(99),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(310),
    [anon_sym_DOLLAR] = ACTIONS(312),
    [sym__special_character] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [sym_raw_string] = ACTIONS(773),
    [sym_ansi_c_string] = ACTIONS(773),
    [aux_sym_number_token1] = ACTIONS(320),
    [aux_sym_number_token2] = ACTIONS(322),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(324),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(326),
    [anon_sym_BQUOTE] = ACTIONS(328),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(330),
    [anon_sym_LT_LPAREN] = ACTIONS(332),
    [anon_sym_GT_LPAREN] = ACTIONS(332),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(133),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(775),
    [sym__brace_start] = ACTIONS(340),
  },
  [STATE(447)] = {
    [sym__expression] = STATE(2624),
    [sym_binary_expression] = STATE(2608),
    [sym_ternary_expression] = STATE(2608),
    [sym_unary_expression] = STATE(2608),
    [sym_postfix_expression] = STATE(2608),
    [sym_parenthesized_expression] = STATE(2608),
    [sym_arithmetic_expansion] = STATE(2403),
    [sym_brace_expression] = STATE(2403),
    [sym_concatenation] = STATE(2608),
    [sym_string] = STATE(2403),
    [sym_translated_string] = STATE(2403),
    [sym_number] = STATE(2403),
    [sym_simple_expansion] = STATE(2403),
    [sym_expansion] = STATE(2403),
    [sym_command_substitution] = STATE(2403),
    [sym_process_substitution] = STATE(2403),
    [aux_sym__literal_repeat1] = STATE(2407),
    [aux_sym_concatenation_repeat1] = STATE(2317),
    [sym_word] = ACTIONS(1071),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1073),
    [anon_sym_BANG] = ACTIONS(1075),
    [anon_sym_RBRACK] = ACTIONS(1077),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1079),
    [anon_sym_DASH_DASH2] = ACTIONS(1079),
    [anon_sym_DASH2] = ACTIONS(1081),
    [anon_sym_PLUS2] = ACTIONS(1081),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(1085),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(1089),
    [sym_ansi_c_string] = ACTIONS(1089),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1091),
    [sym_test_operator] = ACTIONS(1093),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(448)] = {
    [sym__expression] = STATE(2624),
    [sym_binary_expression] = STATE(2608),
    [sym_ternary_expression] = STATE(2608),
    [sym_unary_expression] = STATE(2608),
    [sym_postfix_expression] = STATE(2608),
    [sym_parenthesized_expression] = STATE(2608),
    [sym_arithmetic_expansion] = STATE(2403),
    [sym_brace_expression] = STATE(2403),
    [sym_concatenation] = STATE(2608),
    [sym_string] = STATE(2403),
    [sym_translated_string] = STATE(2403),
    [sym_number] = STATE(2403),
    [sym_simple_expansion] = STATE(2403),
    [sym_expansion] = STATE(2403),
    [sym_command_substitution] = STATE(2403),
    [sym_process_substitution] = STATE(2403),
    [aux_sym__literal_repeat1] = STATE(2407),
    [aux_sym_concatenation_repeat1] = STATE(2317),
    [sym_word] = ACTIONS(1071),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1073),
    [anon_sym_BANG] = ACTIONS(1075),
    [anon_sym_RBRACK] = ACTIONS(1095),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1079),
    [anon_sym_DASH_DASH2] = ACTIONS(1079),
    [anon_sym_DASH2] = ACTIONS(1081),
    [anon_sym_PLUS2] = ACTIONS(1081),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(1085),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(1089),
    [sym_ansi_c_string] = ACTIONS(1089),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1097),
    [sym_test_operator] = ACTIONS(1093),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(449)] = {
    [sym__expression] = STATE(2624),
    [sym_binary_expression] = STATE(2608),
    [sym_ternary_expression] = STATE(2608),
    [sym_unary_expression] = STATE(2608),
    [sym_postfix_expression] = STATE(2608),
    [sym_parenthesized_expression] = STATE(2608),
    [sym_arithmetic_expansion] = STATE(2403),
    [sym_brace_expression] = STATE(2403),
    [sym_concatenation] = STATE(2608),
    [sym_string] = STATE(2403),
    [sym_translated_string] = STATE(2403),
    [sym_number] = STATE(2403),
    [sym_simple_expansion] = STATE(2403),
    [sym_expansion] = STATE(2403),
    [sym_command_substitution] = STATE(2403),
    [sym_process_substitution] = STATE(2403),
    [aux_sym__literal_repeat1] = STATE(2407),
    [aux_sym_concatenation_repeat1] = STATE(2317),
    [sym_word] = ACTIONS(1071),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1073),
    [anon_sym_BANG] = ACTIONS(1075),
    [anon_sym_RBRACK] = ACTIONS(1099),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1079),
    [anon_sym_DASH_DASH2] = ACTIONS(1079),
    [anon_sym_DASH2] = ACTIONS(1081),
    [anon_sym_PLUS2] = ACTIONS(1081),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(1085),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(1089),
    [sym_ansi_c_string] = ACTIONS(1089),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1101),
    [sym_test_operator] = ACTIONS(1093),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(450)] = {
    [sym__expression] = STATE(2624),
    [sym_binary_expression] = STATE(2608),
    [sym_ternary_expression] = STATE(2608),
    [sym_unary_expression] = STATE(2608),
    [sym_postfix_expression] = STATE(2608),
    [sym_parenthesized_expression] = STATE(2608),
    [sym_arithmetic_expansion] = STATE(2403),
    [sym_brace_expression] = STATE(2403),
    [sym_concatenation] = STATE(2608),
    [sym_string] = STATE(2403),
    [sym_translated_string] = STATE(2403),
    [sym_number] = STATE(2403),
    [sym_simple_expansion] = STATE(2403),
    [sym_expansion] = STATE(2403),
    [sym_command_substitution] = STATE(2403),
    [sym_process_substitution] = STATE(2403),
    [aux_sym__literal_repeat1] = STATE(2407),
    [aux_sym_concatenation_repeat1] = STATE(2317),
    [sym_word] = ACTIONS(1071),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1073),
    [anon_sym_BANG] = ACTIONS(1075),
    [anon_sym_RBRACK] = ACTIONS(1103),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1079),
    [anon_sym_DASH_DASH2] = ACTIONS(1079),
    [anon_sym_DASH2] = ACTIONS(1081),
    [anon_sym_PLUS2] = ACTIONS(1081),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(1085),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(1089),
    [sym_ansi_c_string] = ACTIONS(1089),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1105),
    [sym_test_operator] = ACTIONS(1093),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(451)] = {
    [sym__expression] = STATE(2624),
    [sym_binary_expression] = STATE(2608),
    [sym_ternary_expression] = STATE(2608),
    [sym_unary_expression] = STATE(2608),
    [sym_postfix_expression] = STATE(2608),
    [sym_parenthesized_expression] = STATE(2608),
    [sym_arithmetic_expansion] = STATE(2403),
    [sym_brace_expression] = STATE(2403),
    [sym_concatenation] = STATE(2608),
    [sym_string] = STATE(2403),
    [sym_translated_string] = STATE(2403),
    [sym_number] = STATE(2403),
    [sym_simple_expansion] = STATE(2403),
    [sym_expansion] = STATE(2403),
    [sym_command_substitution] = STATE(2403),
    [sym_process_substitution] = STATE(2403),
    [aux_sym__literal_repeat1] = STATE(2407),
    [aux_sym_concatenation_repeat1] = STATE(2317),
    [sym_word] = ACTIONS(1071),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1073),
    [anon_sym_BANG] = ACTIONS(1075),
    [anon_sym_RBRACK] = ACTIONS(358),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1079),
    [anon_sym_DASH_DASH2] = ACTIONS(1079),
    [anon_sym_DASH2] = ACTIONS(1081),
    [anon_sym_PLUS2] = ACTIONS(1081),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(1085),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(1089),
    [sym_ansi_c_string] = ACTIONS(1089),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(358),
    [sym_test_operator] = ACTIONS(1093),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(452)] = {
    [sym__expression] = STATE(2956),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(2344),
    [sym_brace_expression] = STATE(2344),
    [sym_concatenation] = STATE(2518),
    [sym_string] = STATE(2344),
    [sym_translated_string] = STATE(2344),
    [sym_number] = STATE(2344),
    [sym_simple_expansion] = STATE(2344),
    [sym_expansion] = STATE(2344),
    [sym_command_substitution] = STATE(2344),
    [sym_process_substitution] = STATE(2344),
    [aux_sym__literal_repeat1] = STATE(2312),
    [aux_sym_concatenation_repeat1] = STATE(2314),
    [sym_word] = ACTIONS(235),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1107),
    [anon_sym_RPAREN] = ACTIONS(358),
    [anon_sym_BANG] = ACTIONS(246),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(101),
    [anon_sym_DASH_DASH2] = ACTIONS(101),
    [anon_sym_DASH2] = ACTIONS(103),
    [anon_sym_PLUS2] = ACTIONS(103),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1109),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1111),
    [aux_sym_concatenation_token1] = ACTIONS(1113),
    [anon_sym_DOLLAR] = ACTIONS(256),
    [sym__special_character] = ACTIONS(1115),
    [anon_sym_DQUOTE] = ACTIONS(1117),
    [sym_raw_string] = ACTIONS(1119),
    [sym_ansi_c_string] = ACTIONS(1119),
    [aux_sym_number_token1] = ACTIONS(262),
    [aux_sym_number_token2] = ACTIONS(264),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1121),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(268),
    [anon_sym_BQUOTE] = ACTIONS(270),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1123),
    [anon_sym_LT_LPAREN] = ACTIONS(1125),
    [anon_sym_GT_LPAREN] = ACTIONS(1125),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1113),
    [sym_test_operator] = ACTIONS(280),
    [sym__brace_start] = ACTIONS(282),
  },
  [STATE(453)] = {
    [sym__expression] = STATE(2951),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(2361),
    [sym_brace_expression] = STATE(2361),
    [sym_concatenation] = STATE(2518),
    [sym_string] = STATE(2361),
    [sym_translated_string] = STATE(2361),
    [sym_number] = STATE(2361),
    [sym_simple_expansion] = STATE(2361),
    [sym_expansion] = STATE(2361),
    [sym_command_substitution] = STATE(2361),
    [sym_process_substitution] = STATE(2361),
    [aux_sym__literal_repeat1] = STATE(2451),
    [aux_sym_concatenation_repeat1] = STATE(2421),
    [sym_word] = ACTIONS(1127),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1107),
    [anon_sym_BANG] = ACTIONS(1129),
    [anon_sym_RBRACK_RBRACK] = ACTIONS(358),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1131),
    [anon_sym_DASH_DASH2] = ACTIONS(1131),
    [anon_sym_DASH2] = ACTIONS(1133),
    [anon_sym_PLUS2] = ACTIONS(1133),
    [anon_sym_TILDE] = ACTIONS(1135),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1109),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1111),
    [aux_sym_concatenation_token1] = ACTIONS(1113),
    [anon_sym_DOLLAR] = ACTIONS(256),
    [sym__special_character] = ACTIONS(1137),
    [anon_sym_DQUOTE] = ACTIONS(1117),
    [sym_raw_string] = ACTIONS(1139),
    [sym_ansi_c_string] = ACTIONS(1139),
    [aux_sym_number_token1] = ACTIONS(262),
    [aux_sym_number_token2] = ACTIONS(264),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1121),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(268),
    [anon_sym_BQUOTE] = ACTIONS(270),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1123),
    [anon_sym_LT_LPAREN] = ACTIONS(1125),
    [anon_sym_GT_LPAREN] = ACTIONS(1125),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1113),
    [sym_test_operator] = ACTIONS(1141),
    [sym__brace_start] = ACTIONS(282),
  },
  [STATE(454)] = {
    [sym__expression] = STATE(2624),
    [sym_binary_expression] = STATE(2608),
    [sym_ternary_expression] = STATE(2608),
    [sym_unary_expression] = STATE(2608),
    [sym_postfix_expression] = STATE(2608),
    [sym_parenthesized_expression] = STATE(2608),
    [sym_arithmetic_expansion] = STATE(2403),
    [sym_brace_expression] = STATE(2403),
    [sym_concatenation] = STATE(2608),
    [sym_string] = STATE(2403),
    [sym_translated_string] = STATE(2403),
    [sym_number] = STATE(2403),
    [sym_simple_expansion] = STATE(2403),
    [sym_expansion] = STATE(2403),
    [sym_command_substitution] = STATE(2403),
    [sym_process_substitution] = STATE(2403),
    [aux_sym__literal_repeat1] = STATE(2407),
    [aux_sym_concatenation_repeat1] = STATE(2317),
    [sym_word] = ACTIONS(1071),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1073),
    [anon_sym_BANG] = ACTIONS(1075),
    [anon_sym_RBRACK] = ACTIONS(1143),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1079),
    [anon_sym_DASH_DASH2] = ACTIONS(1079),
    [anon_sym_DASH2] = ACTIONS(1081),
    [anon_sym_PLUS2] = ACTIONS(1081),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(1085),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(1089),
    [sym_ansi_c_string] = ACTIONS(1089),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1145),
    [sym_test_operator] = ACTIONS(1093),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(455)] = {
    [sym__expression] = STATE(2989),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(2381),
    [sym_brace_expression] = STATE(2381),
    [sym_concatenation] = STATE(2518),
    [sym_string] = STATE(2381),
    [sym_translated_string] = STATE(2381),
    [sym_number] = STATE(2381),
    [sym_simple_expansion] = STATE(2381),
    [sym_expansion] = STATE(2381),
    [sym_command_substitution] = STATE(2381),
    [sym_process_substitution] = STATE(2381),
    [aux_sym__literal_repeat1] = STATE(2312),
    [aux_sym_concatenation_repeat1] = STATE(2396),
    [sym_word] = ACTIONS(1147),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1107),
    [anon_sym_BANG] = ACTIONS(1149),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_COLON] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1151),
    [anon_sym_DASH_DASH2] = ACTIONS(1151),
    [anon_sym_DASH2] = ACTIONS(1153),
    [anon_sym_PLUS2] = ACTIONS(1153),
    [anon_sym_TILDE] = ACTIONS(1155),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1109),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1111),
    [aux_sym_concatenation_token1] = ACTIONS(1113),
    [anon_sym_DOLLAR] = ACTIONS(256),
    [sym__special_character] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1117),
    [sym_raw_string] = ACTIONS(1159),
    [sym_ansi_c_string] = ACTIONS(1159),
    [aux_sym_number_token1] = ACTIONS(262),
    [aux_sym_number_token2] = ACTIONS(264),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1121),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(268),
    [anon_sym_BQUOTE] = ACTIONS(270),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1123),
    [anon_sym_LT_LPAREN] = ACTIONS(1125),
    [anon_sym_GT_LPAREN] = ACTIONS(1125),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1113),
    [sym_test_operator] = ACTIONS(1161),
    [sym__brace_start] = ACTIONS(282),
  },
  [STATE(456)] = {
    [sym__expression] = STATE(2624),
    [sym_binary_expression] = STATE(2608),
    [sym_ternary_expression] = STATE(2608),
    [sym_unary_expression] = STATE(2608),
    [sym_postfix_expression] = STATE(2608),
    [sym_parenthesized_expression] = STATE(2608),
    [sym_arithmetic_expansion] = STATE(2403),
    [sym_brace_expression] = STATE(2403),
    [sym_concatenation] = STATE(2608),
    [sym_string] = STATE(2403),
    [sym_translated_string] = STATE(2403),
    [sym_number] = STATE(2403),
    [sym_simple_expansion] = STATE(2403),
    [sym_expansion] = STATE(2403),
    [sym_command_substitution] = STATE(2403),
    [sym_process_substitution] = STATE(2403),
    [aux_sym__literal_repeat1] = STATE(2407),
    [aux_sym_concatenation_repeat1] = STATE(2317),
    [sym_word] = ACTIONS(1071),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1073),
    [anon_sym_BANG] = ACTIONS(1075),
    [anon_sym_RBRACK] = ACTIONS(1163),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1079),
    [anon_sym_DASH_DASH2] = ACTIONS(1079),
    [anon_sym_DASH2] = ACTIONS(1081),
    [anon_sym_PLUS2] = ACTIONS(1081),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(1085),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(1089),
    [sym_ansi_c_string] = ACTIONS(1089),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1165),
    [sym_test_operator] = ACTIONS(1093),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(457)] = {
    [sym__expression] = STATE(2994),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(2309),
    [sym_brace_expression] = STATE(2309),
    [sym_concatenation] = STATE(2847),
    [sym_string] = STATE(2309),
    [sym_translated_string] = STATE(2309),
    [sym_number] = STATE(2309),
    [sym_simple_expansion] = STATE(2309),
    [sym_expansion] = STATE(2309),
    [sym_command_substitution] = STATE(2309),
    [sym_process_substitution] = STATE(2309),
    [aux_sym__literal_repeat1] = STATE(2549),
    [aux_sym_concatenation_repeat1] = STATE(2417),
    [sym_word] = ACTIONS(356),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(363),
    [anon_sym_BANG] = ACTIONS(365),
    [anon_sym_RBRACK] = ACTIONS(358),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(367),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(369),
    [aux_sym_concatenation_token1] = ACTIONS(1085),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym__special_character] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [sym_raw_string] = ACTIONS(379),
    [sym_ansi_c_string] = ACTIONS(379),
    [aux_sym_number_token1] = ACTIONS(381),
    [aux_sym_number_token2] = ACTIONS(383),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(385),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(387),
    [anon_sym_BQUOTE] = ACTIONS(389),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(391),
    [anon_sym_LT_LPAREN] = ACTIONS(393),
    [anon_sym_GT_LPAREN] = ACTIONS(393),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1085),
    [sym_test_operator] = ACTIONS(395),
    [sym__brace_start] = ACTIONS(397),
  },
  [STATE(458)] = {
    [sym__expression] = STATE(3258),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(2557),
    [sym_brace_expression] = STATE(2557),
    [sym_concatenation] = STATE(2518),
    [sym_string] = STATE(2557),
    [sym_translated_string] = STATE(2557),
    [sym_number] = STATE(2557),
    [sym_simple_expansion] = STATE(2557),
    [sym_expansion] = STATE(2557),
    [sym_command_substitution] = STATE(2557),
    [sym_process_substitution] = STATE(2557),
    [aux_sym__literal_repeat1] = STATE(2312),
    [aux_sym_concatenation_repeat1] = STATE(2528),
    [sym_word] = ACTIONS(1167),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(239),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(239),
    [anon_sym_GT] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(239),
    [anon_sym_GT_GT] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(1107),
    [anon_sym_BANG] = ACTIONS(1169),
    [anon_sym_EQ_TILDE] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_PLUS_PLUS2] = ACTIONS(1171),
    [anon_sym_DASH_DASH2] = ACTIONS(1171),
    [anon_sym_DASH2] = ACTIONS(1173),
    [anon_sym_PLUS2] = ACTIONS(1173),
    [anon_sym_TILDE] = ACTIONS(1175),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1109),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1111),
    [aux_sym_concatenation_token1] = ACTIONS(1113),
    [anon_sym_DOLLAR] = ACTIONS(256),
    [sym__special_character] = ACTIONS(1177),
    [anon_sym_DQUOTE] = ACTIONS(1117),
    [sym_raw_string] = ACTIONS(1179),
    [sym_ansi_c_string] = ACTIONS(1179),
    [aux_sym_number_token1] = ACTIONS(262),
    [aux_sym_number_token2] = ACTIONS(264),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1121),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(268),
    [anon_sym_BQUOTE] = ACTIONS(270),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1123),
    [anon_sym_LT_LPAREN] = ACTIONS(1125),
    [anon_sym_GT_LPAREN] = ACTIONS(1125),
    [sym_comment] = ACTIONS(71),
    [sym__concat] = ACTIONS(1113),
    [sym_test_operator] = ACTIONS(1181),
    [sym__brace_start] = ACTIONS(282),
  },
  [STATE(459)] = {
    [sym_string] = STATE(470),
    [sym_word] = ACTIONS(1183),
    [anon_sym_SEMI] = ACTIONS(1183),
    [anon_sym_EQ] = ACTIONS(1183),
    [anon_sym_PLUS_PLUS] = ACTIONS(1183),
    [anon_sym_DASH_DASH] = ACTIONS(1183),
    [anon_sym_PLUS_EQ] = ACTIONS(1183),
    [anon_sym_DASH_EQ] = ACTIONS(1183),
    [anon_sym_STAR_EQ] = ACTIONS(1183),
    [anon_sym_SLASH_EQ] = ACTIONS(1183),
    [anon_sym_PERCENT_EQ] = ACTIONS(1183),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1183),
    [anon_sym_LT_LT_EQ] = ACTIONS(1183),
    [anon_sym_GT_GT_EQ] = ACTIONS(1183),
    [anon_sym_AMP_EQ] = ACTIONS(1183),
    [anon_sym_CARET_EQ] = ACTIONS(1183),
    [anon_sym_PIPE_EQ] = ACTIONS(1183),
    [anon_sym_PIPE_PIPE] = ACTIONS(1183),
    [anon_sym_AMP_AMP] = ACTIONS(1183),
    [anon_sym_PIPE] = ACTIONS(1183),
    [anon_sym_CARET] = ACTIONS(1183),
    [anon_sym_AMP] = ACTIONS(1183),
    [anon_sym_EQ_EQ] = ACTIONS(1183),
    [anon_sym_BANG_EQ] = ACTIONS(1183),
    [anon_sym_LT] = ACTIONS(1183),
    [anon_sym_GT] = ACTIONS(1183),
    [anon_sym_LT_EQ] = ACTIONS(1183),
    [anon_sym_GT_EQ] = ACTIONS(1183),
    [anon_sym_LT_LT] = ACTIONS(1183),
    [anon_sym_GT_GT] = ACTIONS(1183),
    [anon_sym_PLUS] = ACTIONS(1183),
    [anon_sym_DASH] = ACTIONS(1185),
    [anon_sym_STAR] = ACTIONS(1185),
    [anon_sym_SLASH] = ACTIONS(1183),
    [anon_sym_PERCENT] = ACTIONS(1183),
    [anon_sym_STAR_STAR] = ACTIONS(1183),
    [anon_sym_LPAREN] = ACTIONS(1183),
    [anon_sym_RPAREN] = ACTIONS(1183),
    [anon_sym_SEMI_SEMI] = ACTIONS(1183),
    [anon_sym_PIPE_AMP] = ACTIONS(1183),
    [anon_sym_BANG] = ACTIONS(1185),
    [anon_sym_EQ_TILDE] = ACTIONS(1183),
    [anon_sym_AMP_GT] = ACTIONS(1183),
    [anon_sym_AMP_GT_GT] = ACTIONS(1183),
    [anon_sym_LT_AMP] = ACTIONS(1183),
    [anon_sym_GT_AMP] = ACTIONS(1183),
    [anon_sym_GT_PIPE] = ACTIONS(1183),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1183),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1183),
    [anon_sym_LT_LT_DASH] = ACTIONS(1183),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1183),
    [anon_sym_LT_LT_LT] = ACTIONS(1183),
    [anon_sym_QMARK] = ACTIONS(1185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1183),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1183),
    [anon_sym_DOLLAR] = ACTIONS(1185),
    [sym__special_character] = ACTIONS(1183),
    [anon_sym_DQUOTE] = ACTIONS(1187),
    [sym_raw_string] = ACTIONS(1183),
    [sym_ansi_c_string] = ACTIONS(1183),
    [aux_sym_number_token1] = ACTIONS(1183),
    [aux_sym_number_token2] = ACTIONS(1183),
    [anon_sym_POUND] = ACTIONS(1185),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1183),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1183),
    [anon_sym_BQUOTE] = ACTIONS(1183),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1183),
    [anon_sym_LT_LPAREN] = ACTIONS(1183),
    [anon_sym_GT_LPAREN] = ACTIONS(1183),
    [sym_comment] = ACTIONS(3),
    [aux_sym__simple_variable_name_token1] = ACTIONS(1189),
    [aux_sym__multiline_variable_name_token1] = ACTIONS(1189),
    [anon_sym_AT2] = ACTIONS(1185),
    [anon_sym__] = ACTIONS(1185),
    [sym_file_descriptor] = ACTIONS(1191),
    [sym_variable_name] = ACTIONS(1193),
    [sym_test_operator] = ACTIONS(1191),
    [sym__bare_dollar] = ACTIONS(1191),
    [sym__brace_start] = ACTIONS(1191),
  },
  [STATE(460)] = {
    [sym_string] = STATE(470),
    [sym_word] = ACTIONS(1195),
    [anon_sym_SEMI] = ACTIONS(1195),
    [anon_sym_EQ] = ACTIONS(1195),
    [anon_sym_PLUS_PLUS] = ACTIONS(1195),
    [anon_sym_DASH_DASH] = ACTIONS(1195),
    [anon_sym_PLUS_EQ] = ACTIONS(1195),
    [anon_sym_DASH_EQ] = ACTIONS(1195),
    [anon_sym_STAR_EQ] = ACTIONS(1195),
    [anon_sym_SLASH_EQ] = ACTIONS(1195),
    [anon_sym_PERCENT_EQ] = ACTIONS(1195),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1195),
    [anon_sym_LT_LT_EQ] = ACTIONS(1195),
    [anon_sym_GT_GT_EQ] = ACTIONS(1195),
    [anon_sym_AMP_EQ] = ACTIONS(1195),
    [anon_sym_CARET_EQ] = ACTIONS(1195),
    [anon_sym_PIPE_EQ] = ACTIONS(1195),
    [anon_sym_PIPE_PIPE] = ACTIONS(1195),
    [anon_sym_AMP_AMP] = ACTIONS(1195),
    [anon_sym_PIPE] = ACTIONS(1195),
    [anon_sym_CARET] = ACTIONS(1195),
    [anon_sym_AMP] = ACTIONS(1195),
    [anon_sym_EQ_EQ] = ACTIONS(1195),
    [anon_sym_BANG_EQ] = ACTIONS(1195),
    [anon_sym_LT] = ACTIONS(1195),
    [anon_sym_GT] = ACTIONS(1195),
    [anon_sym_LT_EQ] = ACTIONS(1195),
    [anon_sym_GT_EQ] = ACTIONS(1195),
    [anon_sym_LT_LT] = ACTIONS(1195),
    [anon_sym_GT_GT] = ACTIONS(1195),
    [anon_sym_PLUS] = ACTIONS(1195),
    [anon_sym_DASH] = ACTIONS(1185),
    [anon_sym_STAR] = ACTIONS(1185),
    [anon_sym_SLASH] = ACTIONS(1195),
    [anon_sym_PERCENT] = ACTIONS(1195),
    [anon_sym_STAR_STAR] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(1195),
    [anon_sym_RPAREN] = ACTIONS(1195),
    [anon_sym_SEMI_SEMI] = ACTIONS(1195),
    [anon_sym_PIPE_AMP] = ACTIONS(1195),
    [anon_sym_BANG] = ACTIONS(1185),
    [anon_sym_EQ_TILDE] = ACTIONS(1195),
    [anon_sym_AMP_GT] = ACTIONS(1195),
    [anon_sym_AMP_GT_GT] = ACTIONS(1195),
    [anon_sym_LT_AMP] = ACTIONS(1195),
    [anon_sym_GT_AMP] = ACTIONS(1195),
    [anon_sym_GT_PIPE] = ACTIONS(1195),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1195),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1195),
    [anon_sym_LT_LT_DASH] = ACTIONS(1195),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1195),
    [anon_sym_LT_LT_LT] = ACTIONS(1195),
    [anon_sym_QMARK] = ACTIONS(1185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1195),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1195),
    [anon_sym_DOLLAR] = ACTIONS(1185),
    [sym__special_character] = ACTIONS(1195),
    [anon_sym_DQUOTE] = ACTIONS(1187),
    [sym_raw_string] = ACTIONS(1195),
    [sym_ansi_c_string] = ACTIONS(1195),
    [aux_sym_number_token1] = ACTIONS(1195),
    [aux_sym_number_token2] = ACTIONS(1195),
    [anon_sym_POUND] = ACTIONS(1185),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1195),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1195),
    [anon_sym_BQUOTE] = ACTIONS(1195),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1195),
    [anon_sym_LT_LPAREN] = ACTIONS(1195),
    [anon_sym_GT_LPAREN] = ACTIONS(1195),
    [sym_comment] = ACTIONS(3),
    [aux_sym__simple_variable_name_token1] = ACTIONS(1189),
    [aux_sym__multiline_variable_name_token1] = ACTIONS(1189),
    [anon_sym_AT2] = ACTIONS(1185),
    [anon_sym__] = ACTIONS(1185),
    [sym_file_descriptor] = ACTIONS(1197),
    [sym_variable_name] = ACTIONS(1193),
    [sym_test_operator] = ACTIONS(1197),
    [sym__bare_dollar] = ACTIONS(1197),
    [sym__brace_start] = ACTIONS(1197),
  },
  [STATE(461)] = {
    [sym_string] = STATE(516),
    [sym_word] = ACTIONS(1183),
    [anon_sym_EQ] = ACTIONS(1183),
    [anon_sym_PLUS_PLUS] = ACTIONS(1183),
    [anon_sym_DASH_DASH] = ACTIONS(1183),
    [anon_sym_PLUS_EQ] = ACTIONS(1183),
    [anon_sym_DASH_EQ] = ACTIONS(1183),
    [anon_sym_STAR_EQ] = ACTIONS(1183),
    [anon_sym_SLASH_EQ] = ACTIONS(1183),
    [anon_sym_PERCENT_EQ] = ACTIONS(1183),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1183),
    [anon_sym_LT_LT_EQ] = ACTIONS(1183),
    [anon_sym_GT_GT_EQ] = ACTIONS(1183),
    [anon_sym_AMP_EQ] = ACTIONS(1183),
    [anon_sym_CARET_EQ] = ACTIONS(1183),
    [anon_sym_PIPE_EQ] = ACTIONS(1183),
    [anon_sym_PIPE_PIPE] = ACTIONS(1183),
    [anon_sym_AMP_AMP] = ACTIONS(1183),
    [anon_sym_PIPE] = ACTIONS(1183),
    [anon_sym_CARET] = ACTIONS(1183),
    [anon_sym_AMP] = ACTIONS(1183),
    [anon_sym_EQ_EQ] = ACTIONS(1183),
    [anon_sym_BANG_EQ] = ACTIONS(1183),
    [anon_sym_LT] = ACTIONS(1183),
    [anon_sym_GT] = ACTIONS(1183),
    [anon_sym_LT_EQ] = ACTIONS(1183),
    [anon_sym_GT_EQ] = ACTIONS(1183),
    [anon_sym_LT_LT] = ACTIONS(1183),
    [anon_sym_GT_GT] = ACTIONS(1183),
    [anon_sym_PLUS] = ACTIONS(1183),
    [anon_sym_DASH] = ACTIONS(1199),
    [anon_sym_STAR] = ACTIONS(1199),
    [anon_sym_SLASH] = ACTIONS(1183),
    [anon_sym_PERCENT] = ACTIONS(1183),
    [anon_sym_STAR_STAR] = ACTIONS(1183),
    [anon_sym_LPAREN] = ACTIONS(1183),
    [anon_sym_PIPE_AMP] = ACTIONS(1183),
    [anon_sym_BANG] = ACTIONS(1199),
    [anon_sym_RBRACK] = ACTIONS(1183),
    [anon_sym_EQ_TILDE] = ACTIONS(1183),
    [anon_sym_AMP_GT] = ACTIONS(1183),
    [anon_sym_AMP_GT_GT] = ACTIONS(1183),
    [anon_sym_LT_AMP] = ACTIONS(1183),
    [anon_sym_GT_AMP] = ACTIONS(1183),
    [anon_sym_GT_PIPE] = ACTIONS(1183),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1183),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1183),
    [anon_sym_LT_LT_DASH] = ACTIONS(1183),
    [anon_sym_LT_LT_LT] = ACTIONS(1183),
    [anon_sym_QMARK] = ACTIONS(1199),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1183),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1183),
    [anon_sym_DOLLAR] = ACTIONS(1199),
    [sym__special_character] = ACTIONS(1183),
    [anon_sym_DQUOTE] = ACTIONS(1201),
    [sym_raw_string] = ACTIONS(1183),
    [sym_ansi_c_string] = ACTIONS(1183),
    [aux_sym_number_token1] = ACTIONS(1183),
    [aux_sym_number_token2] = ACTIONS(1183),
    [anon_sym_POUND] = ACTIONS(1199),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1183),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1183),
    [anon_sym_BQUOTE] = ACTIONS(1183),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1183),
    [anon_sym_LT_LPAREN] = ACTIONS(1183),
    [anon_sym_GT_LPAREN] = ACTIONS(1183),
    [sym_comment] = ACTIONS(3),
    [aux_sym__simple_variable_name_token1] = ACTIONS(1203),
    [aux_sym__multiline_variable_name_token1] = ACTIONS(1203),
    [anon_sym_AT2] = ACTIONS(1199),
    [anon_sym__] = ACTIONS(1199),
    [sym_file_descriptor] = ACTIONS(1191),
    [sym_variable_name] = ACTIONS(1205),
    [sym_test_operator] = ACTIONS(1191),
    [sym__bare_dollar] = ACTIONS(1191),
    [sym__brace_start] = ACTIONS(1191),
  },
  [STATE(462)] = {
    [sym_string] = STATE(516),
    [sym_word] = ACTIONS(1195),
    [anon_sym_EQ] = ACTIONS(1195),
    [anon_sym_PLUS_PLUS] = ACTIONS(1195),
    [anon_sym_DASH_DASH] = ACTIONS(1195),
    [anon_sym_PLUS_EQ] = ACTIONS(1195),
    [anon_sym_DASH_EQ] = ACTIONS(1195),
    [anon_sym_STAR_EQ] = ACTIONS(1195),
    [anon_sym_SLASH_EQ] = ACTIONS(1195),
    [anon_sym_PERCENT_EQ] = ACTIONS(1195),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1195),
    [anon_sym_LT_LT_EQ] = ACTIONS(1195),
    [anon_sym_GT_GT_EQ] = ACTIONS(1195),
    [anon_sym_AMP_EQ] = ACTIONS(1195),
    [anon_sym_CARET_EQ] = ACTIONS(1195),
    [anon_sym_PIPE_EQ] = ACTIONS(1195),
    [anon_sym_PIPE_PIPE] = ACTIONS(1195),
    [anon_sym_AMP_AMP] = ACTIONS(1195),
    [anon_sym_PIPE] = ACTIONS(1195),
    [anon_sym_CARET] = ACTIONS(1195),
    [anon_sym_AMP] = ACTIONS(1195),
    [anon_sym_EQ_EQ] = ACTIONS(1195),
    [anon_sym_BANG_EQ] = ACTIONS(1195),
    [anon_sym_LT] = ACTIONS(1195),
    [anon_sym_GT] = ACTIONS(1195),
    [anon_sym_LT_EQ] = ACTIONS(1195),
    [anon_sym_GT_EQ] = ACTIONS(1195),
    [anon_sym_LT_LT] = ACTIONS(1195),
    [anon_sym_GT_GT] = ACTIONS(1195),
    [anon_sym_PLUS] = ACTIONS(1195),
    [anon_sym_DASH] = ACTIONS(1199),
    [anon_sym_STAR] = ACTIONS(1199),
    [anon_sym_SLASH] = ACTIONS(1195),
    [anon_sym_PERCENT] = ACTIONS(1195),
    [anon_sym_STAR_STAR] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(1195),
    [anon_sym_PIPE_AMP] = ACTIONS(1195),
    [anon_sym_BANG] = ACTIONS(1199),
    [anon_sym_RBRACK] = ACTIONS(1195),
    [anon_sym_EQ_TILDE] = ACTIONS(1195),
    [anon_sym_AMP_GT] = ACTIONS(1195),
    [anon_sym_AMP_GT_GT] = ACTIONS(1195),
    [anon_sym_LT_AMP] = ACTIONS(1195),
    [anon_sym_GT_AMP] = ACTIONS(1195),
    [anon_sym_GT_PIPE] = ACTIONS(1195),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1195),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1195),
    [anon_sym_LT_LT_DASH] = ACTIONS(1195),
    [anon_sym_LT_LT_LT] = ACTIONS(1195),
    [anon_sym_QMARK] = ACTIONS(1199),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1195),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1195),
    [anon_sym_DOLLAR] = ACTIONS(1199),
    [sym__special_character] = ACTIONS(1195),
    [anon_sym_DQUOTE] = ACTIONS(1201),
    [sym_raw_string] = ACTIONS(1195),
    [sym_ansi_c_string] = ACTIONS(1195),
    [aux_sym_number_token1] = ACTIONS(1195),
    [aux_sym_number_token2] = ACTIONS(1195),
    [anon_sym_POUND] = ACTIONS(1199),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1195),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1195),
    [anon_sym_BQUOTE] = ACTIONS(1195),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1195),
    [anon_sym_LT_LPAREN] = ACTIONS(1195),
    [anon_sym_GT_LPAREN] = ACTIONS(1195),
    [sym_comment] = ACTIONS(3),
    [aux_sym__simple_variable_name_token1] = ACTIONS(1203),
    [aux_sym__multiline_variable_name_token1] = ACTIONS(1203),
    [anon_sym_AT2] = ACTIONS(1199),
    [anon_sym__] = ACTIONS(1199),
    [sym_file_descriptor] = ACTIONS(1197),
    [sym_variable_name] = ACTIONS(1205),
    [sym_test_operator] = ACTIONS(1197),
    [sym__bare_dollar] = ACTIONS(1197),
    [sym__brace_start] = ACTIONS(1197),
  },
  [STATE(463)] = {
    [aux_sym_concatenation_repeat1] = STATE(464),
    [sym_word] = ACTIONS(1207),
    [anon_sym_SEMI] = ACTIONS(1207),
    [anon_sym_EQ] = ACTIONS(1207),
    [anon_sym_PLUS_PLUS] = ACTIONS(1207),
    [anon_sym_DASH_DASH] = ACTIONS(1207),
    [anon_sym_PLUS_EQ] = ACTIONS(1207),
    [anon_sym_DASH_EQ] = ACTIONS(1207),
    [anon_sym_STAR_EQ] = ACTIONS(1207),
    [anon_sym_SLASH_EQ] = ACTIONS(1207),
    [anon_sym_PERCENT_EQ] = ACTIONS(1207),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1207),
    [anon_sym_LT_LT_EQ] = ACTIONS(1207),
    [anon_sym_GT_GT_EQ] = ACTIONS(1207),
    [anon_sym_AMP_EQ] = ACTIONS(1207),
    [anon_sym_CARET_EQ] = ACTIONS(1207),
    [anon_sym_PIPE_EQ] = ACTIONS(1207),
    [anon_sym_PIPE_PIPE] = ACTIONS(1207),
    [anon_sym_AMP_AMP] = ACTIONS(1207),
    [anon_sym_PIPE] = ACTIONS(1207),
    [anon_sym_CARET] = ACTIONS(1207),
    [anon_sym_AMP] = ACTIONS(1207),
    [anon_sym_EQ_EQ] = ACTIONS(1207),
    [anon_sym_BANG_EQ] = ACTIONS(1207),
    [anon_sym_LT] = ACTIONS(1207),
    [anon_sym_GT] = ACTIONS(1207),
    [anon_sym_LT_EQ] = ACTIONS(1207),
    [anon_sym_GT_EQ] = ACTIONS(1207),
    [anon_sym_LT_LT] = ACTIONS(1207),
    [anon_sym_GT_GT] = ACTIONS(1207),
    [anon_sym_PLUS] = ACTIONS(1207),
    [anon_sym_DASH] = ACTIONS(1207),
    [anon_sym_STAR] = ACTIONS(1207),
    [anon_sym_SLASH] = ACTIONS(1207),
    [anon_sym_PERCENT] = ACTIONS(1207),
    [anon_sym_STAR_STAR] = ACTIONS(1207),
    [anon_sym_LPAREN] = ACTIONS(1207),
    [anon_sym_RPAREN] = ACTIONS(1207),
    [anon_sym_SEMI_SEMI] = ACTIONS(1207),
    [anon_sym_PIPE_AMP] = ACTIONS(1207),
    [anon_sym_EQ_TILDE] = ACTIONS(1207),
    [anon_sym_AMP_GT] = ACTIONS(1207),
    [anon_sym_AMP_GT_GT] = ACTIONS(1207),
    [anon_sym_LT_AMP] = ACTIONS(1207),
    [anon_sym_GT_AMP] = ACTIONS(1207),
    [anon_sym_GT_PIPE] = ACTIONS(1207),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1207),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1207),
    [anon_sym_LT_LT_DASH] = ACTIONS(1207),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1209),
    [anon_sym_LT_LT_LT] = ACTIONS(1207),
    [anon_sym_QMARK] = ACTIONS(1207),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1207),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1207),
    [aux_sym_concatenation_token1] = ACTIONS(254),
    [anon_sym_DOLLAR] = ACTIONS(1207),
    [sym__special_character] = ACTIONS(1207),
    [anon_sym_DQUOTE] = ACTIONS(1207),
    [sym_raw_string] = ACTIONS(1207),
    [sym_ansi_c_string] = ACTIONS(1207),
    [aux_sym_number_token1] = ACTIONS(1207),
    [aux_sym_number_token2] = ACTIONS(1207),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1207),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1207),
    [anon_sym_BQUOTE] = ACTIONS(1207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1207),
    [anon_sym_LT_LPAREN] = ACTIONS(1207),
    [anon_sym_GT_LPAREN] = ACTIONS(1207),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1209),
    [sym__concat] = ACTIONS(1211),
    [sym_test_operator] = ACTIONS(1209),
    [sym__bare_dollar] = ACTIONS(1209),
    [sym__brace_start] = ACTIONS(1209),
  },
  [STATE(464)] = {
    [aux_sym_concatenation_repeat1] = STATE(464),
    [sym_word] = ACTIONS(1213),
    [anon_sym_SEMI] = ACTIONS(1213),
    [anon_sym_EQ] = ACTIONS(1213),
    [anon_sym_PLUS_PLUS] = ACTIONS(1213),
    [anon_sym_DASH_DASH] = ACTIONS(1213),
    [anon_sym_PLUS_EQ] = ACTIONS(1213),
    [anon_sym_DASH_EQ] = ACTIONS(1213),
    [anon_sym_STAR_EQ] = ACTIONS(1213),
    [anon_sym_SLASH_EQ] = ACTIONS(1213),
    [anon_sym_PERCENT_EQ] = ACTIONS(1213),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1213),
    [anon_sym_LT_LT_EQ] = ACTIONS(1213),
    [anon_sym_GT_GT_EQ] = ACTIONS(1213),
    [anon_sym_AMP_EQ] = ACTIONS(1213),
    [anon_sym_CARET_EQ] = ACTIONS(1213),
    [anon_sym_PIPE_EQ] = ACTIONS(1213),
    [anon_sym_PIPE_PIPE] = ACTIONS(1213),
    [anon_sym_AMP_AMP] = ACTIONS(1213),
    [anon_sym_PIPE] = ACTIONS(1213),
    [anon_sym_CARET] = ACTIONS(1213),
    [anon_sym_AMP] = ACTIONS(1213),
    [anon_sym_EQ_EQ] = ACTIONS(1213),
    [anon_sym_BANG_EQ] = ACTIONS(1213),
    [anon_sym_LT] = ACTIONS(1213),
    [anon_sym_GT] = ACTIONS(1213),
    [anon_sym_LT_EQ] = ACTIONS(1213),
    [anon_sym_GT_EQ] = ACTIONS(1213),
    [anon_sym_LT_LT] = ACTIONS(1213),
    [anon_sym_GT_GT] = ACTIONS(1213),
    [anon_sym_PLUS] = ACTIONS(1213),
    [anon_sym_DASH] = ACTIONS(1213),
    [anon_sym_STAR] = ACTIONS(1213),
    [anon_sym_SLASH] = ACTIONS(1213),
    [anon_sym_PERCENT] = ACTIONS(1213),
    [anon_sym_STAR_STAR] = ACTIONS(1213),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_RPAREN] = ACTIONS(1213),
    [anon_sym_SEMI_SEMI] = ACTIONS(1213),
    [anon_sym_PIPE_AMP] = ACTIONS(1213),
    [anon_sym_EQ_TILDE] = ACTIONS(1213),
    [anon_sym_AMP_GT] = ACTIONS(1213),
    [anon_sym_AMP_GT_GT] = ACTIONS(1213),
    [anon_sym_LT_AMP] = ACTIONS(1213),
    [anon_sym_GT_AMP] = ACTIONS(1213),
    [anon_sym_GT_PIPE] = ACTIONS(1213),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1213),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1213),
    [anon_sym_LT_LT_DASH] = ACTIONS(1213),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1215),
    [anon_sym_LT_LT_LT] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1213),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1213),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1213),
    [aux_sym_concatenation_token1] = ACTIONS(1217),
    [anon_sym_DOLLAR] = ACTIONS(1213),
    [sym__special_character] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_raw_string] = ACTIONS(1213),
    [sym_ansi_c_string] = ACTIONS(1213),
    [aux_sym_number_token1] = ACTIONS(1213),
    [aux_sym_number_token2] = ACTIONS(1213),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1213),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1213),
    [anon_sym_BQUOTE] = ACTIONS(1213),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1213),
    [anon_sym_LT_LPAREN] = ACTIONS(1213),
    [anon_sym_GT_LPAREN] = ACTIONS(1213),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1215),
    [sym__concat] = ACTIONS(1220),
    [sym_test_operator] = ACTIONS(1215),
    [sym__bare_dollar] = ACTIONS(1215),
    [sym__brace_start] = ACTIONS(1215),
  },
  [STATE(465)] = {
    [aux_sym_concatenation_repeat1] = STATE(466),
    [sym_word] = ACTIONS(1223),
    [anon_sym_SEMI] = ACTIONS(1223),
    [anon_sym_EQ] = ACTIONS(1223),
    [anon_sym_PLUS_PLUS] = ACTIONS(1223),
    [anon_sym_DASH_DASH] = ACTIONS(1223),
    [anon_sym_PLUS_EQ] = ACTIONS(1223),
    [anon_sym_DASH_EQ] = ACTIONS(1223),
    [anon_sym_STAR_EQ] = ACTIONS(1223),
    [anon_sym_SLASH_EQ] = ACTIONS(1223),
    [anon_sym_PERCENT_EQ] = ACTIONS(1223),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1223),
    [anon_sym_LT_LT_EQ] = ACTIONS(1223),
    [anon_sym_GT_GT_EQ] = ACTIONS(1223),
    [anon_sym_AMP_EQ] = ACTIONS(1223),
    [anon_sym_CARET_EQ] = ACTIONS(1223),
    [anon_sym_PIPE_EQ] = ACTIONS(1223),
    [anon_sym_PIPE_PIPE] = ACTIONS(1223),
    [anon_sym_AMP_AMP] = ACTIONS(1223),
    [anon_sym_PIPE] = ACTIONS(1223),
    [anon_sym_CARET] = ACTIONS(1223),
    [anon_sym_AMP] = ACTIONS(1223),
    [anon_sym_EQ_EQ] = ACTIONS(1223),
    [anon_sym_BANG_EQ] = ACTIONS(1223),
    [anon_sym_LT] = ACTIONS(1223),
    [anon_sym_GT] = ACTIONS(1223),
    [anon_sym_LT_EQ] = ACTIONS(1223),
    [anon_sym_GT_EQ] = ACTIONS(1223),
    [anon_sym_LT_LT] = ACTIONS(1223),
    [anon_sym_GT_GT] = ACTIONS(1223),
    [anon_sym_PLUS] = ACTIONS(1223),
    [anon_sym_DASH] = ACTIONS(1223),
    [anon_sym_STAR] = ACTIONS(1223),
    [anon_sym_SLASH] = ACTIONS(1223),
    [anon_sym_PERCENT] = ACTIONS(1223),
    [anon_sym_STAR_STAR] = ACTIONS(1223),
    [anon_sym_LPAREN] = ACTIONS(1223),
    [anon_sym_RPAREN] = ACTIONS(1223),
    [anon_sym_SEMI_SEMI] = ACTIONS(1223),
    [anon_sym_PIPE_AMP] = ACTIONS(1223),
    [anon_sym_EQ_TILDE] = ACTIONS(1223),
    [anon_sym_AMP_GT] = ACTIONS(1223),
    [anon_sym_AMP_GT_GT] = ACTIONS(1223),
    [anon_sym_LT_AMP] = ACTIONS(1223),
    [anon_sym_GT_AMP] = ACTIONS(1223),
    [anon_sym_GT_PIPE] = ACTIONS(1223),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1223),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1223),
    [anon_sym_LT_LT_DASH] = ACTIONS(1223),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1225),
    [anon_sym_LT_LT_LT] = ACTIONS(1223),
    [anon_sym_QMARK] = ACTIONS(1223),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1223),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1223),
    [aux_sym_concatenation_token1] = ACTIONS(254),
    [anon_sym_DOLLAR] = ACTIONS(1223),
    [sym__special_character] = ACTIONS(1223),
    [anon_sym_DQUOTE] = ACTIONS(1223),
    [sym_raw_string] = ACTIONS(1223),
    [sym_ansi_c_string] = ACTIONS(1223),
    [aux_sym_number_token1] = ACTIONS(1223),
    [aux_sym_number_token2] = ACTIONS(1223),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1223),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1223),
    [anon_sym_BQUOTE] = ACTIONS(1223),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1223),
    [anon_sym_LT_LPAREN] = ACTIONS(1223),
    [anon_sym_GT_LPAREN] = ACTIONS(1223),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1225),
    [sym__concat] = ACTIONS(278),
    [sym_test_operator] = ACTIONS(1225),
    [sym__bare_dollar] = ACTIONS(1225),
    [sym__brace_start] = ACTIONS(1225),
  },
  [STATE(466)] = {
    [aux_sym_concatenation_repeat1] = STATE(464),
    [sym_word] = ACTIONS(1227),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_EQ] = ACTIONS(1227),
    [anon_sym_PLUS_PLUS] = ACTIONS(1227),
    [anon_sym_DASH_DASH] = ACTIONS(1227),
    [anon_sym_PLUS_EQ] = ACTIONS(1227),
    [anon_sym_DASH_EQ] = ACTIONS(1227),
    [anon_sym_STAR_EQ] = ACTIONS(1227),
    [anon_sym_SLASH_EQ] = ACTIONS(1227),
    [anon_sym_PERCENT_EQ] = ACTIONS(1227),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1227),
    [anon_sym_LT_LT_EQ] = ACTIONS(1227),
    [anon_sym_GT_GT_EQ] = ACTIONS(1227),
    [anon_sym_AMP_EQ] = ACTIONS(1227),
    [anon_sym_CARET_EQ] = ACTIONS(1227),
    [anon_sym_PIPE_EQ] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1227),
    [anon_sym_AMP] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_LT] = ACTIONS(1227),
    [anon_sym_GT] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1227),
    [anon_sym_PLUS] = ACTIONS(1227),
    [anon_sym_DASH] = ACTIONS(1227),
    [anon_sym_STAR] = ACTIONS(1227),
    [anon_sym_SLASH] = ACTIONS(1227),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_STAR_STAR] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_SEMI_SEMI] = ACTIONS(1227),
    [anon_sym_PIPE_AMP] = ACTIONS(1227),
    [anon_sym_EQ_TILDE] = ACTIONS(1227),
    [anon_sym_AMP_GT] = ACTIONS(1227),
    [anon_sym_AMP_GT_GT] = ACTIONS(1227),
    [anon_sym_LT_AMP] = ACTIONS(1227),
    [anon_sym_GT_AMP] = ACTIONS(1227),
    [anon_sym_GT_PIPE] = ACTIONS(1227),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1227),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1227),
    [anon_sym_LT_LT_DASH] = ACTIONS(1227),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1229),
    [anon_sym_LT_LT_LT] = ACTIONS(1227),
    [anon_sym_QMARK] = ACTIONS(1227),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1227),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1227),
    [aux_sym_concatenation_token1] = ACTIONS(254),
    [anon_sym_DOLLAR] = ACTIONS(1227),
    [sym__special_character] = ACTIONS(1227),
    [anon_sym_DQUOTE] = ACTIONS(1227),
    [sym_raw_string] = ACTIONS(1227),
    [sym_ansi_c_string] = ACTIONS(1227),
    [aux_sym_number_token1] = ACTIONS(1227),
    [aux_sym_number_token2] = ACTIONS(1227),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1227),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1227),
    [anon_sym_BQUOTE] = ACTIONS(1227),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1227),
    [anon_sym_LT_LPAREN] = ACTIONS(1227),
    [anon_sym_GT_LPAREN] = ACTIONS(1227),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1229),
    [sym__concat] = ACTIONS(1231),
    [sym_test_operator] = ACTIONS(1229),
    [sym__bare_dollar] = ACTIONS(1229),
    [sym__brace_start] = ACTIONS(1229),
  },
  [STATE(467)] = {
    [aux_sym_concatenation_repeat1] = STATE(463),
    [sym_word] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(1233),
    [anon_sym_EQ] = ACTIONS(1235),
    [anon_sym_PLUS_PLUS] = ACTIONS(1235),
    [anon_sym_DASH_DASH] = ACTIONS(1235),
    [anon_sym_PLUS_EQ] = ACTIONS(1235),
    [anon_sym_DASH_EQ] = ACTIONS(1235),
    [anon_sym_STAR_EQ] = ACTIONS(1235),
    [anon_sym_SLASH_EQ] = ACTIONS(1235),
    [anon_sym_PERCENT_EQ] = ACTIONS(1235),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT_EQ] = ACTIONS(1235),
    [anon_sym_GT_GT_EQ] = ACTIONS(1235),
    [anon_sym_AMP_EQ] = ACTIONS(1235),
    [anon_sym_CARET_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_PIPE] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1237),
    [anon_sym_PIPE] = ACTIONS(1237),
    [anon_sym_CARET] = ACTIONS(1235),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_EQ_EQ] = ACTIONS(1237),
    [anon_sym_BANG_EQ] = ACTIONS(1235),
    [anon_sym_LT] = ACTIONS(1237),
    [anon_sym_GT] = ACTIONS(1237),
    [anon_sym_LT_EQ] = ACTIONS(1235),
    [anon_sym_GT_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT] = ACTIONS(1237),
    [anon_sym_GT_GT] = ACTIONS(1237),
    [anon_sym_PLUS] = ACTIONS(1235),
    [anon_sym_DASH] = ACTIONS(1235),
    [anon_sym_STAR] = ACTIONS(1235),
    [anon_sym_SLASH] = ACTIONS(1235),
    [anon_sym_PERCENT] = ACTIONS(1235),
    [anon_sym_STAR_STAR] = ACTIONS(1235),
    [anon_sym_LPAREN] = ACTIONS(1233),
    [anon_sym_RPAREN] = ACTIONS(1237),
    [anon_sym_SEMI_SEMI] = ACTIONS(1233),
    [anon_sym_PIPE_AMP] = ACTIONS(1233),
    [anon_sym_EQ_TILDE] = ACTIONS(1237),
    [anon_sym_AMP_GT] = ACTIONS(1233),
    [anon_sym_AMP_GT_GT] = ACTIONS(1233),
    [anon_sym_LT_AMP] = ACTIONS(1233),
    [anon_sym_GT_AMP] = ACTIONS(1233),
    [anon_sym_GT_PIPE] = ACTIONS(1233),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1233),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1233),
    [anon_sym_LT_LT_DASH] = ACTIONS(1233),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1240),
    [anon_sym_LT_LT_LT] = ACTIONS(1233),
    [anon_sym_QMARK] = ACTIONS(1235),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1233),
    [aux_sym_concatenation_token1] = ACTIONS(254),
    [anon_sym_DOLLAR] = ACTIONS(1233),
    [sym__special_character] = ACTIONS(1233),
    [anon_sym_DQUOTE] = ACTIONS(1233),
    [sym_raw_string] = ACTIONS(1233),
    [sym_ansi_c_string] = ACTIONS(1233),
    [aux_sym_number_token1] = ACTIONS(1233),
    [aux_sym_number_token2] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1233),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1233),
    [anon_sym_BQUOTE] = ACTIONS(1233),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1233),
    [anon_sym_LT_LPAREN] = ACTIONS(1233),
    [anon_sym_GT_LPAREN] = ACTIONS(1233),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1240),
    [sym__concat] = ACTIONS(278),
    [sym_test_operator] = ACTIONS(1242),
    [sym__bare_dollar] = ACTIONS(1240),
    [sym__brace_start] = ACTIONS(1240),
  },
  [STATE(468)] = {
    [aux_sym_concatenation_repeat1] = STATE(463),
    [sym_word] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(1233),
    [anon_sym_EQ] = ACTIONS(1235),
    [anon_sym_PLUS_PLUS] = ACTIONS(1235),
    [anon_sym_DASH_DASH] = ACTIONS(1235),
    [anon_sym_PLUS_EQ] = ACTIONS(1235),
    [anon_sym_DASH_EQ] = ACTIONS(1235),
    [anon_sym_STAR_EQ] = ACTIONS(1235),
    [anon_sym_SLASH_EQ] = ACTIONS(1235),
    [anon_sym_PERCENT_EQ] = ACTIONS(1235),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT_EQ] = ACTIONS(1235),
    [anon_sym_GT_GT_EQ] = ACTIONS(1235),
    [anon_sym_AMP_EQ] = ACTIONS(1235),
    [anon_sym_CARET_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_PIPE] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1237),
    [anon_sym_PIPE] = ACTIONS(1237),
    [anon_sym_CARET] = ACTIONS(1235),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_EQ_EQ] = ACTIONS(1237),
    [anon_sym_BANG_EQ] = ACTIONS(1235),
    [anon_sym_LT] = ACTIONS(1237),
    [anon_sym_GT] = ACTIONS(1237),
    [anon_sym_LT_EQ] = ACTIONS(1235),
    [anon_sym_GT_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT] = ACTIONS(1237),
    [anon_sym_GT_GT] = ACTIONS(1237),
    [anon_sym_PLUS] = ACTIONS(1235),
    [anon_sym_DASH] = ACTIONS(1235),
    [anon_sym_STAR] = ACTIONS(1235),
    [anon_sym_SLASH] = ACTIONS(1235),
    [anon_sym_PERCENT] = ACTIONS(1235),
    [anon_sym_STAR_STAR] = ACTIONS(1235),
    [anon_sym_LPAREN] = ACTIONS(1245),
    [anon_sym_RPAREN] = ACTIONS(1237),
    [anon_sym_SEMI_SEMI] = ACTIONS(1233),
    [anon_sym_PIPE_AMP] = ACTIONS(1233),
    [anon_sym_EQ_TILDE] = ACTIONS(1237),
    [anon_sym_AMP_GT] = ACTIONS(1233),
    [anon_sym_AMP_GT_GT] = ACTIONS(1233),
    [anon_sym_LT_AMP] = ACTIONS(1233),
    [anon_sym_GT_AMP] = ACTIONS(1233),
    [anon_sym_GT_PIPE] = ACTIONS(1233),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1233),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1233),
    [anon_sym_LT_LT_DASH] = ACTIONS(1233),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1240),
    [anon_sym_LT_LT_LT] = ACTIONS(1233),
    [anon_sym_QMARK] = ACTIONS(1235),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1233),
    [aux_sym_concatenation_token1] = ACTIONS(254),
    [anon_sym_DOLLAR] = ACTIONS(1233),
    [sym__special_character] = ACTIONS(1233),
    [anon_sym_DQUOTE] = ACTIONS(1233),
    [sym_raw_string] = ACTIONS(1233),
    [sym_ansi_c_string] = ACTIONS(1233),
    [aux_sym_number_token1] = ACTIONS(1233),
    [aux_sym_number_token2] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1233),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1233),
    [anon_sym_BQUOTE] = ACTIONS(1233),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1233),
    [anon_sym_LT_LPAREN] = ACTIONS(1233),
    [anon_sym_GT_LPAREN] = ACTIONS(1233),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1240),
    [sym__concat] = ACTIONS(278),
    [sym_test_operator] = ACTIONS(1242),
    [sym__bare_dollar] = ACTIONS(1240),
    [sym__brace_start] = ACTIONS(1240),
  },
  [STATE(469)] = {
    [sym_word] = ACTIONS(1248),
    [anon_sym_SEMI] = ACTIONS(1248),
    [anon_sym_EQ] = ACTIONS(1248),
    [anon_sym_PLUS_PLUS] = ACTIONS(1248),
    [anon_sym_DASH_DASH] = ACTIONS(1248),
    [anon_sym_PLUS_EQ] = ACTIONS(1248),
    [anon_sym_DASH_EQ] = ACTIONS(1248),
    [anon_sym_STAR_EQ] = ACTIONS(1248),
    [anon_sym_SLASH_EQ] = ACTIONS(1248),
    [anon_sym_PERCENT_EQ] = ACTIONS(1248),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1248),
    [anon_sym_LT_LT_EQ] = ACTIONS(1248),
    [anon_sym_GT_GT_EQ] = ACTIONS(1248),
    [anon_sym_AMP_EQ] = ACTIONS(1248),
    [anon_sym_CARET_EQ] = ACTIONS(1248),
    [anon_sym_PIPE_EQ] = ACTIONS(1248),
    [anon_sym_PIPE_PIPE] = ACTIONS(1248),
    [anon_sym_AMP_AMP] = ACTIONS(1248),
    [anon_sym_PIPE] = ACTIONS(1248),
    [anon_sym_CARET] = ACTIONS(1248),
    [anon_sym_AMP] = ACTIONS(1248),
    [anon_sym_EQ_EQ] = ACTIONS(1248),
    [anon_sym_BANG_EQ] = ACTIONS(1248),
    [anon_sym_LT] = ACTIONS(1248),
    [anon_sym_GT] = ACTIONS(1248),
    [anon_sym_LT_EQ] = ACTIONS(1248),
    [anon_sym_GT_EQ] = ACTIONS(1248),
    [anon_sym_LT_LT] = ACTIONS(1248),
    [anon_sym_GT_GT] = ACTIONS(1248),
    [anon_sym_PLUS] = ACTIONS(1248),
    [anon_sym_DASH] = ACTIONS(1248),
    [anon_sym_STAR] = ACTIONS(1248),
    [anon_sym_SLASH] = ACTIONS(1248),
    [anon_sym_PERCENT] = ACTIONS(1248),
    [anon_sym_STAR_STAR] = ACTIONS(1248),
    [anon_sym_LPAREN] = ACTIONS(1248),
    [anon_sym_RPAREN] = ACTIONS(1248),
    [anon_sym_SEMI_SEMI] = ACTIONS(1248),
    [anon_sym_PIPE_AMP] = ACTIONS(1248),
    [anon_sym_EQ_TILDE] = ACTIONS(1248),
    [anon_sym_AMP_GT] = ACTIONS(1248),
    [anon_sym_AMP_GT_GT] = ACTIONS(1248),
    [anon_sym_LT_AMP] = ACTIONS(1248),
    [anon_sym_GT_AMP] = ACTIONS(1248),
    [anon_sym_GT_PIPE] = ACTIONS(1248),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1248),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1248),
    [anon_sym_LT_LT_DASH] = ACTIONS(1248),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1250),
    [anon_sym_LT_LT_LT] = ACTIONS(1248),
    [anon_sym_QMARK] = ACTIONS(1248),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1248),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1248),
    [aux_sym_concatenation_token1] = ACTIONS(1248),
    [anon_sym_DOLLAR] = ACTIONS(1248),
    [sym__special_character] = ACTIONS(1248),
    [anon_sym_DQUOTE] = ACTIONS(1248),
    [sym_raw_string] = ACTIONS(1248),
    [sym_ansi_c_string] = ACTIONS(1248),
    [aux_sym_number_token1] = ACTIONS(1248),
    [aux_sym_number_token2] = ACTIONS(1248),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1248),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1248),
    [anon_sym_BQUOTE] = ACTIONS(1248),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1248),
    [anon_sym_LT_LPAREN] = ACTIONS(1248),
    [anon_sym_GT_LPAREN] = ACTIONS(1248),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1250),
    [sym__concat] = ACTIONS(1250),
    [sym_test_operator] = ACTIONS(1250),
    [sym__bare_dollar] = ACTIONS(1250),
    [sym__brace_start] = ACTIONS(1250),
  },
  [STATE(470)] = {
    [sym_word] = ACTIONS(1252),
    [anon_sym_SEMI] = ACTIONS(1252),
    [anon_sym_EQ] = ACTIONS(1252),
    [anon_sym_PLUS_PLUS] = ACTIONS(1252),
    [anon_sym_DASH_DASH] = ACTIONS(1252),
    [anon_sym_PLUS_EQ] = ACTIONS(1252),
    [anon_sym_DASH_EQ] = ACTIONS(1252),
    [anon_sym_STAR_EQ] = ACTIONS(1252),
    [anon_sym_SLASH_EQ] = ACTIONS(1252),
    [anon_sym_PERCENT_EQ] = ACTIONS(1252),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1252),
    [anon_sym_LT_LT_EQ] = ACTIONS(1252),
    [anon_sym_GT_GT_EQ] = ACTIONS(1252),
    [anon_sym_AMP_EQ] = ACTIONS(1252),
    [anon_sym_CARET_EQ] = ACTIONS(1252),
    [anon_sym_PIPE_EQ] = ACTIONS(1252),
    [anon_sym_PIPE_PIPE] = ACTIONS(1252),
    [anon_sym_AMP_AMP] = ACTIONS(1252),
    [anon_sym_PIPE] = ACTIONS(1252),
    [anon_sym_CARET] = ACTIONS(1252),
    [anon_sym_AMP] = ACTIONS(1252),
    [anon_sym_EQ_EQ] = ACTIONS(1252),
    [anon_sym_BANG_EQ] = ACTIONS(1252),
    [anon_sym_LT] = ACTIONS(1252),
    [anon_sym_GT] = ACTIONS(1252),
    [anon_sym_LT_EQ] = ACTIONS(1252),
    [anon_sym_GT_EQ] = ACTIONS(1252),
    [anon_sym_LT_LT] = ACTIONS(1252),
    [anon_sym_GT_GT] = ACTIONS(1252),
    [anon_sym_PLUS] = ACTIONS(1252),
    [anon_sym_DASH] = ACTIONS(1252),
    [anon_sym_STAR] = ACTIONS(1252),
    [anon_sym_SLASH] = ACTIONS(1252),
    [anon_sym_PERCENT] = ACTIONS(1252),
    [anon_sym_STAR_STAR] = ACTIONS(1252),
    [anon_sym_LPAREN] = ACTIONS(1252),
    [anon_sym_RPAREN] = ACTIONS(1252),
    [anon_sym_SEMI_SEMI] = ACTIONS(1252),
    [anon_sym_PIPE_AMP] = ACTIONS(1252),
    [anon_sym_EQ_TILDE] = ACTIONS(1252),
    [anon_sym_AMP_GT] = ACTIONS(1252),
    [anon_sym_AMP_GT_GT] = ACTIONS(1252),
    [anon_sym_LT_AMP] = ACTIONS(1252),
    [anon_sym_GT_AMP] = ACTIONS(1252),
    [anon_sym_GT_PIPE] = ACTIONS(1252),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1252),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1252),
    [anon_sym_LT_LT_DASH] = ACTIONS(1252),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1254),
    [anon_sym_LT_LT_LT] = ACTIONS(1252),
    [anon_sym_QMARK] = ACTIONS(1252),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1252),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1252),
    [aux_sym_concatenation_token1] = ACTIONS(1252),
    [anon_sym_DOLLAR] = ACTIONS(1252),
    [sym__special_character] = ACTIONS(1252),
    [anon_sym_DQUOTE] = ACTIONS(1252),
    [sym_raw_string] = ACTIONS(1252),
    [sym_ansi_c_string] = ACTIONS(1252),
    [aux_sym_number_token1] = ACTIONS(1252),
    [aux_sym_number_token2] = ACTIONS(1252),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1252),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1252),
    [anon_sym_BQUOTE] = ACTIONS(1252),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1252),
    [anon_sym_LT_LPAREN] = ACTIONS(1252),
    [anon_sym_GT_LPAREN] = ACTIONS(1252),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1254),
    [sym__concat] = ACTIONS(1254),
    [sym_test_operator] = ACTIONS(1254),
    [sym__bare_dollar] = ACTIONS(1254),
    [sym__brace_start] = ACTIONS(1254),
  },
  [STATE(471)] = {
    [sym_word] = ACTIONS(1256),
    [anon_sym_SEMI] = ACTIONS(1256),
    [anon_sym_EQ] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1256),
    [anon_sym_DASH_DASH] = ACTIONS(1256),
    [anon_sym_PLUS_EQ] = ACTIONS(1256),
    [anon_sym_DASH_EQ] = ACTIONS(1256),
    [anon_sym_STAR_EQ] = ACTIONS(1256),
    [anon_sym_SLASH_EQ] = ACTIONS(1256),
    [anon_sym_PERCENT_EQ] = ACTIONS(1256),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1256),
    [anon_sym_LT_LT_EQ] = ACTIONS(1256),
    [anon_sym_GT_GT_EQ] = ACTIONS(1256),
    [anon_sym_AMP_EQ] = ACTIONS(1256),
    [anon_sym_CARET_EQ] = ACTIONS(1256),
    [anon_sym_PIPE_EQ] = ACTIONS(1256),
    [anon_sym_PIPE_PIPE] = ACTIONS(1256),
    [anon_sym_AMP_AMP] = ACTIONS(1256),
    [anon_sym_PIPE] = ACTIONS(1256),
    [anon_sym_CARET] = ACTIONS(1256),
    [anon_sym_AMP] = ACTIONS(1256),
    [anon_sym_EQ_EQ] = ACTIONS(1256),
    [anon_sym_BANG_EQ] = ACTIONS(1256),
    [anon_sym_LT] = ACTIONS(1256),
    [anon_sym_GT] = ACTIONS(1256),
    [anon_sym_LT_EQ] = ACTIONS(1256),
    [anon_sym_GT_EQ] = ACTIONS(1256),
    [anon_sym_LT_LT] = ACTIONS(1256),
    [anon_sym_GT_GT] = ACTIONS(1256),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_STAR] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(1256),
    [anon_sym_PERCENT] = ACTIONS(1256),
    [anon_sym_STAR_STAR] = ACTIONS(1256),
    [anon_sym_LPAREN] = ACTIONS(1256),
    [anon_sym_RPAREN] = ACTIONS(1256),
    [anon_sym_SEMI_SEMI] = ACTIONS(1256),
    [anon_sym_PIPE_AMP] = ACTIONS(1256),
    [anon_sym_EQ_TILDE] = ACTIONS(1256),
    [anon_sym_AMP_GT] = ACTIONS(1256),
    [anon_sym_AMP_GT_GT] = ACTIONS(1256),
    [anon_sym_LT_AMP] = ACTIONS(1256),
    [anon_sym_GT_AMP] = ACTIONS(1256),
    [anon_sym_GT_PIPE] = ACTIONS(1256),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1256),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1256),
    [anon_sym_LT_LT_DASH] = ACTIONS(1256),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1258),
    [anon_sym_LT_LT_LT] = ACTIONS(1256),
    [anon_sym_QMARK] = ACTIONS(1256),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1256),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1256),
    [aux_sym_concatenation_token1] = ACTIONS(1256),
    [anon_sym_DOLLAR] = ACTIONS(1256),
    [sym__special_character] = ACTIONS(1256),
    [anon_sym_DQUOTE] = ACTIONS(1256),
    [sym_raw_string] = ACTIONS(1256),
    [sym_ansi_c_string] = ACTIONS(1256),
    [aux_sym_number_token1] = ACTIONS(1256),
    [aux_sym_number_token2] = ACTIONS(1256),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1256),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1256),
    [anon_sym_BQUOTE] = ACTIONS(1256),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1256),
    [anon_sym_LT_LPAREN] = ACTIONS(1256),
    [anon_sym_GT_LPAREN] = ACTIONS(1256),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1258),
    [sym__concat] = ACTIONS(1258),
    [sym_test_operator] = ACTIONS(1258),
    [sym__bare_dollar] = ACTIONS(1258),
    [sym__brace_start] = ACTIONS(1258),
  },
  [STATE(472)] = {
    [sym_word] = ACTIONS(1260),
    [anon_sym_SEMI] = ACTIONS(1260),
    [anon_sym_EQ] = ACTIONS(1260),
    [anon_sym_PLUS_PLUS] = ACTIONS(1260),
    [anon_sym_DASH_DASH] = ACTIONS(1260),
    [anon_sym_PLUS_EQ] = ACTIONS(1260),
    [anon_sym_DASH_EQ] = ACTIONS(1260),
    [anon_sym_STAR_EQ] = ACTIONS(1260),
    [anon_sym_SLASH_EQ] = ACTIONS(1260),
    [anon_sym_PERCENT_EQ] = ACTIONS(1260),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1260),
    [anon_sym_LT_LT_EQ] = ACTIONS(1260),
    [anon_sym_GT_GT_EQ] = ACTIONS(1260),
    [anon_sym_AMP_EQ] = ACTIONS(1260),
    [anon_sym_CARET_EQ] = ACTIONS(1260),
    [anon_sym_PIPE_EQ] = ACTIONS(1260),
    [anon_sym_PIPE_PIPE] = ACTIONS(1260),
    [anon_sym_AMP_AMP] = ACTIONS(1260),
    [anon_sym_PIPE] = ACTIONS(1260),
    [anon_sym_CARET] = ACTIONS(1260),
    [anon_sym_AMP] = ACTIONS(1260),
    [anon_sym_EQ_EQ] = ACTIONS(1260),
    [anon_sym_BANG_EQ] = ACTIONS(1260),
    [anon_sym_LT] = ACTIONS(1260),
    [anon_sym_GT] = ACTIONS(1260),
    [anon_sym_LT_EQ] = ACTIONS(1260),
    [anon_sym_GT_EQ] = ACTIONS(1260),
    [anon_sym_LT_LT] = ACTIONS(1260),
    [anon_sym_GT_GT] = ACTIONS(1260),
    [anon_sym_PLUS] = ACTIONS(1260),
    [anon_sym_DASH] = ACTIONS(1260),
    [anon_sym_STAR] = ACTIONS(1260),
    [anon_sym_SLASH] = ACTIONS(1260),
    [anon_sym_PERCENT] = ACTIONS(1260),
    [anon_sym_STAR_STAR] = ACTIONS(1260),
    [anon_sym_LPAREN] = ACTIONS(1260),
    [anon_sym_RPAREN] = ACTIONS(1260),
    [anon_sym_SEMI_SEMI] = ACTIONS(1260),
    [anon_sym_PIPE_AMP] = ACTIONS(1260),
    [anon_sym_EQ_TILDE] = ACTIONS(1260),
    [anon_sym_AMP_GT] = ACTIONS(1260),
    [anon_sym_AMP_GT_GT] = ACTIONS(1260),
    [anon_sym_LT_AMP] = ACTIONS(1260),
    [anon_sym_GT_AMP] = ACTIONS(1260),
    [anon_sym_GT_PIPE] = ACTIONS(1260),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1260),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1260),
    [anon_sym_LT_LT_DASH] = ACTIONS(1260),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1262),
    [anon_sym_LT_LT_LT] = ACTIONS(1260),
    [anon_sym_QMARK] = ACTIONS(1260),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1260),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1260),
    [aux_sym_concatenation_token1] = ACTIONS(1260),
    [anon_sym_DOLLAR] = ACTIONS(1260),
    [sym__special_character] = ACTIONS(1260),
    [anon_sym_DQUOTE] = ACTIONS(1260),
    [sym_raw_string] = ACTIONS(1260),
    [sym_ansi_c_string] = ACTIONS(1260),
    [aux_sym_number_token1] = ACTIONS(1260),
    [aux_sym_number_token2] = ACTIONS(1260),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1260),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1260),
    [anon_sym_BQUOTE] = ACTIONS(1260),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1260),
    [anon_sym_LT_LPAREN] = ACTIONS(1260),
    [anon_sym_GT_LPAREN] = ACTIONS(1260),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1262),
    [sym__concat] = ACTIONS(1262),
    [sym_test_operator] = ACTIONS(1262),
    [sym__bare_dollar] = ACTIONS(1262),
    [sym__brace_start] = ACTIONS(1262),
  },
  [STATE(473)] = {
    [sym_word] = ACTIONS(1264),
    [anon_sym_SEMI] = ACTIONS(1264),
    [anon_sym_EQ] = ACTIONS(1264),
    [anon_sym_PLUS_PLUS] = ACTIONS(1264),
    [anon_sym_DASH_DASH] = ACTIONS(1264),
    [anon_sym_PLUS_EQ] = ACTIONS(1264),
    [anon_sym_DASH_EQ] = ACTIONS(1264),
    [anon_sym_STAR_EQ] = ACTIONS(1264),
    [anon_sym_SLASH_EQ] = ACTIONS(1264),
    [anon_sym_PERCENT_EQ] = ACTIONS(1264),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1264),
    [anon_sym_LT_LT_EQ] = ACTIONS(1264),
    [anon_sym_GT_GT_EQ] = ACTIONS(1264),
    [anon_sym_AMP_EQ] = ACTIONS(1264),
    [anon_sym_CARET_EQ] = ACTIONS(1264),
    [anon_sym_PIPE_EQ] = ACTIONS(1264),
    [anon_sym_PIPE_PIPE] = ACTIONS(1264),
    [anon_sym_AMP_AMP] = ACTIONS(1264),
    [anon_sym_PIPE] = ACTIONS(1264),
    [anon_sym_CARET] = ACTIONS(1264),
    [anon_sym_AMP] = ACTIONS(1264),
    [anon_sym_EQ_EQ] = ACTIONS(1264),
    [anon_sym_BANG_EQ] = ACTIONS(1264),
    [anon_sym_LT] = ACTIONS(1264),
    [anon_sym_GT] = ACTIONS(1264),
    [anon_sym_LT_EQ] = ACTIONS(1264),
    [anon_sym_GT_EQ] = ACTIONS(1264),
    [anon_sym_LT_LT] = ACTIONS(1264),
    [anon_sym_GT_GT] = ACTIONS(1264),
    [anon_sym_PLUS] = ACTIONS(1264),
    [anon_sym_DASH] = ACTIONS(1264),
    [anon_sym_STAR] = ACTIONS(1264),
    [anon_sym_SLASH] = ACTIONS(1264),
    [anon_sym_PERCENT] = ACTIONS(1264),
    [anon_sym_STAR_STAR] = ACTIONS(1264),
    [anon_sym_LPAREN] = ACTIONS(1264),
    [anon_sym_RPAREN] = ACTIONS(1264),
    [anon_sym_SEMI_SEMI] = ACTIONS(1264),
    [anon_sym_PIPE_AMP] = ACTIONS(1264),
    [anon_sym_EQ_TILDE] = ACTIONS(1264),
    [anon_sym_AMP_GT] = ACTIONS(1264),
    [anon_sym_AMP_GT_GT] = ACTIONS(1264),
    [anon_sym_LT_AMP] = ACTIONS(1264),
    [anon_sym_GT_AMP] = ACTIONS(1264),
    [anon_sym_GT_PIPE] = ACTIONS(1264),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1264),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1264),
    [anon_sym_LT_LT_DASH] = ACTIONS(1264),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1266),
    [anon_sym_LT_LT_LT] = ACTIONS(1264),
    [anon_sym_QMARK] = ACTIONS(1264),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1264),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1264),
    [aux_sym_concatenation_token1] = ACTIONS(1264),
    [anon_sym_DOLLAR] = ACTIONS(1264),
    [sym__special_character] = ACTIONS(1264),
    [anon_sym_DQUOTE] = ACTIONS(1264),
    [sym_raw_string] = ACTIONS(1264),
    [sym_ansi_c_string] = ACTIONS(1264),
    [aux_sym_number_token1] = ACTIONS(1264),
    [aux_sym_number_token2] = ACTIONS(1264),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1264),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1264),
    [anon_sym_BQUOTE] = ACTIONS(1264),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1264),
    [anon_sym_LT_LPAREN] = ACTIONS(1264),
    [anon_sym_GT_LPAREN] = ACTIONS(1264),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1266),
    [sym__concat] = ACTIONS(1266),
    [sym_test_operator] = ACTIONS(1266),
    [sym__bare_dollar] = ACTIONS(1266),
    [sym__brace_start] = ACTIONS(1266),
  },
  [STATE(474)] = {
    [sym_word] = ACTIONS(1268),
    [anon_sym_SEMI] = ACTIONS(1268),
    [anon_sym_EQ] = ACTIONS(1268),
    [anon_sym_PLUS_PLUS] = ACTIONS(1268),
    [anon_sym_DASH_DASH] = ACTIONS(1268),
    [anon_sym_PLUS_EQ] = ACTIONS(1268),
    [anon_sym_DASH_EQ] = ACTIONS(1268),
    [anon_sym_STAR_EQ] = ACTIONS(1268),
    [anon_sym_SLASH_EQ] = ACTIONS(1268),
    [anon_sym_PERCENT_EQ] = ACTIONS(1268),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1268),
    [anon_sym_LT_LT_EQ] = ACTIONS(1268),
    [anon_sym_GT_GT_EQ] = ACTIONS(1268),
    [anon_sym_AMP_EQ] = ACTIONS(1268),
    [anon_sym_CARET_EQ] = ACTIONS(1268),
    [anon_sym_PIPE_EQ] = ACTIONS(1268),
    [anon_sym_PIPE_PIPE] = ACTIONS(1268),
    [anon_sym_AMP_AMP] = ACTIONS(1268),
    [anon_sym_PIPE] = ACTIONS(1268),
    [anon_sym_CARET] = ACTIONS(1268),
    [anon_sym_AMP] = ACTIONS(1268),
    [anon_sym_EQ_EQ] = ACTIONS(1268),
    [anon_sym_BANG_EQ] = ACTIONS(1268),
    [anon_sym_LT] = ACTIONS(1268),
    [anon_sym_GT] = ACTIONS(1268),
    [anon_sym_LT_EQ] = ACTIONS(1268),
    [anon_sym_GT_EQ] = ACTIONS(1268),
    [anon_sym_LT_LT] = ACTIONS(1268),
    [anon_sym_GT_GT] = ACTIONS(1268),
    [anon_sym_PLUS] = ACTIONS(1268),
    [anon_sym_DASH] = ACTIONS(1268),
    [anon_sym_STAR] = ACTIONS(1268),
    [anon_sym_SLASH] = ACTIONS(1268),
    [anon_sym_PERCENT] = ACTIONS(1268),
    [anon_sym_STAR_STAR] = ACTIONS(1268),
    [anon_sym_LPAREN] = ACTIONS(1268),
    [anon_sym_RPAREN] = ACTIONS(1268),
    [anon_sym_SEMI_SEMI] = ACTIONS(1268),
    [anon_sym_PIPE_AMP] = ACTIONS(1268),
    [anon_sym_EQ_TILDE] = ACTIONS(1268),
    [anon_sym_AMP_GT] = ACTIONS(1268),
    [anon_sym_AMP_GT_GT] = ACTIONS(1268),
    [anon_sym_LT_AMP] = ACTIONS(1268),
    [anon_sym_GT_AMP] = ACTIONS(1268),
    [anon_sym_GT_PIPE] = ACTIONS(1268),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1268),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1268),
    [anon_sym_LT_LT_DASH] = ACTIONS(1268),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1270),
    [anon_sym_LT_LT_LT] = ACTIONS(1268),
    [anon_sym_QMARK] = ACTIONS(1268),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1268),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1268),
    [aux_sym_concatenation_token1] = ACTIONS(1268),
    [anon_sym_DOLLAR] = ACTIONS(1268),
    [sym__special_character] = ACTIONS(1268),
    [anon_sym_DQUOTE] = ACTIONS(1268),
    [sym_raw_string] = ACTIONS(1268),
    [sym_ansi_c_string] = ACTIONS(1268),
    [aux_sym_number_token1] = ACTIONS(1268),
    [aux_sym_number_token2] = ACTIONS(1268),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1268),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1268),
    [anon_sym_BQUOTE] = ACTIONS(1268),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1268),
    [anon_sym_LT_LPAREN] = ACTIONS(1268),
    [anon_sym_GT_LPAREN] = ACTIONS(1268),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1270),
    [sym__concat] = ACTIONS(1270),
    [sym_test_operator] = ACTIONS(1270),
    [sym__bare_dollar] = ACTIONS(1270),
    [sym__brace_start] = ACTIONS(1270),
  },
  [STATE(475)] = {
    [sym_word] = ACTIONS(1272),
    [anon_sym_SEMI] = ACTIONS(1272),
    [anon_sym_EQ] = ACTIONS(1272),
    [anon_sym_PLUS_PLUS] = ACTIONS(1272),
    [anon_sym_DASH_DASH] = ACTIONS(1272),
    [anon_sym_PLUS_EQ] = ACTIONS(1272),
    [anon_sym_DASH_EQ] = ACTIONS(1272),
    [anon_sym_STAR_EQ] = ACTIONS(1272),
    [anon_sym_SLASH_EQ] = ACTIONS(1272),
    [anon_sym_PERCENT_EQ] = ACTIONS(1272),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1272),
    [anon_sym_LT_LT_EQ] = ACTIONS(1272),
    [anon_sym_GT_GT_EQ] = ACTIONS(1272),
    [anon_sym_AMP_EQ] = ACTIONS(1272),
    [anon_sym_CARET_EQ] = ACTIONS(1272),
    [anon_sym_PIPE_EQ] = ACTIONS(1272),
    [anon_sym_PIPE_PIPE] = ACTIONS(1272),
    [anon_sym_AMP_AMP] = ACTIONS(1272),
    [anon_sym_PIPE] = ACTIONS(1272),
    [anon_sym_CARET] = ACTIONS(1272),
    [anon_sym_AMP] = ACTIONS(1272),
    [anon_sym_EQ_EQ] = ACTIONS(1272),
    [anon_sym_BANG_EQ] = ACTIONS(1272),
    [anon_sym_LT] = ACTIONS(1272),
    [anon_sym_GT] = ACTIONS(1272),
    [anon_sym_LT_EQ] = ACTIONS(1272),
    [anon_sym_GT_EQ] = ACTIONS(1272),
    [anon_sym_LT_LT] = ACTIONS(1272),
    [anon_sym_GT_GT] = ACTIONS(1272),
    [anon_sym_PLUS] = ACTIONS(1272),
    [anon_sym_DASH] = ACTIONS(1272),
    [anon_sym_STAR] = ACTIONS(1272),
    [anon_sym_SLASH] = ACTIONS(1272),
    [anon_sym_PERCENT] = ACTIONS(1272),
    [anon_sym_STAR_STAR] = ACTIONS(1272),
    [anon_sym_LPAREN] = ACTIONS(1272),
    [anon_sym_RPAREN] = ACTIONS(1272),
    [anon_sym_SEMI_SEMI] = ACTIONS(1272),
    [anon_sym_PIPE_AMP] = ACTIONS(1272),
    [anon_sym_EQ_TILDE] = ACTIONS(1272),
    [anon_sym_AMP_GT] = ACTIONS(1272),
    [anon_sym_AMP_GT_GT] = ACTIONS(1272),
    [anon_sym_LT_AMP] = ACTIONS(1272),
    [anon_sym_GT_AMP] = ACTIONS(1272),
    [anon_sym_GT_PIPE] = ACTIONS(1272),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1272),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1272),
    [anon_sym_LT_LT_DASH] = ACTIONS(1272),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1274),
    [anon_sym_LT_LT_LT] = ACTIONS(1272),
    [anon_sym_QMARK] = ACTIONS(1272),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1272),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1272),
    [aux_sym_concatenation_token1] = ACTIONS(1272),
    [anon_sym_DOLLAR] = ACTIONS(1272),
    [sym__special_character] = ACTIONS(1272),
    [anon_sym_DQUOTE] = ACTIONS(1272),
    [sym_raw_string] = ACTIONS(1272),
    [sym_ansi_c_string] = ACTIONS(1272),
    [aux_sym_number_token1] = ACTIONS(1272),
    [aux_sym_number_token2] = ACTIONS(1272),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1272),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1272),
    [anon_sym_BQUOTE] = ACTIONS(1272),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1272),
    [anon_sym_LT_LPAREN] = ACTIONS(1272),
    [anon_sym_GT_LPAREN] = ACTIONS(1272),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1274),
    [sym__concat] = ACTIONS(1274),
    [sym_test_operator] = ACTIONS(1274),
    [sym__bare_dollar] = ACTIONS(1274),
    [sym__brace_start] = ACTIONS(1274),
  },
  [STATE(476)] = {
    [sym_word] = ACTIONS(1276),
    [anon_sym_SEMI] = ACTIONS(1276),
    [anon_sym_EQ] = ACTIONS(1276),
    [anon_sym_PLUS_PLUS] = ACTIONS(1276),
    [anon_sym_DASH_DASH] = ACTIONS(1276),
    [anon_sym_PLUS_EQ] = ACTIONS(1276),
    [anon_sym_DASH_EQ] = ACTIONS(1276),
    [anon_sym_STAR_EQ] = ACTIONS(1276),
    [anon_sym_SLASH_EQ] = ACTIONS(1276),
    [anon_sym_PERCENT_EQ] = ACTIONS(1276),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1276),
    [anon_sym_LT_LT_EQ] = ACTIONS(1276),
    [anon_sym_GT_GT_EQ] = ACTIONS(1276),
    [anon_sym_AMP_EQ] = ACTIONS(1276),
    [anon_sym_CARET_EQ] = ACTIONS(1276),
    [anon_sym_PIPE_EQ] = ACTIONS(1276),
    [anon_sym_PIPE_PIPE] = ACTIONS(1276),
    [anon_sym_AMP_AMP] = ACTIONS(1276),
    [anon_sym_PIPE] = ACTIONS(1276),
    [anon_sym_CARET] = ACTIONS(1276),
    [anon_sym_AMP] = ACTIONS(1276),
    [anon_sym_EQ_EQ] = ACTIONS(1276),
    [anon_sym_BANG_EQ] = ACTIONS(1276),
    [anon_sym_LT] = ACTIONS(1276),
    [anon_sym_GT] = ACTIONS(1276),
    [anon_sym_LT_EQ] = ACTIONS(1276),
    [anon_sym_GT_EQ] = ACTIONS(1276),
    [anon_sym_LT_LT] = ACTIONS(1276),
    [anon_sym_GT_GT] = ACTIONS(1276),
    [anon_sym_PLUS] = ACTIONS(1276),
    [anon_sym_DASH] = ACTIONS(1276),
    [anon_sym_STAR] = ACTIONS(1276),
    [anon_sym_SLASH] = ACTIONS(1276),
    [anon_sym_PERCENT] = ACTIONS(1276),
    [anon_sym_STAR_STAR] = ACTIONS(1276),
    [anon_sym_LPAREN] = ACTIONS(1276),
    [anon_sym_RPAREN] = ACTIONS(1276),
    [anon_sym_SEMI_SEMI] = ACTIONS(1276),
    [anon_sym_PIPE_AMP] = ACTIONS(1276),
    [anon_sym_EQ_TILDE] = ACTIONS(1276),
    [anon_sym_AMP_GT] = ACTIONS(1276),
    [anon_sym_AMP_GT_GT] = ACTIONS(1276),
    [anon_sym_LT_AMP] = ACTIONS(1276),
    [anon_sym_GT_AMP] = ACTIONS(1276),
    [anon_sym_GT_PIPE] = ACTIONS(1276),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1276),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1276),
    [anon_sym_LT_LT_DASH] = ACTIONS(1276),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1278),
    [anon_sym_LT_LT_LT] = ACTIONS(1276),
    [anon_sym_QMARK] = ACTIONS(1276),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1276),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1276),
    [aux_sym_concatenation_token1] = ACTIONS(1276),
    [anon_sym_DOLLAR] = ACTIONS(1276),
    [sym__special_character] = ACTIONS(1276),
    [anon_sym_DQUOTE] = ACTIONS(1276),
    [sym_raw_string] = ACTIONS(1276),
    [sym_ansi_c_string] = ACTIONS(1276),
    [aux_sym_number_token1] = ACTIONS(1276),
    [aux_sym_number_token2] = ACTIONS(1276),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1276),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1276),
    [anon_sym_BQUOTE] = ACTIONS(1276),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1276),
    [anon_sym_LT_LPAREN] = ACTIONS(1276),
    [anon_sym_GT_LPAREN] = ACTIONS(1276),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1278),
    [sym__concat] = ACTIONS(1278),
    [sym_test_operator] = ACTIONS(1278),
    [sym__bare_dollar] = ACTIONS(1278),
    [sym__brace_start] = ACTIONS(1278),
  },
  [STATE(477)] = {
    [sym_word] = ACTIONS(1280),
    [anon_sym_SEMI] = ACTIONS(1280),
    [anon_sym_EQ] = ACTIONS(1280),
    [anon_sym_PLUS_PLUS] = ACTIONS(1280),
    [anon_sym_DASH_DASH] = ACTIONS(1280),
    [anon_sym_PLUS_EQ] = ACTIONS(1280),
    [anon_sym_DASH_EQ] = ACTIONS(1280),
    [anon_sym_STAR_EQ] = ACTIONS(1280),
    [anon_sym_SLASH_EQ] = ACTIONS(1280),
    [anon_sym_PERCENT_EQ] = ACTIONS(1280),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1280),
    [anon_sym_LT_LT_EQ] = ACTIONS(1280),
    [anon_sym_GT_GT_EQ] = ACTIONS(1280),
    [anon_sym_AMP_EQ] = ACTIONS(1280),
    [anon_sym_CARET_EQ] = ACTIONS(1280),
    [anon_sym_PIPE_EQ] = ACTIONS(1280),
    [anon_sym_PIPE_PIPE] = ACTIONS(1280),
    [anon_sym_AMP_AMP] = ACTIONS(1280),
    [anon_sym_PIPE] = ACTIONS(1280),
    [anon_sym_CARET] = ACTIONS(1280),
    [anon_sym_AMP] = ACTIONS(1280),
    [anon_sym_EQ_EQ] = ACTIONS(1280),
    [anon_sym_BANG_EQ] = ACTIONS(1280),
    [anon_sym_LT] = ACTIONS(1280),
    [anon_sym_GT] = ACTIONS(1280),
    [anon_sym_LT_EQ] = ACTIONS(1280),
    [anon_sym_GT_EQ] = ACTIONS(1280),
    [anon_sym_LT_LT] = ACTIONS(1280),
    [anon_sym_GT_GT] = ACTIONS(1280),
    [anon_sym_PLUS] = ACTIONS(1280),
    [anon_sym_DASH] = ACTIONS(1280),
    [anon_sym_STAR] = ACTIONS(1280),
    [anon_sym_SLASH] = ACTIONS(1280),
    [anon_sym_PERCENT] = ACTIONS(1280),
    [anon_sym_STAR_STAR] = ACTIONS(1280),
    [anon_sym_LPAREN] = ACTIONS(1280),
    [anon_sym_RPAREN] = ACTIONS(1280),
    [anon_sym_SEMI_SEMI] = ACTIONS(1280),
    [anon_sym_PIPE_AMP] = ACTIONS(1280),
    [anon_sym_EQ_TILDE] = ACTIONS(1280),
    [anon_sym_AMP_GT] = ACTIONS(1280),
    [anon_sym_AMP_GT_GT] = ACTIONS(1280),
    [anon_sym_LT_AMP] = ACTIONS(1280),
    [anon_sym_GT_AMP] = ACTIONS(1280),
    [anon_sym_GT_PIPE] = ACTIONS(1280),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1280),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1280),
    [anon_sym_LT_LT_DASH] = ACTIONS(1280),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1282),
    [anon_sym_LT_LT_LT] = ACTIONS(1280),
    [anon_sym_QMARK] = ACTIONS(1280),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1280),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1280),
    [aux_sym_concatenation_token1] = ACTIONS(1280),
    [anon_sym_DOLLAR] = ACTIONS(1280),
    [sym__special_character] = ACTIONS(1280),
    [anon_sym_DQUOTE] = ACTIONS(1280),
    [sym_raw_string] = ACTIONS(1280),
    [sym_ansi_c_string] = ACTIONS(1280),
    [aux_sym_number_token1] = ACTIONS(1280),
    [aux_sym_number_token2] = ACTIONS(1280),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1280),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1280),
    [anon_sym_BQUOTE] = ACTIONS(1280),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1280),
    [anon_sym_LT_LPAREN] = ACTIONS(1280),
    [anon_sym_GT_LPAREN] = ACTIONS(1280),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1282),
    [sym__concat] = ACTIONS(1282),
    [sym_test_operator] = ACTIONS(1282),
    [sym__bare_dollar] = ACTIONS(1282),
    [sym__brace_start] = ACTIONS(1282),
  },
  [STATE(478)] = {
    [sym_word] = ACTIONS(1284),
    [anon_sym_SEMI] = ACTIONS(1284),
    [anon_sym_EQ] = ACTIONS(1284),
    [anon_sym_PLUS_PLUS] = ACTIONS(1284),
    [anon_sym_DASH_DASH] = ACTIONS(1284),
    [anon_sym_PLUS_EQ] = ACTIONS(1284),
    [anon_sym_DASH_EQ] = ACTIONS(1284),
    [anon_sym_STAR_EQ] = ACTIONS(1284),
    [anon_sym_SLASH_EQ] = ACTIONS(1284),
    [anon_sym_PERCENT_EQ] = ACTIONS(1284),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1284),
    [anon_sym_LT_LT_EQ] = ACTIONS(1284),
    [anon_sym_GT_GT_EQ] = ACTIONS(1284),
    [anon_sym_AMP_EQ] = ACTIONS(1284),
    [anon_sym_CARET_EQ] = ACTIONS(1284),
    [anon_sym_PIPE_EQ] = ACTIONS(1284),
    [anon_sym_PIPE_PIPE] = ACTIONS(1284),
    [anon_sym_AMP_AMP] = ACTIONS(1284),
    [anon_sym_PIPE] = ACTIONS(1284),
    [anon_sym_CARET] = ACTIONS(1284),
    [anon_sym_AMP] = ACTIONS(1284),
    [anon_sym_EQ_EQ] = ACTIONS(1284),
    [anon_sym_BANG_EQ] = ACTIONS(1284),
    [anon_sym_LT] = ACTIONS(1284),
    [anon_sym_GT] = ACTIONS(1284),
    [anon_sym_LT_EQ] = ACTIONS(1284),
    [anon_sym_GT_EQ] = ACTIONS(1284),
    [anon_sym_LT_LT] = ACTIONS(1284),
    [anon_sym_GT_GT] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1284),
    [anon_sym_DASH] = ACTIONS(1284),
    [anon_sym_STAR] = ACTIONS(1284),
    [anon_sym_SLASH] = ACTIONS(1284),
    [anon_sym_PERCENT] = ACTIONS(1284),
    [anon_sym_STAR_STAR] = ACTIONS(1284),
    [anon_sym_LPAREN] = ACTIONS(1284),
    [anon_sym_RPAREN] = ACTIONS(1284),
    [anon_sym_SEMI_SEMI] = ACTIONS(1284),
    [anon_sym_PIPE_AMP] = ACTIONS(1284),
    [anon_sym_EQ_TILDE] = ACTIONS(1284),
    [anon_sym_AMP_GT] = ACTIONS(1284),
    [anon_sym_AMP_GT_GT] = ACTIONS(1284),
    [anon_sym_LT_AMP] = ACTIONS(1284),
    [anon_sym_GT_AMP] = ACTIONS(1284),
    [anon_sym_GT_PIPE] = ACTIONS(1284),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1284),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1284),
    [anon_sym_LT_LT_DASH] = ACTIONS(1284),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1286),
    [anon_sym_LT_LT_LT] = ACTIONS(1284),
    [anon_sym_QMARK] = ACTIONS(1284),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1284),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1284),
    [aux_sym_concatenation_token1] = ACTIONS(1284),
    [anon_sym_DOLLAR] = ACTIONS(1284),
    [sym__special_character] = ACTIONS(1284),
    [anon_sym_DQUOTE] = ACTIONS(1284),
    [sym_raw_string] = ACTIONS(1284),
    [sym_ansi_c_string] = ACTIONS(1284),
    [aux_sym_number_token1] = ACTIONS(1284),
    [aux_sym_number_token2] = ACTIONS(1284),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1284),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1284),
    [anon_sym_BQUOTE] = ACTIONS(1284),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1284),
    [anon_sym_LT_LPAREN] = ACTIONS(1284),
    [anon_sym_GT_LPAREN] = ACTIONS(1284),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1286),
    [sym__concat] = ACTIONS(1286),
    [sym_test_operator] = ACTIONS(1286),
    [sym__bare_dollar] = ACTIONS(1286),
    [sym__brace_start] = ACTIONS(1286),
  },
  [STATE(479)] = {
    [sym_word] = ACTIONS(1288),
    [anon_sym_SEMI] = ACTIONS(1288),
    [anon_sym_EQ] = ACTIONS(1288),
    [anon_sym_PLUS_PLUS] = ACTIONS(1288),
    [anon_sym_DASH_DASH] = ACTIONS(1288),
    [anon_sym_PLUS_EQ] = ACTIONS(1288),
    [anon_sym_DASH_EQ] = ACTIONS(1288),
    [anon_sym_STAR_EQ] = ACTIONS(1288),
    [anon_sym_SLASH_EQ] = ACTIONS(1288),
    [anon_sym_PERCENT_EQ] = ACTIONS(1288),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1288),
    [anon_sym_LT_LT_EQ] = ACTIONS(1288),
    [anon_sym_GT_GT_EQ] = ACTIONS(1288),
    [anon_sym_AMP_EQ] = ACTIONS(1288),
    [anon_sym_CARET_EQ] = ACTIONS(1288),
    [anon_sym_PIPE_EQ] = ACTIONS(1288),
    [anon_sym_PIPE_PIPE] = ACTIONS(1288),
    [anon_sym_AMP_AMP] = ACTIONS(1288),
    [anon_sym_PIPE] = ACTIONS(1288),
    [anon_sym_CARET] = ACTIONS(1288),
    [anon_sym_AMP] = ACTIONS(1288),
    [anon_sym_EQ_EQ] = ACTIONS(1288),
    [anon_sym_BANG_EQ] = ACTIONS(1288),
    [anon_sym_LT] = ACTIONS(1288),
    [anon_sym_GT] = ACTIONS(1288),
    [anon_sym_LT_EQ] = ACTIONS(1288),
    [anon_sym_GT_EQ] = ACTIONS(1288),
    [anon_sym_LT_LT] = ACTIONS(1288),
    [anon_sym_GT_GT] = ACTIONS(1288),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_STAR] = ACTIONS(1288),
    [anon_sym_SLASH] = ACTIONS(1288),
    [anon_sym_PERCENT] = ACTIONS(1288),
    [anon_sym_STAR_STAR] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1288),
    [anon_sym_RPAREN] = ACTIONS(1288),
    [anon_sym_SEMI_SEMI] = ACTIONS(1288),
    [anon_sym_PIPE_AMP] = ACTIONS(1288),
    [anon_sym_EQ_TILDE] = ACTIONS(1288),
    [anon_sym_AMP_GT] = ACTIONS(1288),
    [anon_sym_AMP_GT_GT] = ACTIONS(1288),
    [anon_sym_LT_AMP] = ACTIONS(1288),
    [anon_sym_GT_AMP] = ACTIONS(1288),
    [anon_sym_GT_PIPE] = ACTIONS(1288),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1288),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1288),
    [anon_sym_LT_LT_DASH] = ACTIONS(1288),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1290),
    [anon_sym_LT_LT_LT] = ACTIONS(1288),
    [anon_sym_QMARK] = ACTIONS(1288),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1288),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1288),
    [aux_sym_concatenation_token1] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1288),
    [sym__special_character] = ACTIONS(1288),
    [anon_sym_DQUOTE] = ACTIONS(1288),
    [sym_raw_string] = ACTIONS(1288),
    [sym_ansi_c_string] = ACTIONS(1288),
    [aux_sym_number_token1] = ACTIONS(1288),
    [aux_sym_number_token2] = ACTIONS(1288),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1288),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1288),
    [anon_sym_BQUOTE] = ACTIONS(1288),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1288),
    [anon_sym_LT_LPAREN] = ACTIONS(1288),
    [anon_sym_GT_LPAREN] = ACTIONS(1288),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1290),
    [sym__concat] = ACTIONS(1290),
    [sym_test_operator] = ACTIONS(1290),
    [sym__bare_dollar] = ACTIONS(1290),
    [sym__brace_start] = ACTIONS(1290),
  },
  [STATE(480)] = {
    [sym_word] = ACTIONS(1292),
    [anon_sym_SEMI] = ACTIONS(1292),
    [anon_sym_EQ] = ACTIONS(1292),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_PLUS_EQ] = ACTIONS(1292),
    [anon_sym_DASH_EQ] = ACTIONS(1292),
    [anon_sym_STAR_EQ] = ACTIONS(1292),
    [anon_sym_SLASH_EQ] = ACTIONS(1292),
    [anon_sym_PERCENT_EQ] = ACTIONS(1292),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1292),
    [anon_sym_LT_LT_EQ] = ACTIONS(1292),
    [anon_sym_GT_GT_EQ] = ACTIONS(1292),
    [anon_sym_AMP_EQ] = ACTIONS(1292),
    [anon_sym_CARET_EQ] = ACTIONS(1292),
    [anon_sym_PIPE_EQ] = ACTIONS(1292),
    [anon_sym_PIPE_PIPE] = ACTIONS(1292),
    [anon_sym_AMP_AMP] = ACTIONS(1292),
    [anon_sym_PIPE] = ACTIONS(1292),
    [anon_sym_CARET] = ACTIONS(1292),
    [anon_sym_AMP] = ACTIONS(1292),
    [anon_sym_EQ_EQ] = ACTIONS(1292),
    [anon_sym_BANG_EQ] = ACTIONS(1292),
    [anon_sym_LT] = ACTIONS(1292),
    [anon_sym_GT] = ACTIONS(1292),
    [anon_sym_LT_EQ] = ACTIONS(1292),
    [anon_sym_GT_EQ] = ACTIONS(1292),
    [anon_sym_LT_LT] = ACTIONS(1292),
    [anon_sym_GT_GT] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1292),
    [anon_sym_DASH] = ACTIONS(1292),
    [anon_sym_STAR] = ACTIONS(1292),
    [anon_sym_SLASH] = ACTIONS(1292),
    [anon_sym_PERCENT] = ACTIONS(1292),
    [anon_sym_STAR_STAR] = ACTIONS(1292),
    [anon_sym_LPAREN] = ACTIONS(1292),
    [anon_sym_RPAREN] = ACTIONS(1292),
    [anon_sym_SEMI_SEMI] = ACTIONS(1292),
    [anon_sym_PIPE_AMP] = ACTIONS(1292),
    [anon_sym_EQ_TILDE] = ACTIONS(1292),
    [anon_sym_AMP_GT] = ACTIONS(1292),
    [anon_sym_AMP_GT_GT] = ACTIONS(1292),
    [anon_sym_LT_AMP] = ACTIONS(1292),
    [anon_sym_GT_AMP] = ACTIONS(1292),
    [anon_sym_GT_PIPE] = ACTIONS(1292),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1292),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1292),
    [anon_sym_LT_LT_DASH] = ACTIONS(1292),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1294),
    [anon_sym_LT_LT_LT] = ACTIONS(1292),
    [anon_sym_QMARK] = ACTIONS(1292),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1292),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1292),
    [aux_sym_concatenation_token1] = ACTIONS(1292),
    [anon_sym_DOLLAR] = ACTIONS(1292),
    [sym__special_character] = ACTIONS(1292),
    [anon_sym_DQUOTE] = ACTIONS(1292),
    [sym_raw_string] = ACTIONS(1292),
    [sym_ansi_c_string] = ACTIONS(1292),
    [aux_sym_number_token1] = ACTIONS(1292),
    [aux_sym_number_token2] = ACTIONS(1292),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1292),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1292),
    [anon_sym_BQUOTE] = ACTIONS(1292),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1292),
    [anon_sym_LT_LPAREN] = ACTIONS(1292),
    [anon_sym_GT_LPAREN] = ACTIONS(1292),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1294),
    [sym__concat] = ACTIONS(1294),
    [sym_test_operator] = ACTIONS(1294),
    [sym__bare_dollar] = ACTIONS(1294),
    [sym__brace_start] = ACTIONS(1294),
  },
  [STATE(481)] = {
    [sym_word] = ACTIONS(1296),
    [anon_sym_SEMI] = ACTIONS(1296),
    [anon_sym_EQ] = ACTIONS(1296),
    [anon_sym_PLUS_PLUS] = ACTIONS(1296),
    [anon_sym_DASH_DASH] = ACTIONS(1296),
    [anon_sym_PLUS_EQ] = ACTIONS(1296),
    [anon_sym_DASH_EQ] = ACTIONS(1296),
    [anon_sym_STAR_EQ] = ACTIONS(1296),
    [anon_sym_SLASH_EQ] = ACTIONS(1296),
    [anon_sym_PERCENT_EQ] = ACTIONS(1296),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1296),
    [anon_sym_LT_LT_EQ] = ACTIONS(1296),
    [anon_sym_GT_GT_EQ] = ACTIONS(1296),
    [anon_sym_AMP_EQ] = ACTIONS(1296),
    [anon_sym_CARET_EQ] = ACTIONS(1296),
    [anon_sym_PIPE_EQ] = ACTIONS(1296),
    [anon_sym_PIPE_PIPE] = ACTIONS(1296),
    [anon_sym_AMP_AMP] = ACTIONS(1296),
    [anon_sym_PIPE] = ACTIONS(1296),
    [anon_sym_CARET] = ACTIONS(1296),
    [anon_sym_AMP] = ACTIONS(1296),
    [anon_sym_EQ_EQ] = ACTIONS(1296),
    [anon_sym_BANG_EQ] = ACTIONS(1296),
    [anon_sym_LT] = ACTIONS(1296),
    [anon_sym_GT] = ACTIONS(1296),
    [anon_sym_LT_EQ] = ACTIONS(1296),
    [anon_sym_GT_EQ] = ACTIONS(1296),
    [anon_sym_LT_LT] = ACTIONS(1296),
    [anon_sym_GT_GT] = ACTIONS(1296),
    [anon_sym_PLUS] = ACTIONS(1296),
    [anon_sym_DASH] = ACTIONS(1296),
    [anon_sym_STAR] = ACTIONS(1296),
    [anon_sym_SLASH] = ACTIONS(1296),
    [anon_sym_PERCENT] = ACTIONS(1296),
    [anon_sym_STAR_STAR] = ACTIONS(1296),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_RPAREN] = ACTIONS(1296),
    [anon_sym_SEMI_SEMI] = ACTIONS(1296),
    [anon_sym_PIPE_AMP] = ACTIONS(1296),
    [anon_sym_EQ_TILDE] = ACTIONS(1296),
    [anon_sym_AMP_GT] = ACTIONS(1296),
    [anon_sym_AMP_GT_GT] = ACTIONS(1296),
    [anon_sym_LT_AMP] = ACTIONS(1296),
    [anon_sym_GT_AMP] = ACTIONS(1296),
    [anon_sym_GT_PIPE] = ACTIONS(1296),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1296),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1296),
    [anon_sym_LT_LT_DASH] = ACTIONS(1296),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1298),
    [anon_sym_LT_LT_LT] = ACTIONS(1296),
    [anon_sym_QMARK] = ACTIONS(1296),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1296),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1296),
    [aux_sym_concatenation_token1] = ACTIONS(1296),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [sym__special_character] = ACTIONS(1296),
    [anon_sym_DQUOTE] = ACTIONS(1296),
    [sym_raw_string] = ACTIONS(1296),
    [sym_ansi_c_string] = ACTIONS(1296),
    [aux_sym_number_token1] = ACTIONS(1296),
    [aux_sym_number_token2] = ACTIONS(1296),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1296),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1296),
    [anon_sym_BQUOTE] = ACTIONS(1296),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1296),
    [anon_sym_LT_LPAREN] = ACTIONS(1296),
    [anon_sym_GT_LPAREN] = ACTIONS(1296),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1298),
    [sym__concat] = ACTIONS(1298),
    [sym_test_operator] = ACTIONS(1298),
    [sym__bare_dollar] = ACTIONS(1298),
    [sym__brace_start] = ACTIONS(1298),
  },
  [STATE(482)] = {
    [sym_word] = ACTIONS(1300),
    [anon_sym_SEMI] = ACTIONS(1300),
    [anon_sym_EQ] = ACTIONS(1300),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_PLUS_EQ] = ACTIONS(1300),
    [anon_sym_DASH_EQ] = ACTIONS(1300),
    [anon_sym_STAR_EQ] = ACTIONS(1300),
    [anon_sym_SLASH_EQ] = ACTIONS(1300),
    [anon_sym_PERCENT_EQ] = ACTIONS(1300),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1300),
    [anon_sym_LT_LT_EQ] = ACTIONS(1300),
    [anon_sym_GT_GT_EQ] = ACTIONS(1300),
    [anon_sym_AMP_EQ] = ACTIONS(1300),
    [anon_sym_CARET_EQ] = ACTIONS(1300),
    [anon_sym_PIPE_EQ] = ACTIONS(1300),
    [anon_sym_PIPE_PIPE] = ACTIONS(1300),
    [anon_sym_AMP_AMP] = ACTIONS(1300),
    [anon_sym_PIPE] = ACTIONS(1300),
    [anon_sym_CARET] = ACTIONS(1300),
    [anon_sym_AMP] = ACTIONS(1300),
    [anon_sym_EQ_EQ] = ACTIONS(1300),
    [anon_sym_BANG_EQ] = ACTIONS(1300),
    [anon_sym_LT] = ACTIONS(1300),
    [anon_sym_GT] = ACTIONS(1300),
    [anon_sym_LT_EQ] = ACTIONS(1300),
    [anon_sym_GT_EQ] = ACTIONS(1300),
    [anon_sym_LT_LT] = ACTIONS(1300),
    [anon_sym_GT_GT] = ACTIONS(1300),
    [anon_sym_PLUS] = ACTIONS(1300),
    [anon_sym_DASH] = ACTIONS(1300),
    [anon_sym_STAR] = ACTIONS(1300),
    [anon_sym_SLASH] = ACTIONS(1300),
    [anon_sym_PERCENT] = ACTIONS(1300),
    [anon_sym_STAR_STAR] = ACTIONS(1300),
    [anon_sym_LPAREN] = ACTIONS(1300),
    [anon_sym_RPAREN] = ACTIONS(1300),
    [anon_sym_SEMI_SEMI] = ACTIONS(1300),
    [anon_sym_PIPE_AMP] = ACTIONS(1300),
    [anon_sym_EQ_TILDE] = ACTIONS(1300),
    [anon_sym_AMP_GT] = ACTIONS(1300),
    [anon_sym_AMP_GT_GT] = ACTIONS(1300),
    [anon_sym_LT_AMP] = ACTIONS(1300),
    [anon_sym_GT_AMP] = ACTIONS(1300),
    [anon_sym_GT_PIPE] = ACTIONS(1300),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1300),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1300),
    [anon_sym_LT_LT_DASH] = ACTIONS(1300),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1302),
    [anon_sym_LT_LT_LT] = ACTIONS(1300),
    [anon_sym_QMARK] = ACTIONS(1300),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1300),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1300),
    [aux_sym_concatenation_token1] = ACTIONS(1300),
    [anon_sym_DOLLAR] = ACTIONS(1300),
    [sym__special_character] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(1300),
    [sym_raw_string] = ACTIONS(1300),
    [sym_ansi_c_string] = ACTIONS(1300),
    [aux_sym_number_token1] = ACTIONS(1300),
    [aux_sym_number_token2] = ACTIONS(1300),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1300),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1300),
    [anon_sym_BQUOTE] = ACTIONS(1300),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1300),
    [anon_sym_LT_LPAREN] = ACTIONS(1300),
    [anon_sym_GT_LPAREN] = ACTIONS(1300),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1302),
    [sym__concat] = ACTIONS(1302),
    [sym_test_operator] = ACTIONS(1302),
    [sym__bare_dollar] = ACTIONS(1302),
    [sym__brace_start] = ACTIONS(1302),
  },
  [STATE(483)] = {
    [sym_word] = ACTIONS(1304),
    [anon_sym_SEMI] = ACTIONS(1304),
    [anon_sym_EQ] = ACTIONS(1304),
    [anon_sym_PLUS_PLUS] = ACTIONS(1304),
    [anon_sym_DASH_DASH] = ACTIONS(1304),
    [anon_sym_PLUS_EQ] = ACTIONS(1304),
    [anon_sym_DASH_EQ] = ACTIONS(1304),
    [anon_sym_STAR_EQ] = ACTIONS(1304),
    [anon_sym_SLASH_EQ] = ACTIONS(1304),
    [anon_sym_PERCENT_EQ] = ACTIONS(1304),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1304),
    [anon_sym_LT_LT_EQ] = ACTIONS(1304),
    [anon_sym_GT_GT_EQ] = ACTIONS(1304),
    [anon_sym_AMP_EQ] = ACTIONS(1304),
    [anon_sym_CARET_EQ] = ACTIONS(1304),
    [anon_sym_PIPE_EQ] = ACTIONS(1304),
    [anon_sym_PIPE_PIPE] = ACTIONS(1304),
    [anon_sym_AMP_AMP] = ACTIONS(1304),
    [anon_sym_PIPE] = ACTIONS(1304),
    [anon_sym_CARET] = ACTIONS(1304),
    [anon_sym_AMP] = ACTIONS(1304),
    [anon_sym_EQ_EQ] = ACTIONS(1304),
    [anon_sym_BANG_EQ] = ACTIONS(1304),
    [anon_sym_LT] = ACTIONS(1304),
    [anon_sym_GT] = ACTIONS(1304),
    [anon_sym_LT_EQ] = ACTIONS(1304),
    [anon_sym_GT_EQ] = ACTIONS(1304),
    [anon_sym_LT_LT] = ACTIONS(1304),
    [anon_sym_GT_GT] = ACTIONS(1304),
    [anon_sym_PLUS] = ACTIONS(1304),
    [anon_sym_DASH] = ACTIONS(1304),
    [anon_sym_STAR] = ACTIONS(1304),
    [anon_sym_SLASH] = ACTIONS(1304),
    [anon_sym_PERCENT] = ACTIONS(1304),
    [anon_sym_STAR_STAR] = ACTIONS(1304),
    [anon_sym_LPAREN] = ACTIONS(1304),
    [anon_sym_RPAREN] = ACTIONS(1304),
    [anon_sym_SEMI_SEMI] = ACTIONS(1304),
    [anon_sym_PIPE_AMP] = ACTIONS(1304),
    [anon_sym_EQ_TILDE] = ACTIONS(1304),
    [anon_sym_AMP_GT] = ACTIONS(1304),
    [anon_sym_AMP_GT_GT] = ACTIONS(1304),
    [anon_sym_LT_AMP] = ACTIONS(1304),
    [anon_sym_GT_AMP] = ACTIONS(1304),
    [anon_sym_GT_PIPE] = ACTIONS(1304),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1304),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1304),
    [anon_sym_LT_LT_DASH] = ACTIONS(1304),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1306),
    [anon_sym_LT_LT_LT] = ACTIONS(1304),
    [anon_sym_QMARK] = ACTIONS(1304),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1304),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1304),
    [aux_sym_concatenation_token1] = ACTIONS(1304),
    [anon_sym_DOLLAR] = ACTIONS(1304),
    [sym__special_character] = ACTIONS(1304),
    [anon_sym_DQUOTE] = ACTIONS(1304),
    [sym_raw_string] = ACTIONS(1304),
    [sym_ansi_c_string] = ACTIONS(1304),
    [aux_sym_number_token1] = ACTIONS(1304),
    [aux_sym_number_token2] = ACTIONS(1304),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1304),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1304),
    [anon_sym_BQUOTE] = ACTIONS(1304),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1304),
    [anon_sym_LT_LPAREN] = ACTIONS(1304),
    [anon_sym_GT_LPAREN] = ACTIONS(1304),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1306),
    [sym__concat] = ACTIONS(1306),
    [sym_test_operator] = ACTIONS(1306),
    [sym__bare_dollar] = ACTIONS(1306),
    [sym__brace_start] = ACTIONS(1306),
  },
  [STATE(484)] = {
    [sym_word] = ACTIONS(1300),
    [anon_sym_SEMI] = ACTIONS(1300),
    [anon_sym_EQ] = ACTIONS(1300),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_PLUS_EQ] = ACTIONS(1300),
    [anon_sym_DASH_EQ] = ACTIONS(1300),
    [anon_sym_STAR_EQ] = ACTIONS(1300),
    [anon_sym_SLASH_EQ] = ACTIONS(1300),
    [anon_sym_PERCENT_EQ] = ACTIONS(1300),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1300),
    [anon_sym_LT_LT_EQ] = ACTIONS(1300),
    [anon_sym_GT_GT_EQ] = ACTIONS(1300),
    [anon_sym_AMP_EQ] = ACTIONS(1300),
    [anon_sym_CARET_EQ] = ACTIONS(1300),
    [anon_sym_PIPE_EQ] = ACTIONS(1300),
    [anon_sym_PIPE_PIPE] = ACTIONS(1300),
    [anon_sym_AMP_AMP] = ACTIONS(1300),
    [anon_sym_PIPE] = ACTIONS(1300),
    [anon_sym_CARET] = ACTIONS(1300),
    [anon_sym_AMP] = ACTIONS(1300),
    [anon_sym_EQ_EQ] = ACTIONS(1300),
    [anon_sym_BANG_EQ] = ACTIONS(1300),
    [anon_sym_LT] = ACTIONS(1300),
    [anon_sym_GT] = ACTIONS(1300),
    [anon_sym_LT_EQ] = ACTIONS(1300),
    [anon_sym_GT_EQ] = ACTIONS(1300),
    [anon_sym_LT_LT] = ACTIONS(1300),
    [anon_sym_GT_GT] = ACTIONS(1300),
    [anon_sym_PLUS] = ACTIONS(1300),
    [anon_sym_DASH] = ACTIONS(1300),
    [anon_sym_STAR] = ACTIONS(1300),
    [anon_sym_SLASH] = ACTIONS(1300),
    [anon_sym_PERCENT] = ACTIONS(1300),
    [anon_sym_STAR_STAR] = ACTIONS(1300),
    [anon_sym_LPAREN] = ACTIONS(1300),
    [anon_sym_RPAREN] = ACTIONS(1300),
    [anon_sym_SEMI_SEMI] = ACTIONS(1300),
    [anon_sym_PIPE_AMP] = ACTIONS(1300),
    [anon_sym_EQ_TILDE] = ACTIONS(1300),
    [anon_sym_AMP_GT] = ACTIONS(1300),
    [anon_sym_AMP_GT_GT] = ACTIONS(1300),
    [anon_sym_LT_AMP] = ACTIONS(1300),
    [anon_sym_GT_AMP] = ACTIONS(1300),
    [anon_sym_GT_PIPE] = ACTIONS(1300),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1300),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1300),
    [anon_sym_LT_LT_DASH] = ACTIONS(1300),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1302),
    [anon_sym_LT_LT_LT] = ACTIONS(1300),
    [anon_sym_QMARK] = ACTIONS(1300),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1300),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1300),
    [aux_sym_concatenation_token1] = ACTIONS(1300),
    [anon_sym_DOLLAR] = ACTIONS(1300),
    [sym__special_character] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(1300),
    [sym_raw_string] = ACTIONS(1300),
    [sym_ansi_c_string] = ACTIONS(1300),
    [aux_sym_number_token1] = ACTIONS(1300),
    [aux_sym_number_token2] = ACTIONS(1300),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1300),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1300),
    [anon_sym_BQUOTE] = ACTIONS(1300),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1300),
    [anon_sym_LT_LPAREN] = ACTIONS(1300),
    [anon_sym_GT_LPAREN] = ACTIONS(1300),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1302),
    [sym__concat] = ACTIONS(1302),
    [sym_test_operator] = ACTIONS(1302),
    [sym__bare_dollar] = ACTIONS(1302),
    [sym__brace_start] = ACTIONS(1302),
  },
  [STATE(485)] = {
    [sym_word] = ACTIONS(1308),
    [anon_sym_SEMI] = ACTIONS(1308),
    [anon_sym_EQ] = ACTIONS(1308),
    [anon_sym_PLUS_PLUS] = ACTIONS(1308),
    [anon_sym_DASH_DASH] = ACTIONS(1308),
    [anon_sym_PLUS_EQ] = ACTIONS(1308),
    [anon_sym_DASH_EQ] = ACTIONS(1308),
    [anon_sym_STAR_EQ] = ACTIONS(1308),
    [anon_sym_SLASH_EQ] = ACTIONS(1308),
    [anon_sym_PERCENT_EQ] = ACTIONS(1308),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1308),
    [anon_sym_LT_LT_EQ] = ACTIONS(1308),
    [anon_sym_GT_GT_EQ] = ACTIONS(1308),
    [anon_sym_AMP_EQ] = ACTIONS(1308),
    [anon_sym_CARET_EQ] = ACTIONS(1308),
    [anon_sym_PIPE_EQ] = ACTIONS(1308),
    [anon_sym_PIPE_PIPE] = ACTIONS(1308),
    [anon_sym_AMP_AMP] = ACTIONS(1308),
    [anon_sym_PIPE] = ACTIONS(1308),
    [anon_sym_CARET] = ACTIONS(1308),
    [anon_sym_AMP] = ACTIONS(1308),
    [anon_sym_EQ_EQ] = ACTIONS(1308),
    [anon_sym_BANG_EQ] = ACTIONS(1308),
    [anon_sym_LT] = ACTIONS(1308),
    [anon_sym_GT] = ACTIONS(1308),
    [anon_sym_LT_EQ] = ACTIONS(1308),
    [anon_sym_GT_EQ] = ACTIONS(1308),
    [anon_sym_LT_LT] = ACTIONS(1308),
    [anon_sym_GT_GT] = ACTIONS(1308),
    [anon_sym_PLUS] = ACTIONS(1308),
    [anon_sym_DASH] = ACTIONS(1308),
    [anon_sym_STAR] = ACTIONS(1308),
    [anon_sym_SLASH] = ACTIONS(1308),
    [anon_sym_PERCENT] = ACTIONS(1308),
    [anon_sym_STAR_STAR] = ACTIONS(1308),
    [anon_sym_LPAREN] = ACTIONS(1308),
    [anon_sym_RPAREN] = ACTIONS(1308),
    [anon_sym_SEMI_SEMI] = ACTIONS(1308),
    [anon_sym_PIPE_AMP] = ACTIONS(1308),
    [anon_sym_EQ_TILDE] = ACTIONS(1308),
    [anon_sym_AMP_GT] = ACTIONS(1308),
    [anon_sym_AMP_GT_GT] = ACTIONS(1308),
    [anon_sym_LT_AMP] = ACTIONS(1308),
    [anon_sym_GT_AMP] = ACTIONS(1308),
    [anon_sym_GT_PIPE] = ACTIONS(1308),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1308),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1308),
    [anon_sym_LT_LT_DASH] = ACTIONS(1308),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1310),
    [anon_sym_LT_LT_LT] = ACTIONS(1308),
    [anon_sym_QMARK] = ACTIONS(1308),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1308),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1308),
    [aux_sym_concatenation_token1] = ACTIONS(1308),
    [anon_sym_DOLLAR] = ACTIONS(1308),
    [sym__special_character] = ACTIONS(1308),
    [anon_sym_DQUOTE] = ACTIONS(1308),
    [sym_raw_string] = ACTIONS(1308),
    [sym_ansi_c_string] = ACTIONS(1308),
    [aux_sym_number_token1] = ACTIONS(1308),
    [aux_sym_number_token2] = ACTIONS(1308),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1308),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1308),
    [anon_sym_BQUOTE] = ACTIONS(1308),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1308),
    [anon_sym_LT_LPAREN] = ACTIONS(1308),
    [anon_sym_GT_LPAREN] = ACTIONS(1308),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1310),
    [sym__concat] = ACTIONS(1310),
    [sym_test_operator] = ACTIONS(1310),
    [sym__bare_dollar] = ACTIONS(1310),
    [sym__brace_start] = ACTIONS(1310),
  },
  [STATE(486)] = {
    [sym_word] = ACTIONS(1213),
    [anon_sym_SEMI] = ACTIONS(1213),
    [anon_sym_EQ] = ACTIONS(1213),
    [anon_sym_PLUS_PLUS] = ACTIONS(1213),
    [anon_sym_DASH_DASH] = ACTIONS(1213),
    [anon_sym_PLUS_EQ] = ACTIONS(1213),
    [anon_sym_DASH_EQ] = ACTIONS(1213),
    [anon_sym_STAR_EQ] = ACTIONS(1213),
    [anon_sym_SLASH_EQ] = ACTIONS(1213),
    [anon_sym_PERCENT_EQ] = ACTIONS(1213),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1213),
    [anon_sym_LT_LT_EQ] = ACTIONS(1213),
    [anon_sym_GT_GT_EQ] = ACTIONS(1213),
    [anon_sym_AMP_EQ] = ACTIONS(1213),
    [anon_sym_CARET_EQ] = ACTIONS(1213),
    [anon_sym_PIPE_EQ] = ACTIONS(1213),
    [anon_sym_PIPE_PIPE] = ACTIONS(1213),
    [anon_sym_AMP_AMP] = ACTIONS(1213),
    [anon_sym_PIPE] = ACTIONS(1213),
    [anon_sym_CARET] = ACTIONS(1213),
    [anon_sym_AMP] = ACTIONS(1213),
    [anon_sym_EQ_EQ] = ACTIONS(1213),
    [anon_sym_BANG_EQ] = ACTIONS(1213),
    [anon_sym_LT] = ACTIONS(1213),
    [anon_sym_GT] = ACTIONS(1213),
    [anon_sym_LT_EQ] = ACTIONS(1213),
    [anon_sym_GT_EQ] = ACTIONS(1213),
    [anon_sym_LT_LT] = ACTIONS(1213),
    [anon_sym_GT_GT] = ACTIONS(1213),
    [anon_sym_PLUS] = ACTIONS(1213),
    [anon_sym_DASH] = ACTIONS(1213),
    [anon_sym_STAR] = ACTIONS(1213),
    [anon_sym_SLASH] = ACTIONS(1213),
    [anon_sym_PERCENT] = ACTIONS(1213),
    [anon_sym_STAR_STAR] = ACTIONS(1213),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_RPAREN] = ACTIONS(1213),
    [anon_sym_SEMI_SEMI] = ACTIONS(1213),
    [anon_sym_PIPE_AMP] = ACTIONS(1213),
    [anon_sym_EQ_TILDE] = ACTIONS(1213),
    [anon_sym_AMP_GT] = ACTIONS(1213),
    [anon_sym_AMP_GT_GT] = ACTIONS(1213),
    [anon_sym_LT_AMP] = ACTIONS(1213),
    [anon_sym_GT_AMP] = ACTIONS(1213),
    [anon_sym_GT_PIPE] = ACTIONS(1213),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1213),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1213),
    [anon_sym_LT_LT_DASH] = ACTIONS(1213),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1215),
    [anon_sym_LT_LT_LT] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1213),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1213),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1213),
    [aux_sym_concatenation_token1] = ACTIONS(1213),
    [anon_sym_DOLLAR] = ACTIONS(1213),
    [sym__special_character] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1213),
    [sym_raw_string] = ACTIONS(1213),
    [sym_ansi_c_string] = ACTIONS(1213),
    [aux_sym_number_token1] = ACTIONS(1213),
    [aux_sym_number_token2] = ACTIONS(1213),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1213),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1213),
    [anon_sym_BQUOTE] = ACTIONS(1213),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1213),
    [anon_sym_LT_LPAREN] = ACTIONS(1213),
    [anon_sym_GT_LPAREN] = ACTIONS(1213),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1215),
    [sym__concat] = ACTIONS(1215),
    [sym_test_operator] = ACTIONS(1215),
    [sym__bare_dollar] = ACTIONS(1215),
    [sym__brace_start] = ACTIONS(1215),
  },
  [STATE(487)] = {
    [sym_word] = ACTIONS(1312),
    [anon_sym_SEMI] = ACTIONS(1312),
    [anon_sym_EQ] = ACTIONS(1312),
    [anon_sym_PLUS_PLUS] = ACTIONS(1312),
    [anon_sym_DASH_DASH] = ACTIONS(1312),
    [anon_sym_PLUS_EQ] = ACTIONS(1312),
    [anon_sym_DASH_EQ] = ACTIONS(1312),
    [anon_sym_STAR_EQ] = ACTIONS(1312),
    [anon_sym_SLASH_EQ] = ACTIONS(1312),
    [anon_sym_PERCENT_EQ] = ACTIONS(1312),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1312),
    [anon_sym_LT_LT_EQ] = ACTIONS(1312),
    [anon_sym_GT_GT_EQ] = ACTIONS(1312),
    [anon_sym_AMP_EQ] = ACTIONS(1312),
    [anon_sym_CARET_EQ] = ACTIONS(1312),
    [anon_sym_PIPE_EQ] = ACTIONS(1312),
    [anon_sym_PIPE_PIPE] = ACTIONS(1312),
    [anon_sym_AMP_AMP] = ACTIONS(1312),
    [anon_sym_PIPE] = ACTIONS(1312),
    [anon_sym_CARET] = ACTIONS(1312),
    [anon_sym_AMP] = ACTIONS(1312),
    [anon_sym_EQ_EQ] = ACTIONS(1312),
    [anon_sym_BANG_EQ] = ACTIONS(1312),
    [anon_sym_LT] = ACTIONS(1312),
    [anon_sym_GT] = ACTIONS(1312),
    [anon_sym_LT_EQ] = ACTIONS(1312),
    [anon_sym_GT_EQ] = ACTIONS(1312),
    [anon_sym_LT_LT] = ACTIONS(1312),
    [anon_sym_GT_GT] = ACTIONS(1312),
    [anon_sym_PLUS] = ACTIONS(1312),
    [anon_sym_DASH] = ACTIONS(1312),
    [anon_sym_STAR] = ACTIONS(1312),
    [anon_sym_SLASH] = ACTIONS(1312),
    [anon_sym_PERCENT] = ACTIONS(1312),
    [anon_sym_STAR_STAR] = ACTIONS(1312),
    [anon_sym_LPAREN] = ACTIONS(1312),
    [anon_sym_RPAREN] = ACTIONS(1312),
    [anon_sym_SEMI_SEMI] = ACTIONS(1312),
    [anon_sym_PIPE_AMP] = ACTIONS(1312),
    [anon_sym_EQ_TILDE] = ACTIONS(1312),
    [anon_sym_AMP_GT] = ACTIONS(1312),
    [anon_sym_AMP_GT_GT] = ACTIONS(1312),
    [anon_sym_LT_AMP] = ACTIONS(1312),
    [anon_sym_GT_AMP] = ACTIONS(1312),
    [anon_sym_GT_PIPE] = ACTIONS(1312),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1312),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1312),
    [anon_sym_LT_LT_DASH] = ACTIONS(1312),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1314),
    [anon_sym_LT_LT_LT] = ACTIONS(1312),
    [anon_sym_QMARK] = ACTIONS(1312),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1312),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1312),
    [aux_sym_concatenation_token1] = ACTIONS(1312),
    [anon_sym_DOLLAR] = ACTIONS(1312),
    [sym__special_character] = ACTIONS(1312),
    [anon_sym_DQUOTE] = ACTIONS(1312),
    [sym_raw_string] = ACTIONS(1312),
    [sym_ansi_c_string] = ACTIONS(1312),
    [aux_sym_number_token1] = ACTIONS(1312),
    [aux_sym_number_token2] = ACTIONS(1312),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1312),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1312),
    [anon_sym_BQUOTE] = ACTIONS(1312),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1312),
    [anon_sym_LT_LPAREN] = ACTIONS(1312),
    [anon_sym_GT_LPAREN] = ACTIONS(1312),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1314),
    [sym__concat] = ACTIONS(1314),
    [sym_test_operator] = ACTIONS(1314),
    [sym__bare_dollar] = ACTIONS(1314),
    [sym__brace_start] = ACTIONS(1314),
  },
  [STATE(488)] = {
    [aux_sym__literal_repeat1] = STATE(488),
    [sym_word] = ACTIONS(1316),
    [anon_sym_SEMI] = ACTIONS(1316),
    [anon_sym_EQ] = ACTIONS(1316),
    [anon_sym_PLUS_PLUS] = ACTIONS(1316),
    [anon_sym_DASH_DASH] = ACTIONS(1316),
    [anon_sym_PLUS_EQ] = ACTIONS(1316),
    [anon_sym_DASH_EQ] = ACTIONS(1316),
    [anon_sym_STAR_EQ] = ACTIONS(1316),
    [anon_sym_SLASH_EQ] = ACTIONS(1316),
    [anon_sym_PERCENT_EQ] = ACTIONS(1316),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1316),
    [anon_sym_LT_LT_EQ] = ACTIONS(1316),
    [anon_sym_GT_GT_EQ] = ACTIONS(1316),
    [anon_sym_AMP_EQ] = ACTIONS(1316),
    [anon_sym_CARET_EQ] = ACTIONS(1316),
    [anon_sym_PIPE_EQ] = ACTIONS(1316),
    [anon_sym_PIPE_PIPE] = ACTIONS(1316),
    [anon_sym_AMP_AMP] = ACTIONS(1316),
    [anon_sym_PIPE] = ACTIONS(1316),
    [anon_sym_CARET] = ACTIONS(1316),
    [anon_sym_AMP] = ACTIONS(1316),
    [anon_sym_EQ_EQ] = ACTIONS(1316),
    [anon_sym_BANG_EQ] = ACTIONS(1316),
    [anon_sym_LT] = ACTIONS(1316),
    [anon_sym_GT] = ACTIONS(1316),
    [anon_sym_LT_EQ] = ACTIONS(1316),
    [anon_sym_GT_EQ] = ACTIONS(1316),
    [anon_sym_LT_LT] = ACTIONS(1316),
    [anon_sym_GT_GT] = ACTIONS(1316),
    [anon_sym_PLUS] = ACTIONS(1316),
    [anon_sym_DASH] = ACTIONS(1316),
    [anon_sym_STAR] = ACTIONS(1316),
    [anon_sym_SLASH] = ACTIONS(1316),
    [anon_sym_PERCENT] = ACTIONS(1316),
    [anon_sym_STAR_STAR] = ACTIONS(1316),
    [anon_sym_LPAREN] = ACTIONS(1316),
    [anon_sym_RPAREN] = ACTIONS(1316),
    [anon_sym_SEMI_SEMI] = ACTIONS(1316),
    [anon_sym_PIPE_AMP] = ACTIONS(1316),
    [anon_sym_EQ_TILDE] = ACTIONS(1316),
    [anon_sym_AMP_GT] = ACTIONS(1316),
    [anon_sym_AMP_GT_GT] = ACTIONS(1316),
    [anon_sym_LT_AMP] = ACTIONS(1316),
    [anon_sym_GT_AMP] = ACTIONS(1316),
    [anon_sym_GT_PIPE] = ACTIONS(1316),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1316),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1316),
    [anon_sym_LT_LT_DASH] = ACTIONS(1316),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1318),
    [anon_sym_LT_LT_LT] = ACTIONS(1316),
    [anon_sym_QMARK] = ACTIONS(1316),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1316),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1316),
    [anon_sym_DOLLAR] = ACTIONS(1316),
    [sym__special_character] = ACTIONS(1320),
    [anon_sym_DQUOTE] = ACTIONS(1316),
    [sym_raw_string] = ACTIONS(1316),
    [sym_ansi_c_string] = ACTIONS(1316),
    [aux_sym_number_token1] = ACTIONS(1316),
    [aux_sym_number_token2] = ACTIONS(1316),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1316),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1316),
    [anon_sym_BQUOTE] = ACTIONS(1316),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1316),
    [anon_sym_LT_LPAREN] = ACTIONS(1316),
    [anon_sym_GT_LPAREN] = ACTIONS(1316),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1318),
    [sym_test_operator] = ACTIONS(1318),
    [sym__bare_dollar] = ACTIONS(1318),
    [sym__brace_start] = ACTIONS(1318),
  },
  [STATE(489)] = {
    [aux_sym__literal_repeat1] = STATE(488),
    [sym_word] = ACTIONS(237),
    [anon_sym_SEMI] = ACTIONS(237),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_GT_EQ] = ACTIONS(239),
    [anon_sym_AMP_EQ] = ACTIONS(239),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(239),
    [anon_sym_PIPE_PIPE] = ACTIONS(241),
    [anon_sym_AMP_AMP] = ACTIONS(241),
    [anon_sym_PIPE] = ACTIONS(241),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(241),
    [anon_sym_EQ_EQ] = ACTIONS(241),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_EQ] = ACTIONS(239),
    [anon_sym_LT_LT] = ACTIONS(241),
    [anon_sym_GT_GT] = ACTIONS(241),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(241),
    [anon_sym_SEMI_SEMI] = ACTIONS(237),
    [anon_sym_PIPE_AMP] = ACTIONS(237),
    [anon_sym_EQ_TILDE] = ACTIONS(241),
    [anon_sym_AMP_GT] = ACTIONS(237),
    [anon_sym_AMP_GT_GT] = ACTIONS(237),
    [anon_sym_LT_AMP] = ACTIONS(237),
    [anon_sym_GT_AMP] = ACTIONS(237),
    [anon_sym_GT_PIPE] = ACTIONS(237),
    [anon_sym_LT_AMP_DASH] = ACTIONS(237),
    [anon_sym_GT_AMP_DASH] = ACTIONS(237),
    [anon_sym_LT_LT_DASH] = ACTIONS(237),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(276),
    [anon_sym_LT_LT_LT] = ACTIONS(237),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(237),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(237),
    [anon_sym_DOLLAR] = ACTIONS(237),
    [sym__special_character] = ACTIONS(1323),
    [anon_sym_DQUOTE] = ACTIONS(237),
    [sym_raw_string] = ACTIONS(237),
    [sym_ansi_c_string] = ACTIONS(237),
    [aux_sym_number_token1] = ACTIONS(237),
    [aux_sym_number_token2] = ACTIONS(237),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(237),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(237),
    [anon_sym_BQUOTE] = ACTIONS(237),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(237),
    [anon_sym_LT_LPAREN] = ACTIONS(237),
    [anon_sym_GT_LPAREN] = ACTIONS(237),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(276),
    [sym_test_operator] = ACTIONS(360),
    [sym__bare_dollar] = ACTIONS(276),
    [sym__brace_start] = ACTIONS(276),
  },
  [STATE(490)] = {
    [sym_word] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(1233),
    [anon_sym_EQ] = ACTIONS(1235),
    [anon_sym_PLUS_PLUS] = ACTIONS(1235),
    [anon_sym_DASH_DASH] = ACTIONS(1235),
    [anon_sym_PLUS_EQ] = ACTIONS(1235),
    [anon_sym_DASH_EQ] = ACTIONS(1235),
    [anon_sym_STAR_EQ] = ACTIONS(1235),
    [anon_sym_SLASH_EQ] = ACTIONS(1235),
    [anon_sym_PERCENT_EQ] = ACTIONS(1235),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT_EQ] = ACTIONS(1235),
    [anon_sym_GT_GT_EQ] = ACTIONS(1235),
    [anon_sym_AMP_EQ] = ACTIONS(1235),
    [anon_sym_CARET_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_PIPE] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1237),
    [anon_sym_PIPE] = ACTIONS(1237),
    [anon_sym_CARET] = ACTIONS(1235),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_EQ_EQ] = ACTIONS(1237),
    [anon_sym_BANG_EQ] = ACTIONS(1235),
    [anon_sym_LT] = ACTIONS(1237),
    [anon_sym_GT] = ACTIONS(1237),
    [anon_sym_LT_EQ] = ACTIONS(1235),
    [anon_sym_GT_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT] = ACTIONS(1237),
    [anon_sym_GT_GT] = ACTIONS(1237),
    [anon_sym_PLUS] = ACTIONS(1235),
    [anon_sym_DASH] = ACTIONS(1235),
    [anon_sym_STAR] = ACTIONS(1235),
    [anon_sym_SLASH] = ACTIONS(1235),
    [anon_sym_PERCENT] = ACTIONS(1235),
    [anon_sym_STAR_STAR] = ACTIONS(1235),
    [anon_sym_LPAREN] = ACTIONS(1233),
    [anon_sym_RPAREN] = ACTIONS(1237),
    [anon_sym_SEMI_SEMI] = ACTIONS(1233),
    [anon_sym_PIPE_AMP] = ACTIONS(1233),
    [anon_sym_EQ_TILDE] = ACTIONS(1237),
    [anon_sym_AMP_GT] = ACTIONS(1233),
    [anon_sym_AMP_GT_GT] = ACTIONS(1233),
    [anon_sym_LT_AMP] = ACTIONS(1233),
    [anon_sym_GT_AMP] = ACTIONS(1233),
    [anon_sym_GT_PIPE] = ACTIONS(1233),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1233),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1233),
    [anon_sym_LT_LT_DASH] = ACTIONS(1233),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1240),
    [anon_sym_LT_LT_LT] = ACTIONS(1233),
    [anon_sym_QMARK] = ACTIONS(1235),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1233),
    [anon_sym_DOLLAR] = ACTIONS(1233),
    [sym__special_character] = ACTIONS(1233),
    [anon_sym_DQUOTE] = ACTIONS(1233),
    [sym_raw_string] = ACTIONS(1233),
    [sym_ansi_c_string] = ACTIONS(1233),
    [aux_sym_number_token1] = ACTIONS(1233),
    [aux_sym_number_token2] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1233),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1233),
    [anon_sym_BQUOTE] = ACTIONS(1233),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1233),
    [anon_sym_LT_LPAREN] = ACTIONS(1233),
    [anon_sym_GT_LPAREN] = ACTIONS(1233),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1240),
    [sym_test_operator] = ACTIONS(1242),
    [sym__bare_dollar] = ACTIONS(1240),
    [sym__brace_start] = ACTIONS(1240),
  },
  [STATE(491)] = {
    [sym_word] = ACTIONS(1223),
    [anon_sym_SEMI] = ACTIONS(1223),
    [anon_sym_EQ] = ACTIONS(1223),
    [anon_sym_PLUS_PLUS] = ACTIONS(1223),
    [anon_sym_DASH_DASH] = ACTIONS(1223),
    [anon_sym_PLUS_EQ] = ACTIONS(1223),
    [anon_sym_DASH_EQ] = ACTIONS(1223),
    [anon_sym_STAR_EQ] = ACTIONS(1223),
    [anon_sym_SLASH_EQ] = ACTIONS(1223),
    [anon_sym_PERCENT_EQ] = ACTIONS(1223),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1223),
    [anon_sym_LT_LT_EQ] = ACTIONS(1223),
    [anon_sym_GT_GT_EQ] = ACTIONS(1223),
    [anon_sym_AMP_EQ] = ACTIONS(1223),
    [anon_sym_CARET_EQ] = ACTIONS(1223),
    [anon_sym_PIPE_EQ] = ACTIONS(1223),
    [anon_sym_PIPE_PIPE] = ACTIONS(1223),
    [anon_sym_AMP_AMP] = ACTIONS(1223),
    [anon_sym_PIPE] = ACTIONS(1223),
    [anon_sym_CARET] = ACTIONS(1223),
    [anon_sym_AMP] = ACTIONS(1223),
    [anon_sym_EQ_EQ] = ACTIONS(1223),
    [anon_sym_BANG_EQ] = ACTIONS(1223),
    [anon_sym_LT] = ACTIONS(1223),
    [anon_sym_GT] = ACTIONS(1223),
    [anon_sym_LT_EQ] = ACTIONS(1223),
    [anon_sym_GT_EQ] = ACTIONS(1223),
    [anon_sym_LT_LT] = ACTIONS(1223),
    [anon_sym_GT_GT] = ACTIONS(1223),
    [anon_sym_PLUS] = ACTIONS(1223),
    [anon_sym_DASH] = ACTIONS(1223),
    [anon_sym_STAR] = ACTIONS(1223),
    [anon_sym_SLASH] = ACTIONS(1223),
    [anon_sym_PERCENT] = ACTIONS(1223),
    [anon_sym_STAR_STAR] = ACTIONS(1223),
    [anon_sym_LPAREN] = ACTIONS(1223),
    [anon_sym_RPAREN] = ACTIONS(1223),
    [anon_sym_SEMI_SEMI] = ACTIONS(1223),
    [anon_sym_PIPE_AMP] = ACTIONS(1223),
    [anon_sym_EQ_TILDE] = ACTIONS(1223),
    [anon_sym_AMP_GT] = ACTIONS(1223),
    [anon_sym_AMP_GT_GT] = ACTIONS(1223),
    [anon_sym_LT_AMP] = ACTIONS(1223),
    [anon_sym_GT_AMP] = ACTIONS(1223),
    [anon_sym_GT_PIPE] = ACTIONS(1223),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1223),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1223),
    [anon_sym_LT_LT_DASH] = ACTIONS(1223),
    [aux_sym_heredoc_redirect_token1] = ACTIONS(1225),
    [anon_sym_LT_LT_LT] = ACTIONS(1223),
    [anon_sym_QMARK] = ACTIONS(1223),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1223),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1223),
    [anon_sym_DOLLAR] = ACTIONS(1223),
    [sym__special_character] = ACTIONS(1223),
    [anon_sym_DQUOTE] = ACTIONS(1223),
    [sym_raw_string] = ACTIONS(1223),
    [sym_ansi_c_string] = ACTIONS(1223),
    [aux_sym_number_token1] = ACTIONS(1223),
    [aux_sym_number_token2] = ACTIONS(1223),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1223),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1223),
    [anon_sym_BQUOTE] = ACTIONS(1223),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1223),
    [anon_sym_LT_LPAREN] = ACTIONS(1223),
    [anon_sym_GT_LPAREN] = ACTIONS(1223),
    [sym_comment] = ACTIONS(3),
    [sym_file_descriptor] = ACTIONS(1225),
    [sym_test_operator] = ACTIONS(1225),
    [sym__bare_dollar] = ACTIONS(1225),
    [sym__brace_start] = ACTIONS(1225),
  },
  [STATE(492)] = {
    [aux_sym_concatenation_repeat1] = STATE(494),
    [sym_word] = ACTIONS(1227),
    [anon_sym_EQ] = ACTIONS(1227),
    [anon_sym_PLUS_PLUS] = ACTIONS(1227),
    [anon_sym_DASH_DASH] = ACTIONS(1227),
    [anon_sym_PLUS_EQ] = ACTIONS(1227),
    [anon_sym_DASH_EQ] = ACTIONS(1227),
    [anon_sym_STAR_EQ] = ACTIONS(1227),
    [anon_sym_SLASH_EQ] = ACTIONS(1227),
    [anon_sym_PERCENT_EQ] = ACTIONS(1227),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1227),
    [anon_sym_LT_LT_EQ] = ACTIONS(1229),
    [anon_sym_GT_GT_EQ] = ACTIONS(1229),
    [anon_sym_AMP_EQ] = ACTIONS(1229),
    [anon_sym_CARET_EQ] = ACTIONS(1227),
    [anon_sym_PIPE_EQ] = ACTIONS(1229),
    [anon_sym_PIPE_PIPE] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1229),
    [anon_sym_PIPE] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1227),
    [anon_sym_AMP] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_LT] = ACTIONS(1227),
    [anon_sym_GT] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1229),
    [anon_sym_GT_EQ] = ACTIONS(1229),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1227),
    [anon_sym_PLUS] = ACTIONS(1227),
    [anon_sym_DASH] = ACTIONS(1227),
    [anon_sym_STAR] = ACTIONS(1227),
    [anon_sym_SLASH] = ACTIONS(1227),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_STAR_STAR] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_PIPE_AMP] = ACTIONS(1229),
    [anon_sym_RBRACK] = ACTIONS(1229),
    [anon_sym_EQ_TILDE] = ACTIONS(1227),
    [anon_sym_AMP_GT] = ACTIONS(1227),
    [anon_sym_AMP_GT_GT] = ACTIONS(1229),
    [anon_sym_LT_AMP] = ACTIONS(1227),
    [anon_sym_GT_AMP] = ACTIONS(1227),
    [anon_sym_GT_PIPE] = ACTIONS(1229),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1229),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1229),
    [anon_sym_LT_LT_DASH] = ACTIONS(1229),
    [anon_sym_LT_LT_LT] = ACTIONS(1229),
    [anon_sym_QMARK] = ACTIONS(1227),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1229),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1229),
    [aux_sym_concatenation_token1] = ACTIONS(371),
    [anon_sym_DOLLAR] = ACTIONS(1227),
    [sym__special_character] = ACTIONS(1227),
    [anon_sym_DQUOTE] = ACTIONS(1229),
    [sym_raw_string] = ACTIONS(1229),
    [sym_ansi_c_string] = ACTIONS(1229),
    [aux_sym_number_token1] = ACTIONS(1227),
    [aux_sym_number_token2] = ACTIONS(1227),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1229),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1227),
    [anon_sym_BQUOTE] = ACTIONS(1227),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1229),
    [anon_sym_LT_LPAREN] = ACTIONS(1229),
    [anon_sym_GT_LPAREN] = ACTIONS(1229),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1229),
    [sym__concat] = ACTIONS(1325),
    [sym_test_operator] = ACTIONS(1229),
    [sym__bare_dollar] = ACTIONS(1229),
    [sym__brace_start] = ACTIONS(1229),
  },
  [STATE(493)] = {
    [aux_sym_concatenation_repeat1] = STATE(494),
    [sym_word] = ACTIONS(1207),
    [anon_sym_EQ] = ACTIONS(1207),
    [anon_sym_PLUS_PLUS] = ACTIONS(1207),
    [anon_sym_DASH_DASH] = ACTIONS(1207),
    [anon_sym_PLUS_EQ] = ACTIONS(1207),
    [anon_sym_DASH_EQ] = ACTIONS(1207),
    [anon_sym_STAR_EQ] = ACTIONS(1207),
    [anon_sym_SLASH_EQ] = ACTIONS(1207),
    [anon_sym_PERCENT_EQ] = ACTIONS(1207),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1207),
    [anon_sym_LT_LT_EQ] = ACTIONS(1209),
    [anon_sym_GT_GT_EQ] = ACTIONS(1209),
    [anon_sym_AMP_EQ] = ACTIONS(1209),
    [anon_sym_CARET_EQ] = ACTIONS(1207),
    [anon_sym_PIPE_EQ] = ACTIONS(1209),
    [anon_sym_PIPE_PIPE] = ACTIONS(1209),
    [anon_sym_AMP_AMP] = ACTIONS(1209),
    [anon_sym_PIPE] = ACTIONS(1207),
    [anon_sym_CARET] = ACTIONS(1207),
    [anon_sym_AMP] = ACTIONS(1207),
    [anon_sym_EQ_EQ] = ACTIONS(1207),
    [anon_sym_BANG_EQ] = ACTIONS(1207),
    [anon_sym_LT] = ACTIONS(1207),
    [anon_sym_GT] = ACTIONS(1207),
    [anon_sym_LT_EQ] = ACTIONS(1209),
    [anon_sym_GT_EQ] = ACTIONS(1209),
    [anon_sym_LT_LT] = ACTIONS(1207),
    [anon_sym_GT_GT] = ACTIONS(1207),
    [anon_sym_PLUS] = ACTIONS(1207),
    [anon_sym_DASH] = ACTIONS(1207),
    [anon_sym_STAR] = ACTIONS(1207),
    [anon_sym_SLASH] = ACTIONS(1207),
    [anon_sym_PERCENT] = ACTIONS(1207),
    [anon_sym_STAR_STAR] = ACTIONS(1207),
    [anon_sym_LPAREN] = ACTIONS(1209),
    [anon_sym_PIPE_AMP] = ACTIONS(1209),
    [anon_sym_RBRACK] = ACTIONS(1209),
    [anon_sym_EQ_TILDE] = ACTIONS(1207),
    [anon_sym_AMP_GT] = ACTIONS(1207),
    [anon_sym_AMP_GT_GT] = ACTIONS(1209),
    [anon_sym_LT_AMP] = ACTIONS(1207),
    [anon_sym_GT_AMP] = ACTIONS(1207),
    [anon_sym_GT_PIPE] = ACTIONS(1209),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1209),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1209),
    [anon_sym_LT_LT_DASH] = ACTIONS(1209),
    [anon_sym_LT_LT_LT] = ACTIONS(1209),
    [anon_sym_QMARK] = ACTIONS(1207),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1209),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1209),
    [aux_sym_concatenation_token1] = ACTIONS(371),
    [anon_sym_DOLLAR] = ACTIONS(1207),
    [sym__special_character] = ACTIONS(1207),
    [anon_sym_DQUOTE] = ACTIONS(1209),
    [sym_raw_string] = ACTIONS(1209),
    [sym_ansi_c_string] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1207),
    [aux_sym_number_token2] = ACTIONS(1207),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1209),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1207),
    [anon_sym_BQUOTE] = ACTIONS(1207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1209),
    [anon_sym_LT_LPAREN] = ACTIONS(1209),
    [anon_sym_GT_LPAREN] = ACTIONS(1209),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1209),
    [sym__concat] = ACTIONS(1327),
    [sym_test_operator] = ACTIONS(1209),
    [sym__bare_dollar] = ACTIONS(1209),
    [sym__brace_start] = ACTIONS(1209),
  },
  [STATE(494)] = {
    [aux_sym_concatenation_repeat1] = STATE(494),
    [sym_word] = ACTIONS(1213),
    [anon_sym_EQ] = ACTIONS(1213),
    [anon_sym_PLUS_PLUS] = ACTIONS(1213),
    [anon_sym_DASH_DASH] = ACTIONS(1213),
    [anon_sym_PLUS_EQ] = ACTIONS(1213),
    [anon_sym_DASH_EQ] = ACTIONS(1213),
    [anon_sym_STAR_EQ] = ACTIONS(1213),
    [anon_sym_SLASH_EQ] = ACTIONS(1213),
    [anon_sym_PERCENT_EQ] = ACTIONS(1213),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1213),
    [anon_sym_LT_LT_EQ] = ACTIONS(1215),
    [anon_sym_GT_GT_EQ] = ACTIONS(1215),
    [anon_sym_AMP_EQ] = ACTIONS(1215),
    [anon_sym_CARET_EQ] = ACTIONS(1213),
    [anon_sym_PIPE_EQ] = ACTIONS(1215),
    [anon_sym_PIPE_PIPE] = ACTIONS(1215),
    [anon_sym_AMP_AMP] = ACTIONS(1215),
    [anon_sym_PIPE] = ACTIONS(1213),
    [anon_sym_CARET] = ACTIONS(1213),
    [anon_sym_AMP] = ACTIONS(1213),
    [anon_sym_EQ_EQ] = ACTIONS(1213),
    [anon_sym_BANG_EQ] = ACTIONS(1213),
    [anon_sym_LT] = ACTIONS(1213),
    [anon_sym_GT] = ACTIONS(1213),
    [anon_sym_LT_EQ] = ACTIONS(1215),
    [anon_sym_GT_EQ] = ACTIONS(1215),
    [anon_sym_LT_LT] = ACTIONS(1213),
    [anon_sym_GT_GT] = ACTIONS(1213),
    [anon_sym_PLUS] = ACTIONS(1213),
    [anon_sym_DASH] = ACTIONS(1213),
    [anon_sym_STAR] = ACTIONS(1213),
    [anon_sym_SLASH] = ACTIONS(1213),
    [anon_sym_PERCENT] = ACTIONS(1213),
    [anon_sym_STAR_STAR] = ACTIONS(1213),
    [anon_sym_LPAREN] = ACTIONS(1215),
    [anon_sym_PIPE_AMP] = ACTIONS(1215),
    [anon_sym_RBRACK] = ACTIONS(1215),
    [anon_sym_EQ_TILDE] = ACTIONS(1213),
    [anon_sym_AMP_GT] = ACTIONS(1213),
    [anon_sym_AMP_GT_GT] = ACTIONS(1215),
    [anon_sym_LT_AMP] = ACTIONS(1213),
    [anon_sym_GT_AMP] = ACTIONS(1213),
    [anon_sym_GT_PIPE] = ACTIONS(1215),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1215),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1215),
    [anon_sym_LT_LT_DASH] = ACTIONS(1215),
    [anon_sym_LT_LT_LT] = ACTIONS(1215),
    [anon_sym_QMARK] = ACTIONS(1213),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1215),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1215),
    [aux_sym_concatenation_token1] = ACTIONS(1329),
    [anon_sym_DOLLAR] = ACTIONS(1213),
    [sym__special_character] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_raw_string] = ACTIONS(1215),
    [sym_ansi_c_string] = ACTIONS(1215),
    [aux_sym_number_token1] = ACTIONS(1213),
    [aux_sym_number_token2] = ACTIONS(1213),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1215),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1213),
    [anon_sym_BQUOTE] = ACTIONS(1213),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1215),
    [anon_sym_LT_LPAREN] = ACTIONS(1215),
    [anon_sym_GT_LPAREN] = ACTIONS(1215),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1215),
    [sym__concat] = ACTIONS(1329),
    [sym_test_operator] = ACTIONS(1215),
    [sym__bare_dollar] = ACTIONS(1215),
    [sym__brace_start] = ACTIONS(1215),
  },
  [STATE(495)] = {
    [aux_sym_concatenation_repeat1] = STATE(493),
    [sym_word] = ACTIONS(1233),
    [anon_sym_EQ] = ACTIONS(1235),
    [anon_sym_PLUS_PLUS] = ACTIONS(1235),
    [anon_sym_DASH_DASH] = ACTIONS(1235),
    [anon_sym_PLUS_EQ] = ACTIONS(1235),
    [anon_sym_DASH_EQ] = ACTIONS(1235),
    [anon_sym_STAR_EQ] = ACTIONS(1235),
    [anon_sym_SLASH_EQ] = ACTIONS(1235),
    [anon_sym_PERCENT_EQ] = ACTIONS(1235),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT_EQ] = ACTIONS(1332),
    [anon_sym_GT_GT_EQ] = ACTIONS(1332),
    [anon_sym_AMP_EQ] = ACTIONS(1332),
    [anon_sym_CARET_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_EQ] = ACTIONS(1332),
    [anon_sym_PIPE_PIPE] = ACTIONS(1242),
    [anon_sym_AMP_AMP] = ACTIONS(1242),
    [anon_sym_PIPE] = ACTIONS(1237),
    [anon_sym_CARET] = ACTIONS(1235),
    [anon_sym_AMP] = ACTIONS(1235),
    [anon_sym_EQ_EQ] = ACTIONS(1237),
    [anon_sym_BANG_EQ] = ACTIONS(1235),
    [anon_sym_LT] = ACTIONS(1237),
    [anon_sym_GT] = ACTIONS(1237),
    [anon_sym_LT_EQ] = ACTIONS(1332),
    [anon_sym_GT_EQ] = ACTIONS(1332),
    [anon_sym_LT_LT] = ACTIONS(1237),
    [anon_sym_GT_GT] = ACTIONS(1237),
    [anon_sym_PLUS] = ACTIONS(1235),
    [anon_sym_DASH] = ACTIONS(1235),
    [anon_sym_STAR] = ACTIONS(1235),
    [anon_sym_SLASH] = ACTIONS(1235),
    [anon_sym_PERCENT] = ACTIONS(1235),
    [anon_sym_STAR_STAR] = ACTIONS(1235),
    [anon_sym_LPAREN] = ACTIONS(1334),
    [anon_sym_PIPE_AMP] = ACTIONS(1240),
    [anon_sym_RBRACK] = ACTIONS(1332),
    [anon_sym_EQ_TILDE] = ACTIONS(1237),
    [anon_sym_AMP_GT] = ACTIONS(1233),
    [anon_sym_AMP_GT_GT] = ACTIONS(1240),
    [anon_sym_LT_AMP] = ACTIONS(1233),
    [anon_sym_GT_AMP] = ACTIONS(1233),
    [anon_sym_GT_PIPE] = ACTIONS(1240),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1240),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1240),
    [anon_sym_LT_LT_DASH] = ACTIONS(1240),
    [anon_sym_LT_LT_LT] = ACTIONS(1240),
    [anon_sym_QMARK] = ACTIONS(1235),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1240),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1240),
    [aux_sym_concatenation_token1] = ACTIONS(371),
    [anon_sym_DOLLAR] = ACTIONS(1233),
    [sym__special_character] = ACTIONS(1233),
    [anon_sym_DQUOTE] = ACTIONS(1240),
    [sym_raw_string] = ACTIONS(1240),
    [sym_ansi_c_string] = ACTIONS(1240),
    [aux_sym_number_token1] = ACTIONS(1233),
    [aux_sym_number_token2] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1240),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1233),
    [anon_sym_BQUOTE] = ACTIONS(1233),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1240),
    [anon_sym_LT_LPAREN] = ACTIONS(1240),
    [anon_sym_GT_LPAREN] = ACTIONS(1240),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1240),
    [sym__concat] = ACTIONS(371),
    [sym_test_operator] = ACTIONS(1242),
    [sym__bare_dollar] = ACTIONS(1240),
    [sym__brace_start] = ACTIONS(1240),
  },
  [STATE(496)] = {
    [aux_sym_concatenation_repeat1] = STATE(493),
    [sym_word] = ACTIONS(1233),
    [anon_sym_EQ] = ACTIONS(1235),
    [anon_sym_PLUS_PLUS] = ACTIONS(1235),
    [anon_sym_DASH_DASH] = ACTIONS(1235),
    [anon_sym_PLUS_EQ] = ACTIONS(1235),
    [anon_sym_DASH_EQ] = ACTIONS(1235),
    [anon_sym_STAR_EQ] = ACTIONS(1235),
    [anon_sym_SLASH_EQ] = ACTIONS(1235),
    [anon_sym_PERCENT_EQ] = ACTIONS(1235),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT_EQ] = ACTIONS(1332),
    [anon_sym_GT_GT_EQ] = ACTIONS(1332),
    [anon_sym_AMP_EQ] = ACTIONS(1332),
    [anon_sym_CARET_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_EQ] = ACTIONS(1332),
    [anon_sym_PIPE_PIPE] = ACTIONS(1242),
    [anon_sym_AMP_AMP] = ACTIONS(1242),
    [anon_sym_PIPE] = ACTIONS(1237),
    [anon_sym_CARET] = ACTIONS(1235),
    [anon_sym_AMP] = ACTIONS(1235),
    [anon_sym_EQ_EQ] = ACTIONS(1237),
    [anon_sym_BANG_EQ] = ACTIONS(1235),
    [anon_sym_LT] = ACTIONS(1237),
    [anon_sym_GT] = ACTIONS(1237),
    [anon_sym_LT_EQ] = ACTIONS(1332),
    [anon_sym_GT_EQ] = ACTIONS(1332),
    [anon_sym_LT_LT] = ACTIONS(1237),
    [anon_sym_GT_GT] = ACTIONS(1237),
    [anon_sym_PLUS] = ACTIONS(1235),
    [anon_sym_DASH] = ACTIONS(1235),
    [anon_sym_STAR] = ACTIONS(1235),
    [anon_sym_SLASH] = ACTIONS(1235),
    [anon_sym_PERCENT] = ACTIONS(1235),
    [anon_sym_STAR_STAR] = ACTIONS(1235),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_PIPE_AMP] = ACTIONS(1240),
    [anon_sym_RBRACK] = ACTIONS(1332),
    [anon_sym_EQ_TILDE] = ACTIONS(1237),
    [anon_sym_AMP_GT] = ACTIONS(1233),
    [anon_sym_AMP_GT_GT] = ACTIONS(1240),
    [anon_sym_LT_AMP] = ACTIONS(1233),
    [anon_sym_GT_AMP] = ACTIONS(1233),
    [anon_sym_GT_PIPE] = ACTIONS(1240),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1240),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1240),
    [anon_sym_LT_LT_DASH] = ACTIONS(1240),
    [anon_sym_LT_LT_LT] = ACTIONS(1240),
    [anon_sym_QMARK] = ACTIONS(1235),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1240),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1240),
    [aux_sym_concatenation_token1] = ACTIONS(371),
    [anon_sym_DOLLAR] = ACTIONS(1233),
    [sym__special_character] = ACTIONS(1233),
    [anon_sym_DQUOTE] = ACTIONS(1240),
    [sym_raw_string] = ACTIONS(1240),
    [sym_ansi_c_string] = ACTIONS(1240),
    [aux_sym_number_token1] = ACTIONS(1233),
    [aux_sym_number_token2] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1240),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1233),
    [anon_sym_BQUOTE] = ACTIONS(1233),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1240),
    [anon_sym_LT_LPAREN] = ACTIONS(1240),
    [anon_sym_GT_LPAREN] = ACTIONS(1240),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1240),
    [sym__concat] = ACTIONS(371),
    [sym_test_operator] = ACTIONS(1242),
    [sym__bare_dollar] = ACTIONS(1240),
    [sym__brace_start] = ACTIONS(1240),
  },
  [STATE(497)] = {
    [aux_sym_concatenation_repeat1] = STATE(492),
    [sym_word] = ACTIONS(1223),
    [anon_sym_EQ] = ACTIONS(1223),
    [anon_sym_PLUS_PLUS] = ACTIONS(1223),
    [anon_sym_DASH_DASH] = ACTIONS(1223),
    [anon_sym_PLUS_EQ] = ACTIONS(1223),
    [anon_sym_DASH_EQ] = ACTIONS(1223),
    [anon_sym_STAR_EQ] = ACTIONS(1223),
    [anon_sym_SLASH_EQ] = ACTIONS(1223),
    [anon_sym_PERCENT_EQ] = ACTIONS(1223),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1223),
    [anon_sym_LT_LT_EQ] = ACTIONS(1225),
    [anon_sym_GT_GT_EQ] = ACTIONS(1225),
    [anon_sym_AMP_EQ] = ACTIONS(1225),
    [anon_sym_CARET_EQ] = ACTIONS(1223),
    [anon_sym_PIPE_EQ] = ACTIONS(1225),
    [anon_sym_PIPE_PIPE] = ACTIONS(1225),
    [anon_sym_AMP_AMP] = ACTIONS(1225),
    [anon_sym_PIPE] = ACTIONS(1223),
    [anon_sym_CARET] = ACTIONS(1223),
    [anon_sym_AMP] = ACTIONS(1223),
    [anon_sym_EQ_EQ] = ACTIONS(1223),
    [anon_sym_BANG_EQ] = ACTIONS(1223),
    [anon_sym_LT] = ACTIONS(1223),
    [anon_sym_GT] = ACTIONS(1223),
    [anon_sym_LT_EQ] = ACTIONS(1225),
    [anon_sym_GT_EQ] = ACTIONS(1225),
    [anon_sym_LT_LT] = ACTIONS(1223),
    [anon_sym_GT_GT] = ACTIONS(1223),
    [anon_sym_PLUS] = ACTIONS(1223),
    [anon_sym_DASH] = ACTIONS(1223),
    [anon_sym_STAR] = ACTIONS(1223),
    [anon_sym_SLASH] = ACTIONS(1223),
    [anon_sym_PERCENT] = ACTIONS(1223),
    [anon_sym_STAR_STAR] = ACTIONS(1223),
    [anon_sym_LPAREN] = ACTIONS(1225),
    [anon_sym_PIPE_AMP] = ACTIONS(1225),
    [anon_sym_RBRACK] = ACTIONS(1225),
    [anon_sym_EQ_TILDE] = ACTIONS(1223),
    [anon_sym_AMP_GT] = ACTIONS(1223),
    [anon_sym_AMP_GT_GT] = ACTIONS(1225),
    [anon_sym_LT_AMP] = ACTIONS(1223),
    [anon_sym_GT_AMP] = ACTIONS(1223),
    [anon_sym_GT_PIPE] = ACTIONS(1225),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1225),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1225),
    [anon_sym_LT_LT_DASH] = ACTIONS(1225),
    [anon_sym_LT_LT_LT] = ACTIONS(1225),
    [anon_sym_QMARK] = ACTIONS(1223),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1225),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1225),
    [aux_sym_concatenation_token1] = ACTIONS(371),
    [anon_sym_DOLLAR] = ACTIONS(1223),
    [sym__special_character] = ACTIONS(1223),
    [anon_sym_DQUOTE] = ACTIONS(1225),
    [sym_raw_string] = ACTIONS(1225),
    [sym_ansi_c_string] = ACTIONS(1225),
    [aux_sym_number_token1] = ACTIONS(1223),
    [aux_sym_number_token2] = ACTIONS(1223),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1225),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1223),
    [anon_sym_BQUOTE] = ACTIONS(1223),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1225),
    [anon_sym_LT_LPAREN] = ACTIONS(1225),
    [anon_sym_GT_LPAREN] = ACTIONS(1225),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1225),
    [sym__concat] = ACTIONS(371),
    [sym_test_operator] = ACTIONS(1225),
    [sym__bare_dollar] = ACTIONS(1225),
    [sym__brace_start] = ACTIONS(1225),
  },
  [STATE(498)] = {
    [sym_word] = ACTIONS(1264),
    [anon_sym_EQ] = ACTIONS(1264),
    [anon_sym_PLUS_PLUS] = ACTIONS(1264),
    [anon_sym_DASH_DASH] = ACTIONS(1264),
    [anon_sym_PLUS_EQ] = ACTIONS(1264),
    [anon_sym_DASH_EQ] = ACTIONS(1264),
    [anon_sym_STAR_EQ] = ACTIONS(1264),
    [anon_sym_SLASH_EQ] = ACTIONS(1264),
    [anon_sym_PERCENT_EQ] = ACTIONS(1264),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1264),
    [anon_sym_LT_LT_EQ] = ACTIONS(1266),
    [anon_sym_GT_GT_EQ] = ACTIONS(1266),
    [anon_sym_AMP_EQ] = ACTIONS(1266),
    [anon_sym_CARET_EQ] = ACTIONS(1264),
    [anon_sym_PIPE_EQ] = ACTIONS(1266),
    [anon_sym_PIPE_PIPE] = ACTIONS(1266),
    [anon_sym_AMP_AMP] = ACTIONS(1266),
    [anon_sym_PIPE] = ACTIONS(1264),
    [anon_sym_CARET] = ACTIONS(1264),
    [anon_sym_AMP] = ACTIONS(1264),
    [anon_sym_EQ_EQ] = ACTIONS(1264),
    [anon_sym_BANG_EQ] = ACTIONS(1264),
    [anon_sym_LT] = ACTIONS(1264),
    [anon_sym_GT] = ACTIONS(1264),
    [anon_sym_LT_EQ] = ACTIONS(1266),
    [anon_sym_GT_EQ] = ACTIONS(1266),
    [anon_sym_LT_LT] = ACTIONS(1264),
    [anon_sym_GT_GT] = ACTIONS(1264),
    [anon_sym_PLUS] = ACTIONS(1264),
    [anon_sym_DASH] = ACTIONS(1264),
    [anon_sym_STAR] = ACTIONS(1264),
    [anon_sym_SLASH] = ACTIONS(1264),
    [anon_sym_PERCENT] = ACTIONS(1264),
    [anon_sym_STAR_STAR] = ACTIONS(1264),
    [anon_sym_LPAREN] = ACTIONS(1266),
    [anon_sym_PIPE_AMP] = ACTIONS(1266),
    [anon_sym_RBRACK] = ACTIONS(1266),
    [anon_sym_EQ_TILDE] = ACTIONS(1264),
    [anon_sym_AMP_GT] = ACTIONS(1264),
    [anon_sym_AMP_GT_GT] = ACTIONS(1266),
    [anon_sym_LT_AMP] = ACTIONS(1264),
    [anon_sym_GT_AMP] = ACTIONS(1264),
    [anon_sym_GT_PIPE] = ACTIONS(1266),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1266),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1266),
    [anon_sym_LT_LT_DASH] = ACTIONS(1266),
    [anon_sym_LT_LT_LT] = ACTIONS(1266),
    [anon_sym_QMARK] = ACTIONS(1264),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1266),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1266),
    [aux_sym_concatenation_token1] = ACTIONS(1266),
    [anon_sym_DOLLAR] = ACTIONS(1264),
    [sym__special_character] = ACTIONS(1264),
    [anon_sym_DQUOTE] = ACTIONS(1266),
    [sym_raw_string] = ACTIONS(1266),
    [sym_ansi_c_string] = ACTIONS(1266),
    [aux_sym_number_token1] = ACTIONS(1264),
    [aux_sym_number_token2] = ACTIONS(1264),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1266),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1264),
    [anon_sym_BQUOTE] = ACTIONS(1264),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1266),
    [anon_sym_LT_LPAREN] = ACTIONS(1266),
    [anon_sym_GT_LPAREN] = ACTIONS(1266),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1266),
    [sym__concat] = ACTIONS(1266),
    [sym_test_operator] = ACTIONS(1266),
    [sym__bare_dollar] = ACTIONS(1266),
    [sym__brace_start] = ACTIONS(1266),
  },
  [STATE(499)] = {
    [sym_word] = ACTIONS(1292),
    [anon_sym_EQ] = ACTIONS(1292),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_PLUS_EQ] = ACTIONS(1292),
    [anon_sym_DASH_EQ] = ACTIONS(1292),
    [anon_sym_STAR_EQ] = ACTIONS(1292),
    [anon_sym_SLASH_EQ] = ACTIONS(1292),
    [anon_sym_PERCENT_EQ] = ACTIONS(1292),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1292),
    [anon_sym_LT_LT_EQ] = ACTIONS(1294),
    [anon_sym_GT_GT_EQ] = ACTIONS(1294),
    [anon_sym_AMP_EQ] = ACTIONS(1294),
    [anon_sym_CARET_EQ] = ACTIONS(1292),
    [anon_sym_PIPE_EQ] = ACTIONS(1294),
    [anon_sym_PIPE_PIPE] = ACTIONS(1294),
    [anon_sym_AMP_AMP] = ACTIONS(1294),
    [anon_sym_PIPE] = ACTIONS(1292),
    [anon_sym_CARET] = ACTIONS(1292),
    [anon_sym_AMP] = ACTIONS(1292),
    [anon_sym_EQ_EQ] = ACTIONS(1292),
    [anon_sym_BANG_EQ] = ACTIONS(1292),
    [anon_sym_LT] = ACTIONS(1292),
    [anon_sym_GT] = ACTIONS(1292),
    [anon_sym_LT_EQ] = ACTIONS(1294),
    [anon_sym_GT_EQ] = ACTIONS(1294),
    [anon_sym_LT_LT] = ACTIONS(1292),
    [anon_sym_GT_GT] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1292),
    [anon_sym_DASH] = ACTIONS(1292),
    [anon_sym_STAR] = ACTIONS(1292),
    [anon_sym_SLASH] = ACTIONS(1292),
    [anon_sym_PERCENT] = ACTIONS(1292),
    [anon_sym_STAR_STAR] = ACTIONS(1292),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_PIPE_AMP] = ACTIONS(1294),
    [anon_sym_RBRACK] = ACTIONS(1294),
    [anon_sym_EQ_TILDE] = ACTIONS(1292),
    [anon_sym_AMP_GT] = ACTIONS(1292),
    [anon_sym_AMP_GT_GT] = ACTIONS(1294),
    [anon_sym_LT_AMP] = ACTIONS(1292),
    [anon_sym_GT_AMP] = ACTIONS(1292),
    [anon_sym_GT_PIPE] = ACTIONS(1294),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1294),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1294),
    [anon_sym_LT_LT_DASH] = ACTIONS(1294),
    [anon_sym_LT_LT_LT] = ACTIONS(1294),
    [anon_sym_QMARK] = ACTIONS(1292),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1294),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1294),
    [aux_sym_concatenation_token1] = ACTIONS(1294),
    [anon_sym_DOLLAR] = ACTIONS(1292),
    [sym__special_character] = ACTIONS(1292),
    [anon_sym_DQUOTE] = ACTIONS(1294),
    [sym_raw_string] = ACTIONS(1294),
    [sym_ansi_c_string] = ACTIONS(1294),
    [aux_sym_number_token1] = ACTIONS(1292),
    [aux_sym_number_token2] = ACTIONS(1292),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1294),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1292),
    [anon_sym_BQUOTE] = ACTIONS(1292),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1294),
    [anon_sym_LT_LPAREN] = ACTIONS(1294),
    [anon_sym_GT_LPAREN] = ACTIONS(1294),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1294),
    [sym__concat] = ACTIONS(1294),
    [sym_test_operator] = ACTIONS(1294),
    [sym__bare_dollar] = ACTIONS(1294),
    [sym__brace_start] = ACTIONS(1294),
  },
  [STATE(500)] = {
    [sym_word] = ACTIONS(1248),
    [anon_sym_EQ] = ACTIONS(1248),
    [anon_sym_PLUS_PLUS] = ACTIONS(1248),
    [anon_sym_DASH_DASH] = ACTIONS(1248),
    [anon_sym_PLUS_EQ] = ACTIONS(1248),
    [anon_sym_DASH_EQ] = ACTIONS(1248),
    [anon_sym_STAR_EQ] = ACTIONS(1248),
    [anon_sym_SLASH_EQ] = ACTIONS(1248),
    [anon_sym_PERCENT_EQ] = ACTIONS(1248),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1248),
    [anon_sym_LT_LT_EQ] = ACTIONS(1250),
    [anon_sym_GT_GT_EQ] = ACTIONS(1250),
    [anon_sym_AMP_EQ] = ACTIONS(1250),
    [anon_sym_CARET_EQ] = ACTIONS(1248),
    [anon_sym_PIPE_EQ] = ACTIONS(1250),
    [anon_sym_PIPE_PIPE] = ACTIONS(1250),
    [anon_sym_AMP_AMP] = ACTIONS(1250),
    [anon_sym_PIPE] = ACTIONS(1248),
    [anon_sym_CARET] = ACTIONS(1248),
    [anon_sym_AMP] = ACTIONS(1248),
    [anon_sym_EQ_EQ] = ACTIONS(1248),
    [anon_sym_BANG_EQ] = ACTIONS(1248),
    [anon_sym_LT] = ACTIONS(1248),
    [anon_sym_GT] = ACTIONS(1248),
    [anon_sym_LT_EQ] = ACTIONS(1250),
    [anon_sym_GT_EQ] = ACTIONS(1250),
    [anon_sym_LT_LT] = ACTIONS(1248),
    [anon_sym_GT_GT] = ACTIONS(1248),
    [anon_sym_PLUS] = ACTIONS(1248),
    [anon_sym_DASH] = ACTIONS(1248),
    [anon_sym_STAR] = ACTIONS(1248),
    [anon_sym_SLASH] = ACTIONS(1248),
    [anon_sym_PERCENT] = ACTIONS(1248),
    [anon_sym_STAR_STAR] = ACTIONS(1248),
    [anon_sym_LPAREN] = ACTIONS(1250),
    [anon_sym_PIPE_AMP] = ACTIONS(1250),
    [anon_sym_RBRACK] = ACTIONS(1250),
    [anon_sym_EQ_TILDE] = ACTIONS(1248),
    [anon_sym_AMP_GT] = ACTIONS(1248),
    [anon_sym_AMP_GT_GT] = ACTIONS(1250),
    [anon_sym_LT_AMP] = ACTIONS(1248),
    [anon_sym_GT_AMP] = ACTIONS(1248),
    [anon_sym_GT_PIPE] = ACTIONS(1250),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1250),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1250),
    [anon_sym_LT_LT_DASH] = ACTIONS(1250),
    [anon_sym_LT_LT_LT] = ACTIONS(1250),
    [anon_sym_QMARK] = ACTIONS(1248),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1250),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1250),
    [aux_sym_concatenation_token1] = ACTIONS(1250),
    [anon_sym_DOLLAR] = ACTIONS(1248),
    [sym__special_character] = ACTIONS(1248),
    [anon_sym_DQUOTE] = ACTIONS(1250),
    [sym_raw_string] = ACTIONS(1250),
    [sym_ansi_c_string] = ACTIONS(1250),
    [aux_sym_number_token1] = ACTIONS(1248),
    [aux_sym_number_token2] = ACTIONS(1248),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1250),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1248),
    [anon_sym_BQUOTE] = ACTIONS(1248),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1250),
    [anon_sym_LT_LPAREN] = ACTIONS(1250),
    [anon_sym_GT_LPAREN] = ACTIONS(1250),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1250),
    [sym__concat] = ACTIONS(1250),
    [sym_test_operator] = ACTIONS(1250),
    [sym__bare_dollar] = ACTIONS(1250),
    [sym__brace_start] = ACTIONS(1250),
  },
  [STATE(501)] = {
    [sym_word] = ACTIONS(1296),
    [anon_sym_EQ] = ACTIONS(1296),
    [anon_sym_PLUS_PLUS] = ACTIONS(1296),
    [anon_sym_DASH_DASH] = ACTIONS(1296),
    [anon_sym_PLUS_EQ] = ACTIONS(1296),
    [anon_sym_DASH_EQ] = ACTIONS(1296),
    [anon_sym_STAR_EQ] = ACTIONS(1296),
    [anon_sym_SLASH_EQ] = ACTIONS(1296),
    [anon_sym_PERCENT_EQ] = ACTIONS(1296),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1296),
    [anon_sym_LT_LT_EQ] = ACTIONS(1298),
    [anon_sym_GT_GT_EQ] = ACTIONS(1298),
    [anon_sym_AMP_EQ] = ACTIONS(1298),
    [anon_sym_CARET_EQ] = ACTIONS(1296),
    [anon_sym_PIPE_EQ] = ACTIONS(1298),
    [anon_sym_PIPE_PIPE] = ACTIONS(1298),
    [anon_sym_AMP_AMP] = ACTIONS(1298),
    [anon_sym_PIPE] = ACTIONS(1296),
    [anon_sym_CARET] = ACTIONS(1296),
    [anon_sym_AMP] = ACTIONS(1296),
    [anon_sym_EQ_EQ] = ACTIONS(1296),
    [anon_sym_BANG_EQ] = ACTIONS(1296),
    [anon_sym_LT] = ACTIONS(1296),
    [anon_sym_GT] = ACTIONS(1296),
    [anon_sym_LT_EQ] = ACTIONS(1298),
    [anon_sym_GT_EQ] = ACTIONS(1298),
    [anon_sym_LT_LT] = ACTIONS(1296),
    [anon_sym_GT_GT] = ACTIONS(1296),
    [anon_sym_PLUS] = ACTIONS(1296),
    [anon_sym_DASH] = ACTIONS(1296),
    [anon_sym_STAR] = ACTIONS(1296),
    [anon_sym_SLASH] = ACTIONS(1296),
    [anon_sym_PERCENT] = ACTIONS(1296),
    [anon_sym_STAR_STAR] = ACTIONS(1296),
    [anon_sym_LPAREN] = ACTIONS(1298),
    [anon_sym_PIPE_AMP] = ACTIONS(1298),
    [anon_sym_RBRACK] = ACTIONS(1298),
    [anon_sym_EQ_TILDE] = ACTIONS(1296),
    [anon_sym_AMP_GT] = ACTIONS(1296),
    [anon_sym_AMP_GT_GT] = ACTIONS(1298),
    [anon_sym_LT_AMP] = ACTIONS(1296),
    [anon_sym_GT_AMP] = ACTIONS(1296),
    [anon_sym_GT_PIPE] = ACTIONS(1298),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1298),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1298),
    [anon_sym_LT_LT_DASH] = ACTIONS(1298),
    [anon_sym_LT_LT_LT] = ACTIONS(1298),
    [anon_sym_QMARK] = ACTIONS(1296),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1298),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1298),
    [aux_sym_concatenation_token1] = ACTIONS(1298),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [sym__special_character] = ACTIONS(1296),
    [anon_sym_DQUOTE] = ACTIONS(1298),
    [sym_raw_string] = ACTIONS(1298),
    [sym_ansi_c_string] = ACTIONS(1298),
    [aux_sym_number_token1] = ACTIONS(1296),
    [aux_sym_number_token2] = ACTIONS(1296),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1298),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1296),
    [anon_sym_BQUOTE] = ACTIONS(1296),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1298),
    [anon_sym_LT_LPAREN] = ACTIONS(1298),
    [anon_sym_GT_LPAREN] = ACTIONS(1298),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1298),
    [sym__concat] = ACTIONS(1298),
    [sym_test_operator] = ACTIONS(1298),
    [sym__bare_dollar] = ACTIONS(1298),
    [sym__brace_start] = ACTIONS(1298),
  },
  [STATE(502)] = {
    [sym_word] = ACTIONS(1300),
    [anon_sym_EQ] = ACTIONS(1300),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_PLUS_EQ] = ACTIONS(1300),
    [anon_sym_DASH_EQ] = ACTIONS(1300),
    [anon_sym_STAR_EQ] = ACTIONS(1300),
    [anon_sym_SLASH_EQ] = ACTIONS(1300),
    [anon_sym_PERCENT_EQ] = ACTIONS(1300),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1300),
    [anon_sym_LT_LT_EQ] = ACTIONS(1302),
    [anon_sym_GT_GT_EQ] = ACTIONS(1302),
    [anon_sym_AMP_EQ] = ACTIONS(1302),
    [anon_sym_CARET_EQ] = ACTIONS(1300),
    [anon_sym_PIPE_EQ] = ACTIONS(1302),
    [anon_sym_PIPE_PIPE] = ACTIONS(1302),
    [anon_sym_AMP_AMP] = ACTIONS(1302),
    [anon_sym_PIPE] = ACTIONS(1300),
    [anon_sym_CARET] = ACTIONS(1300),
    [anon_sym_AMP] = ACTIONS(1300),
    [anon_sym_EQ_EQ] = ACTIONS(1300),
    [anon_sym_BANG_EQ] = ACTIONS(1300),
    [anon_sym_LT] = ACTIONS(1300),
    [anon_sym_GT] = ACTIONS(1300),
    [anon_sym_LT_EQ] = ACTIONS(1302),
    [anon_sym_GT_EQ] = ACTIONS(1302),
    [anon_sym_LT_LT] = ACTIONS(1300),
    [anon_sym_GT_GT] = ACTIONS(1300),
    [anon_sym_PLUS] = ACTIONS(1300),
    [anon_sym_DASH] = ACTIONS(1300),
    [anon_sym_STAR] = ACTIONS(1300),
    [anon_sym_SLASH] = ACTIONS(1300),
    [anon_sym_PERCENT] = ACTIONS(1300),
    [anon_sym_STAR_STAR] = ACTIONS(1300),
    [anon_sym_LPAREN] = ACTIONS(1302),
    [anon_sym_PIPE_AMP] = ACTIONS(1302),
    [anon_sym_RBRACK] = ACTIONS(1302),
    [anon_sym_EQ_TILDE] = ACTIONS(1300),
    [anon_sym_AMP_GT] = ACTIONS(1300),
    [anon_sym_AMP_GT_GT] = ACTIONS(1302),
    [anon_sym_LT_AMP] = ACTIONS(1300),
    [anon_sym_GT_AMP] = ACTIONS(1300),
    [anon_sym_GT_PIPE] = ACTIONS(1302),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1302),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1302),
    [anon_sym_LT_LT_DASH] = ACTIONS(1302),
    [anon_sym_LT_LT_LT] = ACTIONS(1302),
    [anon_sym_QMARK] = ACTIONS(1300),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1302),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1302),
    [aux_sym_concatenation_token1] = ACTIONS(1302),
    [anon_sym_DOLLAR] = ACTIONS(1300),
    [sym__special_character] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(1302),
    [sym_raw_string] = ACTIONS(1302),
    [sym_ansi_c_string] = ACTIONS(1302),
    [aux_sym_number_token1] = ACTIONS(1300),
    [aux_sym_number_token2] = ACTIONS(1300),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1302),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1300),
    [anon_sym_BQUOTE] = ACTIONS(1300),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1302),
    [anon_sym_LT_LPAREN] = ACTIONS(1302),
    [anon_sym_GT_LPAREN] = ACTIONS(1302),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1302),
    [sym__concat] = ACTIONS(1302),
    [sym_test_operator] = ACTIONS(1302),
    [sym__bare_dollar] = ACTIONS(1302),
    [sym__brace_start] = ACTIONS(1302),
  },
  [STATE(503)] = {
    [sym_word] = ACTIONS(1304),
    [anon_sym_EQ] = ACTIONS(1304),
    [anon_sym_PLUS_PLUS] = ACTIONS(1304),
    [anon_sym_DASH_DASH] = ACTIONS(1304),
    [anon_sym_PLUS_EQ] = ACTIONS(1304),
    [anon_sym_DASH_EQ] = ACTIONS(1304),
    [anon_sym_STAR_EQ] = ACTIONS(1304),
    [anon_sym_SLASH_EQ] = ACTIONS(1304),
    [anon_sym_PERCENT_EQ] = ACTIONS(1304),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1304),
    [anon_sym_LT_LT_EQ] = ACTIONS(1306),
    [anon_sym_GT_GT_EQ] = ACTIONS(1306),
    [anon_sym_AMP_EQ] = ACTIONS(1306),
    [anon_sym_CARET_EQ] = ACTIONS(1304),
    [anon_sym_PIPE_EQ] = ACTIONS(1306),
    [anon_sym_PIPE_PIPE] = ACTIONS(1306),
    [anon_sym_AMP_AMP] = ACTIONS(1306),
    [anon_sym_PIPE] = ACTIONS(1304),
    [anon_sym_CARET] = ACTIONS(1304),
    [anon_sym_AMP] = ACTIONS(1304),
    [anon_sym_EQ_EQ] = ACTIONS(1304),
    [anon_sym_BANG_EQ] = ACTIONS(1304),
    [anon_sym_LT] = ACTIONS(1304),
    [anon_sym_GT] = ACTIONS(1304),
    [anon_sym_LT_EQ] = ACTIONS(1306),
    [anon_sym_GT_EQ] = ACTIONS(1306),
    [anon_sym_LT_LT] = ACTIONS(1304),
    [anon_sym_GT_GT] = ACTIONS(1304),
    [anon_sym_PLUS] = ACTIONS(1304),
    [anon_sym_DASH] = ACTIONS(1304),
    [anon_sym_STAR] = ACTIONS(1304),
    [anon_sym_SLASH] = ACTIONS(1304),
    [anon_sym_PERCENT] = ACTIONS(1304),
    [anon_sym_STAR_STAR] = ACTIONS(1304),
    [anon_sym_LPAREN] = ACTIONS(1306),
    [anon_sym_PIPE_AMP] = ACTIONS(1306),
    [anon_sym_RBRACK] = ACTIONS(1306),
    [anon_sym_EQ_TILDE] = ACTIONS(1304),
    [anon_sym_AMP_GT] = ACTIONS(1304),
    [anon_sym_AMP_GT_GT] = ACTIONS(1306),
    [anon_sym_LT_AMP] = ACTIONS(1304),
    [anon_sym_GT_AMP] = ACTIONS(1304),
    [anon_sym_GT_PIPE] = ACTIONS(1306),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1306),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1306),
    [anon_sym_LT_LT_DASH] = ACTIONS(1306),
    [anon_sym_LT_LT_LT] = ACTIONS(1306),
    [anon_sym_QMARK] = ACTIONS(1304),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1306),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1306),
    [aux_sym_concatenation_token1] = ACTIONS(1306),
    [anon_sym_DOLLAR] = ACTIONS(1304),
    [sym__special_character] = ACTIONS(1304),
    [anon_sym_DQUOTE] = ACTIONS(1306),
    [sym_raw_string] = ACTIONS(1306),
    [sym_ansi_c_string] = ACTIONS(1306),
    [aux_sym_number_token1] = ACTIONS(1304),
    [aux_sym_number_token2] = ACTIONS(1304),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1306),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1304),
    [anon_sym_BQUOTE] = ACTIONS(1304),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1306),
    [anon_sym_LT_LPAREN] = ACTIONS(1306),
    [anon_sym_GT_LPAREN] = ACTIONS(1306),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1306),
    [sym__concat] = ACTIONS(1306),
    [sym_test_operator] = ACTIONS(1306),
    [sym__bare_dollar] = ACTIONS(1306),
    [sym__brace_start] = ACTIONS(1306),
  },
  [STATE(504)] = {
    [sym_word] = ACTIONS(1300),
    [anon_sym_EQ] = ACTIONS(1300),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_PLUS_EQ] = ACTIONS(1300),
    [anon_sym_DASH_EQ] = ACTIONS(1300),
    [anon_sym_STAR_EQ] = ACTIONS(1300),
    [anon_sym_SLASH_EQ] = ACTIONS(1300),
    [anon_sym_PERCENT_EQ] = ACTIONS(1300),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1300),
    [anon_sym_LT_LT_EQ] = ACTIONS(1302),
    [anon_sym_GT_GT_EQ] = ACTIONS(1302),
    [anon_sym_AMP_EQ] = ACTIONS(1302),
    [anon_sym_CARET_EQ] = ACTIONS(1300),
    [anon_sym_PIPE_EQ] = ACTIONS(1302),
    [anon_sym_PIPE_PIPE] = ACTIONS(1302),
    [anon_sym_AMP_AMP] = ACTIONS(1302),
    [anon_sym_PIPE] = ACTIONS(1300),
    [anon_sym_CARET] = ACTIONS(1300),
    [anon_sym_AMP] = ACTIONS(1300),
    [anon_sym_EQ_EQ] = ACTIONS(1300),
    [anon_sym_BANG_EQ] = ACTIONS(1300),
    [anon_sym_LT] = ACTIONS(1300),
    [anon_sym_GT] = ACTIONS(1300),
    [anon_sym_LT_EQ] = ACTIONS(1302),
    [anon_sym_GT_EQ] = ACTIONS(1302),
    [anon_sym_LT_LT] = ACTIONS(1300),
    [anon_sym_GT_GT] = ACTIONS(1300),
    [anon_sym_PLUS] = ACTIONS(1300),
    [anon_sym_DASH] = ACTIONS(1300),
    [anon_sym_STAR] = ACTIONS(1300),
    [anon_sym_SLASH] = ACTIONS(1300),
    [anon_sym_PERCENT] = ACTIONS(1300),
    [anon_sym_STAR_STAR] = ACTIONS(1300),
    [anon_sym_LPAREN] = ACTIONS(1302),
    [anon_sym_PIPE_AMP] = ACTIONS(1302),
    [anon_sym_RBRACK] = ACTIONS(1302),
    [anon_sym_EQ_TILDE] = ACTIONS(1300),
    [anon_sym_AMP_GT] = ACTIONS(1300),
    [anon_sym_AMP_GT_GT] = ACTIONS(1302),
    [anon_sym_LT_AMP] = ACTIONS(1300),
    [anon_sym_GT_AMP] = ACTIONS(1300),
    [anon_sym_GT_PIPE] = ACTIONS(1302),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1302),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1302),
    [anon_sym_LT_LT_DASH] = ACTIONS(1302),
    [anon_sym_LT_LT_LT] = ACTIONS(1302),
    [anon_sym_QMARK] = ACTIONS(1300),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1302),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1302),
    [aux_sym_concatenation_token1] = ACTIONS(1302),
    [anon_sym_DOLLAR] = ACTIONS(1300),
    [sym__special_character] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(1302),
    [sym_raw_string] = ACTIONS(1302),
    [sym_ansi_c_string] = ACTIONS(1302),
    [aux_sym_number_token1] = ACTIONS(1300),
    [aux_sym_number_token2] = ACTIONS(1300),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1302),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1300),
    [anon_sym_BQUOTE] = ACTIONS(1300),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1302),
    [anon_sym_LT_LPAREN] = ACTIONS(1302),
    [anon_sym_GT_LPAREN] = ACTIONS(1302),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1302),
    [sym__concat] = ACTIONS(1302),
    [sym_test_operator] = ACTIONS(1302),
    [sym__bare_dollar] = ACTIONS(1302),
    [sym__brace_start] = ACTIONS(1302),
  },
  [STATE(505)] = {
    [sym_word] = ACTIONS(1256),
    [anon_sym_EQ] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1256),
    [anon_sym_DASH_DASH] = ACTIONS(1256),
    [anon_sym_PLUS_EQ] = ACTIONS(1256),
    [anon_sym_DASH_EQ] = ACTIONS(1256),
    [anon_sym_STAR_EQ] = ACTIONS(1256),
    [anon_sym_SLASH_EQ] = ACTIONS(1256),
    [anon_sym_PERCENT_EQ] = ACTIONS(1256),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1256),
    [anon_sym_LT_LT_EQ] = ACTIONS(1258),
    [anon_sym_GT_GT_EQ] = ACTIONS(1258),
    [anon_sym_AMP_EQ] = ACTIONS(1258),
    [anon_sym_CARET_EQ] = ACTIONS(1256),
    [anon_sym_PIPE_EQ] = ACTIONS(1258),
    [anon_sym_PIPE_PIPE] = ACTIONS(1258),
    [anon_sym_AMP_AMP] = ACTIONS(1258),
    [anon_sym_PIPE] = ACTIONS(1256),
    [anon_sym_CARET] = ACTIONS(1256),
    [anon_sym_AMP] = ACTIONS(1256),
    [anon_sym_EQ_EQ] = ACTIONS(1256),
    [anon_sym_BANG_EQ] = ACTIONS(1256),
    [anon_sym_LT] = ACTIONS(1256),
    [anon_sym_GT] = ACTIONS(1256),
    [anon_sym_LT_EQ] = ACTIONS(1258),
    [anon_sym_GT_EQ] = ACTIONS(1258),
    [anon_sym_LT_LT] = ACTIONS(1256),
    [anon_sym_GT_GT] = ACTIONS(1256),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_STAR] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(1256),
    [anon_sym_PERCENT] = ACTIONS(1256),
    [anon_sym_STAR_STAR] = ACTIONS(1256),
    [anon_sym_LPAREN] = ACTIONS(1258),
    [anon_sym_PIPE_AMP] = ACTIONS(1258),
    [anon_sym_RBRACK] = ACTIONS(1258),
    [anon_sym_EQ_TILDE] = ACTIONS(1256),
    [anon_sym_AMP_GT] = ACTIONS(1256),
    [anon_sym_AMP_GT_GT] = ACTIONS(1258),
    [anon_sym_LT_AMP] = ACTIONS(1256),
    [anon_sym_GT_AMP] = ACTIONS(1256),
    [anon_sym_GT_PIPE] = ACTIONS(1258),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1258),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1258),
    [anon_sym_LT_LT_DASH] = ACTIONS(1258),
    [anon_sym_LT_LT_LT] = ACTIONS(1258),
    [anon_sym_QMARK] = ACTIONS(1256),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1258),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1258),
    [aux_sym_concatenation_token1] = ACTIONS(1258),
    [anon_sym_DOLLAR] = ACTIONS(1256),
    [sym__special_character] = ACTIONS(1256),
    [anon_sym_DQUOTE] = ACTIONS(1258),
    [sym_raw_string] = ACTIONS(1258),
    [sym_ansi_c_string] = ACTIONS(1258),
    [aux_sym_number_token1] = ACTIONS(1256),
    [aux_sym_number_token2] = ACTIONS(1256),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1258),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1256),
    [anon_sym_BQUOTE] = ACTIONS(1256),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1258),
    [anon_sym_LT_LPAREN] = ACTIONS(1258),
    [anon_sym_GT_LPAREN] = ACTIONS(1258),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1258),
    [sym__concat] = ACTIONS(1258),
    [sym_test_operator] = ACTIONS(1258),
    [sym__bare_dollar] = ACTIONS(1258),
    [sym__brace_start] = ACTIONS(1258),
  },
  [STATE(506)] = {
    [sym_word] = ACTIONS(1280),
    [anon_sym_EQ] = ACTIONS(1280),
    [anon_sym_PLUS_PLUS] = ACTIONS(1280),
    [anon_sym_DASH_DASH] = ACTIONS(1280),
    [anon_sym_PLUS_EQ] = ACTIONS(1280),
    [anon_sym_DASH_EQ] = ACTIONS(1280),
    [anon_sym_STAR_EQ] = ACTIONS(1280),
    [anon_sym_SLASH_EQ] = ACTIONS(1280),
    [anon_sym_PERCENT_EQ] = ACTIONS(1280),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1280),
    [anon_sym_LT_LT_EQ] = ACTIONS(1282),
    [anon_sym_GT_GT_EQ] = ACTIONS(1282),
    [anon_sym_AMP_EQ] = ACTIONS(1282),
    [anon_sym_CARET_EQ] = ACTIONS(1280),
    [anon_sym_PIPE_EQ] = ACTIONS(1282),
    [anon_sym_PIPE_PIPE] = ACTIONS(1282),
    [anon_sym_AMP_AMP] = ACTIONS(1282),
    [anon_sym_PIPE] = ACTIONS(1280),
    [anon_sym_CARET] = ACTIONS(1280),
    [anon_sym_AMP] = ACTIONS(1280),
    [anon_sym_EQ_EQ] = ACTIONS(1280),
    [anon_sym_BANG_EQ] = ACTIONS(1280),
    [anon_sym_LT] = ACTIONS(1280),
    [anon_sym_GT] = ACTIONS(1280),
    [anon_sym_LT_EQ] = ACTIONS(1282),
    [anon_sym_GT_EQ] = ACTIONS(1282),
    [anon_sym_LT_LT] = ACTIONS(1280),
    [anon_sym_GT_GT] = ACTIONS(1280),
    [anon_sym_PLUS] = ACTIONS(1280),
    [anon_sym_DASH] = ACTIONS(1280),
    [anon_sym_STAR] = ACTIONS(1280),
    [anon_sym_SLASH] = ACTIONS(1280),
    [anon_sym_PERCENT] = ACTIONS(1280),
    [anon_sym_STAR_STAR] = ACTIONS(1280),
    [anon_sym_LPAREN] = ACTIONS(1282),
    [anon_sym_PIPE_AMP] = ACTIONS(1282),
    [anon_sym_RBRACK] = ACTIONS(1282),
    [anon_sym_EQ_TILDE] = ACTIONS(1280),
    [anon_sym_AMP_GT] = ACTIONS(1280),
    [anon_sym_AMP_GT_GT] = ACTIONS(1282),
    [anon_sym_LT_AMP] = ACTIONS(1280),
    [anon_sym_GT_AMP] = ACTIONS(1280),
    [anon_sym_GT_PIPE] = ACTIONS(1282),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1282),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1282),
    [anon_sym_LT_LT_DASH] = ACTIONS(1282),
    [anon_sym_LT_LT_LT] = ACTIONS(1282),
    [anon_sym_QMARK] = ACTIONS(1280),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1282),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1282),
    [aux_sym_concatenation_token1] = ACTIONS(1282),
    [anon_sym_DOLLAR] = ACTIONS(1280),
    [sym__special_character] = ACTIONS(1280),
    [anon_sym_DQUOTE] = ACTIONS(1282),
    [sym_raw_string] = ACTIONS(1282),
    [sym_ansi_c_string] = ACTIONS(1282),
    [aux_sym_number_token1] = ACTIONS(1280),
    [aux_sym_number_token2] = ACTIONS(1280),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1282),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1280),
    [anon_sym_BQUOTE] = ACTIONS(1280),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1282),
    [anon_sym_LT_LPAREN] = ACTIONS(1282),
    [anon_sym_GT_LPAREN] = ACTIONS(1282),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1282),
    [sym__concat] = ACTIONS(1282),
    [sym_test_operator] = ACTIONS(1282),
    [sym__bare_dollar] = ACTIONS(1282),
    [sym__brace_start] = ACTIONS(1282),
  },
  [STATE(507)] = {
    [sym_word] = ACTIONS(1284),
    [anon_sym_EQ] = ACTIONS(1284),
    [anon_sym_PLUS_PLUS] = ACTIONS(1284),
    [anon_sym_DASH_DASH] = ACTIONS(1284),
    [anon_sym_PLUS_EQ] = ACTIONS(1284),
    [anon_sym_DASH_EQ] = ACTIONS(1284),
    [anon_sym_STAR_EQ] = ACTIONS(1284),
    [anon_sym_SLASH_EQ] = ACTIONS(1284),
    [anon_sym_PERCENT_EQ] = ACTIONS(1284),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1284),
    [anon_sym_LT_LT_EQ] = ACTIONS(1286),
    [anon_sym_GT_GT_EQ] = ACTIONS(1286),
    [anon_sym_AMP_EQ] = ACTIONS(1286),
    [anon_sym_CARET_EQ] = ACTIONS(1284),
    [anon_sym_PIPE_EQ] = ACTIONS(1286),
    [anon_sym_PIPE_PIPE] = ACTIONS(1286),
    [anon_sym_AMP_AMP] = ACTIONS(1286),
    [anon_sym_PIPE] = ACTIONS(1284),
    [anon_sym_CARET] = ACTIONS(1284),
    [anon_sym_AMP] = ACTIONS(1284),
    [anon_sym_EQ_EQ] = ACTIONS(1284),
    [anon_sym_BANG_EQ] = ACTIONS(1284),
    [anon_sym_LT] = ACTIONS(1284),
    [anon_sym_GT] = ACTIONS(1284),
    [anon_sym_LT_EQ] = ACTIONS(1286),
    [anon_sym_GT_EQ] = ACTIONS(1286),
    [anon_sym_LT_LT] = ACTIONS(1284),
    [anon_sym_GT_GT] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1284),
    [anon_sym_DASH] = ACTIONS(1284),
    [anon_sym_STAR] = ACTIONS(1284),
    [anon_sym_SLASH] = ACTIONS(1284),
    [anon_sym_PERCENT] = ACTIONS(1284),
    [anon_sym_STAR_STAR] = ACTIONS(1284),
    [anon_sym_LPAREN] = ACTIONS(1286),
    [anon_sym_PIPE_AMP] = ACTIONS(1286),
    [anon_sym_RBRACK] = ACTIONS(1286),
    [anon_sym_EQ_TILDE] = ACTIONS(1284),
    [anon_sym_AMP_GT] = ACTIONS(1284),
    [anon_sym_AMP_GT_GT] = ACTIONS(1286),
    [anon_sym_LT_AMP] = ACTIONS(1284),
    [anon_sym_GT_AMP] = ACTIONS(1284),
    [anon_sym_GT_PIPE] = ACTIONS(1286),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1286),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1286),
    [anon_sym_LT_LT_DASH] = ACTIONS(1286),
    [anon_sym_LT_LT_LT] = ACTIONS(1286),
    [anon_sym_QMARK] = ACTIONS(1284),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1286),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1286),
    [aux_sym_concatenation_token1] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1284),
    [sym__special_character] = ACTIONS(1284),
    [anon_sym_DQUOTE] = ACTIONS(1286),
    [sym_raw_string] = ACTIONS(1286),
    [sym_ansi_c_string] = ACTIONS(1286),
    [aux_sym_number_token1] = ACTIONS(1284),
    [aux_sym_number_token2] = ACTIONS(1284),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1286),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1284),
    [anon_sym_BQUOTE] = ACTIONS(1284),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1286),
    [anon_sym_LT_LPAREN] = ACTIONS(1286),
    [anon_sym_GT_LPAREN] = ACTIONS(1286),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1286),
    [sym__concat] = ACTIONS(1286),
    [sym_test_operator] = ACTIONS(1286),
    [sym__bare_dollar] = ACTIONS(1286),
    [sym__brace_start] = ACTIONS(1286),
  },
  [STATE(508)] = {
    [sym_word] = ACTIONS(1213),
    [anon_sym_EQ] = ACTIONS(1213),
    [anon_sym_PLUS_PLUS] = ACTIONS(1213),
    [anon_sym_DASH_DASH] = ACTIONS(1213),
    [anon_sym_PLUS_EQ] = ACTIONS(1213),
    [anon_sym_DASH_EQ] = ACTIONS(1213),
    [anon_sym_STAR_EQ] = ACTIONS(1213),
    [anon_sym_SLASH_EQ] = ACTIONS(1213),
    [anon_sym_PERCENT_EQ] = ACTIONS(1213),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1213),
    [anon_sym_LT_LT_EQ] = ACTIONS(1215),
    [anon_sym_GT_GT_EQ] = ACTIONS(1215),
    [anon_sym_AMP_EQ] = ACTIONS(1215),
    [anon_sym_CARET_EQ] = ACTIONS(1213),
    [anon_sym_PIPE_EQ] = ACTIONS(1215),
    [anon_sym_PIPE_PIPE] = ACTIONS(1215),
    [anon_sym_AMP_AMP] = ACTIONS(1215),
    [anon_sym_PIPE] = ACTIONS(1213),
    [anon_sym_CARET] = ACTIONS(1213),
    [anon_sym_AMP] = ACTIONS(1213),
    [anon_sym_EQ_EQ] = ACTIONS(1213),
    [anon_sym_BANG_EQ] = ACTIONS(1213),
    [anon_sym_LT] = ACTIONS(1213),
    [anon_sym_GT] = ACTIONS(1213),
    [anon_sym_LT_EQ] = ACTIONS(1215),
    [anon_sym_GT_EQ] = ACTIONS(1215),
    [anon_sym_LT_LT] = ACTIONS(1213),
    [anon_sym_GT_GT] = ACTIONS(1213),
    [anon_sym_PLUS] = ACTIONS(1213),
    [anon_sym_DASH] = ACTIONS(1213),
    [anon_sym_STAR] = ACTIONS(1213),
    [anon_sym_SLASH] = ACTIONS(1213),
    [anon_sym_PERCENT] = ACTIONS(1213),
    [anon_sym_STAR_STAR] = ACTIONS(1213),
    [anon_sym_LPAREN] = ACTIONS(1215),
    [anon_sym_PIPE_AMP] = ACTIONS(1215),
    [anon_sym_RBRACK] = ACTIONS(1215),
    [anon_sym_EQ_TILDE] = ACTIONS(1213),
    [anon_sym_AMP_GT] = ACTIONS(1213),
    [anon_sym_AMP_GT_GT] = ACTIONS(1215),
    [anon_sym_LT_AMP] = ACTIONS(1213),
    [anon_sym_GT_AMP] = ACTIONS(1213),
    [anon_sym_GT_PIPE] = ACTIONS(1215),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1215),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1215),
    [anon_sym_LT_LT_DASH] = ACTIONS(1215),
    [anon_sym_LT_LT_LT] = ACTIONS(1215),
    [anon_sym_QMARK] = ACTIONS(1213),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1215),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1215),
    [aux_sym_concatenation_token1] = ACTIONS(1215),
    [anon_sym_DOLLAR] = ACTIONS(1213),
    [sym__special_character] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_raw_string] = ACTIONS(1215),
    [sym_ansi_c_string] = ACTIONS(1215),
    [aux_sym_number_token1] = ACTIONS(1213),
    [aux_sym_number_token2] = ACTIONS(1213),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1215),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1213),
    [anon_sym_BQUOTE] = ACTIONS(1213),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1215),
    [anon_sym_LT_LPAREN] = ACTIONS(1215),
    [anon_sym_GT_LPAREN] = ACTIONS(1215),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1215),
    [sym__concat] = ACTIONS(1215),
    [sym_test_operator] = ACTIONS(1215),
    [sym__bare_dollar] = ACTIONS(1215),
    [sym__brace_start] = ACTIONS(1215),
  },
  [STATE(509)] = {
    [sym_word] = ACTIONS(1260),
    [anon_sym_EQ] = ACTIONS(1260),
    [anon_sym_PLUS_PLUS] = ACTIONS(1260),
    [anon_sym_DASH_DASH] = ACTIONS(1260),
    [anon_sym_PLUS_EQ] = ACTIONS(1260),
    [anon_sym_DASH_EQ] = ACTIONS(1260),
    [anon_sym_STAR_EQ] = ACTIONS(1260),
    [anon_sym_SLASH_EQ] = ACTIONS(1260),
    [anon_sym_PERCENT_EQ] = ACTIONS(1260),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1260),
    [anon_sym_LT_LT_EQ] = ACTIONS(1262),
    [anon_sym_GT_GT_EQ] = ACTIONS(1262),
    [anon_sym_AMP_EQ] = ACTIONS(1262),
    [anon_sym_CARET_EQ] = ACTIONS(1260),
    [anon_sym_PIPE_EQ] = ACTIONS(1262),
    [anon_sym_PIPE_PIPE] = ACTIONS(1262),
    [anon_sym_AMP_AMP] = ACTIONS(1262),
    [anon_sym_PIPE] = ACTIONS(1260),
    [anon_sym_CARET] = ACTIONS(1260),
    [anon_sym_AMP] = ACTIONS(1260),
    [anon_sym_EQ_EQ] = ACTIONS(1260),
    [anon_sym_BANG_EQ] = ACTIONS(1260),
    [anon_sym_LT] = ACTIONS(1260),
    [anon_sym_GT] = ACTIONS(1260),
    [anon_sym_LT_EQ] = ACTIONS(1262),
    [anon_sym_GT_EQ] = ACTIONS(1262),
    [anon_sym_LT_LT] = ACTIONS(1260),
    [anon_sym_GT_GT] = ACTIONS(1260),
    [anon_sym_PLUS] = ACTIONS(1260),
    [anon_sym_DASH] = ACTIONS(1260),
    [anon_sym_STAR] = ACTIONS(1260),
    [anon_sym_SLASH] = ACTIONS(1260),
    [anon_sym_PERCENT] = ACTIONS(1260),
    [anon_sym_STAR_STAR] = ACTIONS(1260),
    [anon_sym_LPAREN] = ACTIONS(1262),
    [anon_sym_PIPE_AMP] = ACTIONS(1262),
    [anon_sym_RBRACK] = ACTIONS(1262),
    [anon_sym_EQ_TILDE] = ACTIONS(1260),
    [anon_sym_AMP_GT] = ACTIONS(1260),
    [anon_sym_AMP_GT_GT] = ACTIONS(1262),
    [anon_sym_LT_AMP] = ACTIONS(1260),
    [anon_sym_GT_AMP] = ACTIONS(1260),
    [anon_sym_GT_PIPE] = ACTIONS(1262),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1262),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1262),
    [anon_sym_LT_LT_DASH] = ACTIONS(1262),
    [anon_sym_LT_LT_LT] = ACTIONS(1262),
    [anon_sym_QMARK] = ACTIONS(1260),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1262),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1262),
    [aux_sym_concatenation_token1] = ACTIONS(1262),
    [anon_sym_DOLLAR] = ACTIONS(1260),
    [sym__special_character] = ACTIONS(1260),
    [anon_sym_DQUOTE] = ACTIONS(1262),
    [sym_raw_string] = ACTIONS(1262),
    [sym_ansi_c_string] = ACTIONS(1262),
    [aux_sym_number_token1] = ACTIONS(1260),
    [aux_sym_number_token2] = ACTIONS(1260),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1262),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1260),
    [anon_sym_BQUOTE] = ACTIONS(1260),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1262),
    [anon_sym_LT_LPAREN] = ACTIONS(1262),
    [anon_sym_GT_LPAREN] = ACTIONS(1262),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1262),
    [sym__concat] = ACTIONS(1262),
    [sym_test_operator] = ACTIONS(1262),
    [sym__bare_dollar] = ACTIONS(1262),
    [sym__brace_start] = ACTIONS(1262),
  },
  [STATE(510)] = {
    [sym_word] = ACTIONS(1312),
    [anon_sym_EQ] = ACTIONS(1312),
    [anon_sym_PLUS_PLUS] = ACTIONS(1312),
    [anon_sym_DASH_DASH] = ACTIONS(1312),
    [anon_sym_PLUS_EQ] = ACTIONS(1312),
    [anon_sym_DASH_EQ] = ACTIONS(1312),
    [anon_sym_STAR_EQ] = ACTIONS(1312),
    [anon_sym_SLASH_EQ] = ACTIONS(1312),
    [anon_sym_PERCENT_EQ] = ACTIONS(1312),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1312),
    [anon_sym_LT_LT_EQ] = ACTIONS(1314),
    [anon_sym_GT_GT_EQ] = ACTIONS(1314),
    [anon_sym_AMP_EQ] = ACTIONS(1314),
    [anon_sym_CARET_EQ] = ACTIONS(1312),
    [anon_sym_PIPE_EQ] = ACTIONS(1314),
    [anon_sym_PIPE_PIPE] = ACTIONS(1314),
    [anon_sym_AMP_AMP] = ACTIONS(1314),
    [anon_sym_PIPE] = ACTIONS(1312),
    [anon_sym_CARET] = ACTIONS(1312),
    [anon_sym_AMP] = ACTIONS(1312),
    [anon_sym_EQ_EQ] = ACTIONS(1312),
    [anon_sym_BANG_EQ] = ACTIONS(1312),
    [anon_sym_LT] = ACTIONS(1312),
    [anon_sym_GT] = ACTIONS(1312),
    [anon_sym_LT_EQ] = ACTIONS(1314),
    [anon_sym_GT_EQ] = ACTIONS(1314),
    [anon_sym_LT_LT] = ACTIONS(1312),
    [anon_sym_GT_GT] = ACTIONS(1312),
    [anon_sym_PLUS] = ACTIONS(1312),
    [anon_sym_DASH] = ACTIONS(1312),
    [anon_sym_STAR] = ACTIONS(1312),
    [anon_sym_SLASH] = ACTIONS(1312),
    [anon_sym_PERCENT] = ACTIONS(1312),
    [anon_sym_STAR_STAR] = ACTIONS(1312),
    [anon_sym_LPAREN] = ACTIONS(1314),
    [anon_sym_PIPE_AMP] = ACTIONS(1314),
    [anon_sym_RBRACK] = ACTIONS(1314),
    [anon_sym_EQ_TILDE] = ACTIONS(1312),
    [anon_sym_AMP_GT] = ACTIONS(1312),
    [anon_sym_AMP_GT_GT] = ACTIONS(1314),
    [anon_sym_LT_AMP] = ACTIONS(1312),
    [anon_sym_GT_AMP] = ACTIONS(1312),
    [anon_sym_GT_PIPE] = ACTIONS(1314),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1314),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1314),
    [anon_sym_LT_LT_DASH] = ACTIONS(1314),
    [anon_sym_LT_LT_LT] = ACTIONS(1314),
    [anon_sym_QMARK] = ACTIONS(1312),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1314),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1314),
    [aux_sym_concatenation_token1] = ACTIONS(1314),
    [anon_sym_DOLLAR] = ACTIONS(1312),
    [sym__special_character] = ACTIONS(1312),
    [anon_sym_DQUOTE] = ACTIONS(1314),
    [sym_raw_string] = ACTIONS(1314),
    [sym_ansi_c_string] = ACTIONS(1314),
    [aux_sym_number_token1] = ACTIONS(1312),
    [aux_sym_number_token2] = ACTIONS(1312),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1314),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1312),
    [anon_sym_BQUOTE] = ACTIONS(1312),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1314),
    [anon_sym_LT_LPAREN] = ACTIONS(1314),
    [anon_sym_GT_LPAREN] = ACTIONS(1314),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1314),
    [sym__concat] = ACTIONS(1314),
    [sym_test_operator] = ACTIONS(1314),
    [sym__bare_dollar] = ACTIONS(1314),
    [sym__brace_start] = ACTIONS(1314),
  },
  [STATE(511)] = {
    [sym_word] = ACTIONS(1288),
    [anon_sym_EQ] = ACTIONS(1288),
    [anon_sym_PLUS_PLUS] = ACTIONS(1288),
    [anon_sym_DASH_DASH] = ACTIONS(1288),
    [anon_sym_PLUS_EQ] = ACTIONS(1288),
    [anon_sym_DASH_EQ] = ACTIONS(1288),
    [anon_sym_STAR_EQ] = ACTIONS(1288),
    [anon_sym_SLASH_EQ] = ACTIONS(1288),
    [anon_sym_PERCENT_EQ] = ACTIONS(1288),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1288),
    [anon_sym_LT_LT_EQ] = ACTIONS(1290),
    [anon_sym_GT_GT_EQ] = ACTIONS(1290),
    [anon_sym_AMP_EQ] = ACTIONS(1290),
    [anon_sym_CARET_EQ] = ACTIONS(1288),
    [anon_sym_PIPE_EQ] = ACTIONS(1290),
    [anon_sym_PIPE_PIPE] = ACTIONS(1290),
    [anon_sym_AMP_AMP] = ACTIONS(1290),
    [anon_sym_PIPE] = ACTIONS(1288),
    [anon_sym_CARET] = ACTIONS(1288),
    [anon_sym_AMP] = ACTIONS(1288),
    [anon_sym_EQ_EQ] = ACTIONS(1288),
    [anon_sym_BANG_EQ] = ACTIONS(1288),
    [anon_sym_LT] = ACTIONS(1288),
    [anon_sym_GT] = ACTIONS(1288),
    [anon_sym_LT_EQ] = ACTIONS(1290),
    [anon_sym_GT_EQ] = ACTIONS(1290),
    [anon_sym_LT_LT] = ACTIONS(1288),
    [anon_sym_GT_GT] = ACTIONS(1288),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_STAR] = ACTIONS(1288),
    [anon_sym_SLASH] = ACTIONS(1288),
    [anon_sym_PERCENT] = ACTIONS(1288),
    [anon_sym_STAR_STAR] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1290),
    [anon_sym_PIPE_AMP] = ACTIONS(1290),
    [anon_sym_RBRACK] = ACTIONS(1290),
    [anon_sym_EQ_TILDE] = ACTIONS(1288),
    [anon_sym_AMP_GT] = ACTIONS(1288),
    [anon_sym_AMP_GT_GT] = ACTIONS(1290),
    [anon_sym_LT_AMP] = ACTIONS(1288),
    [anon_sym_GT_AMP] = ACTIONS(1288),
    [anon_sym_GT_PIPE] = ACTIONS(1290),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1290),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1290),
    [anon_sym_LT_LT_DASH] = ACTIONS(1290),
    [anon_sym_LT_LT_LT] = ACTIONS(1290),
    [anon_sym_QMARK] = ACTIONS(1288),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1290),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1290),
    [aux_sym_concatenation_token1] = ACTIONS(1290),
    [anon_sym_DOLLAR] = ACTIONS(1288),
    [sym__special_character] = ACTIONS(1288),
    [anon_sym_DQUOTE] = ACTIONS(1290),
    [sym_raw_string] = ACTIONS(1290),
    [sym_ansi_c_string] = ACTIONS(1290),
    [aux_sym_number_token1] = ACTIONS(1288),
    [aux_sym_number_token2] = ACTIONS(1288),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1290),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1288),
    [anon_sym_BQUOTE] = ACTIONS(1288),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1290),
    [anon_sym_LT_LPAREN] = ACTIONS(1290),
    [anon_sym_GT_LPAREN] = ACTIONS(1290),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1290),
    [sym__concat] = ACTIONS(1290),
    [sym_test_operator] = ACTIONS(1290),
    [sym__bare_dollar] = ACTIONS(1290),
    [sym__brace_start] = ACTIONS(1290),
  },
  [STATE(512)] = {
    [sym_word] = ACTIONS(1268),
    [anon_sym_EQ] = ACTIONS(1268),
    [anon_sym_PLUS_PLUS] = ACTIONS(1268),
    [anon_sym_DASH_DASH] = ACTIONS(1268),
    [anon_sym_PLUS_EQ] = ACTIONS(1268),
    [anon_sym_DASH_EQ] = ACTIONS(1268),
    [anon_sym_STAR_EQ] = ACTIONS(1268),
    [anon_sym_SLASH_EQ] = ACTIONS(1268),
    [anon_sym_PERCENT_EQ] = ACTIONS(1268),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1268),
    [anon_sym_LT_LT_EQ] = ACTIONS(1270),
    [anon_sym_GT_GT_EQ] = ACTIONS(1270),
    [anon_sym_AMP_EQ] = ACTIONS(1270),
    [anon_sym_CARET_EQ] = ACTIONS(1268),
    [anon_sym_PIPE_EQ] = ACTIONS(1270),
    [anon_sym_PIPE_PIPE] = ACTIONS(1270),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_PIPE] = ACTIONS(1268),
    [anon_sym_CARET] = ACTIONS(1268),
    [anon_sym_AMP] = ACTIONS(1268),
    [anon_sym_EQ_EQ] = ACTIONS(1268),
    [anon_sym_BANG_EQ] = ACTIONS(1268),
    [anon_sym_LT] = ACTIONS(1268),
    [anon_sym_GT] = ACTIONS(1268),
    [anon_sym_LT_EQ] = ACTIONS(1270),
    [anon_sym_GT_EQ] = ACTIONS(1270),
    [anon_sym_LT_LT] = ACTIONS(1268),
    [anon_sym_GT_GT] = ACTIONS(1268),
    [anon_sym_PLUS] = ACTIONS(1268),
    [anon_sym_DASH] = ACTIONS(1268),
    [anon_sym_STAR] = ACTIONS(1268),
    [anon_sym_SLASH] = ACTIONS(1268),
    [anon_sym_PERCENT] = ACTIONS(1268),
    [anon_sym_STAR_STAR] = ACTIONS(1268),
    [anon_sym_LPAREN] = ACTIONS(1270),
    [anon_sym_PIPE_AMP] = ACTIONS(1270),
    [anon_sym_RBRACK] = ACTIONS(1270),
    [anon_sym_EQ_TILDE] = ACTIONS(1268),
    [anon_sym_AMP_GT] = ACTIONS(1268),
    [anon_sym_AMP_GT_GT] = ACTIONS(1270),
    [anon_sym_LT_AMP] = ACTIONS(1268),
    [anon_sym_GT_AMP] = ACTIONS(1268),
    [anon_sym_GT_PIPE] = ACTIONS(1270),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1270),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1270),
    [anon_sym_LT_LT_DASH] = ACTIONS(1270),
    [anon_sym_LT_LT_LT] = ACTIONS(1270),
    [anon_sym_QMARK] = ACTIONS(1268),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1270),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1270),
    [aux_sym_concatenation_token1] = ACTIONS(1270),
    [anon_sym_DOLLAR] = ACTIONS(1268),
    [sym__special_character] = ACTIONS(1268),
    [anon_sym_DQUOTE] = ACTIONS(1270),
    [sym_raw_string] = ACTIONS(1270),
    [sym_ansi_c_string] = ACTIONS(1270),
    [aux_sym_number_token1] = ACTIONS(1268),
    [aux_sym_number_token2] = ACTIONS(1268),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1270),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1268),
    [anon_sym_BQUOTE] = ACTIONS(1268),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1270),
    [anon_sym_LT_LPAREN] = ACTIONS(1270),
    [anon_sym_GT_LPAREN] = ACTIONS(1270),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1270),
    [sym__concat] = ACTIONS(1270),
    [sym_test_operator] = ACTIONS(1270),
    [sym__bare_dollar] = ACTIONS(1270),
    [sym__brace_start] = ACTIONS(1270),
  },
  [STATE(513)] = {
    [sym_word] = ACTIONS(1308),
    [anon_sym_EQ] = ACTIONS(1308),
    [anon_sym_PLUS_PLUS] = ACTIONS(1308),
    [anon_sym_DASH_DASH] = ACTIONS(1308),
    [anon_sym_PLUS_EQ] = ACTIONS(1308),
    [anon_sym_DASH_EQ] = ACTIONS(1308),
    [anon_sym_STAR_EQ] = ACTIONS(1308),
    [anon_sym_SLASH_EQ] = ACTIONS(1308),
    [anon_sym_PERCENT_EQ] = ACTIONS(1308),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1308),
    [anon_sym_LT_LT_EQ] = ACTIONS(1310),
    [anon_sym_GT_GT_EQ] = ACTIONS(1310),
    [anon_sym_AMP_EQ] = ACTIONS(1310),
    [anon_sym_CARET_EQ] = ACTIONS(1308),
    [anon_sym_PIPE_EQ] = ACTIONS(1310),
    [anon_sym_PIPE_PIPE] = ACTIONS(1310),
    [anon_sym_AMP_AMP] = ACTIONS(1310),
    [anon_sym_PIPE] = ACTIONS(1308),
    [anon_sym_CARET] = ACTIONS(1308),
    [anon_sym_AMP] = ACTIONS(1308),
    [anon_sym_EQ_EQ] = ACTIONS(1308),
    [anon_sym_BANG_EQ] = ACTIONS(1308),
    [anon_sym_LT] = ACTIONS(1308),
    [anon_sym_GT] = ACTIONS(1308),
    [anon_sym_LT_EQ] = ACTIONS(1310),
    [anon_sym_GT_EQ] = ACTIONS(1310),
    [anon_sym_LT_LT] = ACTIONS(1308),
    [anon_sym_GT_GT] = ACTIONS(1308),
    [anon_sym_PLUS] = ACTIONS(1308),
    [anon_sym_DASH] = ACTIONS(1308),
    [anon_sym_STAR] = ACTIONS(1308),
    [anon_sym_SLASH] = ACTIONS(1308),
    [anon_sym_PERCENT] = ACTIONS(1308),
    [anon_sym_STAR_STAR] = ACTIONS(1308),
    [anon_sym_LPAREN] = ACTIONS(1310),
    [anon_sym_PIPE_AMP] = ACTIONS(1310),
    [anon_sym_RBRACK] = ACTIONS(1310),
    [anon_sym_EQ_TILDE] = ACTIONS(1308),
    [anon_sym_AMP_GT] = ACTIONS(1308),
    [anon_sym_AMP_GT_GT] = ACTIONS(1310),
    [anon_sym_LT_AMP] = ACTIONS(1308),
    [anon_sym_GT_AMP] = ACTIONS(1308),
    [anon_sym_GT_PIPE] = ACTIONS(1310),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1310),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1310),
    [anon_sym_LT_LT_DASH] = ACTIONS(1310),
    [anon_sym_LT_LT_LT] = ACTIONS(1310),
    [anon_sym_QMARK] = ACTIONS(1308),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1310),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1310),
    [aux_sym_concatenation_token1] = ACTIONS(1310),
    [anon_sym_DOLLAR] = ACTIONS(1308),
    [sym__special_character] = ACTIONS(1308),
    [anon_sym_DQUOTE] = ACTIONS(1310),
    [sym_raw_string] = ACTIONS(1310),
    [sym_ansi_c_string] = ACTIONS(1310),
    [aux_sym_number_token1] = ACTIONS(1308),
    [aux_sym_number_token2] = ACTIONS(1308),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1310),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1308),
    [anon_sym_BQUOTE] = ACTIONS(1308),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1310),
    [anon_sym_LT_LPAREN] = ACTIONS(1310),
    [anon_sym_GT_LPAREN] = ACTIONS(1310),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1310),
    [sym__concat] = ACTIONS(1310),
    [sym_test_operator] = ACTIONS(1310),
    [sym__bare_dollar] = ACTIONS(1310),
    [sym__brace_start] = ACTIONS(1310),
  },
  [STATE(514)] = {
    [sym_word] = ACTIONS(1272),
    [anon_sym_EQ] = ACTIONS(1272),
    [anon_sym_PLUS_PLUS] = ACTIONS(1272),
    [anon_sym_DASH_DASH] = ACTIONS(1272),
    [anon_sym_PLUS_EQ] = ACTIONS(1272),
    [anon_sym_DASH_EQ] = ACTIONS(1272),
    [anon_sym_STAR_EQ] = ACTIONS(1272),
    [anon_sym_SLASH_EQ] = ACTIONS(1272),
    [anon_sym_PERCENT_EQ] = ACTIONS(1272),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1272),
    [anon_sym_LT_LT_EQ] = ACTIONS(1274),
    [anon_sym_GT_GT_EQ] = ACTIONS(1274),
    [anon_sym_AMP_EQ] = ACTIONS(1274),
    [anon_sym_CARET_EQ] = ACTIONS(1272),
    [anon_sym_PIPE_EQ] = ACTIONS(1274),
    [anon_sym_PIPE_PIPE] = ACTIONS(1274),
    [anon_sym_AMP_AMP] = ACTIONS(1274),
    [anon_sym_PIPE] = ACTIONS(1272),
    [anon_sym_CARET] = ACTIONS(1272),
    [anon_sym_AMP] = ACTIONS(1272),
    [anon_sym_EQ_EQ] = ACTIONS(1272),
    [anon_sym_BANG_EQ] = ACTIONS(1272),
    [anon_sym_LT] = ACTIONS(1272),
    [anon_sym_GT] = ACTIONS(1272),
    [anon_sym_LT_EQ] = ACTIONS(1274),
    [anon_sym_GT_EQ] = ACTIONS(1274),
    [anon_sym_LT_LT] = ACTIONS(1272),
    [anon_sym_GT_GT] = ACTIONS(1272),
    [anon_sym_PLUS] = ACTIONS(1272),
    [anon_sym_DASH] = ACTIONS(1272),
    [anon_sym_STAR] = ACTIONS(1272),
    [anon_sym_SLASH] = ACTIONS(1272),
    [anon_sym_PERCENT] = ACTIONS(1272),
    [anon_sym_STAR_STAR] = ACTIONS(1272),
    [anon_sym_LPAREN] = ACTIONS(1274),
    [anon_sym_PIPE_AMP] = ACTIONS(1274),
    [anon_sym_RBRACK] = ACTIONS(1274),
    [anon_sym_EQ_TILDE] = ACTIONS(1272),
    [anon_sym_AMP_GT] = ACTIONS(1272),
    [anon_sym_AMP_GT_GT] = ACTIONS(1274),
    [anon_sym_LT_AMP] = ACTIONS(1272),
    [anon_sym_GT_AMP] = ACTIONS(1272),
    [anon_sym_GT_PIPE] = ACTIONS(1274),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1274),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1274),
    [anon_sym_LT_LT_DASH] = ACTIONS(1274),
    [anon_sym_LT_LT_LT] = ACTIONS(1274),
    [anon_sym_QMARK] = ACTIONS(1272),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1274),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1274),
    [aux_sym_concatenation_token1] = ACTIONS(1274),
    [anon_sym_DOLLAR] = ACTIONS(1272),
    [sym__special_character] = ACTIONS(1272),
    [anon_sym_DQUOTE] = ACTIONS(1274),
    [sym_raw_string] = ACTIONS(1274),
    [sym_ansi_c_string] = ACTIONS(1274),
    [aux_sym_number_token1] = ACTIONS(1272),
    [aux_sym_number_token2] = ACTIONS(1272),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1274),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1272),
    [anon_sym_BQUOTE] = ACTIONS(1272),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1274),
    [anon_sym_LT_LPAREN] = ACTIONS(1274),
    [anon_sym_GT_LPAREN] = ACTIONS(1274),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1274),
    [sym__concat] = ACTIONS(1274),
    [sym_test_operator] = ACTIONS(1274),
    [sym__bare_dollar] = ACTIONS(1274),
    [sym__brace_start] = ACTIONS(1274),
  },
  [STATE(515)] = {
    [sym_word] = ACTIONS(1276),
    [anon_sym_EQ] = ACTIONS(1276),
    [anon_sym_PLUS_PLUS] = ACTIONS(1276),
    [anon_sym_DASH_DASH] = ACTIONS(1276),
    [anon_sym_PLUS_EQ] = ACTIONS(1276),
    [anon_sym_DASH_EQ] = ACTIONS(1276),
    [anon_sym_STAR_EQ] = ACTIONS(1276),
    [anon_sym_SLASH_EQ] = ACTIONS(1276),
    [anon_sym_PERCENT_EQ] = ACTIONS(1276),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1276),
    [anon_sym_LT_LT_EQ] = ACTIONS(1278),
    [anon_sym_GT_GT_EQ] = ACTIONS(1278),
    [anon_sym_AMP_EQ] = ACTIONS(1278),
    [anon_sym_CARET_EQ] = ACTIONS(1276),
    [anon_sym_PIPE_EQ] = ACTIONS(1278),
    [anon_sym_PIPE_PIPE] = ACTIONS(1278),
    [anon_sym_AMP_AMP] = ACTIONS(1278),
    [anon_sym_PIPE] = ACTIONS(1276),
    [anon_sym_CARET] = ACTIONS(1276),
    [anon_sym_AMP] = ACTIONS(1276),
    [anon_sym_EQ_EQ] = ACTIONS(1276),
    [anon_sym_BANG_EQ] = ACTIONS(1276),
    [anon_sym_LT] = ACTIONS(1276),
    [anon_sym_GT] = ACTIONS(1276),
    [anon_sym_LT_EQ] = ACTIONS(1278),
    [anon_sym_GT_EQ] = ACTIONS(1278),
    [anon_sym_LT_LT] = ACTIONS(1276),
    [anon_sym_GT_GT] = ACTIONS(1276),
    [anon_sym_PLUS] = ACTIONS(1276),
    [anon_sym_DASH] = ACTIONS(1276),
    [anon_sym_STAR] = ACTIONS(1276),
    [anon_sym_SLASH] = ACTIONS(1276),
    [anon_sym_PERCENT] = ACTIONS(1276),
    [anon_sym_STAR_STAR] = ACTIONS(1276),
    [anon_sym_LPAREN] = ACTIONS(1278),
    [anon_sym_PIPE_AMP] = ACTIONS(1278),
    [anon_sym_RBRACK] = ACTIONS(1278),
    [anon_sym_EQ_TILDE] = ACTIONS(1276),
    [anon_sym_AMP_GT] = ACTIONS(1276),
    [anon_sym_AMP_GT_GT] = ACTIONS(1278),
    [anon_sym_LT_AMP] = ACTIONS(1276),
    [anon_sym_GT_AMP] = ACTIONS(1276),
    [anon_sym_GT_PIPE] = ACTIONS(1278),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1278),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1278),
    [anon_sym_LT_LT_DASH] = ACTIONS(1278),
    [anon_sym_LT_LT_LT] = ACTIONS(1278),
    [anon_sym_QMARK] = ACTIONS(1276),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1278),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1278),
    [aux_sym_concatenation_token1] = ACTIONS(1278),
    [anon_sym_DOLLAR] = ACTIONS(1276),
    [sym__special_character] = ACTIONS(1276),
    [anon_sym_DQUOTE] = ACTIONS(1278),
    [sym_raw_string] = ACTIONS(1278),
    [sym_ansi_c_string] = ACTIONS(1278),
    [aux_sym_number_token1] = ACTIONS(1276),
    [aux_sym_number_token2] = ACTIONS(1276),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1278),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1276),
    [anon_sym_BQUOTE] = ACTIONS(1276),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1278),
    [anon_sym_LT_LPAREN] = ACTIONS(1278),
    [anon_sym_GT_LPAREN] = ACTIONS(1278),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1278),
    [sym__concat] = ACTIONS(1278),
    [sym_test_operator] = ACTIONS(1278),
    [sym__bare_dollar] = ACTIONS(1278),
    [sym__brace_start] = ACTIONS(1278),
  },
  [STATE(516)] = {
    [sym_word] = ACTIONS(1252),
    [anon_sym_EQ] = ACTIONS(1252),
    [anon_sym_PLUS_PLUS] = ACTIONS(1252),
    [anon_sym_DASH_DASH] = ACTIONS(1252),
    [anon_sym_PLUS_EQ] = ACTIONS(1252),
    [anon_sym_DASH_EQ] = ACTIONS(1252),
    [anon_sym_STAR_EQ] = ACTIONS(1252),
    [anon_sym_SLASH_EQ] = ACTIONS(1252),
    [anon_sym_PERCENT_EQ] = ACTIONS(1252),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1252),
    [anon_sym_LT_LT_EQ] = ACTIONS(1254),
    [anon_sym_GT_GT_EQ] = ACTIONS(1254),
    [anon_sym_AMP_EQ] = ACTIONS(1254),
    [anon_sym_CARET_EQ] = ACTIONS(1252),
    [anon_sym_PIPE_EQ] = ACTIONS(1254),
    [anon_sym_PIPE_PIPE] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1254),
    [anon_sym_PIPE] = ACTIONS(1252),
    [anon_sym_CARET] = ACTIONS(1252),
    [anon_sym_AMP] = ACTIONS(1252),
    [anon_sym_EQ_EQ] = ACTIONS(1252),
    [anon_sym_BANG_EQ] = ACTIONS(1252),
    [anon_sym_LT] = ACTIONS(1252),
    [anon_sym_GT] = ACTIONS(1252),
    [anon_sym_LT_EQ] = ACTIONS(1254),
    [anon_sym_GT_EQ] = ACTIONS(1254),
    [anon_sym_LT_LT] = ACTIONS(1252),
    [anon_sym_GT_GT] = ACTIONS(1252),
    [anon_sym_PLUS] = ACTIONS(1252),
    [anon_sym_DASH] = ACTIONS(1252),
    [anon_sym_STAR] = ACTIONS(1252),
    [anon_sym_SLASH] = ACTIONS(1252),
    [anon_sym_PERCENT] = ACTIONS(1252),
    [anon_sym_STAR_STAR] = ACTIONS(1252),
    [anon_sym_LPAREN] = ACTIONS(1254),
    [anon_sym_PIPE_AMP] = ACTIONS(1254),
    [anon_sym_RBRACK] = ACTIONS(1254),
    [anon_sym_EQ_TILDE] = ACTIONS(1252),
    [anon_sym_AMP_GT] = ACTIONS(1252),
    [anon_sym_AMP_GT_GT] = ACTIONS(1254),
    [anon_sym_LT_AMP] = ACTIONS(1252),
    [anon_sym_GT_AMP] = ACTIONS(1252),
    [anon_sym_GT_PIPE] = ACTIONS(1254),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1254),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1254),
    [anon_sym_LT_LT_DASH] = ACTIONS(1254),
    [anon_sym_LT_LT_LT] = ACTIONS(1254),
    [anon_sym_QMARK] = ACTIONS(1252),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1254),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1254),
    [aux_sym_concatenation_token1] = ACTIONS(1254),
    [anon_sym_DOLLAR] = ACTIONS(1252),
    [sym__special_character] = ACTIONS(1252),
    [anon_sym_DQUOTE] = ACTIONS(1254),
    [sym_raw_string] = ACTIONS(1254),
    [sym_ansi_c_string] = ACTIONS(1254),
    [aux_sym_number_token1] = ACTIONS(1252),
    [aux_sym_number_token2] = ACTIONS(1252),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1254),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1252),
    [anon_sym_BQUOTE] = ACTIONS(1252),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1254),
    [anon_sym_LT_LPAREN] = ACTIONS(1254),
    [anon_sym_GT_LPAREN] = ACTIONS(1254),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1254),
    [sym__concat] = ACTIONS(1254),
    [sym_test_operator] = ACTIONS(1254),
    [sym__bare_dollar] = ACTIONS(1254),
    [sym__brace_start] = ACTIONS(1254),
  },
  [STATE(517)] = {
    [aux_sym__literal_repeat1] = STATE(518),
    [sym_word] = ACTIONS(237),
    [anon_sym_EQ] = ACTIONS(239),
    [anon_sym_PLUS_PLUS] = ACTIONS(239),
    [anon_sym_DASH_DASH] = ACTIONS(239),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_SLASH_EQ] = ACTIONS(239),
    [anon_sym_PERCENT_EQ] = ACTIONS(239),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(239),
    [anon_sym_LT_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_GT_EQ] = ACTIONS(358),
    [anon_sym_AMP_EQ] = ACTIONS(358),
    [anon_sym_CARET_EQ] = ACTIONS(239),
    [anon_sym_PIPE_EQ] = ACTIONS(358),
    [anon_sym_PIPE_PIPE] = ACTIONS(360),
    [anon_sym_AMP_AMP] = ACTIONS(360),
    [anon_sym_PIPE] = ACTIONS(241),
    [anon_sym_CARET] = ACTIONS(239),
    [anon_sym_AMP] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(241),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_LT_EQ] = ACTIONS(358),
    [anon_sym_GT_EQ] = ACTIONS(358),
    [anon_sym_LT_LT] = ACTIONS(241),
    [anon_sym_GT_GT] = ACTIONS(241),
    [anon_sym_PLUS] = ACTIONS(239),
    [anon_sym_DASH] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(239),
    [anon_sym_PERCENT] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(276),
    [anon_sym_PIPE_AMP] = ACTIONS(276),
    [anon_sym_RBRACK] = ACTIONS(358),
    [anon_sym_EQ_TILDE] = ACTIONS(241),
    [anon_sym_AMP_GT] = ACTIONS(237),
    [anon_sym_AMP_GT_GT] = ACTIONS(276),
    [anon_sym_LT_AMP] = ACTIONS(237),
    [anon_sym_GT_AMP] = ACTIONS(237),
    [anon_sym_GT_PIPE] = ACTIONS(276),
    [anon_sym_LT_AMP_DASH] = ACTIONS(276),
    [anon_sym_GT_AMP_DASH] = ACTIONS(276),
    [anon_sym_LT_LT_DASH] = ACTIONS(276),
    [anon_sym_LT_LT_LT] = ACTIONS(276),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(276),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(276),
    [anon_sym_DOLLAR] = ACTIONS(237),
    [sym__special_character] = ACTIONS(1337),
    [anon_sym_DQUOTE] = ACTIONS(276),
    [sym_raw_string] = ACTIONS(276),
    [sym_ansi_c_string] = ACTIONS(276),
    [aux_sym_number_token1] = ACTIONS(237),
    [aux_sym_number_token2] = ACTIONS(237),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(276),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(237),
    [anon_sym_BQUOTE] = ACTIONS(276),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(276),
    [anon_sym_LT_LPAREN] = ACTIONS(276),
    [anon_sym_GT_LPAREN] = ACTIONS(276),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(276),
    [sym_test_operator] = ACTIONS(360),
    [sym__bare_dollar] = ACTIONS(276),
    [sym__brace_start] = ACTIONS(276),
  },
  [STATE(518)] = {
    [aux_sym__literal_repeat1] = STATE(518),
    [sym_word] = ACTIONS(1316),
    [anon_sym_EQ] = ACTIONS(1316),
    [anon_sym_PLUS_PLUS] = ACTIONS(1316),
    [anon_sym_DASH_DASH] = ACTIONS(1316),
    [anon_sym_PLUS_EQ] = ACTIONS(1316),
    [anon_sym_DASH_EQ] = ACTIONS(1316),
    [anon_sym_STAR_EQ] = ACTIONS(1316),
    [anon_sym_SLASH_EQ] = ACTIONS(1316),
    [anon_sym_PERCENT_EQ] = ACTIONS(1316),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1316),
    [anon_sym_LT_LT_EQ] = ACTIONS(1318),
    [anon_sym_GT_GT_EQ] = ACTIONS(1318),
    [anon_sym_AMP_EQ] = ACTIONS(1318),
    [anon_sym_CARET_EQ] = ACTIONS(1316),
    [anon_sym_PIPE_EQ] = ACTIONS(1318),
    [anon_sym_PIPE_PIPE] = ACTIONS(1318),
    [anon_sym_AMP_AMP] = ACTIONS(1318),
    [anon_sym_PIPE] = ACTIONS(1316),
    [anon_sym_CARET] = ACTIONS(1316),
    [anon_sym_AMP] = ACTIONS(1316),
    [anon_sym_EQ_EQ] = ACTIONS(1316),
    [anon_sym_BANG_EQ] = ACTIONS(1316),
    [anon_sym_LT] = ACTIONS(1316),
    [anon_sym_GT] = ACTIONS(1316),
    [anon_sym_LT_EQ] = ACTIONS(1318),
    [anon_sym_GT_EQ] = ACTIONS(1318),
    [anon_sym_LT_LT] = ACTIONS(1316),
    [anon_sym_GT_GT] = ACTIONS(1316),
    [anon_sym_PLUS] = ACTIONS(1316),
    [anon_sym_DASH] = ACTIONS(1316),
    [anon_sym_STAR] = ACTIONS(1316),
    [anon_sym_SLASH] = ACTIONS(1316),
    [anon_sym_PERCENT] = ACTIONS(1316),
    [anon_sym_STAR_STAR] = ACTIONS(1316),
    [anon_sym_LPAREN] = ACTIONS(1318),
    [anon_sym_PIPE_AMP] = ACTIONS(1318),
    [anon_sym_RBRACK] = ACTIONS(1318),
    [anon_sym_EQ_TILDE] = ACTIONS(1316),
    [anon_sym_AMP_GT] = ACTIONS(1316),
    [anon_sym_AMP_GT_GT] = ACTIONS(1318),
    [anon_sym_LT_AMP] = ACTIONS(1316),
    [anon_sym_GT_AMP] = ACTIONS(1316),
    [anon_sym_GT_PIPE] = ACTIONS(1318),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1318),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1318),
    [anon_sym_LT_LT_DASH] = ACTIONS(1318),
    [anon_sym_LT_LT_LT] = ACTIONS(1318),
    [anon_sym_QMARK] = ACTIONS(1316),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1318),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1318),
    [anon_sym_DOLLAR] = ACTIONS(1316),
    [sym__special_character] = ACTIONS(1339),
    [anon_sym_DQUOTE] = ACTIONS(1318),
    [sym_raw_string] = ACTIONS(1318),
    [sym_ansi_c_string] = ACTIONS(1318),
    [aux_sym_number_token1] = ACTIONS(1316),
    [aux_sym_number_token2] = ACTIONS(1316),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1318),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1316),
    [anon_sym_BQUOTE] = ACTIONS(1318),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1318),
    [anon_sym_LT_LPAREN] = ACTIONS(1318),
    [anon_sym_GT_LPAREN] = ACTIONS(1318),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1318),
    [sym_test_operator] = ACTIONS(1318),
    [sym__bare_dollar] = ACTIONS(1318),
    [sym__brace_start] = ACTIONS(1318),
  },
  [STATE(519)] = {
    [sym_word] = ACTIONS(1223),
    [anon_sym_EQ] = ACTIONS(1223),
    [anon_sym_PLUS_PLUS] = ACTIONS(1223),
    [anon_sym_DASH_DASH] = ACTIONS(1223),
    [anon_sym_PLUS_EQ] = ACTIONS(1223),
    [anon_sym_DASH_EQ] = ACTIONS(1223),
    [anon_sym_STAR_EQ] = ACTIONS(1223),
    [anon_sym_SLASH_EQ] = ACTIONS(1223),
    [anon_sym_PERCENT_EQ] = ACTIONS(1223),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1223),
    [anon_sym_LT_LT_EQ] = ACTIONS(1225),
    [anon_sym_GT_GT_EQ] = ACTIONS(1225),
    [anon_sym_AMP_EQ] = ACTIONS(1225),
    [anon_sym_CARET_EQ] = ACTIONS(1223),
    [anon_sym_PIPE_EQ] = ACTIONS(1225),
    [anon_sym_PIPE_PIPE] = ACTIONS(1225),
    [anon_sym_AMP_AMP] = ACTIONS(1225),
    [anon_sym_PIPE] = ACTIONS(1223),
    [anon_sym_CARET] = ACTIONS(1223),
    [anon_sym_AMP] = ACTIONS(1223),
    [anon_sym_EQ_EQ] = ACTIONS(1223),
    [anon_sym_BANG_EQ] = ACTIONS(1223),
    [anon_sym_LT] = ACTIONS(1223),
    [anon_sym_GT] = ACTIONS(1223),
    [anon_sym_LT_EQ] = ACTIONS(1225),
    [anon_sym_GT_EQ] = ACTIONS(1225),
    [anon_sym_LT_LT] = ACTIONS(1223),
    [anon_sym_GT_GT] = ACTIONS(1223),
    [anon_sym_PLUS] = ACTIONS(1223),
    [anon_sym_DASH] = ACTIONS(1223),
    [anon_sym_STAR] = ACTIONS(1223),
    [anon_sym_SLASH] = ACTIONS(1223),
    [anon_sym_PERCENT] = ACTIONS(1223),
    [anon_sym_STAR_STAR] = ACTIONS(1223),
    [anon_sym_LPAREN] = ACTIONS(1225),
    [anon_sym_PIPE_AMP] = ACTIONS(1225),
    [anon_sym_RBRACK] = ACTIONS(1225),
    [anon_sym_EQ_TILDE] = ACTIONS(1223),
    [anon_sym_AMP_GT] = ACTIONS(1223),
    [anon_sym_AMP_GT_GT] = ACTIONS(1225),
    [anon_sym_LT_AMP] = ACTIONS(1223),
    [anon_sym_GT_AMP] = ACTIONS(1223),
    [anon_sym_GT_PIPE] = ACTIONS(1225),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1225),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1225),
    [anon_sym_LT_LT_DASH] = ACTIONS(1225),
    [anon_sym_LT_LT_LT] = ACTIONS(1225),
    [anon_sym_QMARK] = ACTIONS(1223),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1225),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1225),
    [anon_sym_DOLLAR] = ACTIONS(1223),
    [sym__special_character] = ACTIONS(1223),
    [anon_sym_DQUOTE] = ACTIONS(1225),
    [sym_raw_string] = ACTIONS(1225),
    [sym_ansi_c_string] = ACTIONS(1225),
    [aux_sym_number_token1] = ACTIONS(1223),
    [aux_sym_number_token2] = ACTIONS(1223),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1225),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1223),
    [anon_sym_BQUOTE] = ACTIONS(1225),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1225),
    [anon_sym_LT_LPAREN] = ACTIONS(1225),
    [anon_sym_GT_LPAREN] = ACTIONS(1225),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1225),
    [sym_test_operator] = ACTIONS(1225),
    [sym__bare_dollar] = ACTIONS(1225),
    [sym__brace_start] = ACTIONS(1225),
  },
  [STATE(520)] = {
    [sym_word] = ACTIONS(1233),
    [anon_sym_EQ] = ACTIONS(1235),
    [anon_sym_PLUS_PLUS] = ACTIONS(1235),
    [anon_sym_DASH_DASH] = ACTIONS(1235),
    [anon_sym_PLUS_EQ] = ACTIONS(1235),
    [anon_sym_DASH_EQ] = ACTIONS(1235),
    [anon_sym_STAR_EQ] = ACTIONS(1235),
    [anon_sym_SLASH_EQ] = ACTIONS(1235),
    [anon_sym_PERCENT_EQ] = ACTIONS(1235),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1235),
    [anon_sym_LT_LT_EQ] = ACTIONS(1332),
    [anon_sym_GT_GT_EQ] = ACTIONS(1332),
    [anon_sym_AMP_EQ] = ACTIONS(1332),
    [anon_sym_CARET_EQ] = ACTIONS(1235),
    [anon_sym_PIPE_EQ] = ACTIONS(1332),
    [anon_sym_PIPE_PIPE] = ACTIONS(1242),
    [anon_sym_AMP_AMP] = ACTIONS(1242),
    [anon_sym_PIPE] = ACTIONS(1237),
    [anon_sym_CARET] = ACTIONS(1235),
    [anon_sym_AMP] = ACTIONS(1235),
    [anon_sym_EQ_EQ] = ACTIONS(1237),
    [anon_sym_BANG_EQ] = ACTIONS(1235),
    [anon_sym_LT] = ACTIONS(1237),
    [anon_sym_GT] = ACTIONS(1237),
    [anon_sym_LT_EQ] = ACTIONS(1332),
    [anon_sym_GT_EQ] = ACTIONS(1332),
    [anon_sym_LT_LT] = ACTIONS(1237),
    [anon_sym_GT_GT] = ACTIONS(1237),
    [anon_sym_PLUS] = ACTIONS(1235),
    [anon_sym_DASH] = ACTIONS(1235),
    [anon_sym_STAR] = ACTIONS(1235),
    [anon_sym_SLASH] = ACTIONS(1235),
    [anon_sym_PERCENT] = ACTIONS(1235),
    [anon_sym_STAR_STAR] = ACTIONS(1235),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_PIPE_AMP] = ACTIONS(1240),
    [anon_sym_RBRACK] = ACTIONS(1332),
    [anon_sym_EQ_TILDE] = ACTIONS(1237),
    [anon_sym_AMP_GT] = ACTIONS(1233),
    [anon_sym_AMP_GT_GT] = ACTIONS(1240),
    [anon_sym_LT_AMP] = ACTIONS(1233),
    [anon_sym_GT_AMP] = ACTIONS(1233),
    [anon_sym_GT_PIPE] = ACTIONS(1240),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1240),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1240),
    [anon_sym_LT_LT_DASH] = ACTIONS(1240),
    [anon_sym_LT_LT_LT] = ACTIONS(1240),
    [anon_sym_QMARK] = ACTIONS(1235),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(1240),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(1240),
    [anon_sym_DOLLAR] = ACTIONS(1233),
    [sym__special_character] = ACTIONS(1233),
    [anon_sym_DQUOTE] = ACTIONS(1240),
    [sym_raw_string] = ACTIONS(1240),
    [sym_ansi_c_string] = ACTIONS(1240),
    [aux_sym_number_token1] = ACTIONS(1233),
    [aux_sym_number_token2] = ACTIONS(1233),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1240),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(1233),
    [anon_sym_BQUOTE] = ACTIONS(1240),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(1240),
    [anon_sym_LT_LPAREN] = ACTIONS(1240),
    [anon_sym_GT_LPAREN] = ACTIONS(1240),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1240),
    [sym_test_operator] = ACTIONS(1242),
    [sym__bare_dollar] = ACTIONS(1240),
    [sym__brace_start] = ACTIONS(1240),
  },
  [STATE(521)] = {
    [sym_subshell] = STATE(4724),
    [sym_test_command] = STATE(4724),
    [sym_command] = STATE(4726),
    [sym_command_name] = STATE(532),
    [sym_variable_assignment] = STATE(2030),
    [sym_subscript] = STATE(6664),
    [sym_file_redirect] = STATE(3491),
    [sym_herestring_redirect] = STATE(3491),
    [sym__expression] = STATE(2957),
    [sym_binary_expression] = STATE(2518),
    [sym_ternary_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym_postfix_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2518),
    [sym_arithmetic_expansion] = STATE(467),
    [sym_brace_expression] = STATE(467),
    [sym_concatenation] = STATE(490),
    [sym_string] = STATE(467),
    [sym_translated_string] = STATE(467),
    [sym_number] = STATE(467),
    [sym_simple_expansion] = STATE(467),
    [sym_expansion] = STATE(467),
    [sym_command_substitution] = STATE(467),
    [sym_process_substitution] = STATE(467),
    [aux_sym_command_repeat1] = STATE(961),
    [aux_sym__literal_repeat1] = STATE(489),
    [sym_word] = ACTIONS(1342),
    [anon_sym_LT] = ACTIONS(1344),
    [anon_sym_GT] = ACTIONS(1344),
    [anon_sym_GT_GT] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1348),
    [anon_sym_BANG] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(33),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(35),
    [anon_sym_AMP_GT] = ACTIONS(1344),
    [anon_sym_AMP_GT_GT] = ACTIONS(1346),
    [anon_sym_LT_AMP] = ACTIONS(1344),
    [anon_sym_GT_AMP] = ACTIONS(1344),
    [anon_sym_GT_PIPE] = ACTIONS(1346),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1350),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1350),
    [anon_sym_LT_LT_LT] = ACTIONS(1352),
    [anon_sym_PLUS_PLUS2] = ACTIONS(101),
    [anon_sym_DASH_DASH2] = ACTIONS(101),
    [anon_sym_DASH2] = ACTIONS(103),
    [anon_sym_PLUS2] = ACTIONS(103),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(107),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(109),
    [anon_sym_DOLLAR] = ACTIONS(111),
    [sym__special_character] = ACTIONS(113),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_raw_string] = ACTIONS(117),
    [sym_ansi_c_string] = ACTIONS(117),
    [aux_sym_number_token1] = ACTIONS(119),
    [aux_sym_number_token2] = ACTIONS(121),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(123),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(125),
    [anon_sym_BQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(129),
    [anon_sym_LT_LPAREN] = ACTIONS(131),
    [anon_sym_GT_LPAREN] = ACTIONS(131),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1354),
    [sym_variable_name] = ACTIONS(135),
    [sym_test_operator] = ACTIONS(137),
    [sym__brace_start] = ACTIONS(139),
  },
  [STATE(522)] = {
    [sym_subshell] = STATE(5584),
    [sym_test_command] = STATE(5584),
    [sym_command] = STATE(5567),
    [sym_command_name] = STATE(639),
    [sym_variable_assignment] = STATE(2945),
    [sym_subscript] = STATE(6641),
    [sym_file_redirect] = STATE(3491),
    [sym_herestring_redirect] = STATE(3491),
    [sym__expression] = STATE(3013),
    [sym_binary_expression] = STATE(2847),
    [sym_ternary_expression] = STATE(2847),
    [sym_unary_expression] = STATE(2847),
    [sym_postfix_expression] = STATE(2847),
    [sym_parenthesized_expression] = STATE(2847),
    [sym_arithmetic_expansion] = STATE(496),
    [sym_brace_expression] = STATE(496),
    [sym_concatenation] = STATE(520),
    [sym_string] = STATE(496),
    [sym_translated_string] = STATE(496),
    [sym_number] = STATE(496),
    [sym_simple_expansion] = STATE(496),
    [sym_expansion] = STATE(496),
    [sym_command_substitution] = STATE(496),
    [sym_process_substitution] = STATE(496),
    [aux_sym_command_repeat1] = STATE(880),
    [aux_sym__literal_repeat1] = STATE(517),
    [sym_word] = ACTIONS(1356),
    [anon_sym_LT] = ACTIONS(1344),
    [anon_sym_GT] = ACTIONS(1344),
    [anon_sym_GT_GT] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1358),
    [anon_sym_BANG] = ACTIONS(365),
    [anon_sym_LBRACK] = ACTIONS(167),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(171),
    [anon_sym_AMP_GT] = ACTIONS(1344),
    [anon_sym_AMP_GT_GT] = ACTIONS(1346),
    [anon_sym_LT_AMP] = ACTIONS(1344),
    [anon_sym_GT_AMP] = ACTIONS(1344),
    [anon_sym_GT_PIPE] = ACTIONS(1346),
    [anon_sym_LT_AMP_DASH] = ACTIONS(1350),
    [anon_sym_GT_AMP_DASH] = ACTIONS(1350),
    [anon_sym_LT_LT_LT] = ACTIONS(1352),
    [anon_sym_PLUS_PLUS2] = ACTIONS(181),
    [anon_sym_DASH_DASH2] = ACTIONS(181),
    [anon_sym_DASH2] = ACTIONS(183),
    [anon_sym_PLUS2] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_DOLLAR_LPAREN_LPAREN] = ACTIONS(187),
    [anon_sym_DOLLAR_LBRACK] = ACTIONS(189),
    [anon_sym_DOLLAR] = ACTIONS(191),
    [sym__special_character] = ACTIONS(193),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_raw_string] = ACTIONS(197),
    [sym_ansi_c_string] = ACTIONS(197),
    [aux_sym_number_token1] = ACTIONS(199),
    [aux_sym_number_token2] = ACTIONS(201),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(203),
    [anon_sym_DOLLAR_LPAREN] = ACTIONS(205),
    [anon_sym_BQUOTE] = ACTIONS(207),
    [anon_sym_DOLLAR_BQUOTE] = ACTIONS(209),
    [anon_sym_LT_LPAREN] = ACTIONS(211),
    [anon_sym_GT_LPAREN] = ACTIONS(211),
    [sym_comment] = ACTIONS(71),
    [sym_file_descriptor] = ACTIONS(1354),
    [sym_variable_name] = ACTIONS(215),
    [sym_test_operator] = ACTIONS(217),
    [sym__brace_start] = ACTIONS(219),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(411), 1,
      anon_sym_LPAREN,
    ACTIONS(1368), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1370), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1372), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1376), 1,
      sym__special_character,
    ACTIONS(1378), 1,
      anon_sym_DQUOTE,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1384), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1388), 1,
      anon_sym_BQUOTE,
    ACTIONS(1390), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1394), 1,
      sym_test_operator,
    ACTIONS(1396), 1,
      sym__bare_dollar,
    ACTIONS(1398), 1,
      sym__brace_start,
    STATE(531), 1,
      aux_sym_command_repeat2,
    STATE(1071), 1,
      aux_sym__literal_repeat1,
    STATE(1196), 1,
      sym_concatenation,
    STATE(1197), 1,
      sym_herestring_redirect,
    STATE(4723), 1,
      sym_subshell,
    ACTIONS(1364), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1366), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1392), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1360), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(839), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1362), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [119] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(411), 1,
      anon_sym_LPAREN,
    ACTIONS(1368), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1370), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1372), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1376), 1,
      sym__special_character,
    ACTIONS(1378), 1,
      anon_sym_DQUOTE,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1384), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1388), 1,
      anon_sym_BQUOTE,
    ACTIONS(1390), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1394), 1,
      sym_test_operator,
    ACTIONS(1396), 1,
      sym__bare_dollar,
    ACTIONS(1398), 1,
      sym__brace_start,
    STATE(527), 1,
      aux_sym_command_repeat2,
    STATE(1071), 1,
      aux_sym__literal_repeat1,
    STATE(1196), 1,
      sym_concatenation,
    STATE(1197), 1,
      sym_herestring_redirect,
    STATE(4837), 1,
      sym_subshell,
    ACTIONS(1364), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1392), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1402), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1360), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(839), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1400), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [238] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(673), 1,
      anon_sym_LPAREN,
    ACTIONS(1408), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1410), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1412), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1414), 1,
      anon_sym_DOLLAR,
    ACTIONS(1416), 1,
      sym__special_character,
    ACTIONS(1418), 1,
      anon_sym_DQUOTE,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1424), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1428), 1,
      anon_sym_BQUOTE,
    ACTIONS(1430), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1434), 1,
      sym_test_operator,
    ACTIONS(1436), 1,
      sym__bare_dollar,
    ACTIONS(1438), 1,
      sym__brace_start,
    STATE(545), 1,
      aux_sym_command_repeat2,
    STATE(1230), 1,
      aux_sym__literal_repeat1,
    STATE(1330), 1,
      sym_concatenation,
    STATE(1332), 1,
      sym_herestring_redirect,
    STATE(4960), 1,
      sym_subshell,
    ACTIONS(1366), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1406), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1432), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1404), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(952), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1362), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [356] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(673), 1,
      anon_sym_LPAREN,
    ACTIONS(1408), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1410), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1412), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1414), 1,
      anon_sym_DOLLAR,
    ACTIONS(1416), 1,
      sym__special_character,
    ACTIONS(1418), 1,
      anon_sym_DQUOTE,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1424), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1428), 1,
      anon_sym_BQUOTE,
    ACTIONS(1430), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1434), 1,
      sym_test_operator,
    ACTIONS(1436), 1,
      sym__bare_dollar,
    ACTIONS(1438), 1,
      sym__brace_start,
    STATE(543), 1,
      aux_sym_command_repeat2,
    STATE(1230), 1,
      aux_sym__literal_repeat1,
    STATE(1330), 1,
      sym_concatenation,
    STATE(1332), 1,
      sym_herestring_redirect,
    STATE(5016), 1,
      sym_subshell,
    ACTIONS(1402), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1406), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1432), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1404), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(952), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1400), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [474] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1368), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1370), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1372), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1376), 1,
      sym__special_character,
    ACTIONS(1378), 1,
      anon_sym_DQUOTE,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1384), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1388), 1,
      anon_sym_BQUOTE,
    ACTIONS(1390), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1394), 1,
      sym_test_operator,
    ACTIONS(1396), 1,
      sym__bare_dollar,
    ACTIONS(1398), 1,
      sym__brace_start,
    STATE(529), 1,
      aux_sym_command_repeat2,
    STATE(1071), 1,
      aux_sym__literal_repeat1,
    STATE(1196), 1,
      sym_concatenation,
    STATE(1197), 1,
      sym_herestring_redirect,
    ACTIONS(1364), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1392), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1442), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1360), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(839), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1440), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [587] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1448), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1450), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1452), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1454), 1,
      anon_sym_DOLLAR,
    ACTIONS(1456), 1,
      sym__special_character,
    ACTIONS(1458), 1,
      anon_sym_DQUOTE,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1464), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1468), 1,
      anon_sym_BQUOTE,
    ACTIONS(1470), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1474), 1,
      sym_test_operator,
    ACTIONS(1476), 1,
      sym__bare_dollar,
    ACTIONS(1478), 1,
      sym__brace_start,
    STATE(552), 1,
      aux_sym_command_repeat2,
    STATE(1334), 1,
      aux_sym__literal_repeat1,
    STATE(1606), 1,
      sym_concatenation,
    STATE(1607), 1,
      sym_herestring_redirect,
    STATE(4842), 1,
      sym_subshell,
    ACTIONS(1446), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1472), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1402), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1444), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1095), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1400), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [704] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1490), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1493), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1496), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1499), 1,
      anon_sym_DOLLAR,
    ACTIONS(1502), 1,
      sym__special_character,
    ACTIONS(1505), 1,
      anon_sym_DQUOTE,
    ACTIONS(1508), 1,
      aux_sym_number_token1,
    ACTIONS(1511), 1,
      aux_sym_number_token2,
    ACTIONS(1514), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1517), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1520), 1,
      anon_sym_BQUOTE,
    ACTIONS(1523), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1529), 1,
      sym_file_descriptor,
    ACTIONS(1532), 1,
      sym_test_operator,
    ACTIONS(1535), 1,
      sym__bare_dollar,
    ACTIONS(1538), 1,
      sym__brace_start,
    STATE(529), 1,
      aux_sym_command_repeat2,
    STATE(1071), 1,
      aux_sym__literal_repeat1,
    STATE(1196), 1,
      sym_concatenation,
    STATE(1197), 1,
      sym_herestring_redirect,
    ACTIONS(1485), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1480), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(839), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1483), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [819] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1545), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1553), 1,
      sym__special_character,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1571), 1,
      sym_test_operator,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    STATE(548), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    STATE(4702), 1,
      sym_subshell,
    ACTIONS(1366), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1543), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1541), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1118), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1362), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [936] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1368), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1370), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1372), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1376), 1,
      sym__special_character,
    ACTIONS(1378), 1,
      anon_sym_DQUOTE,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1384), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1388), 1,
      anon_sym_BQUOTE,
    ACTIONS(1390), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1394), 1,
      sym_test_operator,
    ACTIONS(1396), 1,
      sym__bare_dollar,
    ACTIONS(1398), 1,
      sym__brace_start,
    STATE(529), 1,
      aux_sym_command_repeat2,
    STATE(1071), 1,
      aux_sym__literal_repeat1,
    STATE(1196), 1,
      sym_concatenation,
    STATE(1197), 1,
      sym_herestring_redirect,
    ACTIONS(1364), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1392), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1579), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1360), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(839), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1577), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [1049] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1545), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1553), 1,
      sym__special_character,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1571), 1,
      sym_test_operator,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    STATE(555), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    STATE(4842), 1,
      sym_subshell,
    ACTIONS(1402), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1543), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1541), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1118), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1400), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [1166] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1448), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1450), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1452), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1454), 1,
      anon_sym_DOLLAR,
    ACTIONS(1456), 1,
      sym__special_character,
    ACTIONS(1458), 1,
      anon_sym_DQUOTE,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1464), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1468), 1,
      anon_sym_BQUOTE,
    ACTIONS(1470), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1474), 1,
      sym_test_operator,
    ACTIONS(1476), 1,
      sym__bare_dollar,
    ACTIONS(1478), 1,
      sym__brace_start,
    STATE(553), 1,
      aux_sym_command_repeat2,
    STATE(1334), 1,
      aux_sym__literal_repeat1,
    STATE(1606), 1,
      sym_concatenation,
    STATE(1607), 1,
      sym_herestring_redirect,
    STATE(4702), 1,
      sym_subshell,
    ACTIONS(1446), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1472), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1366), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1444), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1095), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1362), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [1283] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1587), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1589), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1591), 1,
      anon_sym_DOLLAR,
    ACTIONS(1593), 1,
      sym__special_character,
    ACTIONS(1595), 1,
      anon_sym_DQUOTE,
    ACTIONS(1597), 1,
      aux_sym_number_token1,
    ACTIONS(1599), 1,
      aux_sym_number_token2,
    ACTIONS(1601), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1603), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_BQUOTE,
    ACTIONS(1607), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1611), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(1613), 1,
      sym_variable_name,
    ACTIONS(1615), 1,
      sym_test_operator,
    ACTIONS(1617), 1,
      sym__brace_start,
    STATE(1427), 1,
      aux_sym__literal_repeat1,
    STATE(6651), 1,
      sym_subscript,
    ACTIONS(1585), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1609), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1581), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(539), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1064), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1583), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [1391] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1625), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1628), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1631), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1634), 1,
      anon_sym_DOLLAR,
    ACTIONS(1637), 1,
      sym__special_character,
    ACTIONS(1640), 1,
      anon_sym_DQUOTE,
    ACTIONS(1643), 1,
      aux_sym_number_token1,
    ACTIONS(1646), 1,
      aux_sym_number_token2,
    ACTIONS(1649), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1652), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1655), 1,
      anon_sym_BQUOTE,
    ACTIONS(1658), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1664), 1,
      sym_file_descriptor,
    ACTIONS(1667), 1,
      sym_test_operator,
    ACTIONS(1670), 1,
      sym__bare_dollar,
    ACTIONS(1673), 1,
      sym__brace_start,
    STATE(535), 1,
      aux_sym_command_repeat2,
    STATE(1230), 1,
      aux_sym__literal_repeat1,
    STATE(1330), 1,
      sym_concatenation,
    STATE(1332), 1,
      sym_herestring_redirect,
    ACTIONS(1622), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1619), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(952), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1483), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [1505] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 1,
      anon_sym_DQUOTE,
    ACTIONS(1682), 1,
      sym_variable_name,
    STATE(857), 1,
      sym_string,
    ACTIONS(1680), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(1676), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [1581] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 1,
      anon_sym_DQUOTE,
    ACTIONS(1682), 1,
      sym_variable_name,
    STATE(857), 1,
      sym_string,
    ACTIONS(1680), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(1676), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [1657] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(1688), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1690), 1,
      sym__special_character,
    ACTIONS(1692), 1,
      sym_test_operator,
    STATE(561), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    STATE(4842), 1,
      sym_subshell,
    ACTIONS(1402), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1686), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1684), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1400), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [1771] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1587), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1589), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1591), 1,
      anon_sym_DOLLAR,
    ACTIONS(1593), 1,
      sym__special_character,
    ACTIONS(1595), 1,
      anon_sym_DQUOTE,
    ACTIONS(1597), 1,
      aux_sym_number_token1,
    ACTIONS(1599), 1,
      aux_sym_number_token2,
    ACTIONS(1601), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1603), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_BQUOTE,
    ACTIONS(1607), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1613), 1,
      sym_variable_name,
    ACTIONS(1615), 1,
      sym_test_operator,
    ACTIONS(1617), 1,
      sym__brace_start,
    ACTIONS(1698), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1427), 1,
      aux_sym__literal_repeat1,
    STATE(6651), 1,
      sym_subscript,
    ACTIONS(1609), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1696), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1581), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(541), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1064), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1694), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [1879] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(1688), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1690), 1,
      sym__special_character,
    ACTIONS(1692), 1,
      sym_test_operator,
    STATE(562), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    STATE(4702), 1,
      sym_subshell,
    ACTIONS(1366), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1686), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1684), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1362), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [1993] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1707), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1710), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1713), 1,
      anon_sym_DOLLAR,
    ACTIONS(1716), 1,
      sym__special_character,
    ACTIONS(1719), 1,
      anon_sym_DQUOTE,
    ACTIONS(1722), 1,
      aux_sym_number_token1,
    ACTIONS(1725), 1,
      aux_sym_number_token2,
    ACTIONS(1728), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1731), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1734), 1,
      anon_sym_BQUOTE,
    ACTIONS(1737), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1743), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(1746), 1,
      sym_variable_name,
    ACTIONS(1749), 1,
      sym_test_operator,
    ACTIONS(1752), 1,
      sym__brace_start,
    STATE(1427), 1,
      aux_sym__literal_repeat1,
    STATE(6651), 1,
      sym_subscript,
    ACTIONS(1705), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1740), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1700), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(541), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1064), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1703), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [2101] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(1688), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1690), 1,
      sym__special_character,
    ACTIONS(1692), 1,
      sym_test_operator,
    STATE(579), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    STATE(4702), 1,
      sym_subshell,
    ACTIONS(1366), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1686), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1684), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1362), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [2217] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1408), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1410), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1412), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1414), 1,
      anon_sym_DOLLAR,
    ACTIONS(1416), 1,
      sym__special_character,
    ACTIONS(1418), 1,
      anon_sym_DQUOTE,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1424), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1428), 1,
      anon_sym_BQUOTE,
    ACTIONS(1430), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1434), 1,
      sym_test_operator,
    ACTIONS(1436), 1,
      sym__bare_dollar,
    ACTIONS(1438), 1,
      sym__brace_start,
    STATE(535), 1,
      aux_sym_command_repeat2,
    STATE(1230), 1,
      aux_sym__literal_repeat1,
    STATE(1330), 1,
      sym_concatenation,
    STATE(1332), 1,
      sym_herestring_redirect,
    ACTIONS(1406), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1432), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1442), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1404), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(952), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1440), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [2329] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(1688), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1690), 1,
      sym__special_character,
    ACTIONS(1692), 1,
      sym_test_operator,
    STATE(577), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    STATE(4842), 1,
      sym_subshell,
    ACTIONS(1402), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1686), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1684), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1400), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [2445] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1408), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1410), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1412), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1414), 1,
      anon_sym_DOLLAR,
    ACTIONS(1416), 1,
      sym__special_character,
    ACTIONS(1418), 1,
      anon_sym_DQUOTE,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1424), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1428), 1,
      anon_sym_BQUOTE,
    ACTIONS(1430), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1434), 1,
      sym_test_operator,
    ACTIONS(1436), 1,
      sym__bare_dollar,
    ACTIONS(1438), 1,
      sym__brace_start,
    STATE(535), 1,
      aux_sym_command_repeat2,
    STATE(1230), 1,
      aux_sym__literal_repeat1,
    STATE(1330), 1,
      sym_concatenation,
    STATE(1332), 1,
      sym_herestring_redirect,
    ACTIONS(1406), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1432), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1579), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1404), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(952), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1577), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [2557] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1757), 1,
      anon_sym_DQUOTE,
    ACTIONS(1761), 1,
      sym_variable_name,
    STATE(898), 1,
      sym_string,
    ACTIONS(1759), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(1755), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [2632] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1378), 1,
      anon_sym_DQUOTE,
    ACTIONS(1767), 1,
      sym_variable_name,
    STATE(890), 1,
      sym_string,
    ACTIONS(1765), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(1763), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [2707] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1545), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1553), 1,
      sym__special_character,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1571), 1,
      sym_test_operator,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    STATE(556), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1543), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1579), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1541), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1118), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1577), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [2818] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1757), 1,
      anon_sym_DQUOTE,
    ACTIONS(1761), 1,
      sym_variable_name,
    STATE(898), 1,
      sym_string,
    ACTIONS(1759), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(1755), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [2893] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1772), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1775), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1778), 1,
      anon_sym_DOLLAR,
    ACTIONS(1781), 1,
      sym__special_character,
    ACTIONS(1784), 1,
      anon_sym_DQUOTE,
    ACTIONS(1787), 1,
      aux_sym_number_token1,
    ACTIONS(1790), 1,
      aux_sym_number_token2,
    ACTIONS(1793), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1796), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1799), 1,
      anon_sym_BQUOTE,
    ACTIONS(1802), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1808), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(1811), 1,
      sym_variable_name,
    ACTIONS(1814), 1,
      sym_test_operator,
    ACTIONS(1817), 1,
      sym__brace_start,
    STATE(1605), 1,
      aux_sym__literal_repeat1,
    STATE(6695), 1,
      sym_subscript,
    ACTIONS(1705), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1805), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1769), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(550), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1227), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1703), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3000] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1826), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1829), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1832), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1835), 1,
      anon_sym_DOLLAR,
    ACTIONS(1838), 1,
      sym__special_character,
    ACTIONS(1841), 1,
      anon_sym_DQUOTE,
    ACTIONS(1844), 1,
      aux_sym_number_token1,
    ACTIONS(1847), 1,
      aux_sym_number_token2,
    ACTIONS(1850), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1853), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1856), 1,
      anon_sym_BQUOTE,
    ACTIONS(1859), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1865), 1,
      sym_file_descriptor,
    ACTIONS(1868), 1,
      sym_test_operator,
    ACTIONS(1871), 1,
      sym__bare_dollar,
    ACTIONS(1874), 1,
      sym__brace_start,
    STATE(551), 1,
      aux_sym_command_repeat2,
    STATE(1334), 1,
      aux_sym__literal_repeat1,
    STATE(1606), 1,
      sym_concatenation,
    STATE(1607), 1,
      sym_herestring_redirect,
    ACTIONS(1488), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1823), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1862), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1820), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1095), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1483), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3113] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1448), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1450), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1452), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1454), 1,
      anon_sym_DOLLAR,
    ACTIONS(1456), 1,
      sym__special_character,
    ACTIONS(1458), 1,
      anon_sym_DQUOTE,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1464), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1468), 1,
      anon_sym_BQUOTE,
    ACTIONS(1470), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1474), 1,
      sym_test_operator,
    ACTIONS(1476), 1,
      sym__bare_dollar,
    ACTIONS(1478), 1,
      sym__brace_start,
    STATE(551), 1,
      aux_sym_command_repeat2,
    STATE(1334), 1,
      aux_sym__literal_repeat1,
    STATE(1606), 1,
      sym_concatenation,
    STATE(1607), 1,
      sym_herestring_redirect,
    ACTIONS(1446), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1472), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1442), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1444), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1095), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1440), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3224] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1448), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1450), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1452), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1454), 1,
      anon_sym_DOLLAR,
    ACTIONS(1456), 1,
      sym__special_character,
    ACTIONS(1458), 1,
      anon_sym_DQUOTE,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1464), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1468), 1,
      anon_sym_BQUOTE,
    ACTIONS(1470), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1474), 1,
      sym_test_operator,
    ACTIONS(1476), 1,
      sym__bare_dollar,
    ACTIONS(1478), 1,
      sym__brace_start,
    STATE(551), 1,
      aux_sym_command_repeat2,
    STATE(1334), 1,
      aux_sym__literal_repeat1,
    STATE(1606), 1,
      sym_concatenation,
    STATE(1607), 1,
      sym_herestring_redirect,
    ACTIONS(1446), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1472), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1444), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(1579), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(1095), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1577), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3335] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1881), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1883), 1,
      anon_sym_DOLLAR,
    ACTIONS(1885), 1,
      sym__special_character,
    ACTIONS(1887), 1,
      anon_sym_DQUOTE,
    ACTIONS(1889), 1,
      aux_sym_number_token1,
    ACTIONS(1891), 1,
      aux_sym_number_token2,
    ACTIONS(1893), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1895), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1897), 1,
      anon_sym_BQUOTE,
    ACTIONS(1899), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1903), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(1905), 1,
      sym_variable_name,
    ACTIONS(1907), 1,
      sym_test_operator,
    ACTIONS(1909), 1,
      sym__brace_start,
    STATE(1605), 1,
      aux_sym__literal_repeat1,
    STATE(6695), 1,
      sym_subscript,
    ACTIONS(1585), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1901), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1877), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(557), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1227), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1583), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3442] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1545), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1553), 1,
      sym__special_character,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1571), 1,
      sym_test_operator,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    STATE(556), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1442), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1543), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1541), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1118), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1440), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3553] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1917), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1920), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1923), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1926), 1,
      anon_sym_DOLLAR,
    ACTIONS(1929), 1,
      sym__special_character,
    ACTIONS(1932), 1,
      anon_sym_DQUOTE,
    ACTIONS(1935), 1,
      aux_sym_number_token1,
    ACTIONS(1938), 1,
      aux_sym_number_token2,
    ACTIONS(1941), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1944), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1947), 1,
      anon_sym_BQUOTE,
    ACTIONS(1950), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1956), 1,
      sym_file_descriptor,
    ACTIONS(1959), 1,
      sym_test_operator,
    ACTIONS(1962), 1,
      sym__bare_dollar,
    ACTIONS(1965), 1,
      sym__brace_start,
    STATE(556), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1914), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1953), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1911), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1118), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1483), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3666] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1881), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1883), 1,
      anon_sym_DOLLAR,
    ACTIONS(1885), 1,
      sym__special_character,
    ACTIONS(1887), 1,
      anon_sym_DQUOTE,
    ACTIONS(1889), 1,
      aux_sym_number_token1,
    ACTIONS(1891), 1,
      aux_sym_number_token2,
    ACTIONS(1893), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1895), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1897), 1,
      anon_sym_BQUOTE,
    ACTIONS(1899), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1905), 1,
      sym_variable_name,
    ACTIONS(1907), 1,
      sym_test_operator,
    ACTIONS(1909), 1,
      sym__brace_start,
    ACTIONS(1968), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1605), 1,
      aux_sym__literal_repeat1,
    STATE(6695), 1,
      sym_subscript,
    ACTIONS(1696), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1901), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1877), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(550), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1227), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1694), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3773] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1378), 1,
      anon_sym_DQUOTE,
    ACTIONS(1767), 1,
      sym_variable_name,
    STATE(890), 1,
      sym_string,
    ACTIONS(1765), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(1763), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [3848] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1973), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1979), 1,
      anon_sym_DOLLAR,
    ACTIONS(1982), 1,
      sym__special_character,
    ACTIONS(1985), 1,
      anon_sym_DQUOTE,
    ACTIONS(1988), 1,
      aux_sym_number_token1,
    ACTIONS(1991), 1,
      aux_sym_number_token2,
    ACTIONS(1994), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1997), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2000), 1,
      anon_sym_BQUOTE,
    ACTIONS(2003), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2009), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2012), 1,
      sym_variable_name,
    ACTIONS(2015), 1,
      sym_test_operator,
    ACTIONS(2018), 1,
      sym__brace_start,
    STATE(1771), 1,
      aux_sym__literal_repeat1,
    STATE(6634), 1,
      sym_subscript,
    ACTIONS(2006), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1705), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1970), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(559), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1445), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1703), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [3954] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      anon_sym_DQUOTE,
    ACTIONS(2025), 1,
      sym_variable_name,
    STATE(1012), 1,
      sym_string,
    ACTIONS(2023), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2021), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [4028] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(1688), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1690), 1,
      sym__special_character,
    ACTIONS(1692), 1,
      sym_test_operator,
    STATE(578), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1442), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1686), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1684), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1440), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [4136] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(1688), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1690), 1,
      sym__special_character,
    ACTIONS(1692), 1,
      sym_test_operator,
    STATE(578), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1579), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1686), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1684), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1577), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [4244] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2031), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2035), 1,
      sym__special_character,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2043), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2047), 1,
      anon_sym_BQUOTE,
    ACTIONS(2049), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2053), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2055), 1,
      sym_variable_name,
    ACTIONS(2057), 1,
      sym_test_operator,
    ACTIONS(2059), 1,
      sym__brace_start,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6636), 1,
      sym_subscript,
    ACTIONS(1585), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2051), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2027), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(566), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1368), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1583), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [4350] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      anon_sym_DQUOTE,
    ACTIONS(2025), 1,
      sym_variable_name,
    STATE(1012), 1,
      sym_string,
    ACTIONS(2023), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2021), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [4424] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2063), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2065), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2067), 1,
      anon_sym_DOLLAR,
    ACTIONS(2069), 1,
      sym__special_character,
    ACTIONS(2071), 1,
      anon_sym_DQUOTE,
    ACTIONS(2073), 1,
      aux_sym_number_token1,
    ACTIONS(2075), 1,
      aux_sym_number_token2,
    ACTIONS(2077), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2079), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2081), 1,
      anon_sym_BQUOTE,
    ACTIONS(2083), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2087), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2089), 1,
      sym_variable_name,
    ACTIONS(2091), 1,
      sym_test_operator,
    ACTIONS(2093), 1,
      sym__brace_start,
    STATE(1771), 1,
      aux_sym__literal_repeat1,
    STATE(6634), 1,
      sym_subscript,
    ACTIONS(2085), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1585), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2061), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(573), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1445), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1583), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [4530] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2031), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2035), 1,
      sym__special_character,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2043), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2047), 1,
      anon_sym_BQUOTE,
    ACTIONS(2049), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2055), 1,
      sym_variable_name,
    ACTIONS(2057), 1,
      sym_test_operator,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(2095), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6636), 1,
      sym_subscript,
    ACTIONS(1696), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2051), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2027), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(568), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1368), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1694), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [4636] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2099), 1,
      anon_sym_DQUOTE,
    ACTIONS(2103), 1,
      sym_variable_name,
    STATE(1087), 1,
      sym_string,
    ACTIONS(2101), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(2097), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [4710] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2108), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2114), 1,
      anon_sym_DOLLAR,
    ACTIONS(2117), 1,
      sym__special_character,
    ACTIONS(2120), 1,
      anon_sym_DQUOTE,
    ACTIONS(2123), 1,
      aux_sym_number_token1,
    ACTIONS(2126), 1,
      aux_sym_number_token2,
    ACTIONS(2129), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2135), 1,
      anon_sym_BQUOTE,
    ACTIONS(2138), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2144), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2147), 1,
      sym_variable_name,
    ACTIONS(2150), 1,
      sym_test_operator,
    ACTIONS(2153), 1,
      sym__brace_start,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6636), 1,
      sym_subscript,
    ACTIONS(1705), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2141), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2105), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(568), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1368), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1703), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [4816] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1320), 1,
      aux_sym__literal_repeat1,
    STATE(572), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [4886] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(801), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(517), 33,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_do,
      anon_sym_if,
      anon_sym_then,
      anon_sym_fi,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [4950] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1320), 1,
      aux_sym__literal_repeat1,
    STATE(572), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [5020] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2171), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2174), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2177), 1,
      anon_sym_DOLLAR,
    ACTIONS(2180), 1,
      sym__special_character,
    ACTIONS(2183), 1,
      anon_sym_DQUOTE,
    ACTIONS(2186), 1,
      aux_sym_number_token1,
    ACTIONS(2189), 1,
      aux_sym_number_token2,
    ACTIONS(2192), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2195), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2198), 1,
      anon_sym_BQUOTE,
    ACTIONS(2201), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2207), 1,
      sym_test_operator,
    ACTIONS(2210), 1,
      sym__brace_start,
    STATE(1320), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2204), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(572), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2164), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(2169), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    STATE(1021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [5120] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2063), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2065), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2067), 1,
      anon_sym_DOLLAR,
    ACTIONS(2069), 1,
      sym__special_character,
    ACTIONS(2071), 1,
      anon_sym_DQUOTE,
    ACTIONS(2073), 1,
      aux_sym_number_token1,
    ACTIONS(2075), 1,
      aux_sym_number_token2,
    ACTIONS(2077), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2079), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2081), 1,
      anon_sym_BQUOTE,
    ACTIONS(2083), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2089), 1,
      sym_variable_name,
    ACTIONS(2091), 1,
      sym_test_operator,
    ACTIONS(2093), 1,
      sym__brace_start,
    ACTIONS(2213), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1771), 1,
      aux_sym__literal_repeat1,
    STATE(6634), 1,
      sym_subscript,
    ACTIONS(2085), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1696), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2061), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(559), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1445), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1694), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [5226] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2099), 1,
      anon_sym_DQUOTE,
    ACTIONS(2103), 1,
      sym_variable_name,
    STATE(1087), 1,
      sym_string,
    ACTIONS(2101), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(2097), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [5300] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2217), 1,
      anon_sym_DQUOTE,
    ACTIONS(2221), 1,
      sym_variable_name,
    STATE(983), 1,
      sym_string,
    ACTIONS(2219), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2215), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [5374] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2217), 1,
      anon_sym_DQUOTE,
    ACTIONS(2221), 1,
      sym_variable_name,
    STATE(983), 1,
      sym_string,
    ACTIONS(2219), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2215), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [5448] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(1688), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1690), 1,
      sym__special_character,
    ACTIONS(1692), 1,
      sym_test_operator,
    STATE(578), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1442), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1686), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1684), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1440), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [5558] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1920), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1923), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1926), 1,
      anon_sym_DOLLAR,
    ACTIONS(1932), 1,
      anon_sym_DQUOTE,
    ACTIONS(1935), 1,
      aux_sym_number_token1,
    ACTIONS(1938), 1,
      aux_sym_number_token2,
    ACTIONS(1941), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1944), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1947), 1,
      anon_sym_BQUOTE,
    ACTIONS(1950), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1962), 1,
      sym__bare_dollar,
    ACTIONS(1965), 1,
      sym__brace_start,
    ACTIONS(2229), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2232), 1,
      sym__special_character,
    ACTIONS(2235), 1,
      sym_file_descriptor,
    ACTIONS(2238), 1,
      sym_test_operator,
    STATE(578), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1953), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2226), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2223), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1483), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [5670] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(1688), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1690), 1,
      sym__special_character,
    ACTIONS(1692), 1,
      sym_test_operator,
    STATE(578), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1579), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1686), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(1684), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1270), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1577), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [5780] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2245), 2,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
    ACTIONS(2247), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(2243), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [5847] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(2253), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2255), 1,
      sym__special_character,
    ACTIONS(2257), 1,
      sym_test_operator,
    STATE(679), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    STATE(4842), 1,
      sym_subshell,
    ACTIONS(1402), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2251), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2249), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1890), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1400), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [5960] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      anon_sym_DQUOTE,
    ACTIONS(2263), 1,
      sym_variable_name,
    STATE(1246), 1,
      sym_string,
    ACTIONS(2261), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(2259), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [6033] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      anon_sym_DQUOTE,
    ACTIONS(2263), 1,
      sym_variable_name,
    STATE(1246), 1,
      sym_string,
    ACTIONS(2261), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(2259), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [6106] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(2269), 1,
      sym_variable_name,
    STATE(1273), 1,
      sym_string,
    ACTIONS(2267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2265), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [6179] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(2269), 1,
      sym_variable_name,
    STATE(1273), 1,
      sym_string,
    ACTIONS(2267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2265), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [6252] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1457), 1,
      aux_sym__literal_repeat1,
    STATE(1479), 1,
      sym_concatenation,
    ACTIONS(2273), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1015), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [6321] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1337), 1,
      aux_sym__literal_repeat1,
    STATE(1670), 1,
      sym_concatenation,
    ACTIONS(2277), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1096), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [6390] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2285), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2287), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2289), 1,
      anon_sym_DOLLAR,
    ACTIONS(2291), 1,
      sym__special_character,
    ACTIONS(2293), 1,
      anon_sym_DQUOTE,
    ACTIONS(2295), 1,
      aux_sym_number_token1,
    ACTIONS(2297), 1,
      aux_sym_number_token2,
    ACTIONS(2299), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2301), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2303), 1,
      anon_sym_BQUOTE,
    ACTIONS(2305), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2309), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2311), 1,
      sym_test_operator,
    ACTIONS(2313), 1,
      sym__brace_start,
    STATE(1464), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2283), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2307), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(591), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2279), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1137), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2281), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [6491] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2031), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2043), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2049), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(2317), 1,
      sym__special_character,
    ACTIONS(2319), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2321), 1,
      sym_variable_name,
    ACTIONS(2323), 1,
      sym_test_operator,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6652), 1,
      sym_subscript,
    ACTIONS(1696), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2051), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2315), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(603), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1666), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1694), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [6594] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2245), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(2247), 3,
      anon_sym_RPAREN,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(2243), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [6661] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2285), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2287), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2289), 1,
      anon_sym_DOLLAR,
    ACTIONS(2291), 1,
      sym__special_character,
    ACTIONS(2293), 1,
      anon_sym_DQUOTE,
    ACTIONS(2295), 1,
      aux_sym_number_token1,
    ACTIONS(2297), 1,
      aux_sym_number_token2,
    ACTIONS(2299), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2301), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2303), 1,
      anon_sym_BQUOTE,
    ACTIONS(2305), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2311), 1,
      sym_test_operator,
    ACTIONS(2313), 1,
      sym__brace_start,
    ACTIONS(2329), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1464), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2307), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2327), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(598), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2279), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1137), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2325), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [6762] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2333), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2335), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2337), 1,
      anon_sym_DOLLAR,
    ACTIONS(2339), 1,
      sym__special_character,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2343), 1,
      aux_sym_number_token1,
    ACTIONS(2345), 1,
      aux_sym_number_token2,
    ACTIONS(2347), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2349), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2351), 1,
      anon_sym_BQUOTE,
    ACTIONS(2353), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2357), 1,
      sym_test_operator,
    ACTIONS(2359), 1,
      sym__brace_start,
    STATE(1491), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2355), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(594), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2331), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1165), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [6861] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2333), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2335), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2337), 1,
      anon_sym_DOLLAR,
    ACTIONS(2339), 1,
      sym__special_character,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2343), 1,
      aux_sym_number_token1,
    ACTIONS(2345), 1,
      aux_sym_number_token2,
    ACTIONS(2347), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2349), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2351), 1,
      anon_sym_BQUOTE,
    ACTIONS(2353), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2357), 1,
      sym_test_operator,
    ACTIONS(2359), 1,
      sym__brace_start,
    STATE(1491), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2355), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(594), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2331), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1165), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [6960] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2364), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2367), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2370), 1,
      anon_sym_DOLLAR,
    ACTIONS(2373), 1,
      sym__special_character,
    ACTIONS(2376), 1,
      anon_sym_DQUOTE,
    ACTIONS(2379), 1,
      aux_sym_number_token1,
    ACTIONS(2382), 1,
      aux_sym_number_token2,
    ACTIONS(2385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2388), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2391), 1,
      anon_sym_BQUOTE,
    ACTIONS(2394), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2400), 1,
      sym_test_operator,
    ACTIONS(2403), 1,
      sym__brace_start,
    STATE(1491), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2397), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(594), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2361), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1165), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [7059] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1501), 1,
      aux_sym__literal_repeat1,
    STATE(597), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1210), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [7128] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1501), 1,
      aux_sym__literal_repeat1,
    STATE(597), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1210), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [7197] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2409), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2412), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2415), 1,
      anon_sym_DOLLAR,
    ACTIONS(2418), 1,
      sym__special_character,
    ACTIONS(2421), 1,
      anon_sym_DQUOTE,
    ACTIONS(2424), 1,
      aux_sym_number_token1,
    ACTIONS(2427), 1,
      aux_sym_number_token2,
    ACTIONS(2430), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2433), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2436), 1,
      anon_sym_BQUOTE,
    ACTIONS(2439), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2445), 1,
      sym_test_operator,
    ACTIONS(2448), 1,
      sym__brace_start,
    STATE(1501), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2442), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(597), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2169), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2406), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1210), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [7296] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2458), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2461), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2464), 1,
      anon_sym_DOLLAR,
    ACTIONS(2467), 1,
      sym__special_character,
    ACTIONS(2470), 1,
      anon_sym_DQUOTE,
    ACTIONS(2473), 1,
      aux_sym_number_token1,
    ACTIONS(2476), 1,
      aux_sym_number_token2,
    ACTIONS(2479), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2482), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2485), 1,
      anon_sym_BQUOTE,
    ACTIONS(2488), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2494), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2497), 1,
      sym_test_operator,
    ACTIONS(2500), 1,
      sym__brace_start,
    STATE(1464), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2456), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2491), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(598), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2451), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1137), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2454), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [7397] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2503), 2,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
    ACTIONS(2505), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(2243), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [7464] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2031), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2043), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2049), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(2317), 1,
      sym__special_character,
    ACTIONS(2321), 1,
      sym_variable_name,
    ACTIONS(2323), 1,
      sym_test_operator,
    ACTIONS(2507), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6652), 1,
      sym_subscript,
    ACTIONS(1585), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2051), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2315), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(589), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1666), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1583), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [7567] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2031), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2043), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2047), 1,
      anon_sym_BQUOTE,
    ACTIONS(2049), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(2317), 1,
      sym__special_character,
    ACTIONS(2319), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2321), 1,
      sym_variable_name,
    ACTIONS(2323), 1,
      sym_test_operator,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6652), 1,
      sym_subscript,
    ACTIONS(1696), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2051), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2315), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(603), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1666), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1694), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [7672] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2217), 1,
      anon_sym_DQUOTE,
    ACTIONS(2221), 1,
      sym_variable_name,
    STATE(983), 1,
      sym_string,
    ACTIONS(2219), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2215), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [7745] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2108), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2114), 1,
      anon_sym_DOLLAR,
    ACTIONS(2120), 1,
      anon_sym_DQUOTE,
    ACTIONS(2123), 1,
      aux_sym_number_token1,
    ACTIONS(2126), 1,
      aux_sym_number_token2,
    ACTIONS(2129), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2135), 1,
      anon_sym_BQUOTE,
    ACTIONS(2138), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2153), 1,
      sym__brace_start,
    ACTIONS(2512), 1,
      sym__special_character,
    ACTIONS(2515), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2518), 1,
      sym_variable_name,
    ACTIONS(2521), 1,
      sym_test_operator,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6652), 1,
      sym_subscript,
    ACTIONS(1705), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2141), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2509), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(603), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1666), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1703), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [7850] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2217), 1,
      anon_sym_DQUOTE,
    ACTIONS(2221), 1,
      sym_variable_name,
    STATE(983), 1,
      sym_string,
    ACTIONS(2219), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2215), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [7923] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      anon_sym_LPAREN,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(2253), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2255), 1,
      sym__special_character,
    ACTIONS(2257), 1,
      sym_test_operator,
    STATE(643), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    STATE(4702), 1,
      sym_subshell,
    ACTIONS(1366), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2251), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2249), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1890), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1362), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [8036] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(2505), 3,
      anon_sym_RPAREN,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(2243), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [8103] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2031), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2043), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2047), 1,
      anon_sym_BQUOTE,
    ACTIONS(2049), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(2317), 1,
      sym__special_character,
    ACTIONS(2321), 1,
      sym_variable_name,
    ACTIONS(2323), 1,
      sym_test_operator,
    ACTIONS(2524), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6652), 1,
      sym_subscript,
    ACTIONS(1585), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2051), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2315), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(601), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(1666), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1583), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [8208] = 36,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(433), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(445), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(447), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(449), 1,
      anon_sym_DOLLAR,
    ACTIONS(451), 1,
      sym__special_character,
    ACTIONS(453), 1,
      anon_sym_DQUOTE,
    ACTIONS(457), 1,
      aux_sym_number_token1,
    ACTIONS(459), 1,
      aux_sym_number_token2,
    ACTIONS(461), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(463), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(465), 1,
      anon_sym_BQUOTE,
    ACTIONS(467), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(473), 1,
      sym_variable_name,
    ACTIONS(475), 1,
      sym_test_operator,
    ACTIONS(477), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2526), 1,
      sym_word,
    ACTIONS(2528), 1,
      anon_sym_LPAREN,
    STATE(524), 1,
      sym_command_name,
    STATE(942), 1,
      aux_sym_command_repeat1,
    STATE(943), 1,
      aux_sym__literal_repeat1,
    STATE(1056), 1,
      sym_concatenation,
    STATE(1604), 1,
      sym_variable_assignment,
    STATE(4805), 1,
      sym_command,
    STATE(6697), 1,
      sym_subscript,
    ACTIONS(455), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(469), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    STATE(4789), 2,
      sym_subshell,
      sym_test_command,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(781), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [8336] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1803), 1,
      aux_sym__literal_repeat1,
    STATE(622), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2158), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(1325), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [8404] = 36,
    ACTIONS(33), 1,
      anon_sym_LBRACK,
    ACTIONS(35), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(135), 1,
      sym_variable_name,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(771), 1,
      sym__special_character,
    ACTIONS(775), 1,
      sym_test_operator,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2530), 1,
      sym_word,
    ACTIONS(2532), 1,
      anon_sym_LPAREN,
    STATE(532), 1,
      sym_command_name,
    STATE(961), 1,
      aux_sym_command_repeat1,
    STATE(1237), 1,
      aux_sym__literal_repeat1,
    STATE(1350), 1,
      sym_concatenation,
    STATE(2030), 1,
      sym_variable_assignment,
    STATE(4726), 1,
      sym_command,
    STATE(6664), 1,
      sym_subscript,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(773), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    STATE(4724), 2,
      sym_subshell,
      sym_test_command,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(956), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [8532] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2536), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2538), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2540), 1,
      anon_sym_DOLLAR,
    ACTIONS(2542), 1,
      sym__special_character,
    ACTIONS(2544), 1,
      anon_sym_DQUOTE,
    ACTIONS(2546), 1,
      aux_sym_number_token1,
    ACTIONS(2548), 1,
      aux_sym_number_token2,
    ACTIONS(2550), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2552), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2554), 1,
      anon_sym_BQUOTE,
    ACTIONS(2556), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2560), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2562), 1,
      sym_test_operator,
    ACTIONS(2564), 1,
      sym__brace_start,
    STATE(1801), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2283), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2558), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(614), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2534), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1324), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2281), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [8632] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1542), 1,
      aux_sym__literal_repeat1,
    STATE(1709), 1,
      sym_concatenation,
    ACTIONS(2273), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1240), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [8700] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1627), 1,
      aux_sym__literal_repeat1,
    STATE(1833), 1,
      sym_concatenation,
    ACTIONS(2277), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1266), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [8768] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2536), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2538), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2540), 1,
      anon_sym_DOLLAR,
    ACTIONS(2542), 1,
      sym__special_character,
    ACTIONS(2544), 1,
      anon_sym_DQUOTE,
    ACTIONS(2546), 1,
      aux_sym_number_token1,
    ACTIONS(2548), 1,
      aux_sym_number_token2,
    ACTIONS(2550), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2552), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2554), 1,
      anon_sym_BQUOTE,
    ACTIONS(2556), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2562), 1,
      sym_test_operator,
    ACTIONS(2564), 1,
      sym__brace_start,
    ACTIONS(2566), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1801), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2327), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2558), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(636), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2534), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1324), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2325), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [8868] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    STATE(616), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1355), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [8936] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2571), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2574), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2577), 1,
      anon_sym_DOLLAR,
    ACTIONS(2580), 1,
      sym__special_character,
    ACTIONS(2583), 1,
      anon_sym_DQUOTE,
    ACTIONS(2586), 1,
      aux_sym_number_token1,
    ACTIONS(2589), 1,
      aux_sym_number_token2,
    ACTIONS(2592), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2595), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2598), 1,
      anon_sym_BQUOTE,
    ACTIONS(2601), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2607), 1,
      sym_test_operator,
    ACTIONS(2610), 1,
      sym__brace_start,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2604), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(616), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2169), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2568), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1355), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [9034] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2615), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2617), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2619), 1,
      anon_sym_DOLLAR,
    ACTIONS(2621), 1,
      sym__special_character,
    ACTIONS(2623), 1,
      anon_sym_DQUOTE,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      aux_sym_number_token2,
    ACTIONS(2629), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2631), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2633), 1,
      anon_sym_BQUOTE,
    ACTIONS(2635), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2639), 1,
      sym_test_operator,
    ACTIONS(2641), 1,
      sym__brace_start,
    STATE(1903), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2637), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(621), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2613), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1348), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [9132] = 36,
    ACTIONS(33), 1,
      anon_sym_LBRACK,
    ACTIONS(35), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(314), 1,
      sym__special_character,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(336), 1,
      sym_variable_name,
    ACTIONS(338), 1,
      sym_test_operator,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2532), 1,
      anon_sym_LPAREN,
    ACTIONS(2643), 1,
      sym_word,
    STATE(538), 1,
      sym_command_name,
    STATE(938), 1,
      aux_sym_command_repeat1,
    STATE(1237), 1,
      aux_sym__literal_repeat1,
    STATE(1350), 1,
      sym_concatenation,
    STATE(2285), 1,
      sym_variable_assignment,
    STATE(4726), 1,
      sym_command,
    STATE(6650), 1,
      sym_subscript,
    ACTIONS(318), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    STATE(4724), 2,
      sym_subshell,
      sym_test_command,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(1126), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [9260] = 29,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2645), 1,
      sym_word,
    ACTIONS(2649), 1,
      anon_sym_LPAREN,
    ACTIONS(2651), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DOLLAR,
    ACTIONS(2659), 1,
      sym__special_character,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2679), 1,
      sym_test_operator,
    ACTIONS(2681), 1,
      sym__bare_dollar,
    ACTIONS(2683), 1,
      sym__brace_start,
    STATE(702), 1,
      aux_sym_command_repeat2,
    STATE(2399), 1,
      aux_sym__literal_repeat1,
    STATE(2449), 1,
      sym_concatenation,
    STATE(2488), 1,
      sym_herestring_redirect,
    STATE(5570), 1,
      sym_subshell,
    ACTIONS(2647), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2663), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1362), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2177), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1366), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [9374] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2615), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2617), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2619), 1,
      anon_sym_DOLLAR,
    ACTIONS(2621), 1,
      sym__special_character,
    ACTIONS(2623), 1,
      anon_sym_DQUOTE,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      aux_sym_number_token2,
    ACTIONS(2629), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2631), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2633), 1,
      anon_sym_BQUOTE,
    ACTIONS(2635), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2639), 1,
      sym_test_operator,
    ACTIONS(2641), 1,
      sym__brace_start,
    STATE(1903), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2637), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(621), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2613), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1348), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [9472] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2688), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2691), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2694), 1,
      anon_sym_DOLLAR,
    ACTIONS(2697), 1,
      sym__special_character,
    ACTIONS(2700), 1,
      anon_sym_DQUOTE,
    ACTIONS(2703), 1,
      aux_sym_number_token1,
    ACTIONS(2706), 1,
      aux_sym_number_token2,
    ACTIONS(2709), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2712), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2715), 1,
      anon_sym_BQUOTE,
    ACTIONS(2718), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2724), 1,
      sym_test_operator,
    ACTIONS(2727), 1,
      sym__brace_start,
    STATE(1903), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2721), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(621), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2685), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1348), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [9570] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2733), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2736), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2739), 1,
      anon_sym_DOLLAR,
    ACTIONS(2742), 1,
      sym__special_character,
    ACTIONS(2745), 1,
      anon_sym_DQUOTE,
    ACTIONS(2748), 1,
      aux_sym_number_token1,
    ACTIONS(2751), 1,
      aux_sym_number_token2,
    ACTIONS(2754), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2757), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2760), 1,
      anon_sym_BQUOTE,
    ACTIONS(2763), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2769), 1,
      sym_test_operator,
    ACTIONS(2772), 1,
      sym__brace_start,
    STATE(1803), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2766), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(622), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2730), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(2169), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(1325), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [9668] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    STATE(616), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1355), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [9736] = 36,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(689), 1,
      anon_sym_LBRACK,
    ACTIONS(691), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(701), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(703), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(705), 1,
      anon_sym_DOLLAR,
    ACTIONS(707), 1,
      sym__special_character,
    ACTIONS(709), 1,
      anon_sym_DQUOTE,
    ACTIONS(713), 1,
      aux_sym_number_token1,
    ACTIONS(715), 1,
      aux_sym_number_token2,
    ACTIONS(717), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(719), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(721), 1,
      anon_sym_BQUOTE,
    ACTIONS(723), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(729), 1,
      sym_variable_name,
    ACTIONS(731), 1,
      sym_test_operator,
    ACTIONS(733), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2775), 1,
      sym_word,
    ACTIONS(2777), 1,
      anon_sym_LPAREN,
    STATE(526), 1,
      sym_command_name,
    STATE(949), 1,
      aux_sym_command_repeat1,
    STATE(1089), 1,
      aux_sym__literal_repeat1,
    STATE(1220), 1,
      sym_concatenation,
    STATE(1813), 1,
      sym_variable_assignment,
    STATE(4953), 1,
      sym_command,
    STATE(6673), 1,
      sym_subscript,
    ACTIONS(711), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(725), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    STATE(4993), 2,
      sym_subshell,
      sym_test_command,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(865), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [9864] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2781), 1,
      anon_sym_DQUOTE,
    ACTIONS(2785), 1,
      sym_variable_name,
    STATE(1143), 1,
      sym_string,
    ACTIONS(2783), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(2779), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [9936] = 36,
    ACTIONS(33), 1,
      anon_sym_LBRACK,
    ACTIONS(35), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(45), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(47), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(51), 1,
      sym__special_character,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(57), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      aux_sym_number_token2,
    ACTIONS(61), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(63), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(65), 1,
      anon_sym_BQUOTE,
    ACTIONS(67), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(75), 1,
      sym_variable_name,
    ACTIONS(77), 1,
      sym_test_operator,
    ACTIONS(79), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2532), 1,
      anon_sym_LPAREN,
    ACTIONS(2787), 1,
      sym_word,
    STATE(528), 1,
      sym_command_name,
    STATE(937), 1,
      aux_sym_command_repeat1,
    STATE(1181), 1,
      aux_sym__literal_repeat1,
    STATE(1431), 1,
      sym_concatenation,
    STATE(2121), 1,
      sym_variable_assignment,
    STATE(4726), 1,
      sym_command,
    STATE(6655), 1,
      sym_subscript,
    ACTIONS(55), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(69), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    STATE(4724), 2,
      sym_subshell,
      sym_test_command,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(944), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [10064] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2793), 1,
      sym_variable_name,
    STATE(1340), 1,
      sym_string,
    ACTIONS(2791), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(2789), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [10136] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2793), 1,
      sym_variable_name,
    STATE(1340), 1,
      sym_string,
    ACTIONS(2791), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(2789), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [10208] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1803), 1,
      aux_sym__literal_repeat1,
    STATE(622), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2162), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(1325), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [10276] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(2269), 1,
      sym_variable_name,
    STATE(1273), 1,
      sym_string,
    ACTIONS(2267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2265), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [10348] = 36,
    ACTIONS(33), 1,
      anon_sym_LBRACK,
    ACTIONS(35), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(314), 1,
      sym__special_character,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(336), 1,
      sym_variable_name,
    ACTIONS(338), 1,
      sym_test_operator,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2532), 1,
      anon_sym_LPAREN,
    ACTIONS(2643), 1,
      sym_word,
    STATE(544), 1,
      sym_command_name,
    STATE(970), 1,
      aux_sym_command_repeat1,
    STATE(1237), 1,
      aux_sym__literal_repeat1,
    STATE(1350), 1,
      sym_concatenation,
    STATE(2030), 1,
      sym_variable_assignment,
    STATE(4726), 1,
      sym_command,
    STATE(6650), 1,
      sym_subscript,
    ACTIONS(318), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    STATE(4724), 2,
      sym_subshell,
      sym_test_command,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(1126), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [10476] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(2269), 1,
      sym_variable_name,
    STATE(1273), 1,
      sym_string,
    ACTIONS(2267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2265), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [10548] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2797), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2799), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2801), 1,
      anon_sym_DOLLAR,
    ACTIONS(2803), 1,
      sym__special_character,
    ACTIONS(2805), 1,
      anon_sym_DQUOTE,
    ACTIONS(2807), 1,
      aux_sym_number_token1,
    ACTIONS(2809), 1,
      aux_sym_number_token2,
    ACTIONS(2811), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2813), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2815), 1,
      anon_sym_BQUOTE,
    ACTIONS(2817), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2821), 1,
      sym_test_operator,
    ACTIONS(2823), 1,
      sym__brace_start,
    STATE(1722), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2819), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(638), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2795), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1292), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [10646] = 36,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(167), 1,
      anon_sym_LBRACK,
    ACTIONS(171), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(215), 1,
      sym_variable_name,
    ACTIONS(1039), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1041), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1043), 1,
      anon_sym_DOLLAR,
    ACTIONS(1045), 1,
      sym__special_character,
    ACTIONS(1047), 1,
      anon_sym_DQUOTE,
    ACTIONS(1051), 1,
      aux_sym_number_token1,
    ACTIONS(1053), 1,
      aux_sym_number_token2,
    ACTIONS(1055), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1057), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1059), 1,
      anon_sym_BQUOTE,
    ACTIONS(1061), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1067), 1,
      sym_test_operator,
    ACTIONS(1069), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2649), 1,
      anon_sym_LPAREN,
    ACTIONS(2825), 1,
      sym_word,
    STATE(639), 1,
      sym_command_name,
    STATE(880), 1,
      aux_sym_command_repeat1,
    STATE(2307), 1,
      aux_sym__literal_repeat1,
    STATE(2412), 1,
      sym_concatenation,
    STATE(2945), 1,
      sym_variable_assignment,
    STATE(5567), 1,
      sym_command,
    STATE(6641), 1,
      sym_subscript,
    ACTIONS(1049), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1063), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    STATE(5584), 2,
      sym_subshell,
      sym_test_command,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(1879), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [10774] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2797), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2799), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2801), 1,
      anon_sym_DOLLAR,
    ACTIONS(2803), 1,
      sym__special_character,
    ACTIONS(2805), 1,
      anon_sym_DQUOTE,
    ACTIONS(2807), 1,
      aux_sym_number_token1,
    ACTIONS(2809), 1,
      aux_sym_number_token2,
    ACTIONS(2811), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2813), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2815), 1,
      anon_sym_BQUOTE,
    ACTIONS(2817), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2821), 1,
      sym_test_operator,
    ACTIONS(2823), 1,
      sym__brace_start,
    STATE(1722), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2819), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(638), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2795), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1292), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [10872] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2830), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2833), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2836), 1,
      anon_sym_DOLLAR,
    ACTIONS(2839), 1,
      sym__special_character,
    ACTIONS(2842), 1,
      anon_sym_DQUOTE,
    ACTIONS(2845), 1,
      aux_sym_number_token1,
    ACTIONS(2848), 1,
      aux_sym_number_token2,
    ACTIONS(2851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2854), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2857), 1,
      anon_sym_BQUOTE,
    ACTIONS(2860), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2866), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2869), 1,
      sym_test_operator,
    ACTIONS(2872), 1,
      sym__brace_start,
    STATE(1801), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2456), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2863), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(636), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2827), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1324), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2454), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [10972] = 36,
    ACTIONS(33), 1,
      anon_sym_LBRACK,
    ACTIONS(35), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(1015), 1,
      sym__special_character,
    ACTIONS(1021), 1,
      sym_variable_name,
    ACTIONS(1023), 1,
      sym_test_operator,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2532), 1,
      anon_sym_LPAREN,
    ACTIONS(2875), 1,
      sym_word,
    STATE(581), 1,
      sym_command_name,
    STATE(974), 1,
      aux_sym_command_repeat1,
    STATE(1237), 1,
      aux_sym__literal_repeat1,
    STATE(1350), 1,
      sym_concatenation,
    STATE(2030), 1,
      sym_variable_assignment,
    STATE(4726), 1,
      sym_command,
    STATE(6679), 1,
      sym_subscript,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1017), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    STATE(4724), 2,
      sym_subshell,
      sym_test_command,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(1692), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [11100] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2880), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2883), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2886), 1,
      anon_sym_DOLLAR,
    ACTIONS(2889), 1,
      sym__special_character,
    ACTIONS(2892), 1,
      anon_sym_DQUOTE,
    ACTIONS(2895), 1,
      aux_sym_number_token1,
    ACTIONS(2898), 1,
      aux_sym_number_token2,
    ACTIONS(2901), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2904), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2907), 1,
      anon_sym_BQUOTE,
    ACTIONS(2910), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2916), 1,
      sym_test_operator,
    ACTIONS(2919), 1,
      sym__brace_start,
    STATE(1722), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2913), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(638), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2877), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1292), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [11198] = 29,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2645), 1,
      sym_word,
    ACTIONS(2649), 1,
      anon_sym_LPAREN,
    ACTIONS(2651), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DOLLAR,
    ACTIONS(2659), 1,
      sym__special_character,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2679), 1,
      sym_test_operator,
    ACTIONS(2681), 1,
      sym__bare_dollar,
    ACTIONS(2683), 1,
      sym__brace_start,
    STATE(695), 1,
      aux_sym_command_repeat2,
    STATE(2399), 1,
      aux_sym__literal_repeat1,
    STATE(2449), 1,
      sym_concatenation,
    STATE(2488), 1,
      sym_herestring_redirect,
    STATE(5593), 1,
      sym_subshell,
    ACTIONS(2647), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2663), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1400), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2177), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1402), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [11312] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2924), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2926), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2928), 1,
      anon_sym_DOLLAR,
    ACTIONS(2930), 1,
      sym__special_character,
    ACTIONS(2932), 1,
      anon_sym_DQUOTE,
    ACTIONS(2934), 1,
      aux_sym_number_token1,
    ACTIONS(2936), 1,
      aux_sym_number_token2,
    ACTIONS(2938), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2940), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2942), 1,
      anon_sym_BQUOTE,
    ACTIONS(2944), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2948), 1,
      sym_test_operator,
    ACTIONS(2950), 1,
      sym__brace_start,
    STATE(4245), 1,
      aux_sym__literal_repeat1,
    STATE(4580), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2946), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2922), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4133), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [11410] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2924), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2926), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2928), 1,
      anon_sym_DOLLAR,
    ACTIONS(2930), 1,
      sym__special_character,
    ACTIONS(2932), 1,
      anon_sym_DQUOTE,
    ACTIONS(2934), 1,
      aux_sym_number_token1,
    ACTIONS(2936), 1,
      aux_sym_number_token2,
    ACTIONS(2938), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2940), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2942), 1,
      anon_sym_BQUOTE,
    ACTIONS(2944), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2950), 1,
      sym__brace_start,
    ACTIONS(2954), 1,
      sym_test_operator,
    STATE(4198), 1,
      aux_sym__literal_repeat1,
    STATE(4643), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2946), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2952), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4165), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [11508] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2781), 1,
      anon_sym_DQUOTE,
    ACTIONS(2785), 1,
      sym_variable_name,
    STATE(1143), 1,
      sym_string,
    ACTIONS(2783), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(2779), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [11580] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(2253), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2255), 1,
      sym__special_character,
    ACTIONS(2257), 1,
      sym_test_operator,
    STATE(680), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1579), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2251), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2249), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1890), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1577), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [11687] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2959), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2962), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2965), 1,
      anon_sym_DOLLAR,
    ACTIONS(2968), 1,
      sym__special_character,
    ACTIONS(2971), 1,
      anon_sym_DQUOTE,
    ACTIONS(2974), 1,
      aux_sym_number_token1,
    ACTIONS(2977), 1,
      aux_sym_number_token2,
    ACTIONS(2980), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2983), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2986), 1,
      anon_sym_BQUOTE,
    ACTIONS(2989), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2995), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(2998), 1,
      sym_test_operator,
    ACTIONS(3001), 1,
      sym__brace_start,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2456), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2992), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(644), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2956), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1615), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2454), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [11786] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3008), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3012), 1,
      sym__special_character,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3020), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3024), 1,
      anon_sym_BQUOTE,
    ACTIONS(3026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3030), 1,
      sym_test_operator,
    ACTIONS(3032), 1,
      sym__brace_start,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(647), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3004), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1653), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [11883] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3008), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3012), 1,
      sym__special_character,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3020), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3024), 1,
      anon_sym_BQUOTE,
    ACTIONS(3026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3030), 1,
      sym_test_operator,
    ACTIONS(3032), 1,
      sym__brace_start,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(647), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3004), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1653), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [11980] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3037), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3040), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3043), 1,
      anon_sym_DOLLAR,
    ACTIONS(3046), 1,
      sym__special_character,
    ACTIONS(3049), 1,
      anon_sym_DQUOTE,
    ACTIONS(3052), 1,
      aux_sym_number_token1,
    ACTIONS(3055), 1,
      aux_sym_number_token2,
    ACTIONS(3058), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3061), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3064), 1,
      anon_sym_BQUOTE,
    ACTIONS(3067), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3073), 1,
      sym_test_operator,
    ACTIONS(3076), 1,
      sym__brace_start,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3070), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(647), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3034), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1653), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [12077] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3081), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3083), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3087), 1,
      sym__special_character,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3095), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3099), 1,
      anon_sym_BQUOTE,
    ACTIONS(3101), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3105), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(3107), 1,
      sym_test_operator,
    ACTIONS(3109), 1,
      sym__brace_start,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2283), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3103), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(657), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(3079), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1615), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2281), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [12176] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1825), 1,
      aux_sym__literal_repeat1,
    STATE(2047), 1,
      sym_concatenation,
    ACTIONS(2273), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1370), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [12243] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2623), 1,
      anon_sym_DQUOTE,
    ACTIONS(3115), 1,
      sym_variable_name,
    STATE(1528), 1,
      sym_string,
    ACTIONS(3113), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3111), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [12314] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1885), 1,
      aux_sym__literal_repeat1,
    STATE(2158), 1,
      sym_concatenation,
    ACTIONS(2277), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1422), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [12381] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3119), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3121), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3123), 1,
      anon_sym_DOLLAR,
    ACTIONS(3125), 1,
      sym__special_character,
    ACTIONS(3127), 1,
      anon_sym_DQUOTE,
    ACTIONS(3129), 1,
      aux_sym_number_token1,
    ACTIONS(3131), 1,
      aux_sym_number_token2,
    ACTIONS(3133), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3135), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3137), 1,
      anon_sym_BQUOTE,
    ACTIONS(3139), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3143), 1,
      sym_test_operator,
    ACTIONS(3145), 1,
      sym__brace_start,
    STATE(4405), 1,
      aux_sym__literal_repeat1,
    STATE(4910), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3141), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3117), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4268), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [12478] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3119), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3121), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3123), 1,
      anon_sym_DOLLAR,
    ACTIONS(3125), 1,
      sym__special_character,
    ACTIONS(3127), 1,
      anon_sym_DQUOTE,
    ACTIONS(3129), 1,
      aux_sym_number_token1,
    ACTIONS(3131), 1,
      aux_sym_number_token2,
    ACTIONS(3133), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3135), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3137), 1,
      anon_sym_BQUOTE,
    ACTIONS(3139), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3145), 1,
      sym__brace_start,
    ACTIONS(3149), 1,
      sym_test_operator,
    STATE(4419), 1,
      aux_sym__literal_repeat1,
    STATE(4696), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3141), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3147), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4168), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [12575] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1787), 1,
      aux_sym__literal_repeat1,
    STATE(1973), 1,
      sym_concatenation,
    ACTIONS(2273), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(1301), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [12642] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1809), 1,
      aux_sym__literal_repeat1,
    STATE(2020), 1,
      sym_concatenation,
    ACTIONS(2277), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(1344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [12709] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3154), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3157), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3160), 1,
      anon_sym_DOLLAR,
    ACTIONS(3163), 1,
      sym__special_character,
    ACTIONS(3166), 1,
      anon_sym_DQUOTE,
    ACTIONS(3169), 1,
      aux_sym_number_token1,
    ACTIONS(3172), 1,
      aux_sym_number_token2,
    ACTIONS(3175), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3178), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3181), 1,
      anon_sym_BQUOTE,
    ACTIONS(3184), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3190), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(3193), 1,
      sym_test_operator,
    ACTIONS(3196), 1,
      sym__brace_start,
    STATE(1968), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3187), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(656), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2456), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3151), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1598), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2454), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [12808] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3081), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3083), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3087), 1,
      sym__special_character,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3095), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3099), 1,
      anon_sym_BQUOTE,
    ACTIONS(3101), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3107), 1,
      sym_test_operator,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(3199), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2327), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3103), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(644), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(3079), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1615), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2325), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [12907] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2623), 1,
      anon_sym_DQUOTE,
    ACTIONS(3115), 1,
      sym_variable_name,
    STATE(1528), 1,
      sym_string,
    ACTIONS(3113), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3111), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [12978] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3203), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3205), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3207), 1,
      anon_sym_DOLLAR,
    ACTIONS(3209), 1,
      sym__special_character,
    ACTIONS(3211), 1,
      anon_sym_DQUOTE,
    ACTIONS(3213), 1,
      aux_sym_number_token1,
    ACTIONS(3215), 1,
      aux_sym_number_token2,
    ACTIONS(3217), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3219), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3221), 1,
      anon_sym_BQUOTE,
    ACTIONS(3223), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3227), 1,
      sym_test_operator,
    ACTIONS(3229), 1,
      sym__brace_start,
    STATE(2027), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3225), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(666), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2162), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3201), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1611), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [13075] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3233), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3235), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3237), 1,
      anon_sym_DOLLAR,
    ACTIONS(3239), 1,
      sym__special_character,
    ACTIONS(3241), 1,
      anon_sym_DQUOTE,
    ACTIONS(3243), 1,
      aux_sym_number_token1,
    ACTIONS(3245), 1,
      aux_sym_number_token2,
    ACTIONS(3247), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3249), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3251), 1,
      anon_sym_BQUOTE,
    ACTIONS(3253), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3257), 1,
      sym_test_operator,
    ACTIONS(3259), 1,
      sym__brace_start,
    STATE(2110), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3255), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(662), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3231), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1524), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [13172] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3233), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3235), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3237), 1,
      anon_sym_DOLLAR,
    ACTIONS(3239), 1,
      sym__special_character,
    ACTIONS(3241), 1,
      anon_sym_DQUOTE,
    ACTIONS(3243), 1,
      aux_sym_number_token1,
    ACTIONS(3245), 1,
      aux_sym_number_token2,
    ACTIONS(3247), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3249), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3251), 1,
      anon_sym_BQUOTE,
    ACTIONS(3253), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3257), 1,
      sym_test_operator,
    ACTIONS(3259), 1,
      sym__brace_start,
    STATE(2110), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3255), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(662), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3231), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1524), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [13269] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3264), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3267), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3270), 1,
      anon_sym_DOLLAR,
    ACTIONS(3273), 1,
      sym__special_character,
    ACTIONS(3276), 1,
      anon_sym_DQUOTE,
    ACTIONS(3279), 1,
      aux_sym_number_token1,
    ACTIONS(3282), 1,
      aux_sym_number_token2,
    ACTIONS(3285), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3288), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3291), 1,
      anon_sym_BQUOTE,
    ACTIONS(3294), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3300), 1,
      sym_test_operator,
    ACTIONS(3303), 1,
      sym__brace_start,
    STATE(2110), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3297), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(662), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3261), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1524), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [13366] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3312), 1,
      anon_sym_DOLLAR,
    ACTIONS(3314), 1,
      sym__special_character,
    ACTIONS(3316), 1,
      anon_sym_DQUOTE,
    ACTIONS(3318), 1,
      aux_sym_number_token1,
    ACTIONS(3320), 1,
      aux_sym_number_token2,
    ACTIONS(3322), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3324), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3326), 1,
      anon_sym_BQUOTE,
    ACTIONS(3328), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3332), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(3334), 1,
      sym_test_operator,
    ACTIONS(3336), 1,
      sym__brace_start,
    STATE(1968), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3330), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(681), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2283), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3306), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1598), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2281), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [13465] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3340), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3342), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3344), 1,
      anon_sym_DOLLAR,
    ACTIONS(3346), 1,
      sym__special_character,
    ACTIONS(3348), 1,
      anon_sym_DQUOTE,
    ACTIONS(3350), 1,
      aux_sym_number_token1,
    ACTIONS(3352), 1,
      aux_sym_number_token2,
    ACTIONS(3354), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3356), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3358), 1,
      anon_sym_BQUOTE,
    ACTIONS(3360), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3364), 1,
      sym_test_operator,
    ACTIONS(3366), 1,
      sym__brace_start,
    STATE(4400), 1,
      aux_sym__literal_repeat1,
    STATE(4835), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3362), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3338), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4234), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [13562] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3340), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3342), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3344), 1,
      anon_sym_DOLLAR,
    ACTIONS(3346), 1,
      sym__special_character,
    ACTIONS(3348), 1,
      anon_sym_DQUOTE,
    ACTIONS(3350), 1,
      aux_sym_number_token1,
    ACTIONS(3352), 1,
      aux_sym_number_token2,
    ACTIONS(3354), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3356), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3358), 1,
      anon_sym_BQUOTE,
    ACTIONS(3360), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3366), 1,
      sym__brace_start,
    ACTIONS(3370), 1,
      sym_test_operator,
    STATE(4336), 1,
      aux_sym__literal_repeat1,
    STATE(4886), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3362), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3368), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4254), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [13659] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3375), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3378), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3381), 1,
      anon_sym_DOLLAR,
    ACTIONS(3384), 1,
      sym__special_character,
    ACTIONS(3387), 1,
      anon_sym_DQUOTE,
    ACTIONS(3390), 1,
      aux_sym_number_token1,
    ACTIONS(3393), 1,
      aux_sym_number_token2,
    ACTIONS(3396), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3399), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3402), 1,
      anon_sym_BQUOTE,
    ACTIONS(3405), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3411), 1,
      sym_test_operator,
    ACTIONS(3414), 1,
      sym__brace_start,
    STATE(2027), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(666), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2169), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3372), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1611), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [13756] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1595), 1,
      anon_sym_DQUOTE,
    ACTIONS(3421), 1,
      sym_variable_name,
    STATE(1202), 1,
      sym_string,
    ACTIONS(3419), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3417), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [13827] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1595), 1,
      anon_sym_DQUOTE,
    ACTIONS(3421), 1,
      sym_variable_name,
    STATE(1202), 1,
      sym_string,
    ACTIONS(3419), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3417), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [13898] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2293), 1,
      anon_sym_DQUOTE,
    ACTIONS(3427), 1,
      sym_variable_name,
    STATE(1404), 1,
      sym_string,
    ACTIONS(3425), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3423), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [13969] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2293), 1,
      anon_sym_DQUOTE,
    ACTIONS(3427), 1,
      sym_variable_name,
    STATE(1404), 1,
      sym_string,
    ACTIONS(3425), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3423), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [14040] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2805), 1,
      anon_sym_DQUOTE,
    ACTIONS(3433), 1,
      sym_variable_name,
    STATE(1473), 1,
      sym_string,
    ACTIONS(3431), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3429), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [14111] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2805), 1,
      anon_sym_DQUOTE,
    ACTIONS(3433), 1,
      sym_variable_name,
    STATE(1473), 1,
      sym_string,
    ACTIONS(3431), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3429), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [14182] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3203), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3205), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3207), 1,
      anon_sym_DOLLAR,
    ACTIONS(3209), 1,
      sym__special_character,
    ACTIONS(3211), 1,
      anon_sym_DQUOTE,
    ACTIONS(3213), 1,
      aux_sym_number_token1,
    ACTIONS(3215), 1,
      aux_sym_number_token2,
    ACTIONS(3217), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3219), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3221), 1,
      anon_sym_BQUOTE,
    ACTIONS(3223), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3227), 1,
      sym_test_operator,
    ACTIONS(3229), 1,
      sym__brace_start,
    STATE(2027), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3225), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(666), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2158), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3201), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1611), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [14279] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3437), 1,
      anon_sym_DQUOTE,
    ACTIONS(3441), 1,
      sym_variable_name,
    STATE(1296), 1,
      sym_string,
    ACTIONS(3439), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3435), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [14350] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3437), 1,
      anon_sym_DQUOTE,
    ACTIONS(3441), 1,
      sym_variable_name,
    STATE(1296), 1,
      sym_string,
    ACTIONS(3439), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3435), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [14421] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    STATE(678), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1663), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [14488] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    STATE(678), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1663), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [14555] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2571), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2574), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2577), 1,
      anon_sym_DOLLAR,
    ACTIONS(2583), 1,
      anon_sym_DQUOTE,
    ACTIONS(2586), 1,
      aux_sym_number_token1,
    ACTIONS(2589), 1,
      aux_sym_number_token2,
    ACTIONS(2592), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2595), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2598), 1,
      anon_sym_BQUOTE,
    ACTIONS(2601), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2610), 1,
      sym__brace_start,
    ACTIONS(3446), 1,
      sym__special_character,
    ACTIONS(3449), 1,
      sym_test_operator,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2604), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(678), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2169), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3443), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1663), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [14652] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1547), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1549), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1561), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1565), 1,
      anon_sym_BQUOTE,
    ACTIONS(1567), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1573), 1,
      sym__bare_dollar,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(2253), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2255), 1,
      sym__special_character,
    ACTIONS(2257), 1,
      sym_test_operator,
    STATE(680), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1442), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1569), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2251), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2249), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1890), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1440), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [14759] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1920), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1923), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1926), 1,
      anon_sym_DOLLAR,
    ACTIONS(1932), 1,
      anon_sym_DQUOTE,
    ACTIONS(1935), 1,
      aux_sym_number_token1,
    ACTIONS(1938), 1,
      aux_sym_number_token2,
    ACTIONS(1941), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1944), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1947), 1,
      anon_sym_BQUOTE,
    ACTIONS(1950), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1962), 1,
      sym__bare_dollar,
    ACTIONS(1965), 1,
      sym__brace_start,
    ACTIONS(3458), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3461), 1,
      sym__special_character,
    ACTIONS(3464), 1,
      sym_file_descriptor,
    ACTIONS(3467), 1,
      sym_test_operator,
    STATE(680), 1,
      aux_sym_command_repeat2,
    STATE(1412), 1,
      aux_sym__literal_repeat1,
    STATE(1649), 1,
      sym_concatenation,
    STATE(1654), 1,
      sym_herestring_redirect,
    ACTIONS(1953), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3455), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(3452), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1890), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1483), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [14868] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3312), 1,
      anon_sym_DOLLAR,
    ACTIONS(3314), 1,
      sym__special_character,
    ACTIONS(3316), 1,
      anon_sym_DQUOTE,
    ACTIONS(3318), 1,
      aux_sym_number_token1,
    ACTIONS(3320), 1,
      aux_sym_number_token2,
    ACTIONS(3322), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3324), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3326), 1,
      anon_sym_BQUOTE,
    ACTIONS(3328), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3334), 1,
      sym_test_operator,
    ACTIONS(3336), 1,
      sym__brace_start,
    ACTIONS(3470), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1968), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3330), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(656), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2327), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3306), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1598), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2325), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [14967] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(801), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(517), 29,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_done,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [15027] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3474), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3476), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3478), 1,
      anon_sym_DOLLAR,
    ACTIONS(3480), 1,
      sym__special_character,
    ACTIONS(3482), 1,
      anon_sym_DQUOTE,
    ACTIONS(3484), 1,
      aux_sym_number_token1,
    ACTIONS(3486), 1,
      aux_sym_number_token2,
    ACTIONS(3488), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3490), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3492), 1,
      anon_sym_BQUOTE,
    ACTIONS(3494), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3498), 1,
      sym_test_operator,
    ACTIONS(3500), 1,
      sym__brace_start,
    STATE(4662), 1,
      aux_sym__literal_repeat1,
    STATE(4979), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3496), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3472), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4414), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [15123] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3510), 1,
      sym__special_character,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3522), 1,
      anon_sym_BQUOTE,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3528), 1,
      sym_test_operator,
    ACTIONS(3530), 1,
      sym__brace_start,
    STATE(4236), 1,
      aux_sym__literal_repeat1,
    STATE(4549), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3502), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4454), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [15219] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3474), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3476), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3478), 1,
      anon_sym_DOLLAR,
    ACTIONS(3480), 1,
      sym__special_character,
    ACTIONS(3482), 1,
      anon_sym_DQUOTE,
    ACTIONS(3484), 1,
      aux_sym_number_token1,
    ACTIONS(3486), 1,
      aux_sym_number_token2,
    ACTIONS(3488), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3490), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3492), 1,
      anon_sym_BQUOTE,
    ACTIONS(3494), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3500), 1,
      sym__brace_start,
    ACTIONS(3534), 1,
      sym_test_operator,
    STATE(4607), 1,
      aux_sym__literal_repeat1,
    STATE(5004), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3496), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3532), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4343), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [15315] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3510), 1,
      sym__special_character,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3522), 1,
      anon_sym_BQUOTE,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(3538), 1,
      sym_test_operator,
    STATE(4265), 1,
      aux_sym__literal_repeat1,
    STATE(4609), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3536), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4456), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [15411] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3550), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    STATE(3540), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(7115), 1,
      sym__heredoc_pipeline,
    STATE(7116), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5435), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [15525] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3584), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3541), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(7133), 1,
      sym__heredoc_pipeline,
    STATE(7136), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5436), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [15639] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3586), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3529), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(7277), 1,
      sym__heredoc_pipeline,
    STATE(7298), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5446), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [15753] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3590), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3592), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3594), 1,
      anon_sym_DOLLAR,
    ACTIONS(3596), 1,
      sym__special_character,
    ACTIONS(3598), 1,
      anon_sym_DQUOTE,
    ACTIONS(3600), 1,
      aux_sym_number_token1,
    ACTIONS(3602), 1,
      aux_sym_number_token2,
    ACTIONS(3604), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3606), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3608), 1,
      anon_sym_BQUOTE,
    ACTIONS(3610), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3614), 1,
      sym_test_operator,
    ACTIONS(3616), 1,
      sym__brace_start,
    STATE(2279), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3612), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(723), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2158), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3588), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1800), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [15849] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2247), 1,
      ts_builtin_sym_end,
    ACTIONS(2243), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [15911] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3620), 1,
      anon_sym_DQUOTE,
    ACTIONS(3624), 1,
      sym_variable_name,
    STATE(1625), 1,
      sym_string,
    ACTIONS(3622), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(3618), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [15981] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3620), 1,
      anon_sym_DQUOTE,
    ACTIONS(3624), 1,
      sym_variable_name,
    STATE(1625), 1,
      sym_string,
    ACTIONS(3622), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(3618), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [16051] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3626), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3551), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(6888), 1,
      sym__heredoc_pipeline,
    STATE(6895), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5451), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [16165] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2645), 1,
      sym_word,
    ACTIONS(2651), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DOLLAR,
    ACTIONS(2659), 1,
      sym__special_character,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2679), 1,
      sym_test_operator,
    ACTIONS(2681), 1,
      sym__bare_dollar,
    ACTIONS(2683), 1,
      sym__brace_start,
    STATE(699), 1,
      aux_sym_command_repeat2,
    STATE(2399), 1,
      aux_sym__literal_repeat1,
    STATE(2449), 1,
      sym_concatenation,
    STATE(2488), 1,
      sym_herestring_redirect,
    ACTIONS(2647), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2663), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1440), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2177), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1442), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [16273] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3628), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3526), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(6729), 1,
      sym__heredoc_pipeline,
    STATE(6759), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5410), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [16387] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3630), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3517), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(7396), 1,
      sym__heredoc_pipeline,
    STATE(7397), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5421), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [16501] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3640), 1,
      sym__special_character,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3648), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3652), 1,
      anon_sym_BQUOTE,
    ACTIONS(3654), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3658), 1,
      sym_test_operator,
    ACTIONS(3660), 1,
      sym__brace_start,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3656), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(707), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3632), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1851), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [16597] = 28,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3662), 1,
      sym_word,
    ACTIONS(3668), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3671), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3674), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3677), 1,
      anon_sym_DOLLAR,
    ACTIONS(3680), 1,
      sym__special_character,
    ACTIONS(3683), 1,
      anon_sym_DQUOTE,
    ACTIONS(3689), 1,
      aux_sym_number_token1,
    ACTIONS(3692), 1,
      aux_sym_number_token2,
    ACTIONS(3695), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3698), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3701), 1,
      anon_sym_BQUOTE,
    ACTIONS(3704), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3710), 1,
      sym_file_descriptor,
    ACTIONS(3713), 1,
      sym_test_operator,
    ACTIONS(3716), 1,
      sym__bare_dollar,
    ACTIONS(3719), 1,
      sym__brace_start,
    STATE(699), 1,
      aux_sym_command_repeat2,
    STATE(2399), 1,
      aux_sym__literal_repeat1,
    STATE(2449), 1,
      sym_concatenation,
    STATE(2488), 1,
      sym_herestring_redirect,
    ACTIONS(3665), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(3686), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(3707), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1483), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1488), 9,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
    STATE(2177), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [16707] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2217), 1,
      anon_sym_DQUOTE,
    ACTIONS(2221), 1,
      sym_variable_name,
    STATE(983), 1,
      sym_string,
    ACTIONS(2219), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2215), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [16777] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2217), 1,
      anon_sym_DQUOTE,
    ACTIONS(2221), 1,
      sym_variable_name,
    STATE(983), 1,
      sym_string,
    ACTIONS(2219), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2215), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [16847] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2645), 1,
      sym_word,
    ACTIONS(2651), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DOLLAR,
    ACTIONS(2659), 1,
      sym__special_character,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2679), 1,
      sym_test_operator,
    ACTIONS(2681), 1,
      sym__bare_dollar,
    ACTIONS(2683), 1,
      sym__brace_start,
    STATE(699), 1,
      aux_sym_command_repeat2,
    STATE(2399), 1,
      aux_sym__literal_repeat1,
    STATE(2449), 1,
      sym_concatenation,
    STATE(2488), 1,
      sym_herestring_redirect,
    ACTIONS(2647), 2,
      anon_sym_EQ_EQ,
      anon_sym_EQ_TILDE,
    ACTIONS(2663), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1577), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2177), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1579), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [16955] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3522), 1,
      anon_sym_BQUOTE,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(3724), 1,
      sym__special_character,
    ACTIONS(3726), 1,
      sym_test_operator,
    STATE(4236), 1,
      aux_sym__literal_repeat1,
    STATE(4549), 1,
      sym_concatenation,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2273), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3722), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4441), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [17051] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3728), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3518), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(7407), 1,
      sym__heredoc_pipeline,
    STATE(7409), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5426), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [17165] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3081), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3083), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3095), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3101), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(3732), 1,
      sym__special_character,
    ACTIONS(3734), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(3736), 1,
      sym_test_operator,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2327), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3103), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(725), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(3730), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1876), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2325), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [17261] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3738), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3535), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(6921), 1,
      sym__heredoc_pipeline,
    STATE(6925), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5417), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [17375] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3743), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3746), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3749), 1,
      anon_sym_DOLLAR,
    ACTIONS(3752), 1,
      sym__special_character,
    ACTIONS(3755), 1,
      anon_sym_DQUOTE,
    ACTIONS(3758), 1,
      aux_sym_number_token1,
    ACTIONS(3761), 1,
      aux_sym_number_token2,
    ACTIONS(3764), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3767), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3770), 1,
      anon_sym_BQUOTE,
    ACTIONS(3773), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3779), 1,
      sym_test_operator,
    ACTIONS(3782), 1,
      sym__brace_start,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3776), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(707), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3740), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1851), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [17471] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3785), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3536), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(6952), 1,
      sym__heredoc_pipeline,
    STATE(6953), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5418), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [17585] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3522), 1,
      anon_sym_BQUOTE,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(3724), 1,
      sym__special_character,
    ACTIONS(3789), 1,
      sym_test_operator,
    STATE(4265), 1,
      aux_sym__literal_repeat1,
    STATE(4609), 1,
      sym_concatenation,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2277), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3787), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4476), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [17681] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(3791), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3528), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    STATE(7248), 1,
      sym__heredoc_pipeline,
    STATE(7253), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3544), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5445), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [17795] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3640), 1,
      sym__special_character,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3648), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3652), 1,
      anon_sym_BQUOTE,
    ACTIONS(3654), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3658), 1,
      sym_test_operator,
    ACTIONS(3660), 1,
      sym__brace_start,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3656), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(707), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3632), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1851), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [17891] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3008), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3020), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(3795), 1,
      sym__special_character,
    ACTIONS(3797), 1,
      sym_test_operator,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(724), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3793), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [17985] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3241), 1,
      anon_sym_DQUOTE,
    ACTIONS(3803), 1,
      sym_variable_name,
    STATE(1839), 1,
      sym_string,
    ACTIONS(3801), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3799), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [18055] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3590), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3592), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3594), 1,
      anon_sym_DOLLAR,
    ACTIONS(3596), 1,
      sym__special_character,
    ACTIONS(3598), 1,
      anon_sym_DQUOTE,
    ACTIONS(3600), 1,
      aux_sym_number_token1,
    ACTIONS(3602), 1,
      aux_sym_number_token2,
    ACTIONS(3604), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3606), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3608), 1,
      anon_sym_BQUOTE,
    ACTIONS(3610), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3614), 1,
      sym_test_operator,
    ACTIONS(3616), 1,
      sym__brace_start,
    STATE(2279), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3612), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(723), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2162), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3588), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1800), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [18151] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 1,
      anon_sym_DQUOTE,
    ACTIONS(3809), 1,
      sym_variable_name,
    STATE(1336), 1,
      sym_string,
    ACTIONS(3807), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3805), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [18221] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3081), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3083), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3095), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3101), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(3732), 1,
      sym__special_character,
    ACTIONS(3736), 1,
      sym_test_operator,
    ACTIONS(3811), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2283), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3103), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(705), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(3730), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1876), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2281), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [18317] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 1,
      anon_sym_DQUOTE,
    ACTIONS(3809), 1,
      sym_variable_name,
    STATE(1336), 1,
      sym_string,
    ACTIONS(3807), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3805), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [18387] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3008), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3020), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3024), 1,
      anon_sym_BQUOTE,
    ACTIONS(3026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(3795), 1,
      sym__special_character,
    ACTIONS(3797), 1,
      sym_test_operator,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(724), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3793), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [18483] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3817), 1,
      sym_variable_name,
    STATE(1777), 1,
      sym_string,
    ACTIONS(3815), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3813), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [18553] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3008), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3020), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3024), 1,
      anon_sym_BQUOTE,
    ACTIONS(3026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(3795), 1,
      sym__special_character,
    ACTIONS(3797), 1,
      sym_test_operator,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(724), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3793), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [18649] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3081), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3083), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3095), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3099), 1,
      anon_sym_BQUOTE,
    ACTIONS(3101), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(3732), 1,
      sym__special_character,
    ACTIONS(3734), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(3736), 1,
      sym_test_operator,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2327), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3103), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(725), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(3730), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1876), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2325), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [18747] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3008), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3020), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(3795), 1,
      sym__special_character,
    ACTIONS(3797), 1,
      sym_test_operator,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(724), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3793), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [18841] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3822), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3825), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3828), 1,
      anon_sym_DOLLAR,
    ACTIONS(3831), 1,
      sym__special_character,
    ACTIONS(3834), 1,
      anon_sym_DQUOTE,
    ACTIONS(3837), 1,
      aux_sym_number_token1,
    ACTIONS(3840), 1,
      aux_sym_number_token2,
    ACTIONS(3843), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3849), 1,
      anon_sym_BQUOTE,
    ACTIONS(3852), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3858), 1,
      sym_test_operator,
    ACTIONS(3861), 1,
      sym__brace_start,
    STATE(2279), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3855), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(723), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2169), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3819), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1800), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [18937] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3037), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3040), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3043), 1,
      anon_sym_DOLLAR,
    ACTIONS(3049), 1,
      anon_sym_DQUOTE,
    ACTIONS(3052), 1,
      aux_sym_number_token1,
    ACTIONS(3055), 1,
      aux_sym_number_token2,
    ACTIONS(3058), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3061), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3064), 1,
      anon_sym_BQUOTE,
    ACTIONS(3067), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3076), 1,
      sym__brace_start,
    ACTIONS(3867), 1,
      sym__special_character,
    ACTIONS(3870), 1,
      sym_test_operator,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3070), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(724), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(3864), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [19033] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2959), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2962), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2965), 1,
      anon_sym_DOLLAR,
    ACTIONS(2971), 1,
      anon_sym_DQUOTE,
    ACTIONS(2974), 1,
      aux_sym_number_token1,
    ACTIONS(2977), 1,
      aux_sym_number_token2,
    ACTIONS(2980), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2983), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2986), 1,
      anon_sym_BQUOTE,
    ACTIONS(2989), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3001), 1,
      sym__brace_start,
    ACTIONS(3876), 1,
      sym__special_character,
    ACTIONS(3879), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(3882), 1,
      sym_test_operator,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2456), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2992), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(725), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(3873), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1876), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2454), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [19131] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2505), 1,
      ts_builtin_sym_end,
    ACTIONS(2243), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [19193] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2544), 1,
      anon_sym_DQUOTE,
    ACTIONS(3889), 1,
      sym_variable_name,
    STATE(1503), 1,
      sym_string,
    ACTIONS(3887), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3885), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [19263] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2031), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2043), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2047), 1,
      anon_sym_BQUOTE,
    ACTIONS(2049), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(3893), 1,
      sym__special_character,
    ACTIONS(3895), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(3897), 1,
      sym_variable_name,
    ACTIONS(3899), 1,
      sym_test_operator,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6681), 1,
      sym_subscript,
    ACTIONS(1696), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2051), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3891), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(731), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(2289), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1694), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [19365] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3211), 1,
      anon_sym_DQUOTE,
    ACTIONS(3905), 1,
      sym_variable_name,
    STATE(1724), 1,
      sym_string,
    ACTIONS(3903), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(3901), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [19435] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3909), 1,
      anon_sym_DQUOTE,
    ACTIONS(3913), 1,
      sym_variable_name,
    STATE(1657), 1,
      sym_string,
    ACTIONS(3911), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3907), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [19505] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2108), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2114), 1,
      anon_sym_DOLLAR,
    ACTIONS(2120), 1,
      anon_sym_DQUOTE,
    ACTIONS(2123), 1,
      aux_sym_number_token1,
    ACTIONS(2126), 1,
      aux_sym_number_token2,
    ACTIONS(2129), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2135), 1,
      anon_sym_BQUOTE,
    ACTIONS(2138), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2153), 1,
      sym__brace_start,
    ACTIONS(3918), 1,
      sym__special_character,
    ACTIONS(3921), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(3924), 1,
      sym_variable_name,
    ACTIONS(3927), 1,
      sym_test_operator,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6681), 1,
      sym_subscript,
    ACTIONS(1705), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2141), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3915), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(731), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(2289), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1703), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [19607] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3909), 1,
      anon_sym_DQUOTE,
    ACTIONS(3913), 1,
      sym_variable_name,
    STATE(1657), 1,
      sym_string,
    ACTIONS(3911), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3907), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [19677] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3241), 1,
      anon_sym_DQUOTE,
    ACTIONS(3803), 1,
      sym_variable_name,
    STATE(1839), 1,
      sym_string,
    ACTIONS(3801), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3799), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [19747] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2544), 1,
      anon_sym_DQUOTE,
    ACTIONS(3889), 1,
      sym_variable_name,
    STATE(1503), 1,
      sym_string,
    ACTIONS(3887), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3885), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [19817] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3817), 1,
      sym_variable_name,
    STATE(1777), 1,
      sym_string,
    ACTIONS(3815), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3813), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [19887] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3081), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3083), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3095), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3099), 1,
      anon_sym_BQUOTE,
    ACTIONS(3101), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(3732), 1,
      sym__special_character,
    ACTIONS(3736), 1,
      sym_test_operator,
    ACTIONS(3930), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2283), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3103), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(721), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(3730), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1876), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2281), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [19985] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1825), 1,
      aux_sym__literal_repeat1,
    STATE(2047), 1,
      sym_concatenation,
    ACTIONS(2273), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1667), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20051] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3211), 1,
      anon_sym_DQUOTE,
    ACTIONS(3905), 1,
      sym_variable_name,
    STATE(1724), 1,
      sym_string,
    ACTIONS(3903), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(3901), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20121] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1885), 1,
      aux_sym__literal_repeat1,
    STATE(2158), 1,
      sym_concatenation,
    ACTIONS(2277), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(1674), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20187] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2031), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2043), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2047), 1,
      anon_sym_BQUOTE,
    ACTIONS(2049), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(3893), 1,
      sym__special_character,
    ACTIONS(3897), 1,
      sym_variable_name,
    ACTIONS(3899), 1,
      sym_test_operator,
    ACTIONS(3932), 1,
      aux_sym__simple_variable_name_token1,
    STATE(1820), 1,
      aux_sym__literal_repeat1,
    STATE(6681), 1,
      sym_subscript,
    ACTIONS(1585), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2051), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3891), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(728), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    STATE(2289), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1583), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [20289] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(801), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(517), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [20349] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3316), 1,
      anon_sym_DQUOTE,
    ACTIONS(3938), 1,
      sym_variable_name,
    STATE(1838), 1,
      sym_string,
    ACTIONS(3936), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(3934), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20418] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3948), 1,
      sym__special_character,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3960), 1,
      anon_sym_BQUOTE,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3966), 1,
      sym_test_operator,
    ACTIONS(3968), 1,
      sym__brace_start,
    STATE(4368), 1,
      aux_sym__literal_repeat1,
    STATE(4735), 1,
      sym_concatenation,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2277), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3940), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4635), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [20513] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2071), 1,
      anon_sym_DQUOTE,
    ACTIONS(3974), 1,
      sym_variable_name,
    STATE(1616), 1,
      sym_string,
    ACTIONS(3972), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(3970), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20582] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3980), 1,
      sym_variable_name,
    STATE(1912), 1,
      sym_string,
    ACTIONS(3978), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3976), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20651] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3986), 1,
      sym_variable_name,
    STATE(1710), 1,
      sym_string,
    ACTIONS(3984), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3982), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20720] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3988), 1,
      sym_word,
    ACTIONS(3991), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3994), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3997), 1,
      anon_sym_DOLLAR,
    ACTIONS(4000), 1,
      sym__special_character,
    ACTIONS(4003), 1,
      anon_sym_DQUOTE,
    ACTIONS(4009), 1,
      aux_sym_number_token1,
    ACTIONS(4012), 1,
      aux_sym_number_token2,
    ACTIONS(4015), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4018), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4021), 1,
      anon_sym_BQUOTE,
    ACTIONS(4024), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4030), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(4033), 1,
      sym_variable_name,
    ACTIONS(4036), 1,
      sym_test_operator,
    ACTIONS(4039), 1,
      sym__brace_start,
    STATE(2610), 1,
      aux_sym__literal_repeat1,
    STATE(6637), 1,
      sym_subscript,
    ACTIONS(4006), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4027), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(747), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    ACTIONS(1703), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2321), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1705), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [20823] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3316), 1,
      anon_sym_DQUOTE,
    ACTIONS(3938), 1,
      sym_variable_name,
    STATE(1838), 1,
      sym_string,
    ACTIONS(3936), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(3934), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20892] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4044), 1,
      anon_sym_DQUOTE,
    ACTIONS(4048), 1,
      sym_variable_name,
    STATE(2111), 1,
      sym_string,
    ACTIONS(4046), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(4042), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 34,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [20961] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4044), 1,
      anon_sym_DQUOTE,
    ACTIONS(4048), 1,
      sym_variable_name,
    STATE(2111), 1,
      sym_string,
    ACTIONS(4046), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(4042), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 34,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [21030] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3598), 1,
      anon_sym_DQUOTE,
    ACTIONS(4054), 1,
      sym_variable_name,
    STATE(1986), 1,
      sym_string,
    ACTIONS(4052), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(4050), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [21099] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3598), 1,
      anon_sym_DQUOTE,
    ACTIONS(4054), 1,
      sym_variable_name,
    STATE(1986), 1,
      sym_string,
    ACTIONS(4052), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(4050), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [21168] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2247), 1,
      anon_sym_BQUOTE,
    ACTIONS(2243), 22,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [21229] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(2269), 1,
      sym_variable_name,
    STATE(1273), 1,
      sym_string,
    ACTIONS(2267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2265), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 34,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [21298] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(2269), 1,
      sym_variable_name,
    STATE(1273), 1,
      sym_string,
    ACTIONS(2267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(2265), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 34,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [21367] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3648), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3652), 1,
      anon_sym_BQUOTE,
    ACTIONS(3654), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4058), 1,
      sym__special_character,
    ACTIONS(4060), 1,
      sym_test_operator,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3656), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(765), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4056), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [21462] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3648), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3654), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4058), 1,
      sym__special_character,
    ACTIONS(4060), 1,
      sym_test_operator,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3656), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(765), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4056), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [21555] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3648), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3654), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4058), 1,
      sym__special_character,
    ACTIONS(4060), 1,
      sym_test_operator,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3656), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(765), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4056), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [21648] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3648), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3652), 1,
      anon_sym_BQUOTE,
    ACTIONS(3654), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4058), 1,
      sym__special_character,
    ACTIONS(4060), 1,
      sym_test_operator,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3656), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(765), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4056), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [21743] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3986), 1,
      sym_variable_name,
    STATE(1710), 1,
      sym_string,
    ACTIONS(3984), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3982), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [21812] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4062), 1,
      sym_word,
    ACTIONS(4064), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4066), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4068), 1,
      anon_sym_DOLLAR,
    ACTIONS(4070), 1,
      sym__special_character,
    ACTIONS(4072), 1,
      anon_sym_DQUOTE,
    ACTIONS(4076), 1,
      aux_sym_number_token1,
    ACTIONS(4078), 1,
      aux_sym_number_token2,
    ACTIONS(4080), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4082), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4084), 1,
      anon_sym_BQUOTE,
    ACTIONS(4086), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4090), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(4092), 1,
      sym_variable_name,
    ACTIONS(4094), 1,
      sym_test_operator,
    ACTIONS(4096), 1,
      sym__brace_start,
    STATE(2610), 1,
      aux_sym__literal_repeat1,
    STATE(6637), 1,
      sym_subscript,
    ACTIONS(4074), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4088), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(779), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    ACTIONS(1583), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2321), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1585), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [21915] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(4100), 1,
      sym__special_character,
    ACTIONS(4102), 1,
      sym_test_operator,
    STATE(4236), 1,
      aux_sym__literal_repeat1,
    STATE(4549), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4098), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4495), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [22008] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2505), 1,
      anon_sym_BQUOTE,
    ACTIONS(2243), 22,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [22069] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(4100), 1,
      sym__special_character,
    ACTIONS(4106), 1,
      sym_test_operator,
    STATE(4265), 1,
      aux_sym__literal_repeat1,
    STATE(4609), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4104), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4497), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [22162] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3743), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3746), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3749), 1,
      anon_sym_DOLLAR,
    ACTIONS(3755), 1,
      anon_sym_DQUOTE,
    ACTIONS(3758), 1,
      aux_sym_number_token1,
    ACTIONS(3761), 1,
      aux_sym_number_token2,
    ACTIONS(3764), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3767), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3770), 1,
      anon_sym_BQUOTE,
    ACTIONS(3773), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3782), 1,
      sym__brace_start,
    ACTIONS(4111), 1,
      sym__special_character,
    ACTIONS(4114), 1,
      sym_test_operator,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3776), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(765), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4108), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [22257] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3960), 1,
      anon_sym_BQUOTE,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(4119), 1,
      sym__special_character,
    ACTIONS(4121), 1,
      sym_test_operator,
    STATE(4348), 1,
      aux_sym__literal_repeat1,
    STATE(4860), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4117), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4568), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [22352] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3980), 1,
      sym_variable_name,
    STATE(1912), 1,
      sym_string,
    ACTIONS(3978), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3976), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [22421] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3960), 1,
      anon_sym_BQUOTE,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(4119), 1,
      sym__special_character,
    ACTIONS(4125), 1,
      sym_test_operator,
    STATE(4368), 1,
      aux_sym__literal_repeat1,
    STATE(4735), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4123), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4572), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [22516] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3522), 1,
      anon_sym_BQUOTE,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(4129), 1,
      sym__special_character,
    ACTIONS(4131), 1,
      sym_test_operator,
    STATE(4236), 1,
      aux_sym__literal_repeat1,
    STATE(4549), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4127), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4625), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [22611] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3522), 1,
      anon_sym_BQUOTE,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(4129), 1,
      sym__special_character,
    ACTIONS(4135), 1,
      sym_test_operator,
    STATE(4265), 1,
      aux_sym__literal_repeat1,
    STATE(4609), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4133), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4627), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [22706] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3948), 1,
      sym__special_character,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3960), 1,
      anon_sym_BQUOTE,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(4139), 1,
      sym_test_operator,
    STATE(4348), 1,
      aux_sym__literal_repeat1,
    STATE(4860), 1,
      sym_concatenation,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2273), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4137), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4637), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [22801] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(4145), 1,
      sym_variable_name,
    STATE(1694), 1,
      sym_string,
    ACTIONS(4143), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4141), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [22870] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(4145), 1,
      sym_variable_name,
    STATE(1694), 1,
      sym_string,
    ACTIONS(4143), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4141), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [22939] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3817), 1,
      sym_variable_name,
    STATE(1777), 1,
      sym_string,
    ACTIONS(3815), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3813), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23008] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2071), 1,
      anon_sym_DQUOTE,
    ACTIONS(3974), 1,
      sym_variable_name,
    STATE(1616), 1,
      sym_string,
    ACTIONS(3972), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
    ACTIONS(3970), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23077] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3909), 1,
      anon_sym_DQUOTE,
    ACTIONS(3913), 1,
      sym_variable_name,
    STATE(1657), 1,
      sym_string,
    ACTIONS(3911), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3907), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23146] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3909), 1,
      anon_sym_DQUOTE,
    ACTIONS(3913), 1,
      sym_variable_name,
    STATE(1657), 1,
      sym_string,
    ACTIONS(3911), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3907), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23215] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2243), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LPAREN_LPAREN,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2241), 28,
      anon_sym_for,
      anon_sym_select,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_until,
      anon_sym_if,
      anon_sym_case,
      anon_sym_function,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_declare,
      anon_sym_typeset,
      anon_sym_export,
      anon_sym_readonly,
      anon_sym_local,
      anon_sym_unset,
      anon_sym_unsetenv,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
  [23274] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4062), 1,
      sym_word,
    ACTIONS(4064), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4066), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4068), 1,
      anon_sym_DOLLAR,
    ACTIONS(4070), 1,
      sym__special_character,
    ACTIONS(4072), 1,
      anon_sym_DQUOTE,
    ACTIONS(4076), 1,
      aux_sym_number_token1,
    ACTIONS(4078), 1,
      aux_sym_number_token2,
    ACTIONS(4080), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4082), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4084), 1,
      anon_sym_BQUOTE,
    ACTIONS(4086), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4092), 1,
      sym_variable_name,
    ACTIONS(4094), 1,
      sym_test_operator,
    ACTIONS(4096), 1,
      sym__brace_start,
    ACTIONS(4147), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2610), 1,
      aux_sym__literal_repeat1,
    STATE(6637), 1,
      sym_subscript,
    ACTIONS(4074), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4088), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(747), 3,
      sym_variable_assignment,
      sym_concatenation,
      aux_sym_declaration_command_repeat1,
    ACTIONS(1694), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2321), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(1696), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [23377] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3817), 1,
      sym_variable_name,
    STATE(1777), 1,
      sym_string,
    ACTIONS(3815), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3813), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23446] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4149), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4151), 1,
      sym__concat,
    STATE(803), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23510] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4163), 1,
      sym_variable_name,
    STATE(6669), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    STATE(4159), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23582] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4149), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4151), 1,
      sym__concat,
    ACTIONS(4166), 1,
      anon_sym_LPAREN,
    STATE(803), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23648] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3980), 1,
      sym_variable_name,
    STATE(1912), 1,
      sym_string,
    ACTIONS(3978), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3976), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23716] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4163), 1,
      sym_variable_name,
    ACTIONS(4175), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6669), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4169), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(4171), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    STATE(4159), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(2503), 4,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23794] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4177), 1,
      sym_word,
    ACTIONS(4180), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4183), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4186), 1,
      anon_sym_DOLLAR,
    ACTIONS(4189), 1,
      sym__special_character,
    ACTIONS(4192), 1,
      anon_sym_DQUOTE,
    ACTIONS(4198), 1,
      aux_sym_number_token1,
    ACTIONS(4201), 1,
      aux_sym_number_token2,
    ACTIONS(4204), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4207), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4210), 1,
      anon_sym_BQUOTE,
    ACTIONS(4213), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4219), 1,
      sym_test_operator,
    ACTIONS(4222), 1,
      sym__brace_start,
    STATE(2496), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4195), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4216), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(786), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2167), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2283), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2169), 13,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [23890] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3980), 1,
      sym_variable_name,
    STATE(1912), 1,
      sym_string,
    ACTIONS(3978), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3976), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [23958] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(4227), 1,
      sym__special_character,
    ACTIONS(4229), 1,
      sym_test_operator,
    STATE(4348), 1,
      aux_sym__literal_repeat1,
    STATE(4860), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4225), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4650), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [24050] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3960), 1,
      anon_sym_BQUOTE,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(4233), 1,
      sym__special_character,
    ACTIONS(4235), 1,
      sym_test_operator,
    STATE(4348), 1,
      aux_sym__literal_repeat1,
    STATE(4860), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4231), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4876), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [24144] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3960), 1,
      anon_sym_BQUOTE,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(4233), 1,
      sym__special_character,
    ACTIONS(4239), 1,
      sym_test_operator,
    STATE(4368), 1,
      aux_sym__literal_repeat1,
    STATE(4735), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4237), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4880), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [24238] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(4227), 1,
      sym__special_character,
    ACTIONS(4243), 1,
      sym_test_operator,
    STATE(4368), 1,
      aux_sym__literal_repeat1,
    STATE(4735), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4241), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4654), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [24330] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4247), 1,
      anon_sym_DQUOTE,
    ACTIONS(4251), 1,
      sym_variable_name,
    STATE(2251), 1,
      sym_string,
    ACTIONS(4249), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(4245), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [24398] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4163), 1,
      sym_variable_name,
    ACTIONS(4257), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6669), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4171), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4253), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    STATE(4159), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4255), 4,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [24476] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2496), 1,
      aux_sym__literal_repeat1,
    STATE(786), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2283), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2162), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [24540] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    STATE(798), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(2287), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [24604] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4149), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4151), 1,
      sym__concat,
    STATE(802), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(276), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [24668] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    STATE(798), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(2287), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [24732] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2571), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2574), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2577), 1,
      anon_sym_DOLLAR,
    ACTIONS(2583), 1,
      anon_sym_DQUOTE,
    ACTIONS(2586), 1,
      aux_sym_number_token1,
    ACTIONS(2589), 1,
      aux_sym_number_token2,
    ACTIONS(2592), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2595), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2598), 1,
      anon_sym_BQUOTE,
    ACTIONS(2601), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2610), 1,
      sym__brace_start,
    ACTIONS(4262), 1,
      sym__special_character,
    ACTIONS(4265), 1,
      sym_test_operator,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2604), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(798), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2169), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4259), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2287), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [24826] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4247), 1,
      anon_sym_DQUOTE,
    ACTIONS(4251), 1,
      sym_variable_name,
    STATE(2251), 1,
      sym_string,
    ACTIONS(4249), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
    ACTIONS(4245), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [24894] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4163), 1,
      sym_variable_name,
    STATE(6669), 1,
      sym_subscript,
    ACTIONS(4161), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4159), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(4157), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [24964] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2496), 1,
      aux_sym__literal_repeat1,
    STATE(786), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2283), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2158), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [25028] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4149), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4270), 1,
      sym__concat,
    STATE(804), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25092] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4149), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4272), 1,
      sym__concat,
    STATE(804), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25156] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4274), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4277), 1,
      sym__concat,
    STATE(804), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25220] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4149), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4151), 1,
      sym__concat,
    STATE(802), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25284] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(4145), 1,
      sym_variable_name,
    STATE(1694), 1,
      sym_string,
    ACTIONS(4143), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4141), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25352] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3986), 1,
      sym_variable_name,
    STATE(1710), 1,
      sym_string,
    ACTIONS(3984), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3982), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25420] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3986), 1,
      sym_variable_name,
    STATE(1710), 1,
      sym_string,
    ACTIONS(3984), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3982), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25488] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(4145), 1,
      sym_variable_name,
    STATE(1694), 1,
      sym_string,
    ACTIONS(4143), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4141), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25556] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(813), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25619] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25733] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4288), 1,
      sym__concat,
    STATE(819), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25796] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4296), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4298), 1,
      sym_variable_name,
    STATE(6702), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4290), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(4292), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    STATE(4174), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(2503), 3,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25873] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4301), 1,
      sym__concat,
    STATE(819), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25936] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(815), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4305), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [25999] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(813), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [26062] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(815), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [26125] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4315), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4318), 1,
      sym__concat,
    STATE(819), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [26188] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4321), 1,
      sym_word,
    ACTIONS(4323), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4325), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4327), 1,
      anon_sym_DOLLAR,
    ACTIONS(4329), 1,
      sym__special_character,
    ACTIONS(4331), 1,
      anon_sym_DQUOTE,
    ACTIONS(4335), 1,
      aux_sym_number_token1,
    ACTIONS(4337), 1,
      aux_sym_number_token2,
    ACTIONS(4339), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4341), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4343), 1,
      anon_sym_BQUOTE,
    ACTIONS(4345), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4349), 1,
      sym_test_operator,
    ACTIONS(4351), 1,
      sym__brace_start,
    STATE(2630), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4333), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4347), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(829), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2382), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2158), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [26283] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4321), 1,
      sym_word,
    ACTIONS(4323), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4325), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4327), 1,
      anon_sym_DOLLAR,
    ACTIONS(4329), 1,
      sym__special_character,
    ACTIONS(4331), 1,
      anon_sym_DQUOTE,
    ACTIONS(4335), 1,
      aux_sym_number_token1,
    ACTIONS(4337), 1,
      aux_sym_number_token2,
    ACTIONS(4339), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4341), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4343), 1,
      anon_sym_BQUOTE,
    ACTIONS(4345), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4349), 1,
      sym_test_operator,
    ACTIONS(4351), 1,
      sym__brace_start,
    STATE(2630), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4333), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4347), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(829), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2382), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2162), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [26378] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3037), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3040), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3043), 1,
      anon_sym_DOLLAR,
    ACTIONS(3049), 1,
      anon_sym_DQUOTE,
    ACTIONS(3052), 1,
      aux_sym_number_token1,
    ACTIONS(3055), 1,
      aux_sym_number_token2,
    ACTIONS(3058), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3061), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3064), 1,
      anon_sym_BQUOTE,
    ACTIONS(3067), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3076), 1,
      sym__brace_start,
    ACTIONS(4356), 1,
      sym__special_character,
    ACTIONS(4359), 1,
      sym_test_operator,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3070), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(822), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4353), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2413), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [26471] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2458), 1,
      aux_sym__literal_repeat1,
    STATE(2661), 1,
      sym_concatenation,
    STATE(2228), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2273), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [26534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [26591] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [26648] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(813), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [26711] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3008), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3020), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3024), 1,
      anon_sym_BQUOTE,
    ACTIONS(3026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(4364), 1,
      sym__special_character,
    ACTIONS(4366), 1,
      sym_test_operator,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(822), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4362), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2413), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [26804] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(813), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4370), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [26867] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4372), 1,
      sym_word,
    ACTIONS(4375), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4378), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4381), 1,
      anon_sym_DOLLAR,
    ACTIONS(4384), 1,
      sym__special_character,
    ACTIONS(4387), 1,
      anon_sym_DQUOTE,
    ACTIONS(4393), 1,
      aux_sym_number_token1,
    ACTIONS(4396), 1,
      aux_sym_number_token2,
    ACTIONS(4399), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4405), 1,
      anon_sym_BQUOTE,
    ACTIONS(4408), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4414), 1,
      sym_test_operator,
    ACTIONS(4417), 1,
      sym__brace_start,
    STATE(2630), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4390), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4411), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(829), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2167), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2382), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2169), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [26962] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4420), 1,
      anon_sym_LPAREN,
    ACTIONS(4423), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4425), 1,
      sym__concat,
    STATE(833), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27027] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4423), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4427), 1,
      sym__concat,
    STATE(835), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27090] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27147] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4423), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4429), 1,
      sym__concat,
    STATE(835), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27210] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27267] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4431), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4434), 1,
      sym__concat,
    STATE(835), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27330] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27444] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(815), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27507] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(815), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4443), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27570] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4423), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4425), 1,
      sym__concat,
    STATE(831), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27633] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [27690] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2634), 1,
      aux_sym__literal_repeat1,
    STATE(850), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2335), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2158), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [27753] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3081), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3083), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3095), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3099), 1,
      anon_sym_BQUOTE,
    ACTIONS(3101), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(4447), 1,
      sym__special_character,
    ACTIONS(4449), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(4451), 1,
      sym_test_operator,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2327), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3103), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(851), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(4445), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2393), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2325), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [27848] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2634), 1,
      aux_sym__literal_repeat1,
    STATE(850), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2335), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2162), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [27911] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2544), 1,
      aux_sym__literal_repeat1,
    STATE(2677), 1,
      sym_concatenation,
    STATE(2250), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2277), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [27974] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4298), 1,
      sym_variable_name,
    STATE(6702), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    STATE(4174), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28102] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28159] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4423), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4425), 1,
      sym__concat,
    STATE(831), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(276), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28222] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4453), 1,
      sym_word,
    ACTIONS(4456), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4459), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4462), 1,
      anon_sym_DOLLAR,
    ACTIONS(4465), 1,
      sym__special_character,
    ACTIONS(4468), 1,
      anon_sym_DQUOTE,
    ACTIONS(4474), 1,
      aux_sym_number_token1,
    ACTIONS(4477), 1,
      aux_sym_number_token2,
    ACTIONS(4480), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4483), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4486), 1,
      anon_sym_BQUOTE,
    ACTIONS(4489), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4495), 1,
      sym_test_operator,
    ACTIONS(4498), 1,
      sym__brace_start,
    STATE(2634), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4471), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4492), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(850), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2167), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2335), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2169), 12,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [28317] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2959), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2962), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2965), 1,
      anon_sym_DOLLAR,
    ACTIONS(2971), 1,
      anon_sym_DQUOTE,
    ACTIONS(2974), 1,
      aux_sym_number_token1,
    ACTIONS(2977), 1,
      aux_sym_number_token2,
    ACTIONS(2980), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2983), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2986), 1,
      anon_sym_BQUOTE,
    ACTIONS(2989), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3001), 1,
      sym__brace_start,
    ACTIONS(4504), 1,
      sym__special_character,
    ACTIONS(4507), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(4510), 1,
      sym_test_operator,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2456), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2992), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(851), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(4501), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2393), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2454), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [28412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28469] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28526] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3008), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3020), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3024), 1,
      anon_sym_BQUOTE,
    ACTIONS(3026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(4364), 1,
      sym__special_character,
    ACTIONS(4366), 1,
      sym_test_operator,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(822), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4362), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2413), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [28619] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4298), 1,
      sym_variable_name,
    ACTIONS(4515), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6702), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4292), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4513), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    STATE(4174), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4255), 3,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28696] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4286), 1,
      sym__concat,
    STATE(813), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4519), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [28930] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4298), 1,
      sym_variable_name,
    STATE(6702), 1,
      sym_subscript,
    ACTIONS(4161), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4174), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(4157), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [28999] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [29056] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [29113] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3081), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3083), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3095), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3099), 1,
      anon_sym_BQUOTE,
    ACTIONS(3101), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(4447), 1,
      sym__special_character,
    ACTIONS(4451), 1,
      sym_test_operator,
    ACTIONS(4521), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2045), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2283), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3103), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(843), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(4445), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2393), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2281), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [29208] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1825), 1,
      aux_sym__literal_repeat1,
    STATE(2047), 1,
      sym_concatenation,
    ACTIONS(2273), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(2290), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [29271] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4423), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4425), 1,
      sym__concat,
    STATE(833), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [29334] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1885), 1,
      aux_sym__literal_repeat1,
    STATE(2158), 1,
      sym_concatenation,
    ACTIONS(2277), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    STATE(2293), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [29397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 43,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [29454] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4523), 1,
      ts_builtin_sym_end,
    ACTIONS(4531), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4533), 1,
      sym_variable_name,
    STATE(6675), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4527), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    STATE(4341), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4525), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [29530] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2611), 1,
      aux_sym__literal_repeat1,
    STATE(2833), 1,
      sym_concatenation,
    STATE(2419), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2277), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [29592] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4536), 1,
      sym_word,
    ACTIONS(4538), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4540), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4542), 1,
      anon_sym_DOLLAR,
    ACTIONS(4544), 1,
      sym__special_character,
    ACTIONS(4546), 1,
      anon_sym_DQUOTE,
    ACTIONS(4550), 1,
      aux_sym_number_token1,
    ACTIONS(4552), 1,
      aux_sym_number_token2,
    ACTIONS(4554), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4556), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4560), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4564), 1,
      sym_test_operator,
    ACTIONS(4566), 1,
      sym__brace_start,
    STATE(2975), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4548), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4562), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(872), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2540), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2158), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [29686] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4536), 1,
      sym_word,
    ACTIONS(4538), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4540), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4542), 1,
      anon_sym_DOLLAR,
    ACTIONS(4544), 1,
      sym__special_character,
    ACTIONS(4546), 1,
      anon_sym_DQUOTE,
    ACTIONS(4550), 1,
      aux_sym_number_token1,
    ACTIONS(4552), 1,
      aux_sym_number_token2,
    ACTIONS(4554), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4556), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4560), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4564), 1,
      sym_test_operator,
    ACTIONS(4566), 1,
      sym__brace_start,
    STATE(2975), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4548), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4562), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(872), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2540), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2162), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [29780] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4568), 1,
      sym_word,
    ACTIONS(4571), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4574), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4577), 1,
      anon_sym_DOLLAR,
    ACTIONS(4580), 1,
      sym__special_character,
    ACTIONS(4583), 1,
      anon_sym_DQUOTE,
    ACTIONS(4589), 1,
      aux_sym_number_token1,
    ACTIONS(4592), 1,
      aux_sym_number_token2,
    ACTIONS(4595), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4598), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4601), 1,
      anon_sym_BQUOTE,
    ACTIONS(4604), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4610), 1,
      sym_test_operator,
    ACTIONS(4613), 1,
      sym__brace_start,
    STATE(2975), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4586), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4607), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(872), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2167), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2540), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2169), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [29874] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4616), 1,
      sym_variable_name,
    STATE(6703), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    STATE(4436), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 8,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_LT_LT_DASH,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [29944] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4621), 1,
      anon_sym_DQUOTE,
    ACTIONS(4625), 1,
      sym_variable_name,
    STATE(2404), 1,
      sym_string,
    ACTIONS(4623), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4619), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30010] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4621), 1,
      anon_sym_DQUOTE,
    ACTIONS(4625), 1,
      sym_variable_name,
    STATE(2404), 1,
      sym_string,
    ACTIONS(4623), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4619), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30076] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4627), 1,
      sym_word,
    ACTIONS(4629), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4631), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4633), 1,
      anon_sym_DOLLAR,
    ACTIONS(4635), 1,
      sym__special_character,
    ACTIONS(4637), 1,
      anon_sym_DQUOTE,
    ACTIONS(4641), 1,
      aux_sym_number_token1,
    ACTIONS(4643), 1,
      aux_sym_number_token2,
    ACTIONS(4645), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4647), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4649), 1,
      anon_sym_BQUOTE,
    ACTIONS(4651), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4655), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(4657), 1,
      sym_test_operator,
    ACTIONS(4659), 1,
      sym__brace_start,
    STATE(2831), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4639), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4653), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(885), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2281), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2513), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2283), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [30172] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(883), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30234] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(907), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30296] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(910), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30358] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1039), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1041), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1043), 1,
      anon_sym_DOLLAR,
    ACTIONS(1047), 1,
      anon_sym_DQUOTE,
    ACTIONS(1051), 1,
      aux_sym_number_token1,
    ACTIONS(1053), 1,
      aux_sym_number_token2,
    ACTIONS(1055), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1057), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1059), 1,
      anon_sym_BQUOTE,
    ACTIONS(1061), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1067), 1,
      sym_test_operator,
    ACTIONS(1069), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2825), 1,
      sym_word,
    ACTIONS(4669), 1,
      sym__special_character,
    ACTIONS(4671), 1,
      sym_variable_name,
    STATE(619), 1,
      sym_command_name,
    STATE(2307), 1,
      aux_sym__literal_repeat1,
    STATE(2412), 1,
      sym_concatenation,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(1049), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1063), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(1879), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [30468] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(907), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30530] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(910), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30592] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4673), 1,
      sym__concat,
    STATE(895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30654] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4616), 1,
      sym_variable_name,
    STATE(6703), 1,
      sym_subscript,
    ACTIONS(4161), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4436), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(4157), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [30722] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4627), 1,
      sym_word,
    ACTIONS(4629), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4631), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4633), 1,
      anon_sym_DOLLAR,
    ACTIONS(4635), 1,
      sym__special_character,
    ACTIONS(4637), 1,
      anon_sym_DQUOTE,
    ACTIONS(4641), 1,
      aux_sym_number_token1,
    ACTIONS(4643), 1,
      aux_sym_number_token2,
    ACTIONS(4645), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4647), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4649), 1,
      anon_sym_BQUOTE,
    ACTIONS(4651), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4657), 1,
      sym_test_operator,
    ACTIONS(4659), 1,
      sym__brace_start,
    ACTIONS(4675), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2831), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4639), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4653), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(933), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2325), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2513), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2327), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [30818] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4677), 1,
      sym__concat,
    STATE(895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30880] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4679), 1,
      sym__special_character,
    STATE(887), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [30996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31052] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31164] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31332] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4682), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4685), 1,
      sym__concat,
    STATE(895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31394] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31618] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3909), 1,
      anon_sym_DQUOTE,
    ACTIONS(3913), 1,
      sym_variable_name,
    STATE(1657), 1,
      sym_string,
    ACTIONS(3911), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3907), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31684] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3909), 1,
      anon_sym_DQUOTE,
    ACTIONS(3913), 1,
      sym_variable_name,
    STATE(1657), 1,
      sym_string,
    ACTIONS(3911), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3907), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31862] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31918] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [31974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32030] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4688), 1,
      sym__concat,
    STATE(911), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32148] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32204] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4690), 1,
      sym__concat,
    STATE(911), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32266] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4692), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4695), 1,
      sym__concat,
    STATE(911), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32328] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(907), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32390] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32502] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32670] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32782] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [32950] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33006] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2609), 1,
      aux_sym__literal_repeat1,
    STATE(3008), 1,
      sym_concatenation,
    STATE(2408), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2273), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [33068] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3817), 1,
      sym_variable_name,
    STATE(1777), 1,
      sym_string,
    ACTIONS(3815), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3813), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33134] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3817), 1,
      sym_variable_name,
    STATE(1777), 1,
      sym_string,
    ACTIONS(3815), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3813), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33424] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4698), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4700), 1,
      sym__concat,
    STATE(945), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33542] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4702), 1,
      sym_word,
    ACTIONS(4705), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4708), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4711), 1,
      anon_sym_DOLLAR,
    ACTIONS(4714), 1,
      sym__special_character,
    ACTIONS(4717), 1,
      anon_sym_DQUOTE,
    ACTIONS(4723), 1,
      aux_sym_number_token1,
    ACTIONS(4726), 1,
      aux_sym_number_token2,
    ACTIONS(4729), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4732), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4735), 1,
      anon_sym_BQUOTE,
    ACTIONS(4738), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4744), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(4747), 1,
      sym_test_operator,
    ACTIONS(4750), 1,
      sym__brace_start,
    STATE(2831), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4720), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4741), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(933), 2,
      sym_concatenation,
      aux_sym_unset_command_repeat1,
    ACTIONS(2454), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2513), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2456), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [33638] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33694] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [33806] = 30,
    ACTIONS(45), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(47), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(57), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      aux_sym_number_token2,
    ACTIONS(61), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(63), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(65), 1,
      anon_sym_BQUOTE,
    ACTIONS(67), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(77), 1,
      sym_test_operator,
    ACTIONS(79), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2787), 1,
      sym_word,
    ACTIONS(4671), 1,
      sym_variable_name,
    ACTIONS(4753), 1,
      sym__special_character,
    STATE(533), 1,
      sym_command_name,
    STATE(1181), 1,
      aux_sym__literal_repeat1,
    STATE(1431), 1,
      sym_concatenation,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(55), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(69), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(944), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [33916] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(338), 1,
      sym_test_operator,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2643), 1,
      sym_word,
    ACTIONS(4671), 1,
      sym_variable_name,
    ACTIONS(4755), 1,
      sym__special_character,
    STATE(540), 1,
      sym_command_name,
    STATE(1237), 1,
      aux_sym__literal_repeat1,
    STATE(1350), 1,
      sym_concatenation,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(318), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(1126), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [34026] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4533), 1,
      sym_variable_name,
    STATE(6675), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(4341), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 7,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_LT_LT_DASH,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [34096] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4759), 1,
      anon_sym_DQUOTE,
    ACTIONS(4763), 1,
      sym_variable_name,
    STATE(2498), 1,
      sym_string,
    ACTIONS(4761), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4757), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [34162] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4759), 1,
      anon_sym_DQUOTE,
    ACTIONS(4763), 1,
      sym_variable_name,
    STATE(2498), 1,
      sym_string,
    ACTIONS(4761), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4757), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [34228] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(447), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(449), 1,
      anon_sym_DOLLAR,
    ACTIONS(453), 1,
      anon_sym_DQUOTE,
    ACTIONS(457), 1,
      aux_sym_number_token1,
    ACTIONS(459), 1,
      aux_sym_number_token2,
    ACTIONS(461), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(463), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(465), 1,
      anon_sym_BQUOTE,
    ACTIONS(467), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(475), 1,
      sym_test_operator,
    ACTIONS(477), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2526), 1,
      sym_word,
    ACTIONS(4671), 1,
      sym_variable_name,
    ACTIONS(4765), 1,
      sym__special_character,
    STATE(523), 1,
      sym_command_name,
    STATE(943), 1,
      aux_sym__literal_repeat1,
    STATE(1056), 1,
      sym_concatenation,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(455), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(469), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(781), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [34338] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4767), 1,
      sym__special_character,
    STATE(887), 1,
      aux_sym__literal_repeat1,
    ACTIONS(276), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [34398] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4698), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4700), 1,
      sym__concat,
    STATE(950), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [34460] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4698), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4769), 1,
      sym__concat,
    STATE(968), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [34522] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3648), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3652), 1,
      anon_sym_BQUOTE,
    ACTIONS(3654), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4773), 1,
      sym__special_character,
    ACTIONS(4775), 1,
      sym_test_operator,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3656), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(948), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4771), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2556), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [34614] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3648), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3652), 1,
      anon_sym_BQUOTE,
    ACTIONS(3654), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4773), 1,
      sym__special_character,
    ACTIONS(4775), 1,
      sym_test_operator,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3656), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(948), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4771), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2556), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [34706] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3743), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3746), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3749), 1,
      anon_sym_DOLLAR,
    ACTIONS(3755), 1,
      anon_sym_DQUOTE,
    ACTIONS(3758), 1,
      aux_sym_number_token1,
    ACTIONS(3761), 1,
      aux_sym_number_token2,
    ACTIONS(3764), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3767), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3770), 1,
      anon_sym_BQUOTE,
    ACTIONS(3773), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3782), 1,
      sym__brace_start,
    ACTIONS(4780), 1,
      sym__special_character,
    ACTIONS(4783), 1,
      sym_test_operator,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3776), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(948), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(4777), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(2556), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [34798] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(701), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(703), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(705), 1,
      anon_sym_DOLLAR,
    ACTIONS(709), 1,
      anon_sym_DQUOTE,
    ACTIONS(713), 1,
      aux_sym_number_token1,
    ACTIONS(715), 1,
      aux_sym_number_token2,
    ACTIONS(717), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(719), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(721), 1,
      anon_sym_BQUOTE,
    ACTIONS(723), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(731), 1,
      sym_test_operator,
    ACTIONS(733), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2775), 1,
      sym_word,
    ACTIONS(4671), 1,
      sym_variable_name,
    ACTIONS(4786), 1,
      sym__special_character,
    STATE(525), 1,
      sym_command_name,
    STATE(1089), 1,
      aux_sym__literal_repeat1,
    STATE(1220), 1,
      sym_concatenation,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(711), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(725), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(865), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [34908] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4698), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4788), 1,
      sym__concat,
    STATE(968), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [34970] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(907), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4370), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35032] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(910), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4443), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35094] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2505), 1,
      ts_builtin_sym_end,
    ACTIONS(4533), 1,
      sym_variable_name,
    ACTIONS(4792), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6675), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4527), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    STATE(4341), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4790), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35170] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4698), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4700), 1,
      sym__concat,
    ACTIONS(4794), 1,
      anon_sym_LPAREN,
    STATE(950), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35234] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(883), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(276), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35296] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(886), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35358] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1245), 1,
      anon_sym_LPAREN,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(886), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35422] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4255), 1,
      anon_sym_RPAREN,
    ACTIONS(4515), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4616), 1,
      sym_variable_name,
    STATE(6703), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4797), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(4436), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4513), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35498] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(907), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4519), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35560] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4665), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4667), 1,
      sym__concat,
    STATE(910), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4305), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35622] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(775), 1,
      sym_test_operator,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2530), 1,
      sym_word,
    ACTIONS(4671), 1,
      sym_variable_name,
    ACTIONS(4799), 1,
      sym__special_character,
    STATE(530), 1,
      sym_command_name,
    STATE(1237), 1,
      aux_sym__literal_repeat1,
    STATE(1350), 1,
      sym_concatenation,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(773), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(956), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [35732] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4533), 1,
      sym_variable_name,
    STATE(6675), 1,
      sym_subscript,
    ACTIONS(4161), 2,
      sym_test_operator,
      sym__brace_start,
    STATE(4341), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4268), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(4157), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [35800] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4698), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4700), 1,
      sym__concat,
    STATE(945), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(276), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [35862] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4801), 1,
      sym_word,
    ACTIONS(4803), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4805), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_DOLLAR,
    ACTIONS(4809), 1,
      sym__special_character,
    ACTIONS(4811), 1,
      anon_sym_DQUOTE,
    ACTIONS(4815), 1,
      aux_sym_number_token1,
    ACTIONS(4817), 1,
      aux_sym_number_token2,
    ACTIONS(4819), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4821), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4823), 1,
      anon_sym_BQUOTE,
    ACTIONS(4825), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4829), 1,
      sym_test_operator,
    ACTIONS(4831), 1,
      sym__brace_start,
    STATE(2859), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4813), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4827), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(971), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2538), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2158), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [35956] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4801), 1,
      sym_word,
    ACTIONS(4803), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4805), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_DOLLAR,
    ACTIONS(4809), 1,
      sym__special_character,
    ACTIONS(4811), 1,
      anon_sym_DQUOTE,
    ACTIONS(4815), 1,
      aux_sym_number_token1,
    ACTIONS(4817), 1,
      aux_sym_number_token2,
    ACTIONS(4819), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4821), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4823), 1,
      anon_sym_BQUOTE,
    ACTIONS(4825), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4829), 1,
      sym_test_operator,
    ACTIONS(4831), 1,
      sym__brace_start,
    STATE(2859), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4813), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4827), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(971), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2538), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2162), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [36050] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4833), 1,
      sym_word,
    ACTIONS(4835), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4839), 1,
      anon_sym_DOLLAR,
    ACTIONS(4841), 1,
      sym__special_character,
    ACTIONS(4843), 1,
      anon_sym_DQUOTE,
    ACTIONS(4847), 1,
      aux_sym_number_token1,
    ACTIONS(4849), 1,
      aux_sym_number_token2,
    ACTIONS(4851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4853), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4855), 1,
      anon_sym_BQUOTE,
    ACTIONS(4857), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4861), 1,
      sym_test_operator,
    ACTIONS(4863), 1,
      sym__brace_start,
    STATE(5225), 1,
      aux_sym__literal_repeat1,
    STATE(5433), 1,
      sym_concatenation,
    ACTIONS(4845), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4859), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2271), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(5035), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2273), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [36144] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4835), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4839), 1,
      anon_sym_DOLLAR,
    ACTIONS(4841), 1,
      sym__special_character,
    ACTIONS(4843), 1,
      anon_sym_DQUOTE,
    ACTIONS(4847), 1,
      aux_sym_number_token1,
    ACTIONS(4849), 1,
      aux_sym_number_token2,
    ACTIONS(4851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4853), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4855), 1,
      anon_sym_BQUOTE,
    ACTIONS(4857), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4863), 1,
      sym__brace_start,
    ACTIONS(4865), 1,
      sym_word,
    ACTIONS(4869), 1,
      sym_test_operator,
    STATE(5187), 1,
      aux_sym__literal_repeat1,
    STATE(5408), 1,
      sym_concatenation,
    ACTIONS(4859), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4867), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(2275), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(5037), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2277), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [36238] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4871), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4874), 1,
      sym__concat,
    STATE(968), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [36300] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_RPAREN,
    ACTIONS(4296), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4616), 1,
      sym_variable_name,
    STATE(6703), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4797), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(4436), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4290), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [36376] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(338), 1,
      sym_test_operator,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2643), 1,
      sym_word,
    ACTIONS(4671), 1,
      sym_variable_name,
    ACTIONS(4755), 1,
      sym__special_character,
    STATE(542), 1,
      sym_command_name,
    STATE(1237), 1,
      aux_sym__literal_repeat1,
    STATE(1350), 1,
      sym_concatenation,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(318), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(1126), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [36486] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4877), 1,
      sym_word,
    ACTIONS(4880), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4883), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4886), 1,
      anon_sym_DOLLAR,
    ACTIONS(4889), 1,
      sym__special_character,
    ACTIONS(4892), 1,
      anon_sym_DQUOTE,
    ACTIONS(4898), 1,
      aux_sym_number_token1,
    ACTIONS(4901), 1,
      aux_sym_number_token2,
    ACTIONS(4904), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4907), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4910), 1,
      anon_sym_BQUOTE,
    ACTIONS(4913), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4919), 1,
      sym_test_operator,
    ACTIONS(4922), 1,
      sym__brace_start,
    STATE(2859), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4895), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4916), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(971), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2167), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2538), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2169), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [36580] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4927), 1,
      anon_sym_DQUOTE,
    ACTIONS(4931), 1,
      sym_variable_name,
    STATE(2500), 1,
      sym_string,
    ACTIONS(1197), 2,
      sym__concat,
      sym_test_operator,
    ACTIONS(4929), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4925), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
  [36646] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4927), 1,
      anon_sym_DQUOTE,
    ACTIONS(4931), 1,
      sym_variable_name,
    STATE(2500), 1,
      sym_string,
    ACTIONS(1191), 2,
      sym__concat,
      sym_test_operator,
    ACTIONS(4929), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4925), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
  [36712] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(1023), 1,
      sym_test_operator,
    ACTIONS(1352), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(1354), 1,
      sym_file_descriptor,
    ACTIONS(2875), 1,
      sym_word,
    ACTIONS(4671), 1,
      sym_variable_name,
    ACTIONS(4933), 1,
      sym__special_character,
    STATE(605), 1,
      sym_command_name,
    STATE(1237), 1,
      aux_sym__literal_repeat1,
    STATE(1350), 1,
      sym_concatenation,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1017), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1350), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(1346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(1344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(1692), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [36822] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3522), 1,
      anon_sym_BQUOTE,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(4937), 1,
      sym__special_character,
    ACTIONS(4939), 1,
      sym_test_operator,
    STATE(4236), 1,
      aux_sym__literal_repeat1,
    STATE(4549), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4935), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5108), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [36914] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3506), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3522), 1,
      anon_sym_BQUOTE,
    ACTIONS(3524), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(4937), 1,
      sym__special_character,
    ACTIONS(4943), 1,
      sym_test_operator,
    STATE(4265), 1,
      aux_sym__literal_repeat1,
    STATE(4609), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3526), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(4941), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5110), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [37006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37062] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37117] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4947), 1,
      anon_sym_DQUOTE,
    ACTIONS(4951), 1,
      sym_variable_name,
    STATE(2777), 1,
      sym_string,
    ACTIONS(4949), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4945), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37182] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(1197), 1,
      sym_test_operator,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_TILDE,
      anon_sym_COLON,
  [37247] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(1191), 1,
      sym_test_operator,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_TILDE,
      anon_sym_COLON,
  [37312] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4961), 1,
      sym__concat,
    STATE(994), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37373] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37483] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4965), 1,
      sym__concat,
    STATE(987), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37544] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4967), 1,
      sym__concat,
    STATE(987), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37605] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4969), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4972), 1,
      sym__concat,
    STATE(987), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37666] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4975), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4977), 1,
      sym__concat,
    STATE(990), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [37727] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4975), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4979), 1,
      sym__concat,
    STATE(990), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [37788] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4981), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4984), 1,
      sym__concat,
    STATE(990), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [37849] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(985), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [37910] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4975), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4989), 1,
      sym__concat,
    STATE(988), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [37971] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_BQUOTE,
    ACTIONS(4995), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4997), 1,
      sym_variable_name,
    STATE(6672), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4993), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(4492), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4991), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 26,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38046] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5003), 1,
      sym__concat,
    STATE(994), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38107] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5006), 1,
      sym__special_character,
    STATE(995), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38166] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38221] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38276] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5009), 1,
      sym_word,
    ACTIONS(5011), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5013), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5015), 1,
      anon_sym_DOLLAR,
    ACTIONS(5017), 1,
      sym__special_character,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    ACTIONS(5023), 1,
      aux_sym_number_token1,
    ACTIONS(5025), 1,
      aux_sym_number_token2,
    ACTIONS(5027), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5031), 1,
      anon_sym_BQUOTE,
    ACTIONS(5033), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5037), 1,
      sym_test_operator,
    ACTIONS(5039), 1,
      sym__brace_start,
    STATE(3136), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5021), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(5035), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1000), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2655), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2158), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [38369] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5009), 1,
      sym_word,
    ACTIONS(5011), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5013), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5015), 1,
      anon_sym_DOLLAR,
    ACTIONS(5017), 1,
      sym__special_character,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    ACTIONS(5023), 1,
      aux_sym_number_token1,
    ACTIONS(5025), 1,
      aux_sym_number_token2,
    ACTIONS(5027), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5031), 1,
      anon_sym_BQUOTE,
    ACTIONS(5033), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5037), 1,
      sym_test_operator,
    ACTIONS(5039), 1,
      sym__brace_start,
    STATE(3136), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5021), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(5035), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1000), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2655), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2162), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [38462] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5041), 1,
      sym_word,
    ACTIONS(5044), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5047), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5050), 1,
      anon_sym_DOLLAR,
    ACTIONS(5053), 1,
      sym__special_character,
    ACTIONS(5056), 1,
      anon_sym_DQUOTE,
    ACTIONS(5062), 1,
      aux_sym_number_token1,
    ACTIONS(5065), 1,
      aux_sym_number_token2,
    ACTIONS(5068), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5071), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5074), 1,
      anon_sym_BQUOTE,
    ACTIONS(5077), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5083), 1,
      sym_test_operator,
    ACTIONS(5086), 1,
      sym__brace_start,
    STATE(3136), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5059), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(5080), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1000), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2167), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(2655), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2169), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [38555] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5089), 1,
      sym_word,
    ACTIONS(5091), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5093), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5095), 1,
      anon_sym_DOLLAR,
    ACTIONS(5097), 1,
      sym__special_character,
    ACTIONS(5099), 1,
      anon_sym_DQUOTE,
    ACTIONS(5103), 1,
      aux_sym_number_token1,
    ACTIONS(5105), 1,
      aux_sym_number_token2,
    ACTIONS(5107), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5109), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5111), 1,
      anon_sym_BQUOTE,
    ACTIONS(5113), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5117), 1,
      sym_test_operator,
    ACTIONS(5119), 1,
      sym__brace_start,
    STATE(5261), 1,
      aux_sym__literal_repeat1,
    STATE(5482), 1,
      sym_concatenation,
    ACTIONS(5101), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(5115), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2271), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(5141), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2273), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [38648] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(4145), 1,
      sym_variable_name,
    STATE(1694), 1,
      sym_string,
    ACTIONS(4143), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4141), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38713] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5091), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5093), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5095), 1,
      anon_sym_DOLLAR,
    ACTIONS(5097), 1,
      sym__special_character,
    ACTIONS(5099), 1,
      anon_sym_DQUOTE,
    ACTIONS(5103), 1,
      aux_sym_number_token1,
    ACTIONS(5105), 1,
      aux_sym_number_token2,
    ACTIONS(5107), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5109), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5111), 1,
      anon_sym_BQUOTE,
    ACTIONS(5113), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5119), 1,
      sym__brace_start,
    ACTIONS(5121), 1,
      sym_word,
    ACTIONS(5125), 1,
      sym_test_operator,
    STATE(5279), 1,
      aux_sym__literal_repeat1,
    STATE(5506), 1,
      sym_concatenation,
    ACTIONS(5115), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(5123), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(2275), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(5148), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2277), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [38806] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(4145), 1,
      sym_variable_name,
    STATE(1694), 1,
      sym_string,
    ACTIONS(4143), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4141), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38871] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5127), 1,
      sym__special_character,
    STATE(1005), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38930] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3986), 1,
      sym_variable_name,
    STATE(1710), 1,
      sym_string,
    ACTIONS(3984), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3982), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [38995] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3986), 1,
      sym_variable_name,
    STATE(1710), 1,
      sym_string,
    ACTIONS(3984), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3982), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39060] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(985), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39121] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(986), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39237] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39347] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39457] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(986), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39518] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(985), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39579] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39689] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(986), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39750] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(985), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39811] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(986), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39872] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3980), 1,
      sym_variable_name,
    STATE(1912), 1,
      sym_string,
    ACTIONS(3978), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3976), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [39937] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3980), 1,
      sym_variable_name,
    STATE(1912), 1,
      sym_string,
    ACTIONS(3978), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(3976), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40057] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40112] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1120), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4519), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40173] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5140), 1,
      sym__special_character,
    STATE(995), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40232] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(982), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4305), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40293] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5140), 1,
      sym__special_character,
    STATE(995), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40352] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40462] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    ACTIONS(5142), 1,
      anon_sym_LPAREN,
    STATE(1076), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40525] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40580] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40745] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40800] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40910] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [40965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41020] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41130] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41185] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5149), 1,
      anon_sym_DQUOTE,
    ACTIONS(5151), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5153), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5155), 1,
      anon_sym_BQUOTE,
    ACTIONS(5157), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2337), 3,
      sym_string,
      sym_expansion,
      sym_command_substitution,
    ACTIONS(5145), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(5147), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [41252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41307] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5163), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5165), 1,
      sym_variable_name,
    STATE(6701), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(4605), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5159), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41380] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41545] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41655] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1114), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4519), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41771] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1115), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4305), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41832] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 42,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41887] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5174), 1,
      anon_sym_DQUOTE,
    ACTIONS(5178), 1,
      sym_variable_name,
    STATE(2581), 1,
      sym_string,
    ACTIONS(5176), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5172), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [41952] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5174), 1,
      anon_sym_DQUOTE,
    ACTIONS(5178), 1,
      sym_variable_name,
    STATE(2581), 1,
      sym_string,
    ACTIONS(5176), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5172), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42017] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_test_operator,
    ACTIONS(4927), 1,
      anon_sym_DQUOTE,
    ACTIONS(4931), 1,
      sym_variable_name,
    STATE(2500), 1,
      sym_string,
    ACTIONS(4929), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4925), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
  [42082] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5165), 1,
      sym_variable_name,
    ACTIONS(5182), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6701), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(4605), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5180), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42155] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_test_operator,
    ACTIONS(4927), 1,
      anon_sym_DQUOTE,
    ACTIONS(4931), 1,
      sym_variable_name,
    STATE(2500), 1,
      sym_string,
    ACTIONS(4929), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4925), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
  [42220] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4947), 1,
      anon_sym_DQUOTE,
    ACTIONS(4951), 1,
      sym_variable_name,
    STATE(2777), 1,
      sym_string,
    ACTIONS(4949), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4945), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42285] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4975), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4989), 1,
      sym__concat,
    STATE(988), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5186), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [42346] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4975), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4989), 1,
      sym__concat,
    STATE(989), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5190), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5188), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [42407] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5194), 1,
      anon_sym_DQUOTE,
    ACTIONS(5198), 1,
      sym_variable_name,
    STATE(2456), 1,
      sym_string,
    ACTIONS(5196), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5192), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42637] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42747] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5140), 1,
      sym__special_character,
    STATE(995), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4370), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42861] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42916] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4997), 1,
      sym_variable_name,
    STATE(6672), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    STATE(4492), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 7,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_LT_LT_DASH,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [42985] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5200), 1,
      sym__concat,
    STATE(895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43046] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5202), 1,
      sym__concat,
    STATE(895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43272] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43437] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5140), 1,
      sym__special_character,
    STATE(995), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4519), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43606] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43661] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43771] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5204), 1,
      sym__special_character,
    STATE(1005), 1,
      aux_sym__literal_repeat1,
    ACTIONS(276), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43830] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [43940] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4997), 1,
      sym_variable_name,
    STATE(6672), 1,
      sym_subscript,
    ACTIONS(4161), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4492), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 16,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(4157), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [44007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44062] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1114), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4370), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44123] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1115), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4443), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44184] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(986), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44245] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5165), 1,
      sym_variable_name,
    ACTIONS(5208), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6701), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(4605), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5206), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44318] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4255), 1,
      anon_sym_BQUOTE,
    ACTIONS(4997), 1,
      sym_variable_name,
    ACTIONS(5212), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6672), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4993), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(4492), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5210), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 26,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44393] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1114), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44454] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1115), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44515] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1114), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44576] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1115), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44637] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(1197), 1,
      sym_test_operator,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
  [44702] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(1191), 1,
      sym_test_operator,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
  [44767] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1120), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44828] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(982), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44889] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1120), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [44950] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(982), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45011] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45066] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45121] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5214), 1,
      sym_word,
    ACTIONS(5216), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5218), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5220), 1,
      anon_sym_DOLLAR,
    ACTIONS(5222), 1,
      sym__special_character,
    ACTIONS(5224), 1,
      anon_sym_DQUOTE,
    ACTIONS(5228), 1,
      aux_sym_number_token1,
    ACTIONS(5230), 1,
      aux_sym_number_token2,
    ACTIONS(5232), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5234), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5236), 1,
      anon_sym_BQUOTE,
    ACTIONS(5238), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5242), 1,
      sym_test_operator,
    ACTIONS(5244), 1,
      sym__brace_start,
    STATE(5266), 1,
      aux_sym__literal_repeat1,
    STATE(5461), 1,
      sym_concatenation,
    ACTIONS(5226), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(5240), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2271), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(5139), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2273), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [45214] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5170), 1,
      sym__concat,
    STATE(1114), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45275] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5216), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5218), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5220), 1,
      anon_sym_DOLLAR,
    ACTIONS(5222), 1,
      sym__special_character,
    ACTIONS(5224), 1,
      anon_sym_DQUOTE,
    ACTIONS(5228), 1,
      aux_sym_number_token1,
    ACTIONS(5230), 1,
      aux_sym_number_token2,
    ACTIONS(5232), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5234), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5236), 1,
      anon_sym_BQUOTE,
    ACTIONS(5238), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5244), 1,
      sym__brace_start,
    ACTIONS(5246), 1,
      sym_word,
    ACTIONS(5250), 1,
      sym_test_operator,
    STATE(5394), 1,
      aux_sym__literal_repeat1,
    STATE(5464), 1,
      sym_concatenation,
    ACTIONS(5240), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(5248), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(2275), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(5174), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2277), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [45368] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5252), 1,
      sym__concat,
    STATE(1116), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45429] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5254), 1,
      sym__concat,
    STATE(1116), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45490] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5259), 1,
      sym__concat,
    STATE(1116), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45551] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1120), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4370), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45612] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(982), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4443), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45673] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1120), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45734] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5262), 1,
      sym__concat,
    STATE(994), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45795] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(985), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45856] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4963), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4987), 1,
      sym__concat,
    STATE(986), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [45917] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4975), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4989), 1,
      sym__concat,
    STATE(988), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [45978] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4975), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4989), 1,
      sym__concat,
    STATE(989), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [46039] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(1075), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(276), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [46100] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(1076), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [46161] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    ACTIONS(5272), 1,
      anon_sym_LPAREN,
    STATE(1076), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [46224] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5165), 1,
      sym_variable_name,
    STATE(6701), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    STATE(4605), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 7,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_LT_LT_DASH,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [46293] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(1075), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [46354] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5165), 1,
      sym_variable_name,
    STATE(6701), 1,
      sym_subscript,
    ACTIONS(4161), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4605), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(4157), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [46421] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(1197), 1,
      sym_test_operator,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
  [46486] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3960), 1,
      anon_sym_BQUOTE,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(5277), 1,
      sym__special_character,
    ACTIONS(5279), 1,
      sym_test_operator,
    STATE(4348), 1,
      aux_sym__literal_repeat1,
    STATE(4860), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(5275), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5237), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [46577] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3944), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3956), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3960), 1,
      anon_sym_BQUOTE,
    ACTIONS(3962), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(5277), 1,
      sym__special_character,
    ACTIONS(5283), 1,
      sym_test_operator,
    STATE(4368), 1,
      aux_sym__literal_repeat1,
    STATE(4735), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(3964), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(5281), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5241), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [46668] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(1191), 1,
      sym_test_operator,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 33,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
  [46733] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5194), 1,
      anon_sym_DQUOTE,
    ACTIONS(5198), 1,
      sym_variable_name,
    STATE(2456), 1,
      sym_string,
    ACTIONS(5196), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5192), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [46798] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5165), 1,
      sym_variable_name,
    ACTIONS(5287), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6701), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(4605), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5285), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [46871] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5293), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5295), 1,
      sym__concat,
    STATE(1203), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5291), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5289), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [46931] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [46985] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5297), 1,
      sym__special_character,
    STATE(1139), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47205] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47259] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [47313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [47367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [47421] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5293), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5295), 1,
      sym__concat,
    STATE(1201), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [47481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47535] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47643] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47697] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47805] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47859] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47913] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [47967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48021] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5300), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5302), 1,
      sym__concat,
    STATE(1161), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48081] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5304), 1,
      sym__special_character,
    STATE(1159), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48193] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5300), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5307), 1,
      sym__concat,
    STATE(1166), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48253] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5300), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5309), 1,
      sym__concat,
    STATE(1166), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [48421] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5300), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5302), 1,
      sym__concat,
    STATE(1162), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48481] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5314), 1,
      sym__concat,
    STATE(1166), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48541] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48649] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5300), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5302), 1,
      sym__concat,
    STATE(1161), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [48763] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [48817] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [48925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [48979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49033] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5317), 1,
      sym_word,
    ACTIONS(5319), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5321), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5323), 1,
      anon_sym_DOLLAR,
    ACTIONS(5325), 1,
      sym__special_character,
    ACTIONS(5327), 1,
      anon_sym_DQUOTE,
    ACTIONS(5331), 1,
      aux_sym_number_token1,
    ACTIONS(5333), 1,
      aux_sym_number_token2,
    ACTIONS(5335), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5337), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5339), 1,
      anon_sym_BQUOTE,
    ACTIONS(5341), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5345), 1,
      sym_test_operator,
    ACTIONS(5347), 1,
      sym__brace_start,
    STATE(5405), 1,
      aux_sym__literal_repeat1,
    STATE(5594), 1,
      sym_concatenation,
    ACTIONS(5329), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(5343), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(2271), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(5350), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2273), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [49125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49233] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5351), 1,
      anon_sym_DQUOTE,
    ACTIONS(5355), 1,
      sym_variable_name,
    STATE(2736), 1,
      sym_string,
    ACTIONS(5353), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5349), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49297] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5351), 1,
      anon_sym_DQUOTE,
    ACTIONS(5355), 1,
      sym_variable_name,
    STATE(2736), 1,
      sym_string,
    ACTIONS(5353), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5349), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49361] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5357), 1,
      sym__special_character,
    STATE(1232), 1,
      aux_sym__literal_repeat1,
    ACTIONS(276), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49473] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5319), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5321), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5323), 1,
      anon_sym_DOLLAR,
    ACTIONS(5325), 1,
      sym__special_character,
    ACTIONS(5327), 1,
      anon_sym_DQUOTE,
    ACTIONS(5331), 1,
      aux_sym_number_token1,
    ACTIONS(5333), 1,
      aux_sym_number_token2,
    ACTIONS(5335), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5337), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5339), 1,
      anon_sym_BQUOTE,
    ACTIONS(5341), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5347), 1,
      sym__brace_start,
    ACTIONS(5359), 1,
      sym_word,
    ACTIONS(5363), 1,
      sym_test_operator,
    STATE(5413), 1,
      aux_sym__literal_repeat1,
    STATE(5589), 1,
      sym_concatenation,
    ACTIONS(5343), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(5361), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(2275), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    STATE(5397), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2277), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [49565] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49619] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49673] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1087), 1,
      sym__special_character,
    ACTIONS(5365), 1,
      sym_word,
    ACTIONS(5367), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(5369), 1,
      anon_sym_LPAREN,
    ACTIONS(5371), 1,
      anon_sym_LBRACE,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5377), 1,
      sym_test_operator,
    STATE(2363), 1,
      aux_sym__literal_repeat1,
    STATE(3217), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(5373), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6663), 2,
      sym_compound_statement,
      sym_subshell,
    STATE(2518), 3,
      sym_ternary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
    STATE(2790), 3,
      sym_binary_expression,
      sym_unary_expression,
      sym_concatenation,
    STATE(2357), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [49781] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5381), 1,
      anon_sym_DQUOTE,
    ACTIONS(5385), 1,
      sym_variable_name,
    STATE(2864), 1,
      sym_string,
    ACTIONS(5383), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5379), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49845] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5381), 1,
      anon_sym_DQUOTE,
    ACTIONS(5385), 1,
      sym_variable_name,
    STATE(2864), 1,
      sym_string,
    ACTIONS(5383), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5379), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49909] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [49963] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5293), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5295), 1,
      sym__concat,
    STATE(1201), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5389), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [50023] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5393), 1,
      sym__concat,
    STATE(1198), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50083] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50191] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5395), 1,
      sym__concat,
    STATE(1198), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50305] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4443), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5399), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5397), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50413] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5401), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5404), 1,
      sym__concat,
    STATE(1198), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50473] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1087), 1,
      sym__special_character,
    ACTIONS(5367), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(5369), 1,
      anon_sym_LPAREN,
    ACTIONS(5371), 1,
      anon_sym_LBRACE,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5407), 1,
      sym_word,
    ACTIONS(5411), 1,
      sym_test_operator,
    STATE(2345), 1,
      aux_sym__literal_repeat1,
    STATE(3217), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(5409), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6667), 2,
      sym_compound_statement,
      sym_subshell,
    STATE(2518), 3,
      sym_ternary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
    STATE(2657), 3,
      sym_binary_expression,
      sym_unary_expression,
      sym_concatenation,
    STATE(2342), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [50581] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1191), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50641] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5293), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5415), 1,
      sym__concat,
    STATE(1222), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [50701] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [50755] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5293), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5417), 1,
      sym__concat,
    STATE(1222), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [50815] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5419), 1,
      sym__concat,
    STATE(994), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50875] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5421), 1,
      sym__concat,
    STATE(994), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [50935] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1087), 1,
      sym__special_character,
    ACTIONS(5367), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(5369), 1,
      anon_sym_LPAREN,
    ACTIONS(5371), 1,
      anon_sym_LBRACE,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5423), 1,
      sym_word,
    ACTIONS(5427), 1,
      sym_test_operator,
    STATE(2373), 1,
      aux_sym__literal_repeat1,
    STATE(3217), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(5425), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6668), 2,
      sym_compound_statement,
      sym_subshell,
    STATE(2518), 3,
      sym_ternary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
    STATE(2660), 3,
      sym_binary_expression,
      sym_unary_expression,
      sym_concatenation,
    STATE(2431), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [51043] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5429), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5431), 1,
      sym__concat,
    STATE(1219), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [51103] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [51157] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [51211] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [51271] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1191), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [51331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4305), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [51385] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5429), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5433), 1,
      sym__concat,
    STATE(1219), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [51445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [51499] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1087), 1,
      sym__special_character,
    ACTIONS(5367), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(5369), 1,
      anon_sym_LPAREN,
    ACTIONS(5371), 1,
      anon_sym_LBRACE,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5435), 1,
      sym_word,
    ACTIONS(5439), 1,
      sym_test_operator,
    STATE(2366), 1,
      aux_sym__literal_repeat1,
    STATE(3217), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(5437), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6687), 2,
      sym_compound_statement,
      sym_subshell,
    STATE(2518), 3,
      sym_ternary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
    STATE(2663), 3,
      sym_binary_expression,
      sym_unary_expression,
      sym_concatenation,
    STATE(2362), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [51607] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5441), 1,
      anon_sym_DQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5445), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5447), 1,
      anon_sym_BQUOTE,
    ACTIONS(5449), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2543), 3,
      sym_string,
      sym_expansion,
      sym_command_substitution,
    ACTIONS(5145), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(5147), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [51673] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1087), 1,
      sym__special_character,
    ACTIONS(5367), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(5369), 1,
      anon_sym_LPAREN,
    ACTIONS(5371), 1,
      anon_sym_LBRACE,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5451), 1,
      sym_word,
    ACTIONS(5455), 1,
      sym_test_operator,
    STATE(2327), 1,
      aux_sym__literal_repeat1,
    STATE(3217), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(5453), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6639), 2,
      sym_compound_statement,
      sym_subshell,
    STATE(2518), 3,
      sym_ternary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
    STATE(2668), 3,
      sym_binary_expression,
      sym_unary_expression,
      sym_concatenation,
    STATE(2418), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [51781] = 30,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1087), 1,
      sym__special_character,
    ACTIONS(5367), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(5369), 1,
      anon_sym_LPAREN,
    ACTIONS(5371), 1,
      anon_sym_LBRACE,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5457), 1,
      sym_word,
    ACTIONS(5461), 1,
      sym_test_operator,
    STATE(2359), 1,
      aux_sym__literal_repeat1,
    STATE(3217), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(5459), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6666), 2,
      sym_compound_statement,
      sym_subshell,
    STATE(2518), 3,
      sym_ternary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
    STATE(2670), 3,
      sym_binary_expression,
      sym_unary_expression,
      sym_concatenation,
    STATE(2355), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [51889] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5463), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5466), 1,
      sym__concat,
    STATE(1219), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [51949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 41,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52003] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1191), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52063] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5469), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5472), 1,
      sym__concat,
    STATE(1222), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [52123] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52183] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52237] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1191), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52297] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5429), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5475), 1,
      sym__concat,
    STATE(1207), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5186), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [52357] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5429), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5475), 1,
      sym__concat,
    STATE(1213), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5190), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5188), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [52417] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52525] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5477), 1,
      sym__special_character,
    STATE(1139), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4370), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52637] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5479), 1,
      sym__special_character,
    STATE(1232), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52695] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1191), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52755] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52815] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5477), 1,
      sym__special_character,
    STATE(1139), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4519), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52927] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5482), 1,
      sym__special_character,
    STATE(1159), 1,
      aux_sym__literal_repeat1,
    ACTIONS(276), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [52985] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53039] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5429), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5475), 1,
      sym__concat,
    STATE(1207), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [53099] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [53213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [53321] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(1197), 1,
      sym_test_operator,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 32,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_TILDE,
  [53385] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5477), 1,
      sym__special_character,
    STATE(1139), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53605] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53659] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(1191), 1,
      sym_test_operator,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 32,
      anon_sym_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_TILDE,
  [53723] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53777] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53831] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [53993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54047] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54101] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5477), 1,
      sym__special_character,
    STATE(1139), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54375] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54429] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5429), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5475), 1,
      sym__concat,
    STATE(1207), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [54489] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5429), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5475), 1,
      sym__concat,
    STATE(1213), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [54549] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54609] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5486), 1,
      anon_sym_DQUOTE,
    ACTIONS(5490), 1,
      sym_variable_name,
    STATE(2462), 1,
      sym_string,
    ACTIONS(5488), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5484), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54673] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54727] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4370), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54787] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1205), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4443), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54847] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5486), 1,
      anon_sym_DQUOTE,
    ACTIONS(5490), 1,
      sym_variable_name,
    STATE(2462), 1,
      sym_string,
    ACTIONS(5488), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5484), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [54965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [55073] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4519), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55133] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1205), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4305), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55193] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [55247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [55301] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55361] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1205), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55421] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55481] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1205), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55541] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55601] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55655] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 7,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [55763] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [55817] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [55871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [55925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [55979] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5413), 1,
      sym__concat,
    STATE(1194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56039] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5492), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5494), 1,
      sym__concat,
    STATE(1401), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [56151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [56204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [56257] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56310] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5496), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5498), 1,
      sym__concat,
    STATE(1462), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56369] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [56422] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [56475] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56528] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1381), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [56746] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5507), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5513), 1,
      anon_sym_DOLLAR,
    ACTIONS(5516), 1,
      sym__special_character,
    ACTIONS(5519), 1,
      anon_sym_DQUOTE,
    ACTIONS(5522), 1,
      aux_sym_number_token1,
    ACTIONS(5525), 1,
      aux_sym_number_token2,
    ACTIONS(5528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5531), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5534), 1,
      anon_sym_BQUOTE,
    ACTIONS(5537), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5543), 1,
      sym_test_operator,
    ACTIONS(5546), 1,
      sym__brace_start,
    STATE(3369), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2169), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5540), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1305), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(5504), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(3082), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2167), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [56835] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1353), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56894] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1381), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [56953] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57112] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5492), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5494), 1,
      sym__concat,
    STATE(1352), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [57171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57224] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [57277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57330] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57383] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57436] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5496), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5549), 1,
      sym__concat,
    STATE(1297), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [57495] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [57548] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57601] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5551), 1,
      sym__special_character,
    STATE(1423), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [57658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [57711] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1353), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [57770] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5553), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5555), 1,
      sym__concat,
    STATE(1326), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5389), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57829] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5553), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5555), 1,
      sym__concat,
    STATE(1338), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5291), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5289), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [57888] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1381), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [57947] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5553), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5557), 1,
      sym__concat,
    STATE(1345), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58165] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4443), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58271] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5399), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5397), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58324] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58377] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5559), 1,
      sym__special_character,
    STATE(1397), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4370), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58434] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58487] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58540] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5551), 1,
      sym__special_character,
    STATE(1423), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58597] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5553), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5565), 1,
      sym__concat,
    STATE(1345), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58762] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1353), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [58874] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58927] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1381), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [58986] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5567), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5570), 1,
      sym__concat,
    STATE(1345), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [59045] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5496), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5549), 1,
      sym__concat,
    STATE(1297), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59104] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4305), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59157] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5496), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5549), 1,
      sym__concat,
    STATE(1393), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59216] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59322] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [59375] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5492), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5573), 1,
      sym__concat,
    STATE(1421), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59434] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5575), 1,
      sym__concat,
    STATE(1389), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59493] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1418), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59552] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1420), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59611] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1353), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59670] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1381), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59782] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [59835] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5559), 1,
      sym__special_character,
    STATE(1397), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [59945] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1353), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60004] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5502), 1,
      sym__concat,
    STATE(1381), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60063] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60116] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60169] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5559), 1,
      sym__special_character,
    STATE(1397), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60226] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1444), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5186), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60285] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1454), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5190), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5188), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60397] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1420), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60456] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5585), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5587), 1,
      sym__concat,
    STATE(1372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60515] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5585), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5589), 1,
      sym__concat,
    STATE(1378), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60574] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1418), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60633] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1420), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60692] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5585), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5591), 1,
      sym__concat,
    STATE(1378), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60751] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1444), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60810] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1454), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60869] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5593), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5596), 1,
      sym__concat,
    STATE(1378), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [60928] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5492), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5494), 1,
      sym__concat,
    STATE(1352), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [60987] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61040] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5500), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5599), 1,
      sym__concat,
    STATE(1389), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61099] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1418), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61158] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61264] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5601), 1,
      anon_sym_DQUOTE,
    ACTIONS(5603), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5605), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5607), 1,
      anon_sym_BQUOTE,
    ACTIONS(5609), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2594), 3,
      sym_string,
      sym_expansion,
      sym_command_substitution,
    ACTIONS(5145), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(5147), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [61329] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1420), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61388] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5611), 1,
      sym__special_character,
    STATE(1424), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61498] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5613), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5616), 1,
      sym__concat,
    STATE(1389), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61557] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5621), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5623), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5625), 1,
      anon_sym_DOLLAR,
    ACTIONS(5627), 1,
      sym__special_character,
    ACTIONS(5629), 1,
      anon_sym_DQUOTE,
    ACTIONS(5631), 1,
      aux_sym_number_token1,
    ACTIONS(5633), 1,
      aux_sym_number_token2,
    ACTIONS(5635), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5637), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5639), 1,
      anon_sym_BQUOTE,
    ACTIONS(5641), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5645), 1,
      sym_test_operator,
    ACTIONS(5647), 1,
      sym__brace_start,
    STATE(3369), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5643), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1305), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(5619), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(3082), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [61646] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5551), 1,
      sym__special_character,
    STATE(1423), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61703] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [61756] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5496), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5649), 1,
      sym__concat,
    STATE(1462), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61815] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61868] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5559), 1,
      sym__special_character,
    STATE(1397), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4519), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [61925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [61978] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5651), 1,
      sym__special_character,
    STATE(1397), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62035] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62088] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62141] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62194] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5492), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5654), 1,
      sym__concat,
    STATE(1421), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62253] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5553), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5555), 1,
      sym__concat,
    STATE(1326), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [62312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [62418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [62524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62683] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5656), 1,
      sym__special_character,
    STATE(1410), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [62740] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5551), 1,
      sym__special_character,
    STATE(1423), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62797] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5611), 1,
      sym__special_character,
    STATE(1424), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4370), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62854] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [62907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [62960] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [63013] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1418), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [63125] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5659), 1,
      sym__concat,
    STATE(1430), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [63237] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5661), 1,
      sym__concat,
    STATE(1430), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63296] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5666), 1,
      sym__concat,
    STATE(1421), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63355] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1420), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63414] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5669), 1,
      sym__special_character,
    STATE(1423), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63471] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5672), 1,
      sym__special_character,
    STATE(1424), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63528] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5675), 1,
      sym__special_character,
    STATE(1410), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [63585] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [63638] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5675), 1,
      sym__special_character,
    STATE(1410), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5186), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [63695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63748] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5621), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5623), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5625), 1,
      anon_sym_DOLLAR,
    ACTIONS(5627), 1,
      sym__special_character,
    ACTIONS(5629), 1,
      anon_sym_DQUOTE,
    ACTIONS(5631), 1,
      aux_sym_number_token1,
    ACTIONS(5633), 1,
      aux_sym_number_token2,
    ACTIONS(5635), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5637), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5639), 1,
      anon_sym_BQUOTE,
    ACTIONS(5641), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5645), 1,
      sym_test_operator,
    ACTIONS(5647), 1,
      sym__brace_start,
    STATE(3369), 1,
      aux_sym__literal_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5643), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1305), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(5619), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(3082), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [63837] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5677), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5680), 1,
      sym__concat,
    STATE(1430), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1240), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [63949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [64002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64161] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5611), 1,
      sym__special_character,
    STATE(1424), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4519), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64218] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5585), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5587), 1,
      sym__concat,
    STATE(1372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5186), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [64277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64330] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64383] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [64542] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1444), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [64601] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5683), 1,
      sym__concat,
    STATE(1461), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [64660] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5585), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5587), 1,
      sym__concat,
    STATE(1375), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5190), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5188), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [64719] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5585), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5587), 1,
      sym__concat,
    STATE(1372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [64778] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5585), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5587), 1,
      sym__concat,
    STATE(1375), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [64837] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5551), 1,
      sym__special_character,
    STATE(1423), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [64947] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1418), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [65059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65165] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5685), 1,
      sym__concat,
    STATE(1461), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [65224] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65277] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1420), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65336] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5551), 1,
      sym__special_character,
    STATE(1423), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65393] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [65446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 40,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [65552] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5691), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5694), 1,
      sym__concat,
    STATE(1461), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [65611] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5697), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5700), 1,
      sym__concat,
    STATE(1462), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65670] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5611), 1,
      sym__special_character,
    STATE(1424), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65727] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5703), 1,
      sym__special_character,
    STATE(1474), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5389), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [65783] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [65835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [65939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [65991] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5629), 1,
      anon_sym_DQUOTE,
    ACTIONS(5713), 1,
      sym_variable_name,
    STATE(3346), 1,
      sym_string,
    ACTIONS(5711), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5709), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 28,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66053] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5629), 1,
      anon_sym_DQUOTE,
    ACTIONS(5713), 1,
      sym_variable_name,
    STATE(3346), 1,
      sym_string,
    ACTIONS(5711), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5709), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 28,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66115] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5715), 1,
      sym__special_character,
    STATE(1514), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [66171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66223] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66275] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5717), 1,
      sym__special_character,
    STATE(1474), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [66331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66383] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [66487] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66539] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66591] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5720), 1,
      sym__special_character,
    STATE(1504), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4305), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66803] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 1,
      sym__special_character,
    STATE(1484), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [66859] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [66911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [66963] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [67015] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5725), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5728), 1,
      sym__concat,
    STATE(1488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [67073] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67177] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5731), 1,
      sym__special_character,
    STATE(1484), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67233] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [67285] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67337] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67389] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67441] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5735), 1,
      sym__concat,
    STATE(1488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [67499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [67551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [67603] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67655] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67707] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5720), 1,
      sym__special_character,
    STATE(1504), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67763] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5720), 1,
      sym__special_character,
    STATE(1504), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67819] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [67871] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5737), 1,
      sym__special_character,
    STATE(1504), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [67979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [68031] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68083] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5720), 1,
      sym__special_character,
    STATE(1504), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [68191] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5740), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5742), 1,
      sym__concat,
    STATE(1515), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68249] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68353] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5740), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5744), 1,
      sym__concat,
    STATE(1515), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68411] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 1,
      sym__special_character,
    STATE(1514), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [68467] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5749), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5752), 1,
      sym__concat,
    STATE(1515), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68525] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [68577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [68629] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [68681] = 28,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5757), 1,
      sym_extglob_pattern,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2541), 1,
      sym__extglob_blob,
    STATE(2917), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [68783] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [68835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68887] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5740), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5759), 1,
      sym__concat,
    STATE(1510), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [68945] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5740), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5759), 1,
      sym__concat,
    STATE(1510), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69003] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5740), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5759), 1,
      sym__concat,
    STATE(1513), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69061] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69113] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69165] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69373] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69425] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69477] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69633] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [69789] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [69841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [69893] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5763), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5765), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5767), 1,
      anon_sym_DOLLAR,
    ACTIONS(5769), 1,
      sym__special_character,
    ACTIONS(5771), 1,
      anon_sym_DQUOTE,
    ACTIONS(5773), 1,
      aux_sym_number_token1,
    ACTIONS(5775), 1,
      aux_sym_number_token2,
    ACTIONS(5777), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5779), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5781), 1,
      anon_sym_BQUOTE,
    ACTIONS(5783), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5787), 1,
      sym_test_operator,
    ACTIONS(5789), 1,
      sym__brace_start,
    STATE(5595), 1,
      aux_sym__literal_repeat1,
    STATE(5612), 1,
      sym_concatenation,
    ACTIONS(2273), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5785), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(5761), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5489), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [69981] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5720), 1,
      sym__special_character,
    STATE(1504), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70037] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5763), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5765), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5767), 1,
      anon_sym_DOLLAR,
    ACTIONS(5769), 1,
      sym__special_character,
    ACTIONS(5771), 1,
      anon_sym_DQUOTE,
    ACTIONS(5773), 1,
      aux_sym_number_token1,
    ACTIONS(5775), 1,
      aux_sym_number_token2,
    ACTIONS(5777), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5779), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5781), 1,
      anon_sym_BQUOTE,
    ACTIONS(5783), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5789), 1,
      sym__brace_start,
    ACTIONS(5793), 1,
      sym_test_operator,
    STATE(5558), 1,
      aux_sym__literal_repeat1,
    STATE(5613), 1,
      sym_concatenation,
    ACTIONS(2277), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5785), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(5791), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5498), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [70125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70333] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5795), 1,
      sym__concat,
    STATE(1488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [70391] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [70443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [70495] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70703] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [70755] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70807] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70859] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [70911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [70963] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [71015] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [71067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [71119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [71171] = 28,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    ACTIONS(5799), 1,
      sym_extglob_pattern,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2842), 1,
      sym__extglob_blob,
    STATE(3011), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [71273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71325] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [71377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71429] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5803), 1,
      sym__concat,
    STATE(1583), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71487] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [71539] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [71591] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [71643] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5805), 1,
      sym__concat,
    STATE(1583), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71701] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71753] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71805] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71857] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71909] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [71961] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72065] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72117] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72221] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5807), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5810), 1,
      sym__concat,
    STATE(1583), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72279] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72331] = 28,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    ACTIONS(5815), 1,
      sym_extglob_pattern,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2644), 1,
      sym__expression,
    STATE(2645), 1,
      sym__extglob_blob,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [72433] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4305), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72537] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5817), 1,
      sym__concat,
    STATE(1568), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72595] = 28,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5757), 1,
      sym_extglob_pattern,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2541), 1,
      sym__extglob_blob,
    STATE(2969), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [72697] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5819), 1,
      sym__concat,
    STATE(1430), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72755] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5821), 1,
      sym__concat,
    STATE(1430), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [72813] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5823), 1,
      sym__concat,
    STATE(1461), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [72871] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5825), 1,
      sym__concat,
    STATE(1461), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [72929] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5827), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5829), 1,
      sym__concat,
    STATE(1626), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5389), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [72987] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5831), 1,
      sym__concat,
    STATE(895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73097] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5835), 1,
      sym__concat,
    STATE(1600), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73155] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5827), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5829), 1,
      sym__concat,
    STATE(1632), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5291), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5289), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [73213] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5837), 1,
      sym__concat,
    STATE(1600), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73271] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5839), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5842), 1,
      sym__concat,
    STATE(1600), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73329] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5847), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5849), 1,
      sym_variable_name,
    STATE(6633), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5845), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(5105), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73397] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5849), 1,
      sym_variable_name,
    ACTIONS(5852), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6633), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5845), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(5105), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73465] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(1597), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73523] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4161), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(5856), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [73579] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5715), 1,
      sym__special_character,
    STATE(1514), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5186), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [73635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4443), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73687] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5399), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5397), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73739] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5862), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73799] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5862), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73859] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5817), 1,
      sym__concat,
    STATE(1568), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73917] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5817), 1,
      sym__concat,
    STATE(1572), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [73975] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [74027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [74079] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(1496), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5389), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74137] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(1548), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5291), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5289), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74195] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74403] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74507] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74559] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5827), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5829), 1,
      sym__concat,
    STATE(1626), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74617] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [74721] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5827), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5876), 1,
      sym__concat,
    STATE(1636), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74779] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5720), 1,
      sym__special_character,
    STATE(1504), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [74835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [74887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [74991] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75043] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5827), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5878), 1,
      sym__concat,
    STATE(1636), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75101] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75205] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [75257] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5880), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5883), 1,
      sym__concat,
    STATE(1636), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75315] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [75627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [75679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [75731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [75783] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 6,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [75835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [75887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [75939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4443), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [75991] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 7,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76095] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(1597), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76153] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(1599), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5399), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5397), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76263] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76315] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [76367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [76523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [76575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76627] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1590), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76685] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76795] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1592), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5186), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [76853] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1593), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5190), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5188), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [76911] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [76969] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1590), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77027] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77085] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77137] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(1496), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [77195] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77299] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77357] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1590), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77415] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77473] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1590), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77531] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [77641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [77693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77745] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [77797] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [77849] = 28,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5757), 1,
      sym_extglob_pattern,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2541), 1,
      sym__extglob_blob,
    STATE(3250), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [77951] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1592), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [78009] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1593), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [78067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78119] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(1590), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78177] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(1592), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [78235] = 28,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5757), 1,
      sym_extglob_pattern,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2541), 1,
      sym__extglob_blob,
    STATE(2861), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [78337] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(1595), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(276), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(237), 36,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78395] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(1707), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 36,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78453] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    ACTIONS(5892), 1,
      anon_sym_LPAREN,
    STATE(1707), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1240), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1233), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78513] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [78565] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5849), 1,
      sym_variable_name,
    STATE(6633), 1,
      sym_subscript,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    STATE(5105), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4161), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4153), 27,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78631] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [78683] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(4663), 1,
      sym__concat,
    STATE(1595), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78741] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5849), 1,
      sym_variable_name,
    STATE(6633), 1,
      sym_subscript,
    ACTIONS(4161), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(5105), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78805] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78857] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78909] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [78961] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [79013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [79065] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79117] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [79169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [79221] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4661), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5895), 1,
      sym__concat,
    STATE(895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79279] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    ACTIONS(5897), 1,
      sym__regex_no_space,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2870), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [79378] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79429] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [79480] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5899), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5901), 1,
      sym__concat,
    STATE(1715), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79537] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79639] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79690] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5903), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5906), 1,
      sym__concat,
    STATE(1715), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79747] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3442), 1,
      aux_sym__literal_repeat1,
    STATE(1865), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(3373), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2156), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2158), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [79804] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [79906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [79957] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5909), 1,
      sym__special_character,
    STATE(1870), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80012] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5911), 1,
      sym__special_character,
    STATE(1721), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80067] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5914), 1,
      sym__special_character,
    STATE(1811), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80122] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5899), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5916), 1,
      sym__concat,
    STATE(1895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80383] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80434] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [80536] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [80587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [80638] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [80689] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80740] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80791] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [80842] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4155), 1,
      anon_sym_LT_LT,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5918), 1,
      sym_variable_name,
    STATE(6657), 1,
      sym_subscript,
    STATE(5135), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(4159), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_LT_DASH,
    STATE(5381), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4161), 20,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [80909] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [80960] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81011] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81062] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81113] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    ACTIONS(5921), 1,
      sym__regex_no_space,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2637), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [81212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81263] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5918), 1,
      sym_variable_name,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    STATE(6657), 1,
      sym_subscript,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    STATE(5135), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4161), 20,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [81332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81383] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3442), 1,
      aux_sym__literal_repeat1,
    STATE(1865), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(3373), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2160), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2162), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [81440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81491] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5929), 1,
      sym__concat,
    STATE(1600), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81548] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5931), 1,
      sym__concat,
    STATE(1600), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81605] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(1748), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81662] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5918), 1,
      sym_variable_name,
    STATE(6657), 1,
      sym_subscript,
    STATE(5135), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    STATE(5381), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4153), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4157), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4268), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
    ACTIONS(4161), 14,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [81725] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81776] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5935), 1,
      sym__concat,
    STATE(1759), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81833] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2944), 1,
      sym__expression,
    STATE(7403), 1,
      sym__test_command_binary_expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [81932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [81983] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5937), 1,
      sym__special_character,
    STATE(1827), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [82038] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5939), 1,
      sym__concat,
    STATE(1759), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [82095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [82146] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5941), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5944), 1,
      sym__concat,
    STATE(1759), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [82203] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(1748), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [82260] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(1749), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [82317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [82368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [82419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [82470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [82521] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5947), 1,
      sym__concat,
    STATE(1488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [82578] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5949), 1,
      sym__concat,
    STATE(1488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [82635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [82686] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2983), 1,
      sym__expression,
    STATE(6937), 1,
      sym__test_command_binary_expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [82785] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5897), 1,
      sym__regex_no_space,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2962), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [82884] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5937), 1,
      sym__special_character,
    STATE(1827), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5186), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [82939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [82990] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [83041] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83245] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5951), 1,
      sym__concat,
    STATE(994), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83302] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5953), 1,
      sym__concat,
    STATE(994), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83410] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(3006), 1,
      sym__expression,
    STATE(7112), 1,
      sym__test_command_binary_expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [83509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83611] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83662] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2806), 1,
      sym__expression,
    STATE(7232), 1,
      sym__test_command_binary_expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [83761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83812] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5955), 1,
      sym__special_character,
    STATE(1868), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83867] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [83918] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2812), 1,
      sym__expression,
    STATE(7319), 1,
      sym__test_command_binary_expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [84017] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5955), 1,
      sym__special_character,
    STATE(1868), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84072] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(1753), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84129] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84180] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2819), 1,
      sym__expression,
    STATE(7372), 1,
      sym__test_command_binary_expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [84279] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84330] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84483] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2825), 1,
      sym__expression,
    STATE(6817), 1,
      sym__test_command_binary_expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [84582] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5899), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5916), 1,
      sym__concat,
    STATE(1895), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84639] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5899), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5916), 1,
      sym__concat,
    STATE(1711), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84696] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5959), 1,
      sym__special_character,
    STATE(1843), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5389), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [84751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84802] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5955), 1,
      sym__special_character,
    STATE(1868), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84857] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [84908] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2885), 1,
      sym__expression,
    STATE(6919), 1,
      sym__test_command_binary_expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [85007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85160] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5955), 1,
      sym__special_character,
    STATE(1868), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85215] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85266] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5961), 1,
      sym__special_character,
    STATE(1811), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85372] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4161), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(5856), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [85427] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5909), 1,
      sym__special_character,
    STATE(1870), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85482] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85533] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85635] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5955), 1,
      sym__special_character,
    STATE(1868), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85690] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5955), 1,
      sym__special_character,
    STATE(1868), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85745] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5964), 1,
      sym__special_character,
    STATE(1892), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5186), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [85800] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85851] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85902] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 11,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [85961] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 11,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86020] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5909), 1,
      sym__special_character,
    STATE(1870), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86126] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5966), 1,
      sym__special_character,
    STATE(1827), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86181] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5964), 1,
      sym__special_character,
    STATE(1892), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86389] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86491] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5909), 1,
      sym__special_character,
    STATE(1870), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86546] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86597] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [86801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86852] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86903] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [86954] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5969), 1,
      sym__special_character,
    STATE(1843), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87111] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [87162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87264] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5972), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5974), 1,
      sym__concat,
    STATE(1878), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [87321] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(1753), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [87378] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(1757), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [87435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87537] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87639] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [87792] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87843] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87945] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [87996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [88047] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [88098] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5976), 1,
      sym_word,
    ACTIONS(5979), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5982), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5985), 1,
      anon_sym_DOLLAR,
    ACTIONS(5988), 1,
      sym__special_character,
    ACTIONS(5991), 1,
      anon_sym_DQUOTE,
    ACTIONS(5997), 1,
      aux_sym_number_token1,
    ACTIONS(6000), 1,
      aux_sym_number_token2,
    ACTIONS(6003), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6006), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6009), 1,
      anon_sym_BQUOTE,
    ACTIONS(6012), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6018), 1,
      sym_test_operator,
    ACTIONS(6021), 1,
      sym__brace_start,
    STATE(3442), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5994), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(6015), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1865), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2167), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2169), 8,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    STATE(3373), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [88187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [88238] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1849), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5972), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(237), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(276), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [88293] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6024), 1,
      sym__special_character,
    STATE(1868), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [88348] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5972), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6027), 1,
      sym__concat,
    STATE(1878), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [88405] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6029), 1,
      sym__special_character,
    STATE(1870), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [88460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [88511] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [88562] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    ACTIONS(6032), 1,
      sym__regex_no_space,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2870), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [88661] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [88712] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(1766), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5389), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [88769] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(1767), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5291), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5289), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [88826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [88877] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1878), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6034), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [88932] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1869), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5972), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1233), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1240), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [88987] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [89038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [89089] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1334), 1,
      anon_sym_LPAREN,
    STATE(1869), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5972), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1233), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1240), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [89146] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5897), 1,
      sym__regex_no_space,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3243), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [89245] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5897), 1,
      sym__regex_no_space,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2910), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [89344] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5909), 1,
      sym__special_character,
    STATE(1870), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [89399] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1849), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5972), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [89454] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(1766), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [89511] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 39,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [89562] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1778), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4370), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4368), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [89619] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1779), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4443), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4441), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [89676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [89727] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6037), 1,
      sym__special_character,
    STATE(1892), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [89782] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1778), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4519), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4517), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [89839] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1779), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4305), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4303), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [89896] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5899), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6040), 1,
      sym__concat,
    STATE(1715), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [89953] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [90004] = 27,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    ACTIONS(6042), 1,
      sym__regex_no_space,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(3002), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [90103] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1778), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90160] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1779), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90217] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1778), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90274] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1779), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90331] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4959), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5138), 1,
      sym__concat,
    STATE(1778), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90388] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      sym__special_character,
    STATE(1721), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [90494] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5909), 1,
      sym__special_character,
    STATE(1870), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90549] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90600] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6046), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90660] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6049), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90720] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6052), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90830] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [90880] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [90930] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2939), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [91026] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1934), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4517), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4519), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [91080] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(3013), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [91176] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1970), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4303), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4305), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [91230] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2961), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [91326] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2995), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [91422] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2963), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [91518] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2955), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [91614] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2964), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [91710] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2965), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [91806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [91856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [91906] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3451), 1,
      aux_sym__literal_repeat1,
    STATE(3516), 1,
      sym_concatenation,
    STATE(3374), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2275), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2277), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [91962] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2966), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [92058] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2967), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [92154] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2968), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [92250] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(3005), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [92346] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(1991), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [92402] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(1992), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [92458] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2970), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [92554] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [92604] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6055), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6057), 1,
      sym__concat,
    STATE(2044), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [92660] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2971), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [92756] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [92806] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2545), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [92902] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2954), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [92998] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6059), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [93058] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3174), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93154] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2636), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93250] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2637), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [93396] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2972), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93492] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2973), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93588] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2638), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93684] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2974), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93780] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2639), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93876] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2640), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [93972] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [94022] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [94072] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2987), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [94168] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [94218] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2988), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [94314] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2641), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [94410] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [94460] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2642), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [94556] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2643), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [94652] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2646), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [94748] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2647), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [94844] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2648), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [94940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [94990] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2649), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [95086] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2650), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [95182] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2946), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [95278] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2750), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [95374] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2911), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [95470] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6062), 1,
      sym__special_character,
    STATE(2072), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5389), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [95524] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [95574] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6055), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6064), 1,
      sym__concat,
    STATE(2044), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [95630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [95680] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3012), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [95776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [95826] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3015), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [95922] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [95972] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2962), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [96068] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2873), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [96164] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2912), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [96260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [96310] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2979), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [96406] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [96456] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [96506] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2914), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [96602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [96652] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [96702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [96752] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [96802] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [96852] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2870), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [96948] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [96998] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6066), 1,
      sym__concat,
    STATE(1759), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97054] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6068), 1,
      sym__concat,
    STATE(1759), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97110] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2913), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [97206] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [97256] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(1991), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97362] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [97412] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2915), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [97508] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6070), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97568] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2990), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [97664] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6073), 1,
      sym__special_character,
    STATE(2001), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97718] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97768] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [97818] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97868] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [97918] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [97968] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98018] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98118] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98168] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98218] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2626), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [98314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98414] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2627), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [98510] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6076), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98620] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98678] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98836] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [98936] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [98986] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2957), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [99082] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6079), 1,
      sym__special_character,
    STATE(2026), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99136] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6082), 1,
      sym__special_character,
    STATE(2026), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99240] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [99290] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4161), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(5856), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [99344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99394] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2545), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [99490] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2958), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [99586] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99636] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6084), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [99896] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2948), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [99992] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(1071), 1,
      sym_word,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_BANG,
    ACTIONS(1083), 1,
      anon_sym_TILDE,
    ACTIONS(1093), 1,
      sym_test_operator,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5813), 1,
      sym__special_character,
    STATE(2407), 1,
      aux_sym__literal_repeat1,
    STATE(2625), 1,
      sym__expression,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1079), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1081), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1089), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2608), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2403), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [100088] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6087), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1215), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [100142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [100192] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2044), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6090), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [100246] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6093), 1,
      sym__special_character,
    STATE(2087), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5389), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [100300] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2545), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [100396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [100446] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2992), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [100542] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6095), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [100602] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2843), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [100698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [100748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [100798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [100848] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [100898] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [100948] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [100998] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6098), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [101058] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2952), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [101154] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [101204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [101254] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6101), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [101314] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [101364] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [101414] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(3016), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [101510] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [101560] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2916), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [101656] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(3003), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [101752] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6104), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [101812] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 6,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [101862] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6107), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [101922] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2920), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [102018] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6110), 1,
      sym__special_character,
    STATE(2072), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [102072] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6113), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [102132] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6116), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [102192] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6119), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [102252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [102302] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6122), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [102362] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1934), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [102416] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(3001), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [102512] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2875), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [102608] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6125), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [102668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [102718] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6128), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [102778] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6131), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [102838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [102888] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6134), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [102948] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6137), 1,
      sym__special_character,
    STATE(2087), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [103002] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6140), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103062] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2918), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [103158] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6143), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103218] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6146), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103278] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6149), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103338] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6152), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103398] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6155), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103458] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6158), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103518] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6161), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103578] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6164), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103638] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6167), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103698] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2804), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [103794] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6170), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103854] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6173), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103914] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6176), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [103974] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6179), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104034] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6182), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104094] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6185), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104154] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6188), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104214] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6191), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104274] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6194), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104334] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6197), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104394] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6200), 1,
      sym__special_character,
    STATE(2149), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104448] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [104498] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6202), 1,
      sym__special_character,
    STATE(2001), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [104552] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1934), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4280), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4282), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [104606] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1970), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4437), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4439), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [104660] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2844), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [104756] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1934), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4307), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4309), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [104810] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1970), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4311), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4313), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [104864] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2894), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [104960] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2853), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [105056] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2855), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [105152] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4161), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5858), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4153), 17,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(5856), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [105206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 6,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [105256] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6204), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [105316] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6207), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [105376] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5867), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [105434] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2887), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [105530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [105580] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6210), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [105640] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2900), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [105736] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6213), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [105796] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2840), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [105892] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2910), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [105988] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2904), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [106084] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6216), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [106144] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2883), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [106240] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6219), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [106300] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [106350] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3018), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [106446] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6222), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [106506] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6225), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [106566] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6228), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [106626] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1934), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4368), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4370), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [106680] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6231), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [106740] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [106790] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2922), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [106886] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6234), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [106946] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2884), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [107042] = 6,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3427), 1,
      aux_sym__literal_repeat1,
    STATE(3692), 1,
      sym_concatenation,
    STATE(3361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
    ACTIONS(2271), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2273), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [107098] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6237), 1,
      sym__special_character,
    STATE(2149), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [107152] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [107202] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6240), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [107262] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2895), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [107358] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6243), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [107418] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2851), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [107514] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2909), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [107610] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6246), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [107670] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2923), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [107766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [107816] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3242), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [107912] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3245), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108008] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3246), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108104] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3247), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108200] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3248), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108296] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3249), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108392] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6249), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [108452] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3019), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108548] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3252), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108644] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3253), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108740] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3254), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108836] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3255), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [108932] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6252), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [108992] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(105), 1,
      anon_sym_TILDE,
    ACTIONS(235), 1,
      sym_word,
    ACTIONS(246), 1,
      anon_sym_BANG,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(280), 1,
      sym_test_operator,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1115), 1,
      sym__special_character,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2997), 1,
      sym__expression,
    ACTIONS(101), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(103), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1119), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2344), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [109088] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3259), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [109184] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6255), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [109244] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(3002), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [109340] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6258), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [109400] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(1970), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6055), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4441), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4443), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [109454] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2854), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [109550] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 27,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [109600] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2857), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [109696] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2862), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [109792] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6261), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [109852] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6264), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [109912] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(2545), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [110008] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3260), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [110104] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1147), 1,
      sym_word,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    ACTIONS(1155), 1,
      anon_sym_TILDE,
    ACTIONS(1157), 1,
      sym__special_character,
    ACTIONS(1161), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3004), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1151), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1153), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1159), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2381), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [110200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [110250] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2867), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [110346] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6267), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [110406] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      sym_word,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_BANG,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(395), 1,
      sym_test_operator,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(5797), 1,
      sym__special_character,
    STATE(2549), 1,
      aux_sym__literal_repeat1,
    STATE(2868), 1,
      sym__expression,
    ACTIONS(181), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(183), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(379), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2847), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [110502] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2886), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [110598] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6270), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [110658] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6273), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [110718] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6276), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [110778] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [110828] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6279), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [110888] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6282), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [110948] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6285), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111008] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6288), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111068] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6291), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111128] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6294), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111188] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6297), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111248] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6300), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111308] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6303), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111368] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6306), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111428] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6309), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111488] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5867), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111546] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6312), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111606] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2903), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [111702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111752] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6315), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [111812] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1127), 1,
      sym_word,
    ACTIONS(1129), 1,
      anon_sym_BANG,
    ACTIONS(1135), 1,
      anon_sym_TILDE,
    ACTIONS(1141), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(5890), 1,
      sym__special_character,
    STATE(2451), 1,
      aux_sym__literal_repeat1,
    STATE(2938), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1131), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1133), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1139), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2361), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [111908] = 26,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1107), 1,
      anon_sym_LPAREN,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1167), 1,
      sym_word,
    ACTIONS(1169), 1,
      anon_sym_BANG,
    ACTIONS(1175), 1,
      anon_sym_TILDE,
    ACTIONS(1177), 1,
      sym__special_character,
    ACTIONS(1181), 1,
      sym_test_operator,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    STATE(2312), 1,
      aux_sym__literal_repeat1,
    STATE(3243), 1,
      sym__expression,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(1171), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(1173), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    ACTIONS(1179), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2518), 6,
      sym_binary_expression,
      sym_ternary_expression,
      sym_unary_expression,
      sym_postfix_expression,
      sym_parenthesized_expression,
      sym_concatenation,
    STATE(2557), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [112004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 38,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [112054] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6318), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [112114] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(6321), 1,
      anon_sym_RPAREN,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5860), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [112174] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6324), 1,
      sym__special_character,
    STATE(2217), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [112227] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [112276] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1254), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112325] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [112374] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [112423] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [112472] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1286), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112521] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1215), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112570] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1262), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112619] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1314), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112668] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1270), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112717] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2273), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2156), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(2158), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [112770] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1310), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112819] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1274), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112868] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2275), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4280), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4282), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [112921] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1278), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [112970] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1290), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113019] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [113117] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1282), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113166] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113215] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2273), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4437), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4439), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [113268] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113317] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113366] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113415] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113464] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113513] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 27,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      aux_sym_concatenation_token1,
  [113562] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [113611] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2417), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1085), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 15,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      sym__special_character,
    ACTIONS(1225), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [113664] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [113713] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [113762] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6329), 1,
      sym__special_character,
    STATE(2249), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [113815] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2273), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2160), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(2162), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [113868] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [113917] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2275), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4307), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4309), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [113970] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6332), 1,
      sym__special_character,
    STATE(2217), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [114023] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6334), 1,
      sym__concat,
    STATE(1430), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [114078] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6336), 1,
      sym__concat,
    STATE(1430), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [114133] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6338), 1,
      sym__concat,
    STATE(1461), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [114188] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6340), 1,
      sym__concat,
    STATE(1461), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [114243] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114292] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    STATE(2317), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1223), 15,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      sym__special_character,
    ACTIONS(1225), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [114345] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114394] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114443] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6344), 1,
      anon_sym_DQUOTE,
    ACTIONS(6348), 1,
      sym_variable_name,
    STATE(3422), 1,
      sym_string,
    ACTIONS(6346), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1191), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(6342), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 25,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [114502] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114551] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2264), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6350), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114604] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114653] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114702] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114751] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
    ACTIONS(5860), 15,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [114808] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5867), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5869), 1,
      sym_file_descriptor,
    ACTIONS(5872), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(5862), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5864), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
    ACTIONS(5860), 15,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [114865] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2275), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114918] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [114967] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [115016] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6327), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6353), 1,
      sym__concat,
    STATE(2264), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [115071] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [115120] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6327), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6355), 1,
      sym__concat,
    STATE(2264), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [115175] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [115224] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2314), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1113), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1225), 24,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      sym__special_character,
  [115277] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [115326] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6357), 1,
      sym__special_character,
    STATE(2280), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [115379] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6359), 1,
      sym__special_character,
    STATE(2280), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 34,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [115432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 37,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [115481] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2275), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5130), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5132), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [115534] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2273), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5134), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5136), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [115587] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2396), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1113), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1225), 24,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      sym__special_character,
  [115640] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4161), 3,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(4153), 16,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
    ACTIONS(5856), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [115693] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2254), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [115748] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2255), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [115803] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(2256), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5186), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5184), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [115858] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(2257), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5190), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5188), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [115913] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2255), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [115968] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2254), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116023] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2255), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116078] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2255), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116133] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2254), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116188] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2255), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116243] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2254), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116298] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2255), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116353] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116402] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2421), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1113), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 15,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      sym__special_character,
    ACTIONS(1225), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [116455] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(2256), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [116510] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(2257), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [116565] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 15,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 26,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [116614] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5577), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5579), 1,
      sym__concat,
    STATE(2254), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116669] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5583), 1,
      sym__concat,
    STATE(2256), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [116724] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6344), 1,
      anon_sym_DQUOTE,
    ACTIONS(6348), 1,
      sym_variable_name,
    STATE(3422), 1,
      sym_string,
    ACTIONS(6346), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1197), 3,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(6342), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 25,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [116783] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2273), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6327), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4311), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4313), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [116836] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6362), 1,
      sym__special_character,
    STATE(2249), 1,
      aux_sym__literal_repeat1,
    ACTIONS(237), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(276), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [116889] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(2310), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [116943] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2330), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1085), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [116995] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6364), 1,
      sym__concat,
    STATE(1488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [117049] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6366), 1,
      sym__concat,
    STATE(1488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [117103] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6368), 1,
      sym__special_character,
    STATE(2409), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 24,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [117155] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 26,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [117203] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1113), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6370), 1,
      sym__concat,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1229), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [117257] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1113), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6372), 1,
      sym__concat,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1209), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [117311] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [117359] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6374), 1,
      sym__concat,
    STATE(2332), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1229), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [117413] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [117461] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [117509] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6382), 1,
      anon_sym_esac,
    ACTIONS(6384), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7162), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3320), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6378), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [117603] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2420), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6416), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5188), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5190), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [117655] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6420), 1,
      anon_sym_esac,
    ACTIONS(6422), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6805), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3330), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6418), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [117749] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6424), 1,
      sym__special_character,
    STATE(2349), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4280), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4282), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [117801] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6426), 1,
      sym__concat,
    STATE(2332), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1209), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [117855] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6428), 1,
      sym__special_character,
    STATE(2325), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1318), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [117907] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6433), 1,
      anon_sym_esac,
    ACTIONS(6435), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6807), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3331), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6431), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [118001] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1095), 1,
      anon_sym_RBRACK,
    ACTIONS(6437), 1,
      sym__special_character,
    ACTIONS(6439), 1,
      sym__concat,
    STATE(2325), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [118057] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [118105] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6424), 1,
      sym__special_character,
    STATE(2349), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4307), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4309), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [118157] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6441), 1,
      sym__concat,
    STATE(2332), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1209), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [118211] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6445), 1,
      anon_sym_esac,
    ACTIONS(6447), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7165), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3322), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6443), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [118305] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2332), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6449), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1215), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [118357] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [118405] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6454), 1,
      anon_sym_esac,
    ACTIONS(6456), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7066), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3300), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6452), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [118499] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2364), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5134), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5136), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [118551] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6462), 1,
      anon_sym_esac,
    ACTIONS(6464), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7340), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3299), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6460), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [118645] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6470), 1,
      sym_extglob_pattern,
    ACTIONS(6466), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6468), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [118695] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [118743] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [118791] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 26,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [118839] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [118887] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6472), 1,
      anon_sym_RBRACK,
    ACTIONS(6474), 1,
      sym__concat,
    STATE(2324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [118943] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [118991] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2315), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1113), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [119043] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1077), 1,
      anon_sym_RBRACK,
    ACTIONS(6437), 1,
      sym__special_character,
    ACTIONS(6476), 1,
      sym__concat,
    STATE(2325), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [119099] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2364), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5268), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5270), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119151] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119199] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 26,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [119247] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6478), 1,
      sym__special_character,
    STATE(2349), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119299] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2376), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6481), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 5,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 35,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [119399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 36,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [119447] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119495] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2398), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6416), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1225), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119547] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6483), 1,
      anon_sym_RBRACK,
    ACTIONS(6485), 1,
      sym__concat,
    STATE(2324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [119603] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6458), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6487), 1,
      sym__concat,
    STATE(2368), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119657] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6489), 1,
      anon_sym_RBRACK,
    ACTIONS(6491), 1,
      sym__concat,
    STATE(2324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [119713] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119761] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1143), 1,
      anon_sym_RBRACK,
    ACTIONS(6437), 1,
      sym__special_character,
    ACTIONS(6493), 1,
      sym__concat,
    STATE(2325), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [119817] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [119865] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2386), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1113), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [119917] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6495), 1,
      anon_sym_RBRACK,
    ACTIONS(6497), 1,
      sym__concat,
    STATE(2324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [119973] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1163), 1,
      anon_sym_RBRACK,
    ACTIONS(6437), 1,
      sym__special_character,
    ACTIONS(6499), 1,
      sym__concat,
    STATE(2325), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [120029] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6458), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6501), 1,
      sym__concat,
    STATE(2368), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120083] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2365), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6503), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1215), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120135] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1103), 1,
      anon_sym_RBRACK,
    ACTIONS(6437), 1,
      sym__special_character,
    ACTIONS(6506), 1,
      sym__concat,
    STATE(2325), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [120191] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2398), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6416), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5264), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5266), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120243] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2368), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6508), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120295] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2356), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120347] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120395] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2420), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6416), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5268), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5270), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120447] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120495] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1099), 1,
      anon_sym_RBRACK,
    ACTIONS(6437), 1,
      sym__special_character,
    ACTIONS(6511), 1,
      sym__concat,
    STATE(2325), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [120551] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6515), 1,
      anon_sym_esac,
    ACTIONS(6517), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6789), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3327), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6513), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [120645] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6521), 1,
      anon_sym_esac,
    ACTIONS(6523), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7000), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3302), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6519), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [120739] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6481), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6525), 1,
      sym__concat,
    STATE(2406), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [120793] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6529), 1,
      anon_sym_esac,
    ACTIONS(6531), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7003), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3303), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6527), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [120887] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6535), 1,
      anon_sym_esac,
    ACTIONS(6537), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6792), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3328), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6533), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [120981] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6541), 1,
      anon_sym_esac,
    ACTIONS(6543), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7366), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3336), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6539), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [121075] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2376), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6481), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5130), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5132), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [121127] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2400), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1113), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [121179] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2384), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6481), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5134), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5136), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [121231] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6547), 1,
      anon_sym_esac,
    ACTIONS(6549), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7016), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3304), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6545), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [121325] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6481), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6551), 1,
      sym__concat,
    STATE(2406), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [121379] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6555), 1,
      anon_sym_esac,
    ACTIONS(6557), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7019), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3306), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6553), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [121473] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1113), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6559), 1,
      sym__concat,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1209), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [121527] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2356), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5264), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5266), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [121579] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2356), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4280), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4282), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [121631] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6563), 1,
      anon_sym_esac,
    ACTIONS(6565), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6763), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3319), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6561), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [121725] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 26,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [121773] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2364), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4437), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4439), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [121825] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(2310), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5389), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5387), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [121879] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5874), 1,
      sym__concat,
    STATE(2311), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5291), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5289), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
  [121933] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6569), 1,
      anon_sym_esac,
    ACTIONS(6571), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7175), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3323), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6567), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [122027] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2398), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6416), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5184), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5186), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122079] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1113), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6573), 1,
      sym__concat,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1229), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [122133] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122181] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6416), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6575), 1,
      sym__concat,
    STATE(2365), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1229), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122235] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6424), 1,
      sym__special_character,
    STATE(2349), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4368), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4370), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122287] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1113), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6577), 1,
      sym__concat,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1209), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [122341] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122389] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 26,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122437] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    STATE(2324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [122489] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122537] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6424), 1,
      sym__special_character,
    STATE(2349), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4517), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4519), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122589] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2406), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6579), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122641] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6437), 1,
      sym__special_character,
    STATE(2325), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [122693] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2364), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2156), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(2158), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122745] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6582), 1,
      sym__special_character,
    STATE(2409), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1318), 24,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [122797] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2356), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4307), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4309), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122849] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(2416), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [122903] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1233), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1240), 26,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_LPAREN,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [122951] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(2424), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [123005] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [123053] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 26,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [123101] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6585), 1,
      sym__concat,
    STATE(1600), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [123155] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6587), 1,
      sym__concat,
    STATE(2332), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1229), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [123209] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6589), 1,
      anon_sym_RBRACK,
    ACTIONS(6591), 1,
      sym__concat,
    STATE(2324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [123265] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2364), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2160), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(2162), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [123317] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6416), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6593), 1,
      sym__concat,
    STATE(2365), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1209), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [123371] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1113), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6595), 1,
      sym__concat,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1229), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [123425] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2528), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1113), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1225), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      sym__special_character,
  [123477] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2364), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4311), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4313), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [123529] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6597), 1,
      sym__concat,
    STATE(1600), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [123583] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5833), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5854), 1,
      sym__concat,
    STATE(2416), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [123637] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2356), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6458), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5130), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5132), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [123689] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 26,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [123737] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 26,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [123785] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 26,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [123833] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6380), 1,
      anon_sym_LPAREN,
    ACTIONS(6386), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(6388), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6392), 1,
      sym__special_character,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6400), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6404), 1,
      anon_sym_BQUOTE,
    ACTIONS(6406), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6601), 1,
      anon_sym_esac,
    ACTIONS(6603), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7177), 1,
      sym_last_case_item,
    ACTIONS(6408), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3324), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    ACTIONS(6376), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(6599), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [123927] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6605), 1,
      anon_sym_RBRACK,
    ACTIONS(6607), 1,
      sym__concat,
    STATE(2324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [123983] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 25,
      sym__concat,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [124030] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124077] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124124] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124171] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6609), 1,
      sym__special_character,
    STATE(2481), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4280), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4282), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124222] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124269] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1258), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124316] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [124363] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1270), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124410] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1278), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [124457] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6613), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [124504] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1262), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [124551] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 25,
      sym__concat,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [124598] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1314), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124645] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1215), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124692] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124739] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124786] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4441), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4443), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124833] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [124880] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6615), 1,
      sym__special_character,
    STATE(2533), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [124931] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6617), 1,
      sym__special_character,
    STATE(2452), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1318), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [124982] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125029] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125076] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1270), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [125123] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125170] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125217] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6609), 1,
      sym__special_character,
    STATE(2481), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5687), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5689), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125268] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [125315] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125362] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1278), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125409] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1254), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125456] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125503] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125550] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2474), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6620), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1225), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125601] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125648] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 25,
      sym__concat,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [125695] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125742] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125789] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125836] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1290), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125883] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125930] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6622), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6624), 1,
      sym__concat,
    STATE(2476), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [125983] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6620), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6626), 1,
      sym__concat,
    STATE(2479), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1229), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126036] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6622), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6628), 1,
      sym__concat,
    STATE(2476), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126089] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2476), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6630), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126140] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126187] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126234] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2479), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6633), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1215), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126285] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4303), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4305), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126332] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6636), 1,
      sym__special_character,
    STATE(2481), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126383] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1274), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [126430] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126477] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [126524] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126571] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1302), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126618] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6643), 1,
      sym__concat,
    ACTIONS(6641), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6639), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [126667] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5397), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5399), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126714] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [126761] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2473), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6622), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126812] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6649), 1,
      anon_sym_LBRACK,
    ACTIONS(6647), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6645), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [126861] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126908] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1298), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [126955] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1274), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127002] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6655), 1,
      sym__concat,
    ACTIONS(6653), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6651), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [127051] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6609), 1,
      sym__special_character,
    STATE(2481), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5130), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5132), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127102] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4437), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4439), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127149] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127196] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [127243] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1254), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [127290] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 25,
      sym__concat,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [127337] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 15,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      sym__special_character,
    ACTIONS(1225), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [127384] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6620), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6657), 1,
      sym__concat,
    STATE(2479), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1209), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127437] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2514), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6659), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5130), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5132), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127488] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1250), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127535] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1294), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127582] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1266), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127629] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6661), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6663), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [127676] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4311), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4313), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127723] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127770] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1282), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127817] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6665), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6667), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [127864] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2503), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6620), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5289), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5291), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127915] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6659), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6669), 1,
      sym__concat,
    STATE(2527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [127968] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [128015] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1286), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [128062] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1215), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [128109] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [128156] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6659), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6671), 1,
      sym__concat,
    STATE(2527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [128209] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6677), 1,
      sym__concat,
    ACTIONS(6675), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6673), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [128258] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [128305] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1225), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
      sym__special_character,
  [128352] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [128399] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1314), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [128446] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1282), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [128493] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2474), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6620), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5387), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5389), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [128544] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6679), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [128595] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1113), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6682), 1,
      sym__concat,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1229), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [128648] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1310), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [128695] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1113), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6684), 1,
      sym__concat,
    STATE(2042), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1209), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [128748] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2514), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6659), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [128799] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [128846] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6686), 1,
      sym__special_character,
    STATE(2533), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1318), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [128897] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 25,
      sym__concat,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [128944] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1302), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [128991] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2473), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6622), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5130), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5132), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129042] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 25,
      sym__concat,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [129089] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2475), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6622), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5134), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5136), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129140] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6689), 1,
      sym__concat,
    STATE(1759), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [129193] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2519), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6659), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5134), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5136), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129244] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6613), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [129291] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1286), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129338] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6691), 1,
      sym_extglob_pattern,
    ACTIONS(6466), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6468), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [129387] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6609), 1,
      sym__special_character,
    STATE(2481), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5561), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5563), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129438] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6693), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6697), 23,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [129487] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129534] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6699), 1,
      sym__concat,
    STATE(1759), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [129587] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1262), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129634] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6701), 1,
      sym__special_character,
    STATE(2452), 1,
      aux_sym__literal_repeat1,
    ACTIONS(239), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(358), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [129685] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129732] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129779] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129826] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129873] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1306), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [129920] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(2539), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [129973] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(2547), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [130026] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2530), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1113), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [130077] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 25,
      sym__concat,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [130124] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 25,
      sym__concat,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [130171] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1310), 25,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130218] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      aux_sym_concatenation_token1,
    ACTIONS(5957), 1,
      sym__concat,
    STATE(2539), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [130271] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130318] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [130365] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1290), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [130412] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6707), 1,
      sym__concat,
    ACTIONS(6705), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6703), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [130461] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6709), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6711), 25,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [130508] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 26,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130555] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 14,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_EQ_TILDE,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 25,
      sym_file_descriptor,
      sym_test_operator,
      sym__bare_dollar,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130602] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6609), 1,
      sym__special_character,
    STATE(2481), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4307), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4309), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130653] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130700] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 25,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      aux_sym_concatenation_token1,
  [130747] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130794] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130840] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130886] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6713), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6715), 1,
      sym__concat,
    STATE(2577), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130938] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6713), 1,
      aux_sym_concatenation_token1,
    ACTIONS(6717), 1,
      sym__concat,
    STATE(2577), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [130990] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2577), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6719), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131040] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2575), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6713), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131090] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131136] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131182] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131228] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131274] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131320] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [131366] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131412] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [131458] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6653), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6651), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [131504] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6641), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6639), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [131550] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 24,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [131596] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 24,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [131642] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 24,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [131688] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 24,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [131734] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 24,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [131780] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6722), 1,
      sym_extglob_pattern,
    ACTIONS(6466), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6468), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [131828] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6726), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6724), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [131874] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6730), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6728), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [131920] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 24,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [131966] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 24,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [132012] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 24,
      sym_test_operator,
      sym_extglob_pattern,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [132058] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132104] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132150] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6734), 1,
      anon_sym_EQ,
    ACTIONS(6736), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(6732), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [132198] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5862), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(5864), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5867), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_LT_LT_DASH,
    ACTIONS(5860), 6,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5869), 7,
      sym_file_descriptor,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5872), 13,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132252] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5862), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(5864), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5867), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_LT_LT_DASH,
    ACTIONS(5860), 6,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5869), 7,
      sym_file_descriptor,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5872), 13,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132306] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6738), 1,
      sym__special_character,
    STATE(2737), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5264), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5266), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132356] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132402] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132448] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [132494] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6740), 1,
      sym__special_character,
    STATE(2786), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5687), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5689), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132544] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6738), 1,
      sym__special_character,
    STATE(2737), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5184), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5186), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132594] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6740), 1,
      sym__special_character,
    STATE(2786), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5561), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5563), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132644] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132690] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132736] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132782] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132828] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132874] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6744), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6742), 22,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [132930] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6740), 1,
      sym__special_character,
    STATE(2786), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5264), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5266), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [132980] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6744), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6742), 22,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [133028] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [133074] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [133120] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 25,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [133166] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6744), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6742), 22,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [133222] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [133280] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 22,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [133336] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6693), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6697), 22,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [133384] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 22,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [133440] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6709), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6711), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [133486] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6770), 1,
      anon_sym_EQ,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6768), 16,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [133558] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6788), 1,
      sym__special_character,
    STATE(2793), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5130), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5132), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [133608] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6792), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6790), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [133654] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6740), 1,
      sym__special_character,
    STATE(2786), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4280), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4282), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [133704] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6740), 1,
      sym__special_character,
    STATE(2786), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4307), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4309), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [133754] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6740), 1,
      sym__special_character,
    STATE(2786), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5130), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5132), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [133804] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6665), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6667), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [133850] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 22,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [133906] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6798), 1,
      anon_sym_PIPE,
    ACTIONS(6800), 1,
      anon_sym_CARET,
    ACTIONS(6802), 1,
      anon_sym_AMP,
    ACTIONS(6810), 1,
      anon_sym_QMARK,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 14,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
  [133982] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6798), 1,
      anon_sym_PIPE,
    ACTIONS(6800), 1,
      anon_sym_CARET,
    ACTIONS(6802), 1,
      anon_sym_AMP,
    ACTIONS(6810), 1,
      anon_sym_QMARK,
    ACTIONS(6812), 1,
      anon_sym_EQ,
    ACTIONS(6814), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 13,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
  [134060] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6796), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6798), 1,
      anon_sym_PIPE,
    ACTIONS(6800), 1,
      anon_sym_CARET,
    ACTIONS(6802), 1,
      anon_sym_AMP,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134132] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6798), 1,
      anon_sym_PIPE,
    ACTIONS(6800), 1,
      anon_sym_CARET,
    ACTIONS(6802), 1,
      anon_sym_AMP,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 17,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134202] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6800), 1,
      anon_sym_CARET,
    ACTIONS(6802), 1,
      anon_sym_AMP,
    ACTIONS(6611), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 17,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134270] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6802), 1,
      anon_sym_AMP,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6611), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 17,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134336] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 17,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134400] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 19,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134462] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6613), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134508] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 21,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134566] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6613), 22,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134620] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6613), 22,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134672] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 22,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134722] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 22,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134772] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6613), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [134818] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(2932), 1,
      anon_sym_DQUOTE,
    ACTIONS(6820), 1,
      sym_variable_name,
    STATE(4240), 1,
      sym_string,
    ACTIONS(6818), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(6816), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [134874] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(2932), 1,
      anon_sym_DQUOTE,
    ACTIONS(6820), 1,
      sym_variable_name,
    STATE(4240), 1,
      sym_string,
    ACTIONS(6818), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(6816), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [134930] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2575), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6713), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5130), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5132), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [134980] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(2576), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(6713), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5134), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5136), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [135030] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6822), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    STATE(6494), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [135112] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6472), 1,
      anon_sym_RBRACK,
    ACTIONS(6834), 1,
      sym__concat,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [135162] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 15,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      sym__special_character,
    ACTIONS(1225), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [135208] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6836), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6531), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [135290] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6605), 1,
      anon_sym_RBRACK,
    ACTIONS(6838), 1,
      sym__concat,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [135340] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2156), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2158), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [135386] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [135432] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6495), 1,
      anon_sym_RBRACK,
    ACTIONS(6840), 1,
      sym__concat,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [135482] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1274), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [135528] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4437), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4439), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [135574] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [135620] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6842), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6581), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [135702] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6589), 1,
      anon_sym_RBRACK,
    ACTIONS(6844), 1,
      sym__concat,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [135752] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6846), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6600), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [135834] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6483), 1,
      anon_sym_RBRACK,
    ACTIONS(6848), 1,
      sym__concat,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [135884] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6850), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6612), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [135966] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6852), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6505), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136048] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6854), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6544), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136130] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6856), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6566), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136212] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6858), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6540), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136294] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6860), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6601), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136376] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2160), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2162), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [136422] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6862), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6606), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136504] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6864), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6450), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136586] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6866), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6560), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136668] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6868), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6616), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136750] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6870), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6548), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136832] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6872), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6459), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136914] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6874), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6508), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [136996] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6876), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6530), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137078] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4311), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4313), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [137124] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6878), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6553), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137206] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6880), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6572), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137288] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6882), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6603), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137370] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6884), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6626), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137452] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6886), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6526), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137534] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6888), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6554), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137616] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6890), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6596), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137698] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6892), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6452), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137780] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6894), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6467), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137862] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6896), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6497), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [137944] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6898), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6507), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138026] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6900), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6517), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138108] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6902), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6523), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138190] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6904), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6627), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138272] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6906), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6550), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138354] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6908), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6558), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138436] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6910), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6564), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138518] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6568), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138600] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6914), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6586), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138682] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6916), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6597), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138764] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6918), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6613), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138846] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6920), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6625), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [138928] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6922), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6514), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139010] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6924), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6483), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139092] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6926), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6527), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139174] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6930), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6928), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [139220] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6932), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6547), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139302] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6934), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6557), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139384] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6938), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6936), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [139430] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6940), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6582), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139512] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6942), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6598), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139594] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6944), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6451), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139676] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6946), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6454), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139758] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6948), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6461), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139840] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6950), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6471), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [139922] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6952), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6487), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140004] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6954), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6503), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140086] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6956), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6506), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140168] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6958), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6509), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140250] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6960), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6516), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140332] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6964), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6962), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [140378] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6966), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6519), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140460] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6964), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6962), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [140506] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6968), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6522), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140588] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6970), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6529), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140670] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6972), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6536), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140752] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6974), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6542), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140834] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6976), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6549), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140916] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6978), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6552), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [140998] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1254), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141044] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6980), 1,
      sym__special_character,
    STATE(2737), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1318), 23,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141094] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1278), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [141140] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1286), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141186] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1215), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141232] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1290), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [141278] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [141324] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1314), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141370] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1310), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141416] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1282), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [141462] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [141508] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1262), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141554] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1270), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141600] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6661), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6663), 24,
      sym__concat,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [141646] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6798), 1,
      anon_sym_PIPE,
    ACTIONS(6800), 1,
      anon_sym_CARET,
    ACTIONS(6802), 1,
      anon_sym_AMP,
    ACTIONS(6983), 1,
      anon_sym_EQ,
    ACTIONS(6756), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6985), 15,
      sym__concat,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [141720] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6989), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6987), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [141766] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 15,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_COLON,
  [141840] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1274), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141886] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1266), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141932] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1282), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [141978] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1250), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142024] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1258), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142070] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1278), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142116] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1290), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142162] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1294), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142208] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1298), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142254] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1302), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142300] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1306), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142346] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1302), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [142392] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 14,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_COLON,
  [142468] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 17,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [142538] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 18,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [142606] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6993), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 18,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [142672] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(6991), 18,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [142736] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6991), 18,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [142798] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6991), 20,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [142858] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6991), 22,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [142914] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6991), 22,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [142968] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6991), 22,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [143020] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6993), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 22,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [143070] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6993), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6991), 22,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [143118] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143164] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [143210] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143256] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143302] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143348] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143394] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [143440] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [143486] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [143532] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6995), 1,
      sym__special_character,
    STATE(2786), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143582] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143628] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143674] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 24,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [143720] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6489), 1,
      anon_sym_RBRACK,
    ACTIONS(6998), 1,
      sym__concat,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 22,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [143770] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7000), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6515), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [143852] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 15,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      sym__special_character,
    ACTIONS(1225), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [143898] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7002), 1,
      sym__special_character,
    STATE(2793), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143948] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [143994] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144040] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144086] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144132] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144178] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144224] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144270] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144316] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144362] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7005), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6563), 1,
      aux_sym_arithmetic_expansion_repeat1,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [144444] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [144497] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7043), 1,
      anon_sym_RBRACK,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7017), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [144576] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7043), 1,
      anon_sym_RBRACK_RBRACK,
    ACTIONS(7051), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7053), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [144655] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7089), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7091), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7085), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
  [144714] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [144759] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7103), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [144838] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(839), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [144917] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7107), 1,
      anon_sym_RBRACK,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7017), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [144996] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7051), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(7107), 1,
      anon_sym_RBRACK_RBRACK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7053), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145075] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [145120] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [145165] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6709), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6711), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [145210] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(7109), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145289] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(849), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145368] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7111), 1,
      anon_sym_RBRACK,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7017), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145447] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7051), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(7111), 1,
      anon_sym_RBRACK_RBRACK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7053), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145526] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7091), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7085), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [145583] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(7113), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145662] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7115), 1,
      anon_sym_LBRACK,
    ACTIONS(6647), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6645), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [145709] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(857), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145788] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7117), 1,
      anon_sym_RBRACK,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7017), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145867] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7051), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(7117), 1,
      anon_sym_RBRACK_RBRACK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7053), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [145946] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [146001] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(7119), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [146080] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(865), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [146159] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [146212] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(7121), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [146291] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7123), 1,
      sym__special_character,
    STATE(2921), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5387), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5389), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [146340] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [146385] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2160), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2162), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [146430] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [146475] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
  [146526] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7085), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [146575] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7085), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [146624] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7125), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [146669] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5886), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5888), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [146714] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [146769] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5705), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5707), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [146814] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6613), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [146859] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [146916] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [146969] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7129), 1,
      anon_sym_RBRACK,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7017), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [147048] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [147093] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1235), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [147138] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [147183] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [147228] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7131), 1,
      sym__special_character,
    STATE(2850), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [147277] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6611), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [147344] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5268), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5270), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [147389] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [147440] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6611), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [147505] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [147554] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [147599] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [147662] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7134), 1,
      anon_sym_EQ,
    ACTIONS(6732), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6736), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [147709] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7136), 1,
      sym__special_character,
    STATE(2999), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5130), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5132), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [147758] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [147803] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 18,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [147864] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6611), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [147929] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(799), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [148008] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [148053] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [148098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7140), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7138), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [148143] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [148200] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [148249] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [148294] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
  [148369] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4437), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4439), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [148414] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6661), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6663), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [148459] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6983), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6985), 14,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [148532] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4311), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4313), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [148577] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6983), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6985), 14,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [148650] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5886), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5888), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [148695] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7142), 1,
      sym__concat,
    ACTIONS(6675), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6673), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [148742] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7144), 1,
      sym__concat,
    ACTIONS(6705), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6703), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [148789] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [148834] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6613), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [148879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [148924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [148969] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(7146), 1,
      anon_sym_EQ,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK_RBRACK,
  [149046] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [149117] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7051), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(7129), 1,
      anon_sym_RBRACK_RBRACK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7053), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [149196] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [149249] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7148), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7176), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7178), 1,
      anon_sym_QMARK,
    ACTIONS(7180), 1,
      anon_sym_COLON,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7150), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [149328] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [149373] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7184), 2,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [149450] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [149495] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [149540] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [149585] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [149630] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [149699] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [149768] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3127), 1,
      anon_sym_DQUOTE,
    ACTIONS(7190), 1,
      sym_variable_name,
    STATE(4397), 1,
      sym_string,
    ACTIONS(7188), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7186), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [149823] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3127), 1,
      anon_sym_DQUOTE,
    ACTIONS(7190), 1,
      sym_variable_name,
    STATE(4397), 1,
      sym_string,
    ACTIONS(7188), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7186), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [149878] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1225), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [149923] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [149968] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(6611), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [150035] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5268), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(5270), 24,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [150080] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7200), 1,
      anon_sym_PIPE,
    ACTIONS(7202), 1,
      anon_sym_CARET,
    ACTIONS(7204), 1,
      anon_sym_AMP,
    ACTIONS(7206), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7089), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7192), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(7196), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
    ACTIONS(7198), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7091), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7194), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [150151] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [150202] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7148), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7176), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7178), 1,
      anon_sym_QMARK,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(7208), 1,
      anon_sym_COLON,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7150), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [150281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7125), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [150326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7212), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7210), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [150371] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7216), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7214), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [150416] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7218), 1,
      anon_sym_LBRACK,
    ACTIONS(6647), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6645), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [150463] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [150518] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7222), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7224), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7238), 1,
      anon_sym_QMARK,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
  [150593] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7222), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7224), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7238), 1,
      anon_sym_QMARK,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(7242), 1,
      anon_sym_EQ,
    ACTIONS(7244), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RPAREN,
  [150670] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7224), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [150741] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [150810] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6611), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [150877] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6611), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [150942] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [151005] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 18,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [151066] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [151123] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7204), 1,
      anon_sym_AMP,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7089), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7091), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7085), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
  [151184] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [151239] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7246), 1,
      sym__special_character,
    STATE(2921), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1318), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [151288] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [151337] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [151386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [151431] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [151476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [151521] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5705), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5707), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [151566] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7249), 1,
      sym__concat,
    ACTIONS(6653), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6651), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [151613] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5862), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(5867), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5860), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5864), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5869), 7,
      sym_file_descriptor,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5872), 14,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [151666] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5862), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(5867), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(5860), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5864), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5869), 7,
      sym_file_descriptor,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
    ACTIONS(5872), 14,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [151719] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7253), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7251), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [151766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7257), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7255), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [151811] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7259), 1,
      sym__concat,
    ACTIONS(6641), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6639), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [151858] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [151903] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7261), 1,
      anon_sym_EQ,
    ACTIONS(6732), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6736), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [151950] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(7265), 1,
      anon_sym_DQUOTE,
    ACTIONS(7269), 1,
      sym_variable_name,
    STATE(4167), 1,
      sym_string,
    ACTIONS(7267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7263), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [152005] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(7265), 1,
      anon_sym_DQUOTE,
    ACTIONS(7269), 1,
      sym_variable_name,
    STATE(4167), 1,
      sym_string,
    ACTIONS(7267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7263), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [152060] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [152109] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [152158] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3348), 1,
      anon_sym_DQUOTE,
    ACTIONS(7275), 1,
      sym_variable_name,
    STATE(4355), 1,
      sym_string,
    ACTIONS(7273), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7271), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [152213] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3348), 1,
      anon_sym_DQUOTE,
    ACTIONS(7275), 1,
      sym_variable_name,
    STATE(4355), 1,
      sym_string,
    ACTIONS(7273), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7271), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [152268] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(807), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [152347] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7277), 1,
      anon_sym_RBRACK,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7017), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [152426] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7051), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(7277), 1,
      anon_sym_RBRACK_RBRACK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7053), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [152505] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4153), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5856), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5858), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
    ACTIONS(4161), 15,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [152554] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [152617] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(7279), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [152696] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7222), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7224), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7238), 1,
      anon_sym_QMARK,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(7242), 1,
      anon_sym_EQ,
    ACTIONS(7244), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7283), 1,
      anon_sym_RPAREN,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7281), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [152775] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [152820] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [152865] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [152922] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [152977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
  [153022] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [153077] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7148), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7176), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7178), 1,
      anon_sym_QMARK,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(7285), 1,
      anon_sym_COLON,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7150), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [153156] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [153213] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [153268] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [153323] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7287), 1,
      sym__concat,
    ACTIONS(6675), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6673), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [153370] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7289), 1,
      sym__concat,
    ACTIONS(6705), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6703), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [153417] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [153472] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7178), 1,
      anon_sym_QMARK,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_COLON,
  [153547] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7148), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7176), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7178), 1,
      anon_sym_QMARK,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_COLON,
  [153624] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [153695] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [153764] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6611), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [153831] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6611), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [153896] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [153959] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 18,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [154020] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [154077] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [154130] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [154181] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [154230] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [154279] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7291), 1,
      sym__special_character,
    STATE(2850), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5130), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5132), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [154328] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7293), 1,
      sym__concat,
    ACTIONS(6653), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6651), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [154375] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7295), 1,
      sym__concat,
    ACTIONS(6641), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6639), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [154422] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7200), 1,
      anon_sym_PIPE,
    ACTIONS(7202), 1,
      anon_sym_CARET,
    ACTIONS(7204), 1,
      anon_sym_AMP,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7089), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7196), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
    ACTIONS(7198), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7091), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7085), 13,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [154491] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6983), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6985), 14,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [154564] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(815), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [154643] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(7297), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [154722] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7299), 1,
      anon_sym_RBRACK,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7017), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [154801] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7051), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(7299), 1,
      anon_sym_RBRACK_RBRACK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7053), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [154880] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7200), 1,
      anon_sym_PIPE,
    ACTIONS(7202), 1,
      anon_sym_CARET,
    ACTIONS(7204), 1,
      anon_sym_AMP,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7089), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7198), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7091), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7085), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
  [154947] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7200), 1,
      anon_sym_PIPE,
    ACTIONS(7202), 1,
      anon_sym_CARET,
    ACTIONS(7204), 1,
      anon_sym_AMP,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7089), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7091), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7085), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
  [155012] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(7301), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [155091] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7222), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7224), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7238), 1,
      anon_sym_QMARK,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(7242), 1,
      anon_sym_EQ,
    ACTIONS(7244), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7303), 1,
      anon_sym_RPAREN,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7281), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [155170] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7148), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7176), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7178), 1,
      anon_sym_QMARK,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(7305), 1,
      anon_sym_COLON,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7150), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [155249] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [155306] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [155361] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [155406] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
      anon_sym_COLON,
  [155461] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(823), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [155540] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [155597] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7222), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7224), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7238), 1,
      anon_sym_QMARK,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(7242), 1,
      anon_sym_EQ,
    ACTIONS(7244), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7307), 1,
      anon_sym_RPAREN,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7281), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [155676] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7099), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7101), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7202), 1,
      anon_sym_CARET,
    ACTIONS(7204), 1,
      anon_sym_AMP,
    ACTIONS(7087), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7089), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7093), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7095), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7097), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7091), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7085), 18,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_PIPE,
  [155739] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6983), 1,
      anon_sym_EQ,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7222), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7224), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6985), 14,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [155812] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7309), 1,
      anon_sym_RBRACK,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7017), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [155891] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7311), 1,
      sym__special_character,
    STATE(2999), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [155940] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6665), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6667), 23,
      sym_test_operator,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [155985] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [156040] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
  [156115] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7013), 1,
      anon_sym_EQ,
    ACTIONS(7019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7045), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7047), 1,
      anon_sym_QMARK,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
  [156192] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7148), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7176), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7178), 1,
      anon_sym_QMARK,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7150), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [156271] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7023), 1,
      anon_sym_PIPE,
    ACTIONS(7025), 1,
      anon_sym_CARET,
    ACTIONS(7027), 1,
      anon_sym_AMP,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7029), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [156342] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7051), 1,
      anon_sym_EQ,
    ACTIONS(7055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7057), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7059), 1,
      anon_sym_PIPE,
    ACTIONS(7061), 1,
      anon_sym_CARET,
    ACTIONS(7063), 1,
      anon_sym_AMP,
    ACTIONS(7077), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7079), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7081), 1,
      anon_sym_QMARK,
    ACTIONS(7083), 1,
      sym_test_operator,
    ACTIONS(7309), 1,
      anon_sym_RBRACK_RBRACK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7065), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7067), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7069), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7073), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7075), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7053), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [156421] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [156466] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2156), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2158), 25,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [156511] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [156556] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(7316), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [156635] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7049), 1,
      sym_test_operator,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7031), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7033), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 18,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [156696] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7222), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7224), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7226), 1,
      anon_sym_PIPE,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_AMP,
    ACTIONS(7238), 1,
      anon_sym_QMARK,
    ACTIONS(7240), 1,
      sym_test_operator,
    ACTIONS(7242), 1,
      anon_sym_EQ,
    ACTIONS(7244), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7318), 1,
      anon_sym_RPAREN,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7007), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7220), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7232), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7236), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7281), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [156775] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7041), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7035), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7037), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7039), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [156830] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 24,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [156875] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7148), 1,
      anon_sym_EQ,
    ACTIONS(7152), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7154), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7156), 1,
      anon_sym_PIPE,
    ACTIONS(7158), 1,
      anon_sym_CARET,
    ACTIONS(7160), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7176), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7178), 1,
      anon_sym_QMARK,
    ACTIONS(7182), 1,
      sym_test_operator,
    ACTIONS(7320), 1,
      anon_sym_COLON,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7162), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7164), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7166), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7168), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7170), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7172), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7150), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [156954] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6693), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6697), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157001] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(833), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [157080] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7011), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7009), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6613), 21,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157131] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 19,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157187] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6854), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [157263] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(7368), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7370), 1,
      anon_sym_PIPE,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157331] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(7370), 1,
      anon_sym_PIPE,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157397] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6856), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [157473] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6930), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6928), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157517] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6993), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157581] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6858), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [157657] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6938), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6936), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157701] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6860), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [157777] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6993), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157839] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6862), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [157915] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6964), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6962), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [157959] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6991), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [158019] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6864), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [158095] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6964), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6962), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [158139] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6991), 18,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [158197] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6866), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [158273] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [158327] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6868), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [158403] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [158455] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6870), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [158531] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [158581] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6872), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [158657] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6993), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [158705] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6874), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [158781] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6993), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [158827] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6876), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [158903] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7396), 1,
      anon_sym_PIPE,
    ACTIONS(7398), 1,
      anon_sym_CARET,
    ACTIONS(7400), 1,
      anon_sym_AMP,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7392), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
    ACTIONS(7394), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7402), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7404), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7406), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 13,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RPAREN,
  [158971] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159047] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7396), 1,
      anon_sym_PIPE,
    ACTIONS(7398), 1,
      anon_sym_CARET,
    ACTIONS(7400), 1,
      anon_sym_AMP,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7394), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7402), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7404), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7406), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 15,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_RPAREN,
  [159113] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6880), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159189] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7396), 1,
      anon_sym_PIPE,
    ACTIONS(7398), 1,
      anon_sym_CARET,
    ACTIONS(7400), 1,
      anon_sym_AMP,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7402), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7404), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7406), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 17,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_RPAREN,
  [159253] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6882), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159329] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7085), 1,
      anon_sym_PIPE,
    ACTIONS(7398), 1,
      anon_sym_CARET,
    ACTIONS(7400), 1,
      anon_sym_AMP,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7402), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7404), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7406), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 17,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_RPAREN,
  [159393] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6884), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159469] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6886), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159545] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7400), 1,
      anon_sym_AMP,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7085), 2,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7402), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7404), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7406), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 17,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_RPAREN,
  [159607] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6888), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159683] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159759] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7402), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7404), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7406), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7085), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 17,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_RPAREN,
  [159819] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6892), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159895] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6894), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [159971] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [160025] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [160101] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7404), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7406), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7085), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 19,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RPAREN,
  [160159] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6898), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [160235] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 5,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7101), 21,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [160289] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6900), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [160365] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7101), 21,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [160417] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6902), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [160493] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 9,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7101), 21,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [160543] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6904), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [160619] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6906), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [160695] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7422), 1,
      aux_sym_concatenation_token1,
    ACTIONS(7424), 1,
      sym__concat,
    STATE(3279), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [160745] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [160821] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1274), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [160865] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6910), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [160941] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7085), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 21,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [160989] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7085), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 21,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [161037] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6912), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161113] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7422), 1,
      aux_sym_concatenation_token1,
    ACTIONS(7424), 1,
      sym__concat,
    STATE(3279), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [161163] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6914), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161239] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7422), 1,
      aux_sym_concatenation_token1,
    ACTIONS(7424), 1,
      sym__concat,
    STATE(3281), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [161289] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6916), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161365] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6918), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161441] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6920), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161517] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6922), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161593] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [161637] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6924), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161713] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6993), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [161759] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6926), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161835] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [161879] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1282), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [161923] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6932), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161999] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6934), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162075] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [162119] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6940), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162195] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6653), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6651), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [162239] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6942), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162315] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1274), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [162359] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6944), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162435] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6641), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6639), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [162479] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6946), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162555] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7214), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7216), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [162599] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6948), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162675] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7432), 1,
      anon_sym_PIPE,
    ACTIONS(7434), 1,
      anon_sym_CARET,
    ACTIONS(7436), 1,
      anon_sym_AMP,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7428), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
    ACTIONS(7430), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7438), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7440), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7442), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 13,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162743] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6950), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162819] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7432), 1,
      anon_sym_PIPE,
    ACTIONS(7434), 1,
      anon_sym_CARET,
    ACTIONS(7436), 1,
      anon_sym_AMP,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7430), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7438), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7440), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7442), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 15,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
  [162885] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6952), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162961] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [163005] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6954), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [163081] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7138), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7140), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [163125] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6956), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [163201] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6770), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6768), 14,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [163271] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7432), 1,
      anon_sym_PIPE,
    ACTIONS(7434), 1,
      anon_sym_CARET,
    ACTIONS(7436), 1,
      anon_sym_AMP,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7438), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7440), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7442), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 17,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
  [163335] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6958), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [163411] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(7468), 1,
      sym_file_descriptor,
    ACTIONS(7471), 1,
      sym_variable_name,
    STATE(6656), 1,
      sym_subscript,
    ACTIONS(7460), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(3116), 2,
      sym_variable_assignment,
      aux_sym_command_repeat1,
    STATE(3491), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(7457), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(7452), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(7454), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(7466), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [163473] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1282), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [163517] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6960), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [163593] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7085), 1,
      anon_sym_PIPE,
    ACTIONS(7434), 1,
      anon_sym_CARET,
    ACTIONS(7436), 1,
      anon_sym_AMP,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7438), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7440), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7442), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 17,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
  [163657] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7436), 1,
      anon_sym_AMP,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7085), 2,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7438), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7440), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7442), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 17,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
  [163719] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6966), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [163795] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7438), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7440), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7442), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7085), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 17,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
  [163855] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7440), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7442), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7085), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 19,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [163913] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6968), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [163989] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 5,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7101), 21,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [164043] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6970), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [164119] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7101), 21,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [164171] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6972), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [164247] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [164291] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6974), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [164367] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7085), 9,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7101), 21,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [164417] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6976), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [164493] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7085), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 21,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [164541] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6978), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [164617] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7085), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7101), 21,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [164665] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7474), 1,
      sym__special_character,
    STATE(3239), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5130), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5132), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [164713] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1278), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [164757] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3482), 1,
      anon_sym_DQUOTE,
    ACTIONS(7480), 1,
      sym_variable_name,
    STATE(4595), 1,
      sym_string,
    ACTIONS(7478), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7476), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [164811] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3482), 1,
      anon_sym_DQUOTE,
    ACTIONS(7480), 1,
      sym_variable_name,
    STATE(4595), 1,
      sym_string,
    ACTIONS(7478), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7476), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [164865] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1290), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [164909] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1274), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [164953] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(7484), 1,
      anon_sym_DQUOTE,
    ACTIONS(7488), 1,
      sym_variable_name,
    STATE(4380), 1,
      sym_string,
    ACTIONS(7486), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7482), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [165007] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(7484), 1,
      anon_sym_DQUOTE,
    ACTIONS(7488), 1,
      sym_variable_name,
    STATE(4380), 1,
      sym_string,
    ACTIONS(7486), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7482), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [165061] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [165105] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [165149] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [165193] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6822), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [165269] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [165313] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7368), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7370), 1,
      anon_sym_PIPE,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7490), 1,
      anon_sym_EQ,
    ACTIONS(7494), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7496), 1,
      anon_sym_RPAREN,
    ACTIONS(7498), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7500), 1,
      anon_sym_QMARK,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7492), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [165389] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7368), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7370), 1,
      anon_sym_PIPE,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7490), 1,
      anon_sym_EQ,
    ACTIONS(7494), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7498), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7500), 1,
      anon_sym_QMARK,
    ACTIONS(7502), 1,
      anon_sym_RPAREN,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7492), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [165465] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      aux_sym__simple_variable_name_token1,
      sym_word,
    ACTIONS(1225), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [165509] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6726), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6724), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [165553] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6730), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6728), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [165597] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [165641] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7000), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [165717] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7368), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7370), 1,
      anon_sym_PIPE,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7490), 1,
      anon_sym_EQ,
    ACTIONS(7494), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7498), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7500), 1,
      anon_sym_QMARK,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RPAREN,
  [165791] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7138), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7140), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [165835] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7504), 1,
      anon_sym_COLON,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [165911] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6770), 1,
      anon_sym_EQ,
    ACTIONS(7368), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7370), 1,
      anon_sym_PIPE,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7494), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6768), 14,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [165981] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6420), 1,
      anon_sym_esac,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6805), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3330), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [166069] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6433), 1,
      anon_sym_esac,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6807), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3331), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [166157] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1278), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [166201] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7526), 1,
      anon_sym_esac,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6821), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3332), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [166289] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7396), 1,
      anon_sym_PIPE,
    ACTIONS(7398), 1,
      anon_sym_CARET,
    ACTIONS(7400), 1,
      anon_sym_AMP,
    ACTIONS(7414), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7206), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7392), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
    ACTIONS(7394), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7402), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7404), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7406), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7408), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7410), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7412), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7528), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [166359] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7125), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7127), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [166403] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7530), 1,
      anon_sym_esac,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6823), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3334), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [166491] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1290), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [166535] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7532), 1,
      anon_sym_esac,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6880), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3347), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [166623] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [166667] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7210), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7212), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [166711] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7125), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7127), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [166755] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6744), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6742), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [166809] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6744), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6742), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [166855] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6983), 1,
      anon_sym_EQ,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(7534), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7536), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7538), 1,
      anon_sym_PIPE,
    ACTIONS(7540), 1,
      anon_sym_CARET,
    ACTIONS(7542), 1,
      anon_sym_AMP,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7544), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6985), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [166927] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6744), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6742), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [166981] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6792), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6790), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [167025] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1282), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [167069] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [167113] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6836), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [167189] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7368), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7370), 1,
      anon_sym_PIPE,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7490), 1,
      anon_sym_EQ,
    ACTIONS(7494), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7498), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7500), 1,
      anon_sym_QMARK,
    ACTIONS(7550), 1,
      anon_sym_RPAREN,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7492), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [167265] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7552), 1,
      anon_sym_COLON,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [167341] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [167385] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6547), 1,
      anon_sym_esac,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7016), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3304), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [167473] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [167517] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6555), 1,
      anon_sym_esac,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7019), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3306), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [167605] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [167649] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7554), 1,
      anon_sym_esac,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7031), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3307), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [167737] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7556), 1,
      anon_sym_esac,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7033), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3310), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [167825] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1278), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [167869] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [167913] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [167957] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168001] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168045] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168089] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7432), 1,
      anon_sym_PIPE,
    ACTIONS(7434), 1,
      anon_sym_CARET,
    ACTIONS(7436), 1,
      anon_sym_AMP,
    ACTIONS(7450), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7206), 2,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7428), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
    ACTIONS(7430), 2,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
    ACTIONS(7438), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7440), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7442), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7444), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7446), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7448), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7558), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [168159] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7125), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7127), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [168203] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7005), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [168279] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168323] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7210), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7212), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [168367] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6653), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6651), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168411] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7125), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7127), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [168455] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6641), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6639), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168499] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6744), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6742), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168553] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(1197), 2,
      sym_file_descriptor,
      ts_builtin_sym_end,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [168607] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(1191), 2,
      sym_file_descriptor,
      ts_builtin_sym_end,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [168661] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6726), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6724), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168705] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6730), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6728), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168749] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6744), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6742), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168795] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6569), 1,
      anon_sym_esac,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7175), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3323), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [168883] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6744), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6742), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [168937] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1274), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [168981] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7560), 1,
      anon_sym_COLON,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [169057] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1266), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [169101] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6754), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6772), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6774), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6776), 1,
      anon_sym_PIPE,
    ACTIONS(6778), 1,
      anon_sym_CARET,
    ACTIONS(6780), 1,
      anon_sym_AMP,
    ACTIONS(6826), 1,
      anon_sym_EQ,
    ACTIONS(6830), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6832), 1,
      anon_sym_QMARK,
    ACTIONS(7105), 1,
      anon_sym_COMMA,
    ACTIONS(6746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6748), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6750), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6782), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6784), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6786), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6752), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6828), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [169177] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1282), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [169221] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1250), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [169265] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6764), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6766), 1,
      sym_test_operator,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6798), 1,
      anon_sym_PIPE,
    ACTIONS(6800), 1,
      anon_sym_CARET,
    ACTIONS(6802), 1,
      anon_sym_AMP,
    ACTIONS(6812), 1,
      anon_sym_EQ,
    ACTIONS(6814), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7564), 1,
      anon_sym_QMARK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6758), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6804), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6806), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6808), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6762), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7562), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [169341] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1258), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [169385] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6541), 1,
      anon_sym_esac,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7366), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3336), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [169473] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1278), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [169517] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1290), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [169561] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6601), 1,
      anon_sym_esac,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7177), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3324), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [169649] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6792), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6790), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [169693] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [169737] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7566), 1,
      anon_sym_esac,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7188), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3325), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [169825] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7568), 1,
      anon_sym_esac,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7189), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3326), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [169913] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1298), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [169957] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [170011] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [170065] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 24,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [170109] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1290), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [170153] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [170197] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [170241] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [170285] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6842), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [170361] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [170405] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1306), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [170449] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(1302), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [170493] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7570), 1,
      sym__special_character,
    STATE(3239), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 22,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [170541] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(6563), 1,
      anon_sym_esac,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6763), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3319), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [170629] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [170683] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6613), 20,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [170737] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(7534), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7536), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7538), 1,
      anon_sym_PIPE,
    ACTIONS(7540), 1,
      anon_sym_CARET,
    ACTIONS(7542), 1,
      anon_sym_AMP,
    ACTIONS(7564), 1,
      anon_sym_QMARK,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7544), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_EQ_TILDE,
  [170811] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(7534), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7536), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7538), 1,
      anon_sym_PIPE,
    ACTIONS(7540), 1,
      anon_sym_CARET,
    ACTIONS(7542), 1,
      anon_sym_AMP,
    ACTIONS(7564), 1,
      anon_sym_QMARK,
    ACTIONS(7573), 1,
      anon_sym_EQ,
    ACTIONS(7575), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7544), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [170887] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(7536), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7538), 1,
      anon_sym_PIPE,
    ACTIONS(7540), 1,
      anon_sym_CARET,
    ACTIONS(7542), 1,
      anon_sym_AMP,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7544), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 14,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [170957] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6611), 1,
      anon_sym_EQ,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(7538), 1,
      anon_sym_PIPE,
    ACTIONS(7540), 1,
      anon_sym_CARET,
    ACTIONS(7542), 1,
      anon_sym_AMP,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7544), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171025] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(7540), 1,
      anon_sym_CARET,
    ACTIONS(7542), 1,
      anon_sym_AMP,
    ACTIONS(6611), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7544), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171091] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(7542), 1,
      anon_sym_AMP,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7544), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(6611), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171155] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7544), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171217] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7546), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7548), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6613), 17,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171277] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6993), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171325] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6613), 20,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171377] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6611), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6613), 20,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171427] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 20,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171475] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6611), 13,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6613), 20,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171523] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 13,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      sym__special_character,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [171567] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6846), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [171643] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7330), 1,
      sym_test_operator,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 19,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171699] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 20,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171753] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7328), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6695), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7324), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7326), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6693), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6697), 20,
      sym_test_operator,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171807] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7214), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7216), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [171851] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6930), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6928), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [171895] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7390), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7251), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7253), 21,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [171941] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7255), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7257), 23,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
  [171985] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6989), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6987), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172029] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
  [172101] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6938), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6936), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172145] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6850), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [172221] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACK,
  [172295] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172363] = 14,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172429] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6964), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6962), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172473] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(6993), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172537] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6964), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6962), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172581] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7426), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7251), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7253), 21,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [172627] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6993), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172689] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7255), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(7257), 23,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_DASHo,
      anon_sym_AMP_AMP,
      anon_sym_DASHa,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [172733] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6991), 16,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [172793] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7422), 1,
      aux_sym_concatenation_token1,
    ACTIONS(7577), 1,
      sym__concat,
    STATE(3283), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [172843] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6852), 1,
      anon_sym_RBRACK,
    ACTIONS(7332), 1,
      anon_sym_EQ,
    ACTIONS(7338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7342), 1,
      anon_sym_PIPE,
    ACTIONS(7344), 1,
      anon_sym_CARET,
    ACTIONS(7346), 1,
      anon_sym_AMP,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7362), 1,
      anon_sym_EQ_TILDE,
    ACTIONS(7364), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7348), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7336), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [172919] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7422), 1,
      aux_sym_concatenation_token1,
    ACTIONS(7579), 1,
      sym__concat,
    STATE(3283), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [172969] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6989), 14,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
    ACTIONS(6987), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [173013] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7581), 1,
      aux_sym_concatenation_token1,
    ACTIONS(7584), 1,
      sym__concat,
    STATE(3283), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [173063] = 17,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6993), 1,
      anon_sym_EQ,
    ACTIONS(7368), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7370), 1,
      anon_sym_PIPE,
    ACTIONS(7372), 1,
      anon_sym_CARET,
    ACTIONS(7374), 1,
      anon_sym_AMP,
    ACTIONS(7388), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7494), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7500), 1,
      anon_sym_QMARK,
    ACTIONS(7366), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7376), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7380), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7382), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7384), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7386), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6991), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RPAREN,
      anon_sym_EQ_TILDE,
  [173135] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7350), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7352), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(6991), 18,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [173193] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7354), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [173247] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7356), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [173299] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7360), 1,
      anon_sym_STAR_STAR,
    ACTIONS(7334), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7358), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6993), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6991), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_EQ_TILDE,
      anon_sym_QMARK,
  [173349] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7587), 1,
      anon_sym_esac,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6769), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3314), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [173437] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [173490] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(1197), 2,
      sym_file_descriptor,
      ts_builtin_sym_end,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [173543] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(1191), 2,
      sym_file_descriptor,
      ts_builtin_sym_end,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [173596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [173639] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [173682] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [173725] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [173768] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [173811] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 12,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 23,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [173854] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7366), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [173939] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6763), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [174024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [174067] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7016), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [174152] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7019), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [174237] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7031), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [174322] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [174365] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7033), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [174450] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7040), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [174535] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(1197), 2,
      sym_file_descriptor,
      ts_builtin_sym_end,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [174588] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(1191), 2,
      sym_file_descriptor,
      ts_builtin_sym_end,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [174641] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7041), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [174726] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_BQUOTE,
  [174779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [174822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [174865] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7505), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [174950] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_BQUOTE,
  [175003] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [175046] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [175099] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_BQUOTE,
  [175152] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6880), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175237] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7175), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175322] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [175375] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7177), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175460] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7188), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175545] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7189), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175630] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7195), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175715] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7196), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175800] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6805), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175885] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6807), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [175970] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176013] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6821), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [176098] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6823), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [176183] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6830), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [176268] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176311] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6831), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [176396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176439] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(6769), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [176524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176567] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_BQUOTE,
  [176620] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [176673] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176802] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [176855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176898] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [176951] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [176994] = 24,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6376), 1,
      sym_word,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6410), 1,
      sym_test_operator,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7506), 1,
      anon_sym_LPAREN,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6347), 1,
      aux_sym__literal_repeat1,
    STATE(7496), 1,
      sym_last_case_item,
    ACTIONS(7516), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6599), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [177079] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [177131] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3362), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5264), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5266), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177177] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(7609), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7611), 1,
      sym__special_character,
    ACTIONS(7613), 1,
      sym_test_operator,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3360), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(7605), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(7607), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [177255] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4311), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4313), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177301] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5268), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5270), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177347] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [177399] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3362), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177445] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(7611), 1,
      sym__special_character,
    ACTIONS(7613), 1,
      sym_test_operator,
    ACTIONS(7617), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3360), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(7605), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(7615), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [177523] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4437), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4439), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177569] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7619), 1,
      sym_word,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7625), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7628), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7631), 1,
      anon_sym_DOLLAR,
    ACTIONS(7634), 1,
      sym__special_character,
    ACTIONS(7637), 1,
      anon_sym_DQUOTE,
    ACTIONS(7643), 1,
      aux_sym_number_token1,
    ACTIONS(7646), 1,
      aux_sym_number_token2,
    ACTIONS(7649), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7652), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_BQUOTE,
    ACTIONS(7658), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7664), 1,
      sym_test_operator,
    ACTIONS(7667), 1,
      sym_extglob_pattern,
    ACTIONS(7670), 1,
      sym__brace_start,
    STATE(6278), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7640), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3357), 2,
      sym_case_item,
      aux_sym_case_statement_repeat1,
    STATE(6513), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6152), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [177651] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3362), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5130), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5132), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177697] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3359), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7673), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177743] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2169), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(7679), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7682), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7685), 1,
      anon_sym_DOLLAR,
    ACTIONS(7688), 1,
      sym__special_character,
    ACTIONS(7691), 1,
      anon_sym_DQUOTE,
    ACTIONS(7694), 1,
      aux_sym_number_token1,
    ACTIONS(7697), 1,
      aux_sym_number_token2,
    ACTIONS(7700), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7703), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7706), 1,
      anon_sym_BQUOTE,
    ACTIONS(7709), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7715), 1,
      sym_test_operator,
    ACTIONS(7718), 1,
      sym__brace_start,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7712), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3360), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(2167), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    ACTIONS(7676), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [177821] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2156), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(2158), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177867] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7603), 1,
      aux_sym_concatenation_token1,
    ACTIONS(7721), 1,
      sym__concat,
    STATE(3359), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [177915] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7723), 1,
      sym__special_character,
    STATE(3363), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 28,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [177961] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3362), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4280), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4282), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [178007] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(7611), 1,
      sym__special_character,
    ACTIONS(7613), 1,
      sym_test_operator,
    ACTIONS(7728), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3360), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(7605), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(7726), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [178085] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7732), 1,
      anon_sym_SLASH,
    ACTIONS(7734), 1,
      anon_sym_PERCENT,
    ACTIONS(7736), 1,
      anon_sym_COLON,
    ACTIONS(7740), 1,
      anon_sym_RBRACE3,
    ACTIONS(7742), 1,
      anon_sym_AT,
    ACTIONS(7744), 1,
      anon_sym_STAR2,
    STATE(6295), 1,
      aux_sym__expansion_body_repeat1,
    STATE(7102), 1,
      sym__expansion_expression,
    STATE(7104), 1,
      sym__expansion_regex,
    STATE(7130), 1,
      sym__expansion_regex_replacement,
    STATE(7172), 1,
      sym__expansion_regex_removal,
    STATE(7214), 1,
      sym__expansion_max_length,
    STATE(7271), 1,
      sym__expansion_operator,
    ACTIONS(7730), 2,
      anon_sym_COMMA,
      anon_sym_CARET,
    ACTIONS(7750), 2,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
    ACTIONS(7738), 3,
      sym__immediate_double_hash,
      anon_sym_POUND,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7748), 3,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(7746), 8,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
  [178161] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(7611), 1,
      sym__special_character,
    ACTIONS(7613), 1,
      sym_test_operator,
    ACTIONS(7756), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3360), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    ACTIONS(7605), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    ACTIONS(7754), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [178239] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7758), 1,
      sym_word,
    ACTIONS(7760), 1,
      anon_sym_LPAREN,
    ACTIONS(7762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7766), 1,
      anon_sym_DOLLAR,
    ACTIONS(7768), 1,
      sym__special_character,
    ACTIONS(7770), 1,
      anon_sym_DQUOTE,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(7778), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7780), 1,
      anon_sym_RBRACE3,
    ACTIONS(7782), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7784), 1,
      anon_sym_BQUOTE,
    ACTIONS(7786), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7790), 1,
      sym_variable_name,
    ACTIONS(7792), 1,
      sym_test_operator,
    ACTIONS(7794), 1,
      sym__expansion_word,
    ACTIONS(7796), 1,
      sym__brace_start,
    STATE(6232), 1,
      sym_command_substitution,
    STATE(6420), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7772), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7788), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(6312), 5,
      sym_string,
      sym_array,
      sym_simple_expansion,
      sym_expansion,
      sym_process_substitution,
    STATE(6683), 5,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_translated_string,
      sym_number,
      sym__concatenation_in_expansion,
  [178325] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7798), 1,
      sym__special_character,
    STATE(3363), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 28,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [178371] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7760), 1,
      anon_sym_LPAREN,
    ACTIONS(7762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7766), 1,
      anon_sym_DOLLAR,
    ACTIONS(7768), 1,
      sym__special_character,
    ACTIONS(7770), 1,
      anon_sym_DQUOTE,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(7778), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7782), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7784), 1,
      anon_sym_BQUOTE,
    ACTIONS(7786), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7790), 1,
      sym_variable_name,
    ACTIONS(7796), 1,
      sym__brace_start,
    ACTIONS(7800), 1,
      sym_word,
    ACTIONS(7804), 1,
      anon_sym_RBRACE3,
    ACTIONS(7806), 1,
      sym_test_operator,
    ACTIONS(7808), 1,
      sym__expansion_word,
    STATE(6224), 1,
      sym_command_substitution,
    STATE(6398), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7788), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(7802), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6315), 5,
      sym_string,
      sym_array,
      sym_simple_expansion,
      sym_expansion,
      sym_process_substitution,
    STATE(6658), 5,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_translated_string,
      sym_number,
      sym__concatenation_in_expansion,
  [178457] = 25,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7760), 1,
      anon_sym_LPAREN,
    ACTIONS(7762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7766), 1,
      anon_sym_DOLLAR,
    ACTIONS(7768), 1,
      sym__special_character,
    ACTIONS(7770), 1,
      anon_sym_DQUOTE,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(7778), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7782), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7784), 1,
      anon_sym_BQUOTE,
    ACTIONS(7786), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7790), 1,
      sym_variable_name,
    ACTIONS(7796), 1,
      sym__brace_start,
    ACTIONS(7810), 1,
      sym_word,
    ACTIONS(7814), 1,
      anon_sym_RBRACE3,
    ACTIONS(7816), 1,
      sym_test_operator,
    ACTIONS(7818), 1,
      sym__expansion_word,
    STATE(6197), 1,
      sym_command_substitution,
    STATE(6433), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7788), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(7812), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6371), 5,
      sym_string,
      sym_array,
      sym_simple_expansion,
      sym_expansion,
      sym_process_substitution,
    STATE(6665), 5,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_translated_string,
      sym_number,
      sym__concatenation_in_expansion,
  [178543] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7603), 1,
      aux_sym_concatenation_token1,
    ACTIONS(7820), 1,
      sym__concat,
    STATE(3359), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [178591] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5134), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5136), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [178637] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3372), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2160), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(2162), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [178683] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [178735] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(3362), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(7603), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4307), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(4309), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [178781] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [178833] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7732), 1,
      anon_sym_SLASH,
    ACTIONS(7734), 1,
      anon_sym_PERCENT,
    ACTIONS(7736), 1,
      anon_sym_COLON,
    ACTIONS(7740), 1,
      anon_sym_RBRACE3,
    ACTIONS(7822), 1,
      anon_sym_AT,
    STATE(6277), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6713), 1,
      sym__expansion_regex,
    STATE(6724), 1,
      sym__expansion_regex_replacement,
    STATE(6766), 1,
      sym__expansion_regex_removal,
    STATE(6768), 1,
      sym__expansion_max_length,
    STATE(6790), 1,
      sym__expansion_operator,
    STATE(7337), 1,
      sym__expansion_expression,
    ACTIONS(7730), 2,
      anon_sym_COMMA,
      anon_sym_CARET,
    ACTIONS(7750), 2,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
    ACTIONS(7738), 3,
      sym__immediate_double_hash,
      anon_sym_POUND,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7748), 3,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(7746), 8,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
  [178906] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [178947] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [178988] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7824), 1,
      sym_word,
    ACTIONS(7826), 1,
      anon_sym_LPAREN,
    ACTIONS(7828), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7830), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7832), 1,
      anon_sym_DOLLAR,
    ACTIONS(7834), 1,
      sym__special_character,
    ACTIONS(7836), 1,
      anon_sym_DQUOTE,
    ACTIONS(7840), 1,
      aux_sym_number_token1,
    ACTIONS(7842), 1,
      aux_sym_number_token2,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7854), 1,
      sym__comment_word,
    ACTIONS(7856), 1,
      sym__empty_value,
    ACTIONS(7858), 1,
      sym_test_operator,
    ACTIONS(7860), 1,
      sym__brace_start,
    STATE(2618), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7838), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7852), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2852), 2,
      sym_concatenation,
      sym_array,
    STATE(2346), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179069] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [179110] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [179151] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7862), 1,
      sym_word,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7868), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7870), 1,
      anon_sym_DOLLAR,
    ACTIONS(7872), 1,
      sym__special_character,
    ACTIONS(7874), 1,
      anon_sym_DQUOTE,
    ACTIONS(7878), 1,
      aux_sym_number_token1,
    ACTIONS(7880), 1,
      aux_sym_number_token2,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7884), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7892), 1,
      sym__comment_word,
    ACTIONS(7894), 1,
      sym__empty_value,
    ACTIONS(7896), 1,
      sym_test_operator,
    ACTIONS(7898), 1,
      sym__brace_start,
    STATE(1819), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7876), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2036), 2,
      sym_concatenation,
      sym_array,
    STATE(1363), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179232] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7732), 1,
      anon_sym_SLASH,
    ACTIONS(7734), 1,
      anon_sym_PERCENT,
    ACTIONS(7736), 1,
      anon_sym_COLON,
    ACTIONS(7822), 1,
      anon_sym_AT,
    ACTIONS(7900), 1,
      anon_sym_RBRACE3,
    STATE(6318), 1,
      aux_sym__expansion_body_repeat1,
    STATE(7117), 1,
      sym__expansion_expression,
    STATE(7166), 1,
      sym__expansion_operator,
    STATE(7216), 1,
      sym__expansion_regex,
    STATE(7249), 1,
      sym__expansion_max_length,
    STATE(7419), 1,
      sym__expansion_regex_replacement,
    STATE(7423), 1,
      sym__expansion_regex_removal,
    ACTIONS(7730), 2,
      anon_sym_COMMA,
      anon_sym_CARET,
    ACTIONS(7750), 2,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
    ACTIONS(7738), 3,
      sym__immediate_double_hash,
      anon_sym_POUND,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7748), 3,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(7746), 8,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
  [179305] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7732), 1,
      anon_sym_SLASH,
    ACTIONS(7734), 1,
      anon_sym_PERCENT,
    ACTIONS(7736), 1,
      anon_sym_COLON,
    ACTIONS(7822), 1,
      anon_sym_AT,
    ACTIONS(7902), 1,
      anon_sym_RBRACE3,
    STATE(6317), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6704), 1,
      sym__expansion_regex_replacement,
    STATE(6715), 1,
      sym__expansion_expression,
    STATE(6784), 1,
      sym__expansion_max_length,
    STATE(6811), 1,
      sym__expansion_operator,
    STATE(7373), 1,
      sym__expansion_regex_removal,
    STATE(7414), 1,
      sym__expansion_regex,
    ACTIONS(7730), 2,
      anon_sym_COMMA,
      anon_sym_CARET,
    ACTIONS(7750), 2,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
    ACTIONS(7738), 3,
      sym__immediate_double_hash,
      anon_sym_POUND,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7748), 3,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(7746), 8,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
  [179378] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2067), 1,
      anon_sym_DOLLAR,
    ACTIONS(2073), 1,
      aux_sym_number_token1,
    ACTIONS(2075), 1,
      aux_sym_number_token2,
    ACTIONS(2079), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2093), 1,
      sym__brace_start,
    ACTIONS(7904), 1,
      sym_word,
    ACTIONS(7906), 1,
      anon_sym_LPAREN,
    ACTIONS(7908), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7910), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7912), 1,
      sym__special_character,
    ACTIONS(7914), 1,
      anon_sym_DQUOTE,
    ACTIONS(7918), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7920), 1,
      anon_sym_BQUOTE,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7926), 1,
      sym__comment_word,
    ACTIONS(7928), 1,
      sym__empty_value,
    ACTIONS(7930), 1,
      sym_test_operator,
    STATE(1756), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7916), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7924), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1911), 2,
      sym_concatenation,
      sym_array,
    STATE(1447), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179459] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7932), 1,
      sym_word,
    ACTIONS(7934), 1,
      anon_sym_LPAREN,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7940), 1,
      anon_sym_DOLLAR,
    ACTIONS(7942), 1,
      sym__special_character,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7962), 1,
      sym__comment_word,
    ACTIONS(7964), 1,
      sym__empty_value,
    ACTIONS(7966), 1,
      sym_test_operator,
    ACTIONS(7968), 1,
      sym__brace_start,
    STATE(4223), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7946), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(4668), 2,
      sym_concatenation,
      sym_array,
    STATE(4375), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179540] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7970), 1,
      sym_word,
    ACTIONS(7972), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7978), 1,
      anon_sym_DOLLAR,
    ACTIONS(7980), 1,
      sym__special_character,
    ACTIONS(7982), 1,
      anon_sym_DQUOTE,
    ACTIONS(7986), 1,
      aux_sym_number_token1,
    ACTIONS(7988), 1,
      aux_sym_number_token2,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7992), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8000), 1,
      sym__comment_word,
    ACTIONS(8002), 1,
      sym__empty_value,
    ACTIONS(8004), 1,
      sym_test_operator,
    ACTIONS(8006), 1,
      sym__brace_start,
    STATE(3452), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7984), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(7998), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3701), 2,
      sym_concatenation,
      sym_array,
    STATE(3352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179621] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8008), 1,
      sym_word,
    ACTIONS(8010), 1,
      anon_sym_LPAREN,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8016), 1,
      sym__special_character,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8030), 1,
      sym__comment_word,
    ACTIONS(8032), 1,
      sym__empty_value,
    ACTIONS(8034), 1,
      sym_test_operator,
    STATE(1828), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8020), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2056), 2,
      sym_concatenation,
      sym_array,
    STATE(1377), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179702] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7934), 1,
      anon_sym_LPAREN,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7940), 1,
      anon_sym_DOLLAR,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7962), 1,
      sym__comment_word,
    ACTIONS(7964), 1,
      sym__empty_value,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(8036), 1,
      sym_word,
    ACTIONS(8038), 1,
      sym__special_character,
    ACTIONS(8042), 1,
      sym_test_operator,
    STATE(4223), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8040), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4668), 2,
      sym_concatenation,
      sym_array,
    STATE(4422), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179783] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7934), 1,
      anon_sym_LPAREN,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7940), 1,
      anon_sym_DOLLAR,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7962), 1,
      sym__comment_word,
    ACTIONS(7964), 1,
      sym__empty_value,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(8044), 1,
      sym_word,
    ACTIONS(8046), 1,
      sym__special_character,
    ACTIONS(8050), 1,
      sym_test_operator,
    STATE(4223), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8048), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4668), 2,
      sym_concatenation,
      sym_array,
    STATE(4603), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179864] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4064), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4066), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4068), 1,
      anon_sym_DOLLAR,
    ACTIONS(4070), 1,
      sym__special_character,
    ACTIONS(4072), 1,
      anon_sym_DQUOTE,
    ACTIONS(4076), 1,
      aux_sym_number_token1,
    ACTIONS(4078), 1,
      aux_sym_number_token2,
    ACTIONS(4080), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4082), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4084), 1,
      anon_sym_BQUOTE,
    ACTIONS(4086), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4096), 1,
      sym__brace_start,
    ACTIONS(8052), 1,
      sym_word,
    ACTIONS(8054), 1,
      anon_sym_LPAREN,
    ACTIONS(8058), 1,
      sym__comment_word,
    ACTIONS(8060), 1,
      sym__empty_value,
    ACTIONS(8062), 1,
      sym_test_operator,
    STATE(2605), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4088), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8056), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2901), 2,
      sym_concatenation,
      sym_array,
    STATE(2371), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [179945] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8064), 1,
      sym_word,
    ACTIONS(8066), 1,
      anon_sym_LPAREN,
    ACTIONS(8068), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8070), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8072), 1,
      anon_sym_DOLLAR,
    ACTIONS(8074), 1,
      sym__special_character,
    ACTIONS(8076), 1,
      anon_sym_DQUOTE,
    ACTIONS(8080), 1,
      aux_sym_number_token1,
    ACTIONS(8082), 1,
      aux_sym_number_token2,
    ACTIONS(8084), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8088), 1,
      anon_sym_BQUOTE,
    ACTIONS(8090), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8094), 1,
      sym__comment_word,
    ACTIONS(8096), 1,
      sym__empty_value,
    ACTIONS(8098), 1,
      sym_test_operator,
    ACTIONS(8100), 1,
      sym__brace_start,
    STATE(5287), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8078), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8092), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(5507), 2,
      sym_concatenation,
      sym_array,
    STATE(5124), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [180026] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7934), 1,
      anon_sym_LPAREN,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7940), 1,
      anon_sym_DOLLAR,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7962), 1,
      sym__comment_word,
    ACTIONS(7964), 1,
      sym__empty_value,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(8102), 1,
      sym_word,
    ACTIONS(8104), 1,
      sym__special_character,
    ACTIONS(8108), 1,
      sym_test_operator,
    STATE(4223), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8106), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4668), 2,
      sym_concatenation,
      sym_array,
    STATE(4503), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [180107] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8110), 1,
      sym_word,
    ACTIONS(8112), 1,
      anon_sym_LPAREN,
    ACTIONS(8114), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8116), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8118), 1,
      anon_sym_DOLLAR,
    ACTIONS(8120), 1,
      sym__special_character,
    ACTIONS(8122), 1,
      anon_sym_DQUOTE,
    ACTIONS(8126), 1,
      aux_sym_number_token1,
    ACTIONS(8128), 1,
      aux_sym_number_token2,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8140), 1,
      sym__comment_word,
    ACTIONS(8142), 1,
      sym__empty_value,
    ACTIONS(8144), 1,
      sym_test_operator,
    ACTIONS(8146), 1,
      sym__brace_start,
    STATE(1411), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8124), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8138), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1655), 2,
      sym_concatenation,
      sym_array,
    STATE(1122), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [180188] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7934), 1,
      anon_sym_LPAREN,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7940), 1,
      anon_sym_DOLLAR,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7962), 1,
      sym__comment_word,
    ACTIONS(7964), 1,
      sym__empty_value,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(8148), 1,
      sym_word,
    ACTIONS(8150), 1,
      sym__special_character,
    ACTIONS(8154), 1,
      sym_test_operator,
    STATE(4223), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8152), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4668), 2,
      sym_concatenation,
      sym_array,
    STATE(5077), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [180269] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_DOLLAR,
    ACTIONS(1597), 1,
      aux_sym_number_token1,
    ACTIONS(1599), 1,
      aux_sym_number_token2,
    ACTIONS(1603), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1617), 1,
      sym__brace_start,
    ACTIONS(8156), 1,
      sym_word,
    ACTIONS(8158), 1,
      anon_sym_LPAREN,
    ACTIONS(8160), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8162), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8164), 1,
      sym__special_character,
    ACTIONS(8166), 1,
      anon_sym_DQUOTE,
    ACTIONS(8170), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8172), 1,
      anon_sym_BQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8178), 1,
      sym__comment_word,
    ACTIONS(8180), 1,
      sym__empty_value,
    ACTIONS(8182), 1,
      sym_test_operator,
    STATE(1425), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8168), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8176), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1660), 2,
      sym_concatenation,
      sym_array,
    STATE(1124), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [180350] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8184), 1,
      sym_word,
    ACTIONS(8186), 1,
      anon_sym_LPAREN,
    ACTIONS(8188), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8190), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8192), 1,
      anon_sym_DOLLAR,
    ACTIONS(8194), 1,
      sym__special_character,
    ACTIONS(8196), 1,
      anon_sym_DQUOTE,
    ACTIONS(8200), 1,
      aux_sym_number_token1,
    ACTIONS(8202), 1,
      aux_sym_number_token2,
    ACTIONS(8204), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8206), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8208), 1,
      anon_sym_BQUOTE,
    ACTIONS(8210), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8214), 1,
      sym__comment_word,
    ACTIONS(8216), 1,
      sym__empty_value,
    ACTIONS(8218), 1,
      sym_test_operator,
    ACTIONS(8220), 1,
      sym__brace_start,
    STATE(4317), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8198), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8212), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(4604), 2,
      sym_concatenation,
      sym_array,
    STATE(4148), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [180431] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8222), 1,
      sym_word,
    ACTIONS(8224), 1,
      anon_sym_LPAREN,
    ACTIONS(8226), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8228), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8230), 1,
      anon_sym_DOLLAR,
    ACTIONS(8232), 1,
      sym__special_character,
    ACTIONS(8234), 1,
      anon_sym_DQUOTE,
    ACTIONS(8238), 1,
      aux_sym_number_token1,
    ACTIONS(8240), 1,
      aux_sym_number_token2,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8244), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8252), 1,
      sym__comment_word,
    ACTIONS(8254), 1,
      sym__empty_value,
    ACTIONS(8256), 1,
      sym_test_operator,
    ACTIONS(8258), 1,
      sym__brace_start,
    STATE(1480), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8236), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8250), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1906), 2,
      sym_concatenation,
      sym_array,
    STATE(1234), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [180512] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1883), 1,
      anon_sym_DOLLAR,
    ACTIONS(1889), 1,
      aux_sym_number_token1,
    ACTIONS(1891), 1,
      aux_sym_number_token2,
    ACTIONS(1895), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1909), 1,
      sym__brace_start,
    ACTIONS(8260), 1,
      sym_word,
    ACTIONS(8262), 1,
      anon_sym_LPAREN,
    ACTIONS(8264), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8266), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8268), 1,
      sym__special_character,
    ACTIONS(8270), 1,
      anon_sym_DQUOTE,
    ACTIONS(8274), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8276), 1,
      anon_sym_BQUOTE,
    ACTIONS(8278), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8282), 1,
      sym__comment_word,
    ACTIONS(8284), 1,
      sym__empty_value,
    ACTIONS(8286), 1,
      sym_test_operator,
    STATE(1471), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8272), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8280), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1874), 2,
      sym_concatenation,
      sym_array,
    STATE(1265), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [180593] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [180634] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7732), 1,
      anon_sym_SLASH,
    ACTIONS(7734), 1,
      anon_sym_PERCENT,
    ACTIONS(7736), 1,
      anon_sym_COLON,
    ACTIONS(7822), 1,
      anon_sym_AT,
    ACTIONS(8288), 1,
      anon_sym_RBRACE3,
    STATE(6345), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6756), 1,
      sym__expansion_regex,
    STATE(6772), 1,
      sym__expansion_regex_replacement,
    STATE(6975), 1,
      sym__expansion_regex_removal,
    STATE(7001), 1,
      sym__expansion_max_length,
    STATE(7010), 1,
      sym__expansion_operator,
    STATE(7255), 1,
      sym__expansion_expression,
    ACTIONS(7730), 2,
      anon_sym_COMMA,
      anon_sym_CARET,
    ACTIONS(7750), 2,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
    ACTIONS(7738), 3,
      sym__immediate_double_hash,
      anon_sym_POUND,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7748), 3,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(7746), 8,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
  [180707] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [180748] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [180789] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [180830] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [180871] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [180912] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [180953] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [180994] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [181035] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [181076] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [181117] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [181158] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [181199] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(8294), 1,
      sym_variable_name,
    STATE(4874), 1,
      sym_string,
    ACTIONS(1197), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(8292), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(8290), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 18,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [181250] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(8294), 1,
      sym_variable_name,
    STATE(4874), 1,
      sym_string,
    ACTIONS(1191), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(8292), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(8290), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 18,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [181301] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [181342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [181383] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8296), 1,
      sym_word,
    ACTIONS(8298), 1,
      anon_sym_LPAREN,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8306), 1,
      sym__special_character,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8326), 1,
      sym__comment_word,
    ACTIONS(8328), 1,
      sym__empty_value,
    ACTIONS(8330), 1,
      sym_test_operator,
    ACTIONS(8332), 1,
      sym__brace_start,
    STATE(1720), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8310), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(2043), 2,
      sym_concatenation,
      sym_array,
    STATE(1678), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [181464] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8010), 1,
      anon_sym_LPAREN,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8030), 1,
      sym__comment_word,
    ACTIONS(8032), 1,
      sym__empty_value,
    ACTIONS(8334), 1,
      sym_word,
    ACTIONS(8336), 1,
      sym__special_character,
    ACTIONS(8340), 1,
      sym_test_operator,
    STATE(1828), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8338), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2056), 2,
      sym_concatenation,
      sym_array,
    STATE(1686), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [181545] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 22,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [181586] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8298), 1,
      anon_sym_LPAREN,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8326), 1,
      sym__comment_word,
    ACTIONS(8328), 1,
      sym__empty_value,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8342), 1,
      sym_word,
    ACTIONS(8344), 1,
      sym__special_character,
    ACTIONS(8348), 1,
      sym_test_operator,
    STATE(1720), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8346), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2043), 2,
      sym_concatenation,
      sym_array,
    STATE(1386), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [181667] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8298), 1,
      anon_sym_LPAREN,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8326), 1,
      sym__comment_word,
    ACTIONS(8328), 1,
      sym__empty_value,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8350), 1,
      sym_word,
    ACTIONS(8352), 1,
      sym__special_character,
    ACTIONS(8356), 1,
      sym_test_operator,
    STATE(1720), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8354), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2043), 2,
      sym_concatenation,
      sym_array,
    STATE(2297), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [181748] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8010), 1,
      anon_sym_LPAREN,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8030), 1,
      sym__comment_word,
    ACTIONS(8032), 1,
      sym__empty_value,
    ACTIONS(8358), 1,
      sym_word,
    ACTIONS(8360), 1,
      sym__special_character,
    ACTIONS(8364), 1,
      sym_test_operator,
    STATE(1828), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8362), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2056), 2,
      sym_concatenation,
      sym_array,
    STATE(2301), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [181829] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8366), 1,
      sym_word,
    ACTIONS(8368), 1,
      anon_sym_LPAREN,
    ACTIONS(8370), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8372), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8374), 1,
      anon_sym_DOLLAR,
    ACTIONS(8376), 1,
      sym__special_character,
    ACTIONS(8378), 1,
      anon_sym_DQUOTE,
    ACTIONS(8382), 1,
      aux_sym_number_token1,
    ACTIONS(8384), 1,
      aux_sym_number_token2,
    ACTIONS(8386), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8388), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8390), 1,
      anon_sym_BQUOTE,
    ACTIONS(8392), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8396), 1,
      sym__comment_word,
    ACTIONS(8398), 1,
      sym__empty_value,
    ACTIONS(8400), 1,
      sym_test_operator,
    ACTIONS(8402), 1,
      sym__brace_start,
    STATE(4407), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8380), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8394), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(4700), 2,
      sym_concatenation,
      sym_array,
    STATE(4237), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [181910] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8404), 1,
      sym__special_character,
    STATE(3454), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5687), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5689), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [181954] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8420), 1,
      sym_raw_string,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8434), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(8436), 1,
      sym_variable_name,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3429), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3017), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182034] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8438), 1,
      sym_raw_string,
    ACTIONS(8440), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2809), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182114] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8442), 1,
      sym_raw_string,
    ACTIONS(8444), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3434), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2810), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182194] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8446), 1,
      sym_raw_string,
    ACTIONS(8448), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2981), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182274] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8404), 1,
      sym__special_character,
    STATE(3454), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4307), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4309), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [182318] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(8452), 1,
      anon_sym_DQUOTE,
    ACTIONS(8456), 1,
      sym_variable_name,
    STATE(5176), 1,
      sym_string,
    ACTIONS(8454), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(8450), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 18,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [182368] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8458), 1,
      sym_raw_string,
    ACTIONS(8460), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2816), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182448] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8462), 1,
      sym_raw_string,
    ACTIONS(8464), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3436), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2817), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182528] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8466), 1,
      sym_raw_string,
    ACTIONS(8468), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2821), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182608] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8470), 1,
      sym_raw_string,
    ACTIONS(8472), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3439), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2823), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182688] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8474), 1,
      sym_raw_string,
    ACTIONS(8476), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3431), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2863), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182768] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8478), 1,
      sym_raw_string,
    ACTIONS(8480), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2827), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182848] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8482), 1,
      sym_raw_string,
    ACTIONS(8484), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3441), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2828), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [182928] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8486), 1,
      sym_raw_string,
    ACTIONS(8488), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2830), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [183008] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8404), 1,
      sym__special_character,
    STATE(3454), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5130), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5132), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [183052] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(8452), 1,
      anon_sym_DQUOTE,
    ACTIONS(8456), 1,
      sym_variable_name,
    STATE(5176), 1,
      sym_string,
    ACTIONS(8454), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(8450), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 18,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [183102] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8490), 1,
      anon_sym_LPAREN,
    ACTIONS(8493), 1,
      anon_sym_BANG,
    ACTIONS(8502), 1,
      anon_sym_TILDE,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8508), 1,
      anon_sym_DQUOTE,
    ACTIONS(8511), 1,
      sym_raw_string,
    ACTIONS(8514), 1,
      aux_sym_number_token1,
    ACTIONS(8517), 1,
      aux_sym_number_token2,
    ACTIONS(8520), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8523), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8526), 1,
      anon_sym_BQUOTE,
    ACTIONS(8529), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8532), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(8535), 1,
      sym_variable_name,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8496), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8499), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3214), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [183182] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8538), 1,
      sym_raw_string,
    ACTIONS(8540), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3447), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2942), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [183262] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8542), 1,
      sym_raw_string,
    ACTIONS(8544), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3448), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2980), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [183342] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8546), 1,
      sym_raw_string,
    ACTIONS(8548), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2947), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [183422] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8550), 1,
      sym_raw_string,
    ACTIONS(8552), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2986), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [183502] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8404), 1,
      sym__special_character,
    STATE(3454), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4280), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4282), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [183546] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 18,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [183596] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8404), 1,
      sym__special_character,
    STATE(3454), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5561), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5563), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [183640] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8404), 1,
      sym__special_character,
    STATE(3454), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5264), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5266), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [183684] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8554), 1,
      sym_raw_string,
    ACTIONS(8556), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3456), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2993), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [183764] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8558), 1,
      sym__special_character,
    STATE(3454), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 20,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [183808] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 18,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [183858] = 23,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8561), 1,
      sym_raw_string,
    ACTIONS(8563), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    STATE(3444), 1,
      aux_sym_compound_statement_repeat1,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3010), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [183938] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8579), 1,
      sym_raw_string,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8593), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(8595), 1,
      sym_variable_name,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3030), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184015] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8611), 1,
      sym_raw_string,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8625), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(8627), 1,
      sym_variable_name,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3029), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184092] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8629), 1,
      sym_raw_string,
    ACTIONS(8631), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3032), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184169] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8635), 1,
      anon_sym_RPAREN,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3462), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [184244] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8667), 1,
      sym_raw_string,
    ACTIONS(8669), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3035), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184321] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8671), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [184396] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8673), 1,
      sym_raw_string,
    ACTIONS(8675), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3037), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184473] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(8677), 1,
      sym_raw_string,
    ACTIONS(8679), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3173), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184550] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8681), 1,
      sym_raw_string,
    ACTIONS(8683), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3039), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184627] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8685), 1,
      sym_raw_string,
    ACTIONS(8687), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3041), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184704] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(8689), 1,
      sym_raw_string,
    ACTIONS(8691), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3175), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184781] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8693), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3470), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [184856] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8695), 1,
      sym_raw_string,
    ACTIONS(8697), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3043), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [184933] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8699), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185008] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8701), 1,
      sym_raw_string,
    ACTIONS(8703), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3212), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [185085] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8705), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3473), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185160] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8707), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185235] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8709), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185310] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8711), 1,
      sym_raw_string,
    ACTIONS(8713), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3045), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [185387] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8715), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3477), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185462] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8717), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185537] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8719), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3479), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185612] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8721), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185687] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8723), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3485), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185762] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8725), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3482), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185837] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8727), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185912] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8729), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3484), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [185987] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8731), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [186062] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8733), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [186137] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8735), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3487), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [186212] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8737), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [186287] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2169), 1,
      anon_sym_RPAREN,
    ACTIONS(8739), 1,
      sym_word,
    ACTIONS(8742), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8745), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8748), 1,
      anon_sym_DOLLAR,
    ACTIONS(8751), 1,
      sym__special_character,
    ACTIONS(8754), 1,
      anon_sym_DQUOTE,
    ACTIONS(8760), 1,
      aux_sym_number_token1,
    ACTIONS(8763), 1,
      aux_sym_number_token2,
    ACTIONS(8766), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8769), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8772), 1,
      anon_sym_BQUOTE,
    ACTIONS(8775), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8781), 1,
      sym_test_operator,
    ACTIONS(8784), 1,
      sym__brace_start,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8757), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8778), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [186362] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8787), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3490), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [186437] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8789), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [186512] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5860), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5872), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [186551] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8794), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(8796), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8799), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8802), 1,
      anon_sym_DOLLAR,
    ACTIONS(8805), 1,
      sym__special_character,
    ACTIONS(8808), 1,
      anon_sym_DQUOTE,
    ACTIONS(8811), 1,
      aux_sym_number_token1,
    ACTIONS(8814), 1,
      aux_sym_number_token2,
    ACTIONS(8817), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8820), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8823), 1,
      anon_sym_BQUOTE,
    ACTIONS(8826), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8832), 1,
      sym_test_operator,
    ACTIONS(8835), 1,
      sym__brace_start,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(8829), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8791), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [186626] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8838), 1,
      sym_raw_string,
    ACTIONS(8840), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2752), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [186703] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8842), 1,
      sym_raw_string,
    ACTIONS(8844), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2617), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [186780] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8846), 1,
      sym_raw_string,
    ACTIONS(8848), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2765), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [186857] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8850), 1,
      sym_raw_string,
    ACTIONS(8852), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2619), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [186934] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8854), 1,
      sym_raw_string,
    ACTIONS(8856), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2766), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187011] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8858), 1,
      sym_raw_string,
    ACTIONS(8860), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2767), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187088] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8862), 1,
      sym_word,
    ACTIONS(8866), 1,
      sym_test_operator,
    STATE(6356), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8864), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6611), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6248), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [187163] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8868), 1,
      sym_raw_string,
    ACTIONS(8870), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2768), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187240] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8872), 1,
      sym_raw_string,
    ACTIONS(8874), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2623), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187317] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8876), 1,
      sym_raw_string,
    ACTIONS(8878), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2889), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187394] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7732), 1,
      anon_sym_SLASH,
    ACTIONS(7734), 1,
      anon_sym_PERCENT,
    ACTIONS(7736), 1,
      anon_sym_COLON,
    ACTIONS(7740), 1,
      anon_sym_RBRACE3,
    ACTIONS(7742), 1,
      anon_sym_AT,
    ACTIONS(7744), 1,
      anon_sym_STAR2,
    ACTIONS(8880), 1,
      anon_sym_LBRACK,
    STATE(6898), 1,
      sym__expansion_max_length,
    STATE(7219), 1,
      sym__expansion_operator,
    STATE(7245), 1,
      sym__expansion_expression,
    STATE(7425), 1,
      sym__expansion_regex,
    STATE(7426), 1,
      sym__expansion_regex_replacement,
    STATE(7427), 1,
      sym__expansion_regex_removal,
    ACTIONS(7730), 2,
      anon_sym_COMMA,
      anon_sym_CARET,
    ACTIONS(7750), 2,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
    ACTIONS(7738), 3,
      sym__immediate_double_hash,
      anon_sym_POUND,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7748), 3,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
    ACTIONS(7746), 8,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
  [187465] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8882), 1,
      sym_raw_string,
    ACTIONS(8884), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3203), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187542] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8886), 1,
      sym_raw_string,
    ACTIONS(8888), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3208), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187619] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8890), 1,
      sym_raw_string,
    ACTIONS(8892), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3210), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187696] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8894), 1,
      sym_word,
    ACTIONS(8898), 1,
      sym_test_operator,
    STATE(6413), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(8896), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6660), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6313), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [187771] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8900), 1,
      sym_raw_string,
    ACTIONS(8902), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2771), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187848] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [187897] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8904), 1,
      sym_raw_string,
    ACTIONS(8906), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2656), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [187974] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(8908), 1,
      sym_raw_string,
    ACTIONS(8910), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3147), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [188051] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [188100] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8912), 1,
      sym_raw_string,
    ACTIONS(8914), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3149), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [188177] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8916), 1,
      sym_raw_string,
    ACTIONS(8918), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3158), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [188254] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8920), 1,
      sym_raw_string,
    ACTIONS(8922), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2772), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [188331] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2160), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2162), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [188370] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8924), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [188445] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8926), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [188520] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8928), 1,
      sym_raw_string,
    ACTIONS(8930), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2773), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [188597] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4311), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4313), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [188636] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8932), 1,
      sym_raw_string,
    ACTIONS(8934), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2774), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [188713] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8936), 1,
      sym_raw_string,
    ACTIONS(8938), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2659), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [188790] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(8940), 1,
      sym_raw_string,
    ACTIONS(8942), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3179), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [188867] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8944), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3530), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [188942] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(8946), 1,
      sym_raw_string,
    ACTIONS(8948), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3180), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [189019] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8950), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [189094] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8952), 1,
      sym_raw_string,
    ACTIONS(8954), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3181), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [189171] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8956), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [189246] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8958), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [189321] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8960), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [189396] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8962), 1,
      sym_raw_string,
    ACTIONS(8964), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2791), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [189473] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(8966), 1,
      sym_raw_string,
    ACTIONS(8968), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3155), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [189550] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8970), 1,
      sym_raw_string,
    ACTIONS(8972), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2803), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [189627] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(8974), 1,
      sym_raw_string,
    ACTIONS(8976), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3197), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [189704] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8978), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [189779] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8980), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [189854] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8982), 1,
      sym_raw_string,
    ACTIONS(8984), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2775), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [189931] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(8986), 1,
      sym_raw_string,
    ACTIONS(8988), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2667), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [190008] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(8990), 1,
      sym_raw_string,
    ACTIONS(8992), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3235), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [190085] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8994), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [190160] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(8996), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [190235] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(8998), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3545), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [190310] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9000), 1,
      sym_raw_string,
    ACTIONS(9002), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2669), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [190387] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9004), 1,
      sym_raw_string,
    ACTIONS(9006), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3257), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [190464] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(9008), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [190539] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9010), 1,
      sym_raw_string,
    ACTIONS(9012), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2671), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [190616] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9014), 1,
      sym_raw_string,
    ACTIONS(9016), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3268), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [190693] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9018), 1,
      sym_raw_string,
    ACTIONS(9020), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2672), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [190770] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9022), 1,
      sym_raw_string,
    ACTIONS(9024), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3280), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [190847] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(9026), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3552), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [190922] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(3556), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3560), 1,
      sym__special_character,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3568), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3572), 1,
      anon_sym_BQUOTE,
    ACTIONS(3574), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(3580), 1,
      sym_test_operator,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(9028), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(3492), 1,
      aux_sym__heredoc_command,
    STATE(5338), 1,
      aux_sym__literal_repeat1,
    STATE(5447), 1,
      sym_concatenation,
    ACTIONS(3576), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(3540), 3,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(5043), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [190997] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(9030), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [191072] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9032), 1,
      sym_raw_string,
    ACTIONS(9034), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2673), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191149] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9036), 1,
      sym_raw_string,
    ACTIONS(9038), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3020), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191226] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9040), 1,
      sym_raw_string,
    ACTIONS(9042), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2674), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191303] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9044), 1,
      sym_raw_string,
    ACTIONS(9046), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3023), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191380] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9048), 1,
      sym_raw_string,
    ACTIONS(9050), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2675), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191457] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9052), 1,
      sym_raw_string,
    ACTIONS(9054), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3026), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191534] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9056), 1,
      sym_raw_string,
    ACTIONS(9058), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2676), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191611] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9060), 1,
      sym_raw_string,
    ACTIONS(9062), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3028), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191688] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(9064), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3562), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [191763] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(9066), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [191838] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9068), 1,
      sym_raw_string,
    ACTIONS(9070), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2678), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [191915] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(9072), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3474), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [191990] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9074), 1,
      sym_raw_string,
    ACTIONS(9076), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2679), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192067] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9078), 1,
      sym_raw_string,
    ACTIONS(9080), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3033), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192144] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9082), 1,
      sym_raw_string,
    ACTIONS(9084), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2680), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192221] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9086), 1,
      sym_raw_string,
    ACTIONS(9088), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3036), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192298] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9090), 1,
      sym_raw_string,
    ACTIONS(9092), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2681), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192375] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9094), 1,
      sym_raw_string,
    ACTIONS(9096), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3038), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192452] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9098), 1,
      sym_raw_string,
    ACTIONS(9100), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2682), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192529] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9102), 1,
      sym_raw_string,
    ACTIONS(9104), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3040), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192606] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9106), 1,
      sym_raw_string,
    ACTIONS(9108), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2683), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192683] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9110), 1,
      sym_raw_string,
    ACTIONS(9112), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3042), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192760] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9114), 1,
      sym_raw_string,
    ACTIONS(9116), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2684), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192837] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9118), 1,
      sym_raw_string,
    ACTIONS(9120), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3044), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192914] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9122), 1,
      sym_raw_string,
    ACTIONS(9124), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2685), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [192991] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9126), 1,
      sym_raw_string,
    ACTIONS(9128), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3046), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193068] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(9130), 1,
      sym_raw_string,
    ACTIONS(9132), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3025), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193145] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9134), 1,
      sym_raw_string,
    ACTIONS(9136), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3048), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193222] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9138), 1,
      sym_raw_string,
    ACTIONS(9140), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2688), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193299] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9142), 1,
      sym_raw_string,
    ACTIONS(9144), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3050), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193376] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9146), 1,
      sym_raw_string,
    ACTIONS(9148), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2689), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193453] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9150), 1,
      sym_raw_string,
    ACTIONS(9152), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3052), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193530] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9154), 1,
      sym_raw_string,
    ACTIONS(9156), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2690), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193607] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9158), 1,
      sym_raw_string,
    ACTIONS(9160), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3054), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193684] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9162), 1,
      sym_raw_string,
    ACTIONS(9164), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2691), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193761] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9166), 1,
      sym_raw_string,
    ACTIONS(9168), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3055), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193838] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9170), 1,
      sym_raw_string,
    ACTIONS(9172), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2692), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193915] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9174), 1,
      sym_raw_string,
    ACTIONS(9176), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3057), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [193992] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9178), 1,
      sym_raw_string,
    ACTIONS(9180), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2693), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194069] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9182), 1,
      sym_raw_string,
    ACTIONS(9184), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3058), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194146] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9186), 1,
      sym_raw_string,
    ACTIONS(9188), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2694), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194223] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9190), 1,
      sym_raw_string,
    ACTIONS(9192), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3060), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194300] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9194), 1,
      sym_raw_string,
    ACTIONS(9196), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3266), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194377] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9198), 1,
      sym_raw_string,
    ACTIONS(9200), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2695), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194454] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9202), 1,
      sym_raw_string,
    ACTIONS(9204), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3061), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194531] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9206), 1,
      sym_raw_string,
    ACTIONS(9208), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3269), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194608] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9210), 1,
      sym_raw_string,
    ACTIONS(9212), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3270), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194685] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9214), 1,
      sym_raw_string,
    ACTIONS(9216), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3271), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194762] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9218), 1,
      sym_raw_string,
    ACTIONS(9220), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2696), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194839] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9222), 1,
      sym_raw_string,
    ACTIONS(9224), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3063), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194916] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9226), 1,
      sym_raw_string,
    ACTIONS(9228), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3273), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [194993] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9230), 1,
      sym_raw_string,
    ACTIONS(9232), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2697), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195070] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9234), 1,
      sym_raw_string,
    ACTIONS(9236), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3065), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195147] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9238), 1,
      sym_raw_string,
    ACTIONS(9240), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3276), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195224] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9242), 1,
      sym_raw_string,
    ACTIONS(9244), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2698), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195301] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9246), 1,
      sym_raw_string,
    ACTIONS(9248), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3067), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195378] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9250), 1,
      sym_raw_string,
    ACTIONS(9252), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3278), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195455] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9254), 1,
      sym_raw_string,
    ACTIONS(9256), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3285), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195532] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9258), 1,
      sym_raw_string,
    ACTIONS(9260), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2699), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195609] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9262), 1,
      sym_raw_string,
    ACTIONS(9264), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3069), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195686] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9266), 1,
      sym_raw_string,
    ACTIONS(9268), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3286), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195763] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9270), 1,
      sym_raw_string,
    ACTIONS(9272), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2700), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195840] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9274), 1,
      sym_raw_string,
    ACTIONS(9276), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3071), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195917] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9278), 1,
      sym_raw_string,
    ACTIONS(9280), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2701), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [195994] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9282), 1,
      sym_raw_string,
    ACTIONS(9284), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3072), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196071] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9286), 1,
      sym_raw_string,
    ACTIONS(9288), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2702), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196148] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9290), 1,
      sym_raw_string,
    ACTIONS(9292), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3074), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196225] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9294), 1,
      sym_raw_string,
    ACTIONS(9296), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2703), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196302] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9298), 1,
      sym_raw_string,
    ACTIONS(9300), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3076), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196379] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9302), 1,
      sym_raw_string,
    ACTIONS(9304), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2704), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196456] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9306), 1,
      sym_raw_string,
    ACTIONS(9308), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3079), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196533] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9310), 1,
      sym_raw_string,
    ACTIONS(9312), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2705), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196610] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9314), 1,
      sym_raw_string,
    ACTIONS(9316), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3081), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196687] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9318), 1,
      sym_raw_string,
    ACTIONS(9320), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3287), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196764] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9322), 1,
      sym_raw_string,
    ACTIONS(9324), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3288), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196841] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9326), 1,
      sym_raw_string,
    ACTIONS(9328), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2706), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196918] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9330), 1,
      sym_raw_string,
    ACTIONS(9332), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3083), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [196995] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9334), 1,
      sym_raw_string,
    ACTIONS(9336), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2707), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197072] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9338), 1,
      sym_raw_string,
    ACTIONS(9340), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3084), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197149] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9342), 1,
      sym_raw_string,
    ACTIONS(9344), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3251), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197226] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9346), 1,
      sym_raw_string,
    ACTIONS(9348), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3089), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197303] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9350), 1,
      sym_raw_string,
    ACTIONS(9352), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2708), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197380] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9354), 1,
      sym_raw_string,
    ACTIONS(9356), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3085), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197457] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9358), 1,
      sym_raw_string,
    ACTIONS(9360), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2709), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197534] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9362), 1,
      sym_raw_string,
    ACTIONS(9364), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3086), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197611] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9366), 1,
      sym_raw_string,
    ACTIONS(9368), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2710), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197688] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9370), 1,
      sym_raw_string,
    ACTIONS(9372), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3088), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197765] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(9376), 1,
      anon_sym_DQUOTE,
    ACTIONS(9380), 1,
      sym_variable_name,
    STATE(5347), 1,
      sym_string,
    ACTIONS(9378), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9374), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [197814] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9382), 1,
      sym_raw_string,
    ACTIONS(9384), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2711), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197891] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9386), 1,
      sym_raw_string,
    ACTIONS(9388), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3090), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [197968] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(9376), 1,
      anon_sym_DQUOTE,
    ACTIONS(9380), 1,
      sym_variable_name,
    STATE(5347), 1,
      sym_string,
    ACTIONS(9378), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9374), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [198017] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9390), 1,
      sym_raw_string,
    ACTIONS(9392), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2713), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198094] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9394), 1,
      sym_raw_string,
    ACTIONS(9396), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3093), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198171] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9398), 1,
      sym_raw_string,
    ACTIONS(9400), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2714), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198248] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9402), 1,
      sym_raw_string,
    ACTIONS(9404), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3094), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198325] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9406), 1,
      sym_raw_string,
    ACTIONS(9408), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2716), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198402] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9410), 1,
      sym_raw_string,
    ACTIONS(9412), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3096), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198479] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9414), 1,
      sym_raw_string,
    ACTIONS(9416), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2717), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198556] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9418), 1,
      sym_raw_string,
    ACTIONS(9420), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3098), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198633] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9422), 1,
      sym_raw_string,
    ACTIONS(9424), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2718), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198710] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9426), 1,
      sym_raw_string,
    ACTIONS(9428), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3100), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198787] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9430), 1,
      sym_raw_string,
    ACTIONS(9432), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2719), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198864] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9434), 1,
      sym_raw_string,
    ACTIONS(9436), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3102), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [198941] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9438), 1,
      sym_raw_string,
    ACTIONS(9440), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2720), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199018] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9442), 1,
      sym_raw_string,
    ACTIONS(9444), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3104), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199095] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9446), 1,
      sym_raw_string,
    ACTIONS(9448), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2721), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199172] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9450), 1,
      sym_raw_string,
    ACTIONS(9452), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3106), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199249] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9454), 1,
      sym_raw_string,
    ACTIONS(9456), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2722), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199326] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9458), 1,
      sym_raw_string,
    ACTIONS(9460), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3108), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199403] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5886), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5888), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [199442] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9462), 1,
      sym_raw_string,
    ACTIONS(9464), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2723), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199519] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9466), 1,
      sym_raw_string,
    ACTIONS(9468), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3110), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199596] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9470), 1,
      sym_raw_string,
    ACTIONS(9472), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2724), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199673] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9474), 1,
      sym_raw_string,
    ACTIONS(9476), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3112), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199750] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9478), 1,
      sym_raw_string,
    ACTIONS(9480), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2769), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199827] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9482), 1,
      sym_raw_string,
    ACTIONS(9484), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2725), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199904] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9486), 1,
      sym_raw_string,
    ACTIONS(9488), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3115), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [199981] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9490), 1,
      sym_raw_string,
    ACTIONS(9492), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2726), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200058] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9494), 1,
      sym_raw_string,
    ACTIONS(9496), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3118), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200135] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9498), 1,
      sym_raw_string,
    ACTIONS(9500), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2728), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200212] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9502), 1,
      sym_raw_string,
    ACTIONS(9504), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3121), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200289] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9506), 1,
      sym_raw_string,
    ACTIONS(9508), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2730), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200366] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9510), 1,
      sym_raw_string,
    ACTIONS(9512), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3124), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200443] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9514), 1,
      sym_raw_string,
    ACTIONS(9516), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2731), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200520] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9518), 1,
      sym_raw_string,
    ACTIONS(9520), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3126), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200597] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9522), 1,
      sym_raw_string,
    ACTIONS(9524), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2732), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200674] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9526), 1,
      sym_raw_string,
    ACTIONS(9528), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3128), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200751] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9530), 1,
      sym_raw_string,
    ACTIONS(9532), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2733), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200828] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9534), 1,
      sym_raw_string,
    ACTIONS(9536), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3130), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200905] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9538), 1,
      sym_raw_string,
    ACTIONS(9540), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2734), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [200982] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9542), 1,
      sym_raw_string,
    ACTIONS(9544), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3132), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201059] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9546), 1,
      sym_raw_string,
    ACTIONS(9548), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2735), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201136] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9550), 1,
      sym_raw_string,
    ACTIONS(9552), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3134), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201213] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9554), 1,
      sym_raw_string,
    ACTIONS(9556), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2776), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201290] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [201339] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_heredoc_redirect_token1,
  [201388] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6412), 1,
      sym_extglob_pattern,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7512), 1,
      sym__special_character,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9558), 1,
      sym_word,
    ACTIONS(9562), 1,
      sym_test_operator,
    STATE(6307), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9560), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6456), 2,
      sym_concatenation,
      sym__extglob_blob,
    STATE(6153), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [201463] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9564), 1,
      sym_raw_string,
    ACTIONS(9566), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3113), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201540] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5705), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5707), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [201579] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2156), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(2158), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [201618] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(9568), 1,
      sym_raw_string,
    ACTIONS(9570), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3284), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201695] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(9572), 1,
      sym_raw_string,
    ACTIONS(9574), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3159), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201772] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(9576), 1,
      sym_raw_string,
    ACTIONS(9578), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3156), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201849] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4437), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(4439), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [201888] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(9580), 1,
      sym_raw_string,
    ACTIONS(9582), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3150), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [201965] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(9584), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3700), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [202040] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(9586), 1,
      sym_raw_string,
    ACTIONS(9588), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3021), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [202117] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8633), 1,
      sym_word,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8643), 1,
      sym__special_character,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8663), 1,
      sym_test_operator,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(9590), 1,
      anon_sym_RPAREN,
    STATE(5388), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8647), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3488), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(5021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [202192] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5268), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5270), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [202231] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_BANG,
    ACTIONS(8605), 1,
      anon_sym_TILDE,
    ACTIONS(8607), 1,
      anon_sym_DOLLAR,
    ACTIONS(8609), 1,
      anon_sym_DQUOTE,
    ACTIONS(8613), 1,
      aux_sym_number_token1,
    ACTIONS(8615), 1,
      aux_sym_number_token2,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8627), 1,
      sym_variable_name,
    ACTIONS(9592), 1,
      sym_raw_string,
    ACTIONS(9594), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3262), 1,
      sym__arithmetic_binary_expression,
    STATE(3267), 1,
      sym__arithmetic_ternary_expression,
    STATE(3272), 1,
      sym__arithmetic_unary_expression,
    STATE(3274), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8601), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8603), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3022), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [202308] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 21,
      sym_file_descriptor,
      sym_variable_name,
      sym_test_operator,
      sym__brace_start,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [202347] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9596), 1,
      sym_raw_string,
    ACTIONS(9598), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2770), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [202424] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8565), 1,
      anon_sym_LPAREN,
    ACTIONS(8567), 1,
      anon_sym_BANG,
    ACTIONS(8573), 1,
      anon_sym_TILDE,
    ACTIONS(8575), 1,
      anon_sym_DOLLAR,
    ACTIONS(8577), 1,
      anon_sym_DQUOTE,
    ACTIONS(8581), 1,
      aux_sym_number_token1,
    ACTIONS(8583), 1,
      aux_sym_number_token2,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8595), 1,
      sym_variable_name,
    ACTIONS(9600), 1,
      sym_raw_string,
    ACTIONS(9602), 1,
      aux_sym__simple_variable_name_token1,
    STATE(3024), 1,
      sym__arithmetic_binary_expression,
    STATE(3027), 1,
      sym__arithmetic_ternary_expression,
    STATE(3031), 1,
      sym__arithmetic_unary_expression,
    STATE(3034), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8569), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8571), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(3172), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [202501] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9604), 1,
      sym_raw_string,
    ACTIONS(9606), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2629), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [202578] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(9610), 1,
      anon_sym_DQUOTE,
    ACTIONS(9614), 1,
      sym_variable_name,
    STATE(5321), 1,
      sym_string,
    ACTIONS(9612), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9608), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [202627] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(9610), 1,
      anon_sym_DQUOTE,
    ACTIONS(9614), 1,
      sym_variable_name,
    STATE(5321), 1,
      sym_string,
    ACTIONS(9612), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9608), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [202676] = 22,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_LPAREN,
    ACTIONS(8408), 1,
      anon_sym_BANG,
    ACTIONS(8414), 1,
      anon_sym_TILDE,
    ACTIONS(8416), 1,
      anon_sym_DOLLAR,
    ACTIONS(8418), 1,
      anon_sym_DQUOTE,
    ACTIONS(8422), 1,
      aux_sym_number_token1,
    ACTIONS(8424), 1,
      aux_sym_number_token2,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8436), 1,
      sym_variable_name,
    ACTIONS(9616), 1,
      sym_raw_string,
    ACTIONS(9618), 1,
      aux_sym__simple_variable_name_token1,
    STATE(2712), 1,
      sym__arithmetic_binary_expression,
    STATE(2715), 1,
      sym__arithmetic_ternary_expression,
    STATE(2727), 1,
      sym__arithmetic_unary_expression,
    STATE(2729), 1,
      sym__arithmetic_postfix_expression,
    ACTIONS(8410), 2,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
    ACTIONS(8412), 2,
      anon_sym_DASH2,
      anon_sym_PLUS2,
    STATE(2687), 9,
      sym_subscript,
      sym__arithmetic_expression,
      sym__arithmetic_literal,
      sym__arithmetic_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [202753] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9622), 1,
      anon_sym_DQUOTE,
    ACTIONS(9626), 1,
      sym_variable_name,
    STATE(5125), 1,
      sym_string,
    ACTIONS(1197), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(9624), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9620), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 15,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [202801] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2331), 1,
      sym_word,
    ACTIONS(2337), 1,
      anon_sym_DOLLAR,
    ACTIONS(2343), 1,
      aux_sym_number_token1,
    ACTIONS(2345), 1,
      aux_sym_number_token2,
    ACTIONS(2349), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2357), 1,
      sym_test_operator,
    ACTIONS(2359), 1,
      sym__brace_start,
    ACTIONS(9628), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9630), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9632), 1,
      sym__special_character,
    ACTIONS(9634), 1,
      anon_sym_DQUOTE,
    ACTIONS(9638), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9640), 1,
      anon_sym_BQUOTE,
    ACTIONS(9642), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(1491), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9636), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9644), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(592), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1165), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [202873] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2331), 1,
      sym_word,
    ACTIONS(2337), 1,
      anon_sym_DOLLAR,
    ACTIONS(2343), 1,
      aux_sym_number_token1,
    ACTIONS(2345), 1,
      aux_sym_number_token2,
    ACTIONS(2349), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2357), 1,
      sym_test_operator,
    ACTIONS(2359), 1,
      sym__brace_start,
    ACTIONS(9628), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9630), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9632), 1,
      sym__special_character,
    ACTIONS(9634), 1,
      anon_sym_DQUOTE,
    ACTIONS(9638), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9640), 1,
      anon_sym_BQUOTE,
    ACTIONS(9642), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(1491), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9636), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9644), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(593), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1165), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [202945] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1454), 1,
      anon_sym_DOLLAR,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1478), 1,
      sym__brace_start,
    ACTIONS(9646), 1,
      sym_word,
    ACTIONS(9648), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9650), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9652), 1,
      sym__special_character,
    ACTIONS(9654), 1,
      anon_sym_DQUOTE,
    ACTIONS(9658), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9660), 1,
      anon_sym_BQUOTE,
    ACTIONS(9662), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9666), 1,
      sym_test_operator,
    ACTIONS(9668), 1,
      sym_regex,
    STATE(1395), 1,
      aux_sym__literal_repeat1,
    STATE(1586), 1,
      sym_concatenation,
    ACTIONS(9656), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9664), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1055), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203019] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8226), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8228), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8230), 1,
      anon_sym_DOLLAR,
    ACTIONS(8232), 1,
      sym__special_character,
    ACTIONS(8234), 1,
      anon_sym_DQUOTE,
    ACTIONS(8238), 1,
      aux_sym_number_token1,
    ACTIONS(8240), 1,
      aux_sym_number_token2,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8244), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8258), 1,
      sym__brace_start,
    ACTIONS(9670), 1,
      sym_word,
    ACTIONS(9674), 1,
      sym_test_operator,
    STATE(1501), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8250), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9672), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(595), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1210), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203091] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9678), 1,
      anon_sym_RBRACK,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203161] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8226), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8228), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8230), 1,
      anon_sym_DOLLAR,
    ACTIONS(8232), 1,
      sym__special_character,
    ACTIONS(8234), 1,
      anon_sym_DQUOTE,
    ACTIONS(8238), 1,
      aux_sym_number_token1,
    ACTIONS(8240), 1,
      aux_sym_number_token2,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8244), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8258), 1,
      sym__brace_start,
    ACTIONS(9670), 1,
      sym_word,
    ACTIONS(9674), 1,
      sym_test_operator,
    STATE(1501), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8250), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9672), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(596), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1210), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203233] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(3793), 1,
      sym_word,
    ACTIONS(3797), 1,
      sym_test_operator,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9690), 1,
      sym__special_character,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9694), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(718), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203305] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9704), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203375] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3588), 1,
      sym_word,
    ACTIONS(3594), 1,
      anon_sym_DOLLAR,
    ACTIONS(3600), 1,
      aux_sym_number_token1,
    ACTIONS(3602), 1,
      aux_sym_number_token2,
    ACTIONS(3606), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3614), 1,
      sym_test_operator,
    ACTIONS(3616), 1,
      sym__brace_start,
    ACTIONS(9706), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9708), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9710), 1,
      sym__special_character,
    ACTIONS(9712), 1,
      anon_sym_DQUOTE,
    ACTIONS(9716), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9718), 1,
      anon_sym_BQUOTE,
    ACTIONS(9720), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2279), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9714), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9722), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(690), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1800), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203447] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(3793), 1,
      sym_word,
    ACTIONS(3797), 1,
      sym_test_operator,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9690), 1,
      sym__special_character,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9694), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(720), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203519] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3231), 1,
      sym_word,
    ACTIONS(3237), 1,
      anon_sym_DOLLAR,
    ACTIONS(3243), 1,
      aux_sym_number_token1,
    ACTIONS(3245), 1,
      aux_sym_number_token2,
    ACTIONS(3249), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3257), 1,
      sym_test_operator,
    ACTIONS(3259), 1,
      sym__brace_start,
    ACTIONS(9724), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9726), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9728), 1,
      sym__special_character,
    ACTIONS(9730), 1,
      anon_sym_DQUOTE,
    ACTIONS(9734), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9736), 1,
      anon_sym_BQUOTE,
    ACTIONS(9738), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2110), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9732), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9740), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(660), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1524), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203591] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3588), 1,
      sym_word,
    ACTIONS(3594), 1,
      anon_sym_DOLLAR,
    ACTIONS(3600), 1,
      aux_sym_number_token1,
    ACTIONS(3602), 1,
      aux_sym_number_token2,
    ACTIONS(3606), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3614), 1,
      sym_test_operator,
    ACTIONS(3616), 1,
      sym__brace_start,
    ACTIONS(9706), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9708), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9710), 1,
      sym__special_character,
    ACTIONS(9712), 1,
      anon_sym_DQUOTE,
    ACTIONS(9716), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9718), 1,
      anon_sym_BQUOTE,
    ACTIONS(9720), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2279), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9714), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9722), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(714), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1800), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203663] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3231), 1,
      sym_word,
    ACTIONS(3237), 1,
      anon_sym_DOLLAR,
    ACTIONS(3243), 1,
      aux_sym_number_token1,
    ACTIONS(3245), 1,
      aux_sym_number_token2,
    ACTIONS(3249), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3257), 1,
      sym_test_operator,
    ACTIONS(3259), 1,
      sym__brace_start,
    ACTIONS(9724), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9726), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9728), 1,
      sym__special_character,
    ACTIONS(9730), 1,
      anon_sym_DQUOTE,
    ACTIONS(9734), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9736), 1,
      anon_sym_BQUOTE,
    ACTIONS(9738), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2110), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9732), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9740), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(661), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1524), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203735] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2613), 1,
      sym_word,
    ACTIONS(2619), 1,
      anon_sym_DOLLAR,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      aux_sym_number_token2,
    ACTIONS(2631), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2639), 1,
      sym_test_operator,
    ACTIONS(2641), 1,
      sym__brace_start,
    ACTIONS(9742), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9744), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9746), 1,
      sym__special_character,
    ACTIONS(9748), 1,
      anon_sym_DQUOTE,
    ACTIONS(9752), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9754), 1,
      anon_sym_BQUOTE,
    ACTIONS(9756), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(1903), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9750), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9758), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(617), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1348), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203807] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2613), 1,
      sym_word,
    ACTIONS(2619), 1,
      anon_sym_DOLLAR,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      aux_sym_number_token2,
    ACTIONS(2631), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2639), 1,
      sym_test_operator,
    ACTIONS(2641), 1,
      sym__brace_start,
    ACTIONS(9742), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9744), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9746), 1,
      sym__special_character,
    ACTIONS(9748), 1,
      anon_sym_DQUOTE,
    ACTIONS(9752), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9754), 1,
      anon_sym_BQUOTE,
    ACTIONS(9756), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(1903), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9750), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9758), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(620), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1348), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203879] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(3793), 1,
      sym_word,
    ACTIONS(3797), 1,
      sym_test_operator,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9690), 1,
      sym__special_character,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9694), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(712), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [203951] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(3793), 1,
      sym_word,
    ACTIONS(3797), 1,
      sym_test_operator,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9690), 1,
      sym__special_character,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9694), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(722), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1761), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204023] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1414), 1,
      anon_sym_DOLLAR,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1438), 1,
      sym__brace_start,
    ACTIONS(9760), 1,
      sym_word,
    ACTIONS(9762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9766), 1,
      sym__special_character,
    ACTIONS(9768), 1,
      anon_sym_DQUOTE,
    ACTIONS(9772), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9774), 1,
      anon_sym_BQUOTE,
    ACTIONS(9776), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9780), 1,
      sym_test_operator,
    ACTIONS(9782), 1,
      sym_regex,
    STATE(1235), 1,
      aux_sym__literal_repeat1,
    STATE(1347), 1,
      sym_concatenation,
    ACTIONS(9770), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9778), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(960), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204097] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9784), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204167] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(7605), 1,
      sym_word,
    ACTIONS(7613), 1,
      sym_test_operator,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9790), 1,
      sym__special_character,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9794), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3355), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204239] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4056), 1,
      sym_word,
    ACTIONS(4060), 1,
      sym_test_operator,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9808), 1,
      sym__special_character,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9812), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(756), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204311] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7828), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7830), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7832), 1,
      anon_sym_DOLLAR,
    ACTIONS(7834), 1,
      sym__special_character,
    ACTIONS(7836), 1,
      anon_sym_DQUOTE,
    ACTIONS(7840), 1,
      aux_sym_number_token1,
    ACTIONS(7842), 1,
      aux_sym_number_token2,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7860), 1,
      sym__brace_start,
    ACTIONS(9822), 1,
      sym_word,
    ACTIONS(9826), 1,
      sym_test_operator,
    STATE(2634), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7852), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9824), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(842), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2335), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204383] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7828), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7830), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7832), 1,
      anon_sym_DOLLAR,
    ACTIONS(7834), 1,
      sym__special_character,
    ACTIONS(7836), 1,
      anon_sym_DQUOTE,
    ACTIONS(7840), 1,
      aux_sym_number_token1,
    ACTIONS(7842), 1,
      aux_sym_number_token2,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7860), 1,
      sym__brace_start,
    ACTIONS(9822), 1,
      sym_word,
    ACTIONS(9826), 1,
      sym_test_operator,
    STATE(2634), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7852), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9824), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(844), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2335), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204455] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4321), 1,
      sym_word,
    ACTIONS(4323), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4325), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4327), 1,
      anon_sym_DOLLAR,
    ACTIONS(4331), 1,
      anon_sym_DQUOTE,
    ACTIONS(4335), 1,
      aux_sym_number_token1,
    ACTIONS(4337), 1,
      aux_sym_number_token2,
    ACTIONS(4339), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4341), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4343), 1,
      anon_sym_BQUOTE,
    ACTIONS(4345), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4349), 1,
      sym_test_operator,
    ACTIONS(4351), 1,
      sym__brace_start,
    ACTIONS(9828), 1,
      sym__special_character,
    STATE(2630), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4333), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4347), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(820), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2382), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204527] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9830), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204597] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9832), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204667] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3201), 1,
      sym_word,
    ACTIONS(3207), 1,
      anon_sym_DOLLAR,
    ACTIONS(3213), 1,
      aux_sym_number_token1,
    ACTIONS(3215), 1,
      aux_sym_number_token2,
    ACTIONS(3219), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3227), 1,
      sym_test_operator,
    ACTIONS(3229), 1,
      sym__brace_start,
    ACTIONS(9834), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9836), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9838), 1,
      sym__special_character,
    ACTIONS(9840), 1,
      anon_sym_DQUOTE,
    ACTIONS(9844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9846), 1,
      anon_sym_BQUOTE,
    ACTIONS(9848), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2027), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9842), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9850), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(673), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1611), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204739] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3201), 1,
      sym_word,
    ACTIONS(3207), 1,
      anon_sym_DOLLAR,
    ACTIONS(3213), 1,
      aux_sym_number_token1,
    ACTIONS(3215), 1,
      aux_sym_number_token2,
    ACTIONS(3219), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3227), 1,
      sym_test_operator,
    ACTIONS(3229), 1,
      sym__brace_start,
    ACTIONS(9834), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9836), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9838), 1,
      sym__special_character,
    ACTIONS(9840), 1,
      anon_sym_DQUOTE,
    ACTIONS(9844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9846), 1,
      anon_sym_BQUOTE,
    ACTIONS(9848), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2027), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9842), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9850), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(659), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1611), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204811] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4321), 1,
      sym_word,
    ACTIONS(4323), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4325), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4327), 1,
      anon_sym_DOLLAR,
    ACTIONS(4331), 1,
      anon_sym_DQUOTE,
    ACTIONS(4335), 1,
      aux_sym_number_token1,
    ACTIONS(4337), 1,
      aux_sym_number_token2,
    ACTIONS(4339), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4341), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4343), 1,
      anon_sym_BQUOTE,
    ACTIONS(4345), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4349), 1,
      sym_test_operator,
    ACTIONS(4351), 1,
      sym__brace_start,
    ACTIONS(9828), 1,
      sym__special_character,
    STATE(2630), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4333), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4347), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(821), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2382), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204883] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9852), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [204953] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7978), 1,
      anon_sym_DOLLAR,
    ACTIONS(7980), 1,
      sym__special_character,
    ACTIONS(7982), 1,
      anon_sym_DQUOTE,
    ACTIONS(7986), 1,
      aux_sym_number_token1,
    ACTIONS(7988), 1,
      aux_sym_number_token2,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7992), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8006), 1,
      sym__brace_start,
    ACTIONS(9854), 1,
      sym_word,
    ACTIONS(9858), 1,
      sym_test_operator,
    STATE(3442), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7998), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9856), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1716), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(3373), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205025] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7866), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7868), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7870), 1,
      anon_sym_DOLLAR,
    ACTIONS(7872), 1,
      sym__special_character,
    ACTIONS(7874), 1,
      anon_sym_DQUOTE,
    ACTIONS(7878), 1,
      aux_sym_number_token1,
    ACTIONS(7880), 1,
      aux_sym_number_token2,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7884), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7898), 1,
      sym__brace_start,
    ACTIONS(9860), 1,
      sym_word,
    ACTIONS(9864), 1,
      sym_test_operator,
    STATE(1803), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9862), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(609), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1325), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205097] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DOLLAR,
    ACTIONS(2659), 1,
      sym__special_character,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2683), 1,
      sym__brace_start,
    ACTIONS(9866), 1,
      sym_word,
    ACTIONS(9870), 1,
      sym_test_operator,
    ACTIONS(9872), 1,
      sym_regex,
    STATE(2405), 1,
      aux_sym__literal_repeat1,
    STATE(2480), 1,
      sym_concatenation,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9868), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1916), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205171] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5619), 1,
      sym_word,
    ACTIONS(5625), 1,
      anon_sym_DOLLAR,
    ACTIONS(5631), 1,
      aux_sym_number_token1,
    ACTIONS(5633), 1,
      aux_sym_number_token2,
    ACTIONS(5637), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5645), 1,
      sym_test_operator,
    ACTIONS(5647), 1,
      sym__brace_start,
    ACTIONS(9874), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9876), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9878), 1,
      sym__special_character,
    ACTIONS(9880), 1,
      anon_sym_DQUOTE,
    ACTIONS(9884), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9886), 1,
      anon_sym_BQUOTE,
    ACTIONS(9888), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3369), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9882), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1429), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(3082), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205243] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5619), 1,
      sym_word,
    ACTIONS(5625), 1,
      anon_sym_DOLLAR,
    ACTIONS(5631), 1,
      aux_sym_number_token1,
    ACTIONS(5633), 1,
      aux_sym_number_token2,
    ACTIONS(5637), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5645), 1,
      sym_test_operator,
    ACTIONS(5647), 1,
      sym__brace_start,
    ACTIONS(9874), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9876), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9878), 1,
      sym__special_character,
    ACTIONS(9880), 1,
      anon_sym_DQUOTE,
    ACTIONS(9884), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9886), 1,
      anon_sym_BQUOTE,
    ACTIONS(9888), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3369), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9882), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1390), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(3082), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205315] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(8294), 1,
      sym_variable_name,
    STATE(4874), 1,
      sym_string,
    ACTIONS(1191), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(8292), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(8290), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 15,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [205363] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9892), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205433] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9894), 1,
      sym_word,
    ACTIONS(9896), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9898), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9900), 1,
      anon_sym_DOLLAR,
    ACTIONS(9902), 1,
      sym__special_character,
    ACTIONS(9904), 1,
      anon_sym_DQUOTE,
    ACTIONS(9908), 1,
      aux_sym_number_token1,
    ACTIONS(9910), 1,
      aux_sym_number_token2,
    ACTIONS(9912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9914), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(9916), 1,
      anon_sym_BQUOTE,
    ACTIONS(9918), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9922), 1,
      sym_test_operator,
    ACTIONS(9924), 1,
      sym__brace_start,
    STATE(2496), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9906), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9920), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(801), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2283), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205505] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4056), 1,
      sym_word,
    ACTIONS(4060), 1,
      sym_test_operator,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9808), 1,
      sym__special_character,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9812), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(759), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205577] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9926), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205647] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4801), 1,
      sym_word,
    ACTIONS(4803), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4805), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_DOLLAR,
    ACTIONS(4811), 1,
      anon_sym_DQUOTE,
    ACTIONS(4815), 1,
      aux_sym_number_token1,
    ACTIONS(4817), 1,
      aux_sym_number_token2,
    ACTIONS(4819), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4821), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4823), 1,
      anon_sym_BQUOTE,
    ACTIONS(4825), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4829), 1,
      sym_test_operator,
    ACTIONS(4831), 1,
      sym__brace_start,
    ACTIONS(9928), 1,
      sym__special_character,
    STATE(2859), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4813), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4827), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(964), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2538), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205719] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4056), 1,
      sym_word,
    ACTIONS(4060), 1,
      sym_test_operator,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9808), 1,
      sym__special_character,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9812), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(757), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205791] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2795), 1,
      sym_word,
    ACTIONS(2801), 1,
      anon_sym_DOLLAR,
    ACTIONS(2807), 1,
      aux_sym_number_token1,
    ACTIONS(2809), 1,
      aux_sym_number_token2,
    ACTIONS(2813), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2821), 1,
      sym_test_operator,
    ACTIONS(2823), 1,
      sym__brace_start,
    ACTIONS(9930), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9932), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9934), 1,
      sym__special_character,
    ACTIONS(9936), 1,
      anon_sym_DQUOTE,
    ACTIONS(9940), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_BQUOTE,
    ACTIONS(9944), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(1722), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9938), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9946), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(633), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1292), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205863] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2795), 1,
      sym_word,
    ACTIONS(2801), 1,
      anon_sym_DOLLAR,
    ACTIONS(2807), 1,
      aux_sym_number_token1,
    ACTIONS(2809), 1,
      aux_sym_number_token2,
    ACTIONS(2813), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2821), 1,
      sym_test_operator,
    ACTIONS(2823), 1,
      sym__brace_start,
    ACTIONS(9930), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9932), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9934), 1,
      sym__special_character,
    ACTIONS(9936), 1,
      anon_sym_DQUOTE,
    ACTIONS(9940), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_BQUOTE,
    ACTIONS(9944), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(1722), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9938), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9946), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(635), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1292), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [205935] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3632), 1,
      sym_word,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3658), 1,
      sym_test_operator,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9948), 1,
      sym__special_character,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9950), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(711), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1851), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206007] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5009), 1,
      sym_word,
    ACTIONS(5011), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5013), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5015), 1,
      anon_sym_DOLLAR,
    ACTIONS(5017), 1,
      sym__special_character,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    ACTIONS(5023), 1,
      aux_sym_number_token1,
    ACTIONS(5025), 1,
      aux_sym_number_token2,
    ACTIONS(5027), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5031), 1,
      anon_sym_BQUOTE,
    ACTIONS(5033), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5037), 1,
      sym_test_operator,
    ACTIONS(5039), 1,
      sym__brace_start,
    STATE(3136), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5021), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(5035), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(998), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2655), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206079] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5009), 1,
      sym_word,
    ACTIONS(5011), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5013), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5015), 1,
      anon_sym_DOLLAR,
    ACTIONS(5017), 1,
      sym__special_character,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    ACTIONS(5023), 1,
      aux_sym_number_token1,
    ACTIONS(5025), 1,
      aux_sym_number_token2,
    ACTIONS(5027), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5031), 1,
      anon_sym_BQUOTE,
    ACTIONS(5033), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5037), 1,
      sym_test_operator,
    ACTIONS(5039), 1,
      sym__brace_start,
    STATE(3136), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5021), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(5035), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(999), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2655), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206151] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7866), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7868), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7870), 1,
      anon_sym_DOLLAR,
    ACTIONS(7872), 1,
      sym__special_character,
    ACTIONS(7874), 1,
      anon_sym_DQUOTE,
    ACTIONS(7878), 1,
      aux_sym_number_token1,
    ACTIONS(7880), 1,
      aux_sym_number_token2,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7884), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7898), 1,
      sym__brace_start,
    ACTIONS(9860), 1,
      sym_word,
    ACTIONS(9864), 1,
      sym_test_operator,
    STATE(1803), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9862), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(629), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1325), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206223] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9952), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206293] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(7605), 1,
      sym_word,
    ACTIONS(7613), 1,
      sym_test_operator,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9790), 1,
      sym__special_character,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9794), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3350), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206365] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9954), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206435] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9894), 1,
      sym_word,
    ACTIONS(9896), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9898), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9900), 1,
      anon_sym_DOLLAR,
    ACTIONS(9902), 1,
      sym__special_character,
    ACTIONS(9904), 1,
      anon_sym_DQUOTE,
    ACTIONS(9908), 1,
      aux_sym_number_token1,
    ACTIONS(9910), 1,
      aux_sym_number_token2,
    ACTIONS(9912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9914), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(9916), 1,
      anon_sym_BQUOTE,
    ACTIONS(9918), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9922), 1,
      sym_test_operator,
    ACTIONS(9924), 1,
      sym__brace_start,
    STATE(2496), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9906), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9920), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(794), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2283), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206507] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4536), 1,
      sym_word,
    ACTIONS(4538), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4540), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4542), 1,
      anon_sym_DOLLAR,
    ACTIONS(4544), 1,
      sym__special_character,
    ACTIONS(4546), 1,
      anon_sym_DQUOTE,
    ACTIONS(4550), 1,
      aux_sym_number_token1,
    ACTIONS(4552), 1,
      aux_sym_number_token2,
    ACTIONS(4554), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4556), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4560), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4564), 1,
      sym_test_operator,
    ACTIONS(4566), 1,
      sym__brace_start,
    STATE(2975), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4548), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4562), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(870), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2540), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206579] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4536), 1,
      sym_word,
    ACTIONS(4538), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4540), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4542), 1,
      anon_sym_DOLLAR,
    ACTIONS(4544), 1,
      sym__special_character,
    ACTIONS(4546), 1,
      anon_sym_DQUOTE,
    ACTIONS(4550), 1,
      aux_sym_number_token1,
    ACTIONS(4552), 1,
      aux_sym_number_token2,
    ACTIONS(4554), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4556), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4560), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4564), 1,
      sym_test_operator,
    ACTIONS(4566), 1,
      sym__brace_start,
    STATE(2975), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4548), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4562), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(871), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2540), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206651] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4056), 1,
      sym_word,
    ACTIONS(4060), 1,
      sym_test_operator,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9808), 1,
      sym__special_character,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9812), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(758), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1931), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206723] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4801), 1,
      sym_word,
    ACTIONS(4803), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4805), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_DOLLAR,
    ACTIONS(4811), 1,
      anon_sym_DQUOTE,
    ACTIONS(4815), 1,
      aux_sym_number_token1,
    ACTIONS(4817), 1,
      aux_sym_number_token2,
    ACTIONS(4819), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4821), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4823), 1,
      anon_sym_BQUOTE,
    ACTIONS(4825), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4829), 1,
      sym_test_operator,
    ACTIONS(4831), 1,
      sym__brace_start,
    ACTIONS(9928), 1,
      sym__special_character,
    STATE(2859), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4813), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(4827), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(965), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2538), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206795] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9956), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206865] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9684), 1,
      sym_test_operator,
    ACTIONS(9958), 1,
      anon_sym_RBRACK,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9680), 2,
      sym__special_character,
      sym__comment_word,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [206935] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8306), 1,
      sym__special_character,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(9960), 1,
      sym_word,
    ACTIONS(9964), 1,
      sym_test_operator,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9962), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(676), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1663), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207007] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8306), 1,
      sym__special_character,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(9960), 1,
      sym_word,
    ACTIONS(9964), 1,
      sym_test_operator,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9962), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(677), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1663), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207079] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8114), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8116), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8118), 1,
      anon_sym_DOLLAR,
    ACTIONS(8120), 1,
      sym__special_character,
    ACTIONS(8122), 1,
      anon_sym_DQUOTE,
    ACTIONS(8126), 1,
      aux_sym_number_token1,
    ACTIONS(8128), 1,
      aux_sym_number_token2,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8146), 1,
      sym__brace_start,
    ACTIONS(9966), 1,
      sym_word,
    ACTIONS(9970), 1,
      sym_test_operator,
    STATE(1320), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8138), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9968), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(569), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207151] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9972), 1,
      sym_word,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9978), 1,
      sym__special_character,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9992), 1,
      sym_test_operator,
    ACTIONS(9994), 1,
      sym_regex,
    STATE(1436), 1,
      aux_sym__literal_repeat1,
    STATE(1483), 1,
      sym_concatenation,
    ACTIONS(9982), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(1276), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207225] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8114), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8116), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8118), 1,
      anon_sym_DOLLAR,
    ACTIONS(8120), 1,
      sym__special_character,
    ACTIONS(8122), 1,
      anon_sym_DQUOTE,
    ACTIONS(8126), 1,
      aux_sym_number_token1,
    ACTIONS(8128), 1,
      aux_sym_number_token2,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8146), 1,
      sym__brace_start,
    ACTIONS(9966), 1,
      sym_word,
    ACTIONS(9970), 1,
      sym_test_operator,
    STATE(1320), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8138), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9968), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(571), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1021), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207297] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(9998), 1,
      anon_sym_DQUOTE,
    ACTIONS(10002), 1,
      sym_variable_name,
    STATE(5275), 1,
      sym_string,
    ACTIONS(10000), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9996), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [207345] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(10006), 1,
      anon_sym_DQUOTE,
    ACTIONS(10010), 1,
      sym_variable_name,
    STATE(5422), 1,
      sym_string,
    ACTIONS(10008), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(10004), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [207393] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(7605), 1,
      sym_word,
    ACTIONS(7613), 1,
      sym_test_operator,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9790), 1,
      sym__special_character,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9794), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3365), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207465] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(9998), 1,
      anon_sym_DQUOTE,
    ACTIONS(10002), 1,
      sym_variable_name,
    STATE(5275), 1,
      sym_string,
    ACTIONS(10000), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9996), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [207513] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8344), 1,
      sym__special_character,
    ACTIONS(10012), 1,
      sym_word,
    ACTIONS(10016), 1,
      sym_test_operator,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10014), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(623), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1355), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207585] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3004), 1,
      sym_word,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3030), 1,
      sym_test_operator,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10018), 1,
      sym__special_character,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10020), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(645), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1653), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207657] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8344), 1,
      sym__special_character,
    ACTIONS(10012), 1,
      sym_word,
    ACTIONS(10016), 1,
      sym_test_operator,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10014), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(615), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1355), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207729] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3632), 1,
      sym_word,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3658), 1,
      sym_test_operator,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9948), 1,
      sym__special_character,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9950), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(698), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1851), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207801] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(8294), 1,
      sym_variable_name,
    STATE(4874), 1,
      sym_string,
    ACTIONS(1197), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(8292), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(8290), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 15,
      aux_sym_heredoc_redirect_token1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [207849] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4771), 1,
      sym_word,
    ACTIONS(4775), 1,
      sym_test_operator,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10022), 1,
      sym__special_character,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10024), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(946), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2556), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207921] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3004), 1,
      sym_word,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3030), 1,
      sym_test_operator,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10018), 1,
      sym__special_character,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10020), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(646), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(1653), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [207993] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(10006), 1,
      anon_sym_DQUOTE,
    ACTIONS(10010), 1,
      sym_variable_name,
    STATE(5422), 1,
      sym_string,
    ACTIONS(10008), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(10004), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [208041] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8352), 1,
      sym__special_character,
    ACTIONS(10026), 1,
      sym_word,
    ACTIONS(10030), 1,
      sym_test_operator,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10028), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(795), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2287), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208113] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8352), 1,
      sym__special_character,
    ACTIONS(10026), 1,
      sym_word,
    ACTIONS(10030), 1,
      sym_test_operator,
    STATE(1814), 1,
      aux_sym__literal_repeat1,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10028), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(797), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2287), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208185] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7978), 1,
      anon_sym_DOLLAR,
    ACTIONS(7980), 1,
      sym__special_character,
    ACTIONS(7982), 1,
      anon_sym_DQUOTE,
    ACTIONS(7986), 1,
      aux_sym_number_token1,
    ACTIONS(7988), 1,
      aux_sym_number_token2,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7992), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8006), 1,
      sym__brace_start,
    ACTIONS(9854), 1,
      sym_word,
    ACTIONS(9858), 1,
      sym_test_operator,
    STATE(3442), 1,
      aux_sym__literal_repeat1,
    ACTIONS(7998), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9856), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1746), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(3373), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208257] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9994), 1,
      sym_regex,
    ACTIONS(10032), 1,
      sym_word,
    ACTIONS(10034), 1,
      sym__special_character,
    ACTIONS(10038), 1,
      sym_test_operator,
    STATE(1436), 1,
      aux_sym__literal_repeat1,
    STATE(1483), 1,
      sym_concatenation,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10036), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1894), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208331] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1398), 1,
      sym__brace_start,
    ACTIONS(10040), 1,
      sym_word,
    ACTIONS(10042), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10044), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10046), 1,
      sym__special_character,
    ACTIONS(10048), 1,
      anon_sym_DQUOTE,
    ACTIONS(10052), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10054), 1,
      anon_sym_BQUOTE,
    ACTIONS(10056), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10060), 1,
      sym_test_operator,
    ACTIONS(10062), 1,
      sym_regex,
    STATE(1083), 1,
      aux_sym__literal_repeat1,
    STATE(1212), 1,
      sym_concatenation,
    ACTIONS(10050), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(10058), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(816), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208405] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(7605), 1,
      sym_word,
    ACTIONS(7613), 1,
      sym_test_operator,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9790), 1,
      sym__special_character,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(4982), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9794), 2,
      sym_raw_string,
      sym_ansi_c_string,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    STATE(3367), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(4614), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208477] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(4771), 1,
      sym_word,
    ACTIONS(4775), 1,
      sym_test_operator,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10022), 1,
      sym__special_character,
    STATE(2253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10024), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(947), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2556), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208549] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(4362), 1,
      sym_word,
    ACTIONS(4366), 1,
      sym_test_operator,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10064), 1,
      sym__special_character,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10066), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(854), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2413), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208621] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(4362), 1,
      sym_word,
    ACTIONS(4366), 1,
      sym_test_operator,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10064), 1,
      sym__special_character,
    STATE(2112), 1,
      aux_sym__literal_repeat1,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10066), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(827), 2,
      sym_concatenation,
      aux_sym_for_statement_repeat1,
    STATE(2413), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208693] = 21,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9994), 1,
      sym_regex,
    ACTIONS(10068), 1,
      sym_word,
    ACTIONS(10070), 1,
      sym__special_character,
    ACTIONS(10074), 1,
      sym_test_operator,
    STATE(1436), 1,
      aux_sym__literal_repeat1,
    STATE(1483), 1,
      sym_concatenation,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10072), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1028), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208767] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9622), 1,
      anon_sym_DQUOTE,
    ACTIONS(9626), 1,
      sym_variable_name,
    STATE(5125), 1,
      sym_string,
    ACTIONS(1191), 2,
      sym_test_operator,
      sym__brace_start,
    ACTIONS(9624), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9620), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 15,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [208815] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10078), 1,
      anon_sym_DOLLAR,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208882] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5091), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5093), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5095), 1,
      anon_sym_DOLLAR,
    ACTIONS(5099), 1,
      anon_sym_DQUOTE,
    ACTIONS(5103), 1,
      aux_sym_number_token1,
    ACTIONS(5105), 1,
      aux_sym_number_token2,
    ACTIONS(5107), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5109), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5111), 1,
      anon_sym_BQUOTE,
    ACTIONS(5113), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5119), 1,
      sym__brace_start,
    ACTIONS(10086), 1,
      sym_word,
    ACTIONS(10092), 1,
      sym__comment_word,
    ACTIONS(5115), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10088), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10090), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5342), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [208949] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8114), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8116), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8118), 1,
      anon_sym_DOLLAR,
    ACTIONS(8122), 1,
      anon_sym_DQUOTE,
    ACTIONS(8126), 1,
      aux_sym_number_token1,
    ACTIONS(8128), 1,
      aux_sym_number_token2,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8146), 1,
      sym__brace_start,
    ACTIONS(10094), 1,
      sym_word,
    ACTIONS(10100), 1,
      sym__comment_word,
    ACTIONS(8138), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10096), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10098), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1172), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209016] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10102), 1,
      anon_sym_LT_LT_LT,
    STATE(4815), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [209061] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10104), 1,
      sym_word,
    ACTIONS(10106), 1,
      anon_sym_DOLLAR,
    ACTIONS(10112), 1,
      sym__comment_word,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10108), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10110), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1703), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209128] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_DOLLAR,
    ACTIONS(1597), 1,
      aux_sym_number_token1,
    ACTIONS(1599), 1,
      aux_sym_number_token2,
    ACTIONS(1603), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1617), 1,
      sym__brace_start,
    ACTIONS(8160), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8162), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8166), 1,
      anon_sym_DQUOTE,
    ACTIONS(8170), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8172), 1,
      anon_sym_BQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10114), 1,
      sym_word,
    ACTIONS(10120), 1,
      sym__comment_word,
    ACTIONS(8176), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10116), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10118), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1171), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209195] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8068), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8070), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8076), 1,
      anon_sym_DQUOTE,
    ACTIONS(8080), 1,
      aux_sym_number_token1,
    ACTIONS(8082), 1,
      aux_sym_number_token2,
    ACTIONS(8084), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8088), 1,
      anon_sym_BQUOTE,
    ACTIONS(8090), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8100), 1,
      sym__brace_start,
    ACTIONS(10122), 1,
      sym_word,
    ACTIONS(10124), 1,
      anon_sym_DOLLAR,
    ACTIONS(10130), 1,
      sym__comment_word,
    ACTIONS(8092), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10126), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10128), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5281), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209262] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10132), 1,
      sym_word,
    ACTIONS(10134), 1,
      anon_sym_DOLLAR,
    ACTIONS(10140), 1,
      sym__comment_word,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10136), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10138), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4898), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209329] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2289), 1,
      anon_sym_DOLLAR,
    ACTIONS(2295), 1,
      aux_sym_number_token1,
    ACTIONS(2297), 1,
      aux_sym_number_token2,
    ACTIONS(2301), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2313), 1,
      sym__brace_start,
    ACTIONS(10142), 1,
      sym_word,
    ACTIONS(10144), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10146), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10150), 1,
      anon_sym_DQUOTE,
    ACTIONS(10154), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10156), 1,
      anon_sym_BQUOTE,
    ACTIONS(10158), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10162), 1,
      sym__comment_word,
    ACTIONS(10148), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10160), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10152), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1304), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209396] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10104), 1,
      sym_word,
    ACTIONS(10112), 1,
      sym__comment_word,
    ACTIONS(10164), 1,
      anon_sym_DOLLAR,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10108), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10110), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1703), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209463] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1398), 1,
      sym__brace_start,
    ACTIONS(10042), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10044), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10048), 1,
      anon_sym_DQUOTE,
    ACTIONS(10052), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10054), 1,
      anon_sym_BQUOTE,
    ACTIONS(10056), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10166), 1,
      sym_word,
    ACTIONS(10172), 1,
      sym__comment_word,
    ACTIONS(10058), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10168), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10170), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(889), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209530] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4064), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4066), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4072), 1,
      anon_sym_DQUOTE,
    ACTIONS(4076), 1,
      aux_sym_number_token1,
    ACTIONS(4078), 1,
      aux_sym_number_token2,
    ACTIONS(4080), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4082), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4084), 1,
      anon_sym_BQUOTE,
    ACTIONS(4086), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4096), 1,
      sym__brace_start,
    ACTIONS(10174), 1,
      sym_word,
    ACTIONS(10176), 1,
      anon_sym_DOLLAR,
    ACTIONS(10182), 1,
      sym__comment_word,
    ACTIONS(4088), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10178), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10180), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2446), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209597] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2801), 1,
      anon_sym_DOLLAR,
    ACTIONS(2807), 1,
      aux_sym_number_token1,
    ACTIONS(2809), 1,
      aux_sym_number_token2,
    ACTIONS(2813), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2823), 1,
      sym__brace_start,
    ACTIONS(9930), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9932), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9936), 1,
      anon_sym_DQUOTE,
    ACTIONS(9940), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_BQUOTE,
    ACTIONS(9944), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10184), 1,
      sym_word,
    ACTIONS(10190), 1,
      sym__comment_word,
    ACTIONS(9946), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10186), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10188), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1467), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209664] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(47), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(57), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      aux_sym_number_token2,
    ACTIONS(61), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(63), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(65), 1,
      anon_sym_BQUOTE,
    ACTIONS(67), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(79), 1,
      sym__brace_start,
    ACTIONS(10192), 1,
      sym_word,
    ACTIONS(10194), 1,
      anon_sym_DOLLAR,
    ACTIONS(10200), 1,
      sym__comment_word,
    ACTIONS(69), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10196), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10198), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1110), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209731] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3123), 1,
      anon_sym_DOLLAR,
    ACTIONS(3129), 1,
      aux_sym_number_token1,
    ACTIONS(3131), 1,
      aux_sym_number_token2,
    ACTIONS(3135), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3145), 1,
      sym__brace_start,
    ACTIONS(10202), 1,
      sym_word,
    ACTIONS(10204), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10206), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10210), 1,
      anon_sym_DQUOTE,
    ACTIONS(10214), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10216), 1,
      anon_sym_BQUOTE,
    ACTIONS(10218), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10222), 1,
      sym__comment_word,
    ACTIONS(10208), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10220), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10212), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4466), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209798] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10132), 1,
      sym_word,
    ACTIONS(10140), 1,
      sym__comment_word,
    ACTIONS(10224), 1,
      anon_sym_DOLLAR,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10136), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10138), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4898), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209865] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2337), 1,
      anon_sym_DOLLAR,
    ACTIONS(2343), 1,
      aux_sym_number_token1,
    ACTIONS(2345), 1,
      aux_sym_number_token2,
    ACTIONS(2349), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2359), 1,
      sym__brace_start,
    ACTIONS(9628), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9630), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9634), 1,
      anon_sym_DQUOTE,
    ACTIONS(9638), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9640), 1,
      anon_sym_BQUOTE,
    ACTIONS(9642), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10226), 1,
      sym_word,
    ACTIONS(10232), 1,
      sym__comment_word,
    ACTIONS(9644), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10228), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10230), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1329), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209932] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2928), 1,
      anon_sym_DOLLAR,
    ACTIONS(2934), 1,
      aux_sym_number_token1,
    ACTIONS(2936), 1,
      aux_sym_number_token2,
    ACTIONS(2940), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2950), 1,
      sym__brace_start,
    ACTIONS(10234), 1,
      sym_word,
    ACTIONS(10236), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10238), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10242), 1,
      anon_sym_DQUOTE,
    ACTIONS(10246), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10248), 1,
      anon_sym_BQUOTE,
    ACTIONS(10250), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10254), 1,
      sym__comment_word,
    ACTIONS(10240), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10252), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10244), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4301), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [209999] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1438), 1,
      sym__brace_start,
    ACTIONS(9762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9768), 1,
      anon_sym_DQUOTE,
    ACTIONS(9772), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9774), 1,
      anon_sym_BQUOTE,
    ACTIONS(9776), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10256), 1,
      sym_word,
    ACTIONS(10258), 1,
      anon_sym_DOLLAR,
    ACTIONS(10264), 1,
      sym__comment_word,
    ACTIONS(9778), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10260), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10262), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1011), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210066] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(701), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(703), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(705), 1,
      anon_sym_DOLLAR,
    ACTIONS(709), 1,
      anon_sym_DQUOTE,
    ACTIONS(713), 1,
      aux_sym_number_token1,
    ACTIONS(715), 1,
      aux_sym_number_token2,
    ACTIONS(717), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(719), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(721), 1,
      anon_sym_BQUOTE,
    ACTIONS(723), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(733), 1,
      sym__brace_start,
    ACTIONS(10266), 1,
      sym_word,
    ACTIONS(10272), 1,
      sym__comment_word,
    ACTIONS(725), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10268), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10270), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(897), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210133] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8188), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8190), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8192), 1,
      anon_sym_DOLLAR,
    ACTIONS(8196), 1,
      anon_sym_DQUOTE,
    ACTIONS(8200), 1,
      aux_sym_number_token1,
    ACTIONS(8202), 1,
      aux_sym_number_token2,
    ACTIONS(8204), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8206), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8208), 1,
      anon_sym_BQUOTE,
    ACTIONS(8210), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8220), 1,
      sym__brace_start,
    ACTIONS(10274), 1,
      sym_word,
    ACTIONS(10280), 1,
      sym__comment_word,
    ACTIONS(8212), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10276), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10278), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4200), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210200] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1438), 1,
      sym__brace_start,
    ACTIONS(9762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9768), 1,
      anon_sym_DQUOTE,
    ACTIONS(9772), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9774), 1,
      anon_sym_BQUOTE,
    ACTIONS(9776), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10256), 1,
      sym_word,
    ACTIONS(10264), 1,
      sym__comment_word,
    ACTIONS(10282), 1,
      anon_sym_DOLLAR,
    ACTIONS(9778), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10260), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10262), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1011), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210267] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8226), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8228), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8230), 1,
      anon_sym_DOLLAR,
    ACTIONS(8234), 1,
      anon_sym_DQUOTE,
    ACTIONS(8238), 1,
      aux_sym_number_token1,
    ACTIONS(8240), 1,
      aux_sym_number_token2,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8244), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8258), 1,
      sym__brace_start,
    ACTIONS(10284), 1,
      sym_word,
    ACTIONS(10290), 1,
      sym__comment_word,
    ACTIONS(8250), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10286), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10288), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1441), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210334] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3318), 1,
      aux_sym_number_token1,
    ACTIONS(3320), 1,
      aux_sym_number_token2,
    ACTIONS(3324), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3336), 1,
      sym__brace_start,
    ACTIONS(10292), 1,
      sym_word,
    ACTIONS(10294), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10296), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10298), 1,
      anon_sym_DOLLAR,
    ACTIONS(10302), 1,
      anon_sym_DQUOTE,
    ACTIONS(10306), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10308), 1,
      anon_sym_BQUOTE,
    ACTIONS(10310), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10314), 1,
      sym__comment_word,
    ACTIONS(10300), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10312), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10304), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1841), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210401] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10316), 1,
      sym_word,
    ACTIONS(10318), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10320), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10322), 1,
      anon_sym_DOLLAR,
    ACTIONS(10326), 1,
      anon_sym_DQUOTE,
    ACTIONS(10330), 1,
      aux_sym_number_token1,
    ACTIONS(10332), 1,
      aux_sym_number_token2,
    ACTIONS(10334), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10336), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10338), 1,
      anon_sym_BQUOTE,
    ACTIONS(10340), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10344), 1,
      sym__comment_word,
    ACTIONS(10346), 1,
      sym__brace_start,
    ACTIONS(10324), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10342), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10328), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6138), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210468] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1883), 1,
      anon_sym_DOLLAR,
    ACTIONS(1889), 1,
      aux_sym_number_token1,
    ACTIONS(1891), 1,
      aux_sym_number_token2,
    ACTIONS(1895), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1909), 1,
      sym__brace_start,
    ACTIONS(8264), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8266), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8270), 1,
      anon_sym_DQUOTE,
    ACTIONS(8274), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8276), 1,
      anon_sym_BQUOTE,
    ACTIONS(8278), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10348), 1,
      sym_word,
    ACTIONS(10354), 1,
      sym__comment_word,
    ACTIONS(8280), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10350), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10352), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210535] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5011), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5013), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    ACTIONS(5023), 1,
      aux_sym_number_token1,
    ACTIONS(5025), 1,
      aux_sym_number_token2,
    ACTIONS(5027), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5031), 1,
      anon_sym_BQUOTE,
    ACTIONS(5033), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5039), 1,
      sym__brace_start,
    ACTIONS(10356), 1,
      sym_word,
    ACTIONS(10358), 1,
      anon_sym_DOLLAR,
    ACTIONS(10364), 1,
      sym__comment_word,
    ACTIONS(5035), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10360), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10362), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2834), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210602] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2540), 1,
      anon_sym_DOLLAR,
    ACTIONS(2546), 1,
      aux_sym_number_token1,
    ACTIONS(2548), 1,
      aux_sym_number_token2,
    ACTIONS(2552), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2564), 1,
      sym__brace_start,
    ACTIONS(10366), 1,
      sym_word,
    ACTIONS(10368), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10370), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10374), 1,
      anon_sym_DQUOTE,
    ACTIONS(10378), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10380), 1,
      anon_sym_BQUOTE,
    ACTIONS(10382), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10386), 1,
      sym__comment_word,
    ACTIONS(10372), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10384), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10376), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1498), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210669] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4538), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4540), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4546), 1,
      anon_sym_DQUOTE,
    ACTIONS(4550), 1,
      aux_sym_number_token1,
    ACTIONS(4552), 1,
      aux_sym_number_token2,
    ACTIONS(4554), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4556), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4560), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4566), 1,
      sym__brace_start,
    ACTIONS(10388), 1,
      sym_word,
    ACTIONS(10390), 1,
      anon_sym_DOLLAR,
    ACTIONS(10396), 1,
      sym__comment_word,
    ACTIONS(4562), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10392), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10394), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2580), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210736] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 1,
      anon_sym_DOLLAR,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1438), 1,
      sym__brace_start,
    ACTIONS(9762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9768), 1,
      anon_sym_DQUOTE,
    ACTIONS(9772), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9774), 1,
      anon_sym_BQUOTE,
    ACTIONS(9776), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10256), 1,
      sym_word,
    ACTIONS(10264), 1,
      sym__comment_word,
    ACTIONS(9778), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10260), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10262), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1011), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210803] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3237), 1,
      anon_sym_DOLLAR,
    ACTIONS(3243), 1,
      aux_sym_number_token1,
    ACTIONS(3245), 1,
      aux_sym_number_token2,
    ACTIONS(3249), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3259), 1,
      sym__brace_start,
    ACTIONS(9724), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9726), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_DQUOTE,
    ACTIONS(9734), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9736), 1,
      anon_sym_BQUOTE,
    ACTIONS(9738), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10398), 1,
      sym_word,
    ACTIONS(10404), 1,
      sym__comment_word,
    ACTIONS(9740), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10400), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10402), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1831), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210870] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3478), 1,
      anon_sym_DOLLAR,
    ACTIONS(3484), 1,
      aux_sym_number_token1,
    ACTIONS(3486), 1,
      aux_sym_number_token2,
    ACTIONS(3490), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3500), 1,
      sym__brace_start,
    ACTIONS(10406), 1,
      sym_word,
    ACTIONS(10408), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10410), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10414), 1,
      anon_sym_DQUOTE,
    ACTIONS(10418), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10420), 1,
      anon_sym_BQUOTE,
    ACTIONS(10422), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10426), 1,
      sym__comment_word,
    ACTIONS(10412), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10424), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10416), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4511), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [210937] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2619), 1,
      anon_sym_DOLLAR,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      aux_sym_number_token2,
    ACTIONS(2631), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2641), 1,
      sym__brace_start,
    ACTIONS(9742), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9744), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9748), 1,
      anon_sym_DQUOTE,
    ACTIONS(9752), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9754), 1,
      anon_sym_BQUOTE,
    ACTIONS(9756), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10428), 1,
      sym_word,
    ACTIONS(10434), 1,
      sym__comment_word,
    ACTIONS(9758), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10430), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10432), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1526), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211004] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3344), 1,
      anon_sym_DOLLAR,
    ACTIONS(3350), 1,
      aux_sym_number_token1,
    ACTIONS(3352), 1,
      aux_sym_number_token2,
    ACTIONS(3356), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3366), 1,
      sym__brace_start,
    ACTIONS(10436), 1,
      sym_word,
    ACTIONS(10438), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10440), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10444), 1,
      anon_sym_DQUOTE,
    ACTIONS(10448), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10450), 1,
      anon_sym_BQUOTE,
    ACTIONS(10452), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10456), 1,
      sym__comment_word,
    ACTIONS(10442), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10454), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10446), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4339), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211071] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3243), 1,
      aux_sym_number_token1,
    ACTIONS(3245), 1,
      aux_sym_number_token2,
    ACTIONS(3249), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3259), 1,
      sym__brace_start,
    ACTIONS(9724), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9726), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_DQUOTE,
    ACTIONS(9734), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9736), 1,
      anon_sym_BQUOTE,
    ACTIONS(9738), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10398), 1,
      sym_word,
    ACTIONS(10404), 1,
      sym__comment_word,
    ACTIONS(10458), 1,
      anon_sym_DOLLAR,
    ACTIONS(9740), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10400), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10402), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1831), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211138] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8370), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8372), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8374), 1,
      anon_sym_DOLLAR,
    ACTIONS(8378), 1,
      anon_sym_DQUOTE,
    ACTIONS(8382), 1,
      aux_sym_number_token1,
    ACTIONS(8384), 1,
      aux_sym_number_token2,
    ACTIONS(8386), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8388), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8390), 1,
      anon_sym_BQUOTE,
    ACTIONS(8392), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8402), 1,
      sym__brace_start,
    ACTIONS(10460), 1,
      sym_word,
    ACTIONS(10466), 1,
      sym__comment_word,
    ACTIONS(8394), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10462), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10464), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4362), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211205] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3243), 1,
      aux_sym_number_token1,
    ACTIONS(3245), 1,
      aux_sym_number_token2,
    ACTIONS(3249), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3259), 1,
      sym__brace_start,
    ACTIONS(9724), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9726), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_DQUOTE,
    ACTIONS(9734), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9736), 1,
      anon_sym_BQUOTE,
    ACTIONS(9738), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10398), 1,
      sym_word,
    ACTIONS(10404), 1,
      sym__comment_word,
    ACTIONS(10468), 1,
      anon_sym_DOLLAR,
    ACTIONS(9740), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10400), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10402), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1831), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211272] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5631), 1,
      aux_sym_number_token1,
    ACTIONS(5633), 1,
      aux_sym_number_token2,
    ACTIONS(5637), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5647), 1,
      sym__brace_start,
    ACTIONS(9874), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9876), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9880), 1,
      anon_sym_DQUOTE,
    ACTIONS(9884), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9886), 1,
      anon_sym_BQUOTE,
    ACTIONS(9888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10470), 1,
      sym_word,
    ACTIONS(10472), 1,
      anon_sym_DOLLAR,
    ACTIONS(10478), 1,
      sym__comment_word,
    ACTIONS(9890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10474), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10476), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(3342), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211339] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DOLLAR,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211406] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10494), 1,
      anon_sym_DOLLAR,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211473] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(10512), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211540] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10520), 1,
      anon_sym_DOLLAR,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211607] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(10538), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211674] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(10540), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211741] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1454), 1,
      anon_sym_DOLLAR,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1478), 1,
      sym__brace_start,
    ACTIONS(9648), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9650), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9652), 1,
      sym__special_character,
    ACTIONS(9654), 1,
      anon_sym_DQUOTE,
    ACTIONS(9658), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9660), 1,
      anon_sym_BQUOTE,
    ACTIONS(9662), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10542), 1,
      sym_word,
    ACTIONS(10546), 1,
      sym_test_operator,
    STATE(1360), 1,
      aux_sym__literal_repeat1,
    STATE(1612), 1,
      sym_concatenation,
    ACTIONS(9664), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10544), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1100), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211812] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4629), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4631), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4637), 1,
      anon_sym_DQUOTE,
    ACTIONS(4641), 1,
      aux_sym_number_token1,
    ACTIONS(4643), 1,
      aux_sym_number_token2,
    ACTIONS(4645), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4647), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4649), 1,
      anon_sym_BQUOTE,
    ACTIONS(4651), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4659), 1,
      sym__brace_start,
    ACTIONS(10548), 1,
      sym_word,
    ACTIONS(10550), 1,
      anon_sym_DOLLAR,
    ACTIONS(10556), 1,
      sym__comment_word,
    ACTIONS(4653), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10552), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10554), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2740), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211879] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(10558), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [211946] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1454), 1,
      anon_sym_DOLLAR,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1478), 1,
      sym__brace_start,
    ACTIONS(9648), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9650), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9652), 1,
      sym__special_character,
    ACTIONS(9654), 1,
      anon_sym_DQUOTE,
    ACTIONS(9658), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9660), 1,
      anon_sym_BQUOTE,
    ACTIONS(9662), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10560), 1,
      sym_word,
    ACTIONS(10564), 1,
      sym_test_operator,
    STATE(1366), 1,
      aux_sym__literal_repeat1,
    STATE(1613), 1,
      sym_concatenation,
    ACTIONS(9664), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10562), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1102), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212017] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4629), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4631), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4637), 1,
      anon_sym_DQUOTE,
    ACTIONS(4641), 1,
      aux_sym_number_token1,
    ACTIONS(4643), 1,
      aux_sym_number_token2,
    ACTIONS(4645), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4647), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4649), 1,
      anon_sym_BQUOTE,
    ACTIONS(4651), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4659), 1,
      sym__brace_start,
    ACTIONS(10548), 1,
      sym_word,
    ACTIONS(10556), 1,
      sym__comment_word,
    ACTIONS(10566), 1,
      anon_sym_DOLLAR,
    ACTIONS(4653), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10552), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10554), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2740), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212084] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10568), 1,
      sym_word,
    ACTIONS(10570), 1,
      anon_sym_DOLLAR,
    ACTIONS(10576), 1,
      sym__comment_word,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10572), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10574), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1924), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212151] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7982), 1,
      anon_sym_DQUOTE,
    ACTIONS(7986), 1,
      aux_sym_number_token1,
    ACTIONS(7988), 1,
      aux_sym_number_token2,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7992), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8006), 1,
      sym__brace_start,
    ACTIONS(10578), 1,
      sym_word,
    ACTIONS(10580), 1,
      anon_sym_DOLLAR,
    ACTIONS(10586), 1,
      sym__comment_word,
    ACTIONS(7998), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10582), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10584), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(3402), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212218] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10568), 1,
      sym_word,
    ACTIONS(10576), 1,
      sym__comment_word,
    ACTIONS(10588), 1,
      anon_sym_DOLLAR,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10572), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10574), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1924), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212285] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5631), 1,
      aux_sym_number_token1,
    ACTIONS(5633), 1,
      aux_sym_number_token2,
    ACTIONS(5637), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5647), 1,
      sym__brace_start,
    ACTIONS(9874), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9876), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9880), 1,
      anon_sym_DQUOTE,
    ACTIONS(9884), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9886), 1,
      anon_sym_BQUOTE,
    ACTIONS(9888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10470), 1,
      sym_word,
    ACTIONS(10478), 1,
      sym__comment_word,
    ACTIONS(10590), 1,
      anon_sym_DOLLAR,
    ACTIONS(9890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10474), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10476), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(3342), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212352] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3484), 1,
      aux_sym_number_token1,
    ACTIONS(3486), 1,
      aux_sym_number_token2,
    ACTIONS(3490), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3500), 1,
      sym__brace_start,
    ACTIONS(10406), 1,
      sym_word,
    ACTIONS(10408), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10410), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10414), 1,
      anon_sym_DQUOTE,
    ACTIONS(10418), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10420), 1,
      anon_sym_BQUOTE,
    ACTIONS(10422), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10426), 1,
      sym__comment_word,
    ACTIONS(10592), 1,
      anon_sym_DOLLAR,
    ACTIONS(10412), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10424), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10416), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4511), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212419] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7866), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7868), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7870), 1,
      anon_sym_DOLLAR,
    ACTIONS(7872), 1,
      sym__special_character,
    ACTIONS(7874), 1,
      anon_sym_DQUOTE,
    ACTIONS(7878), 1,
      aux_sym_number_token1,
    ACTIONS(7880), 1,
      aux_sym_number_token2,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7884), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7898), 1,
      sym__brace_start,
    ACTIONS(10594), 1,
      sym_word,
    ACTIONS(10598), 1,
      sym_test_operator,
    STATE(1790), 1,
      aux_sym__literal_repeat1,
    STATE(1987), 1,
      sym_concatenation,
    ACTIONS(7890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10596), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1307), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212490] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5773), 1,
      aux_sym_number_token1,
    ACTIONS(5775), 1,
      aux_sym_number_token2,
    ACTIONS(5779), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5789), 1,
      sym__brace_start,
    ACTIONS(10600), 1,
      sym_word,
    ACTIONS(10602), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10604), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10606), 1,
      anon_sym_DOLLAR,
    ACTIONS(10610), 1,
      anon_sym_DQUOTE,
    ACTIONS(10614), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10616), 1,
      anon_sym_BQUOTE,
    ACTIONS(10618), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10622), 1,
      sym__comment_word,
    ACTIONS(10608), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10620), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10612), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5559), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212557] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3484), 1,
      aux_sym_number_token1,
    ACTIONS(3486), 1,
      aux_sym_number_token2,
    ACTIONS(3490), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3500), 1,
      sym__brace_start,
    ACTIONS(10406), 1,
      sym_word,
    ACTIONS(10408), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10410), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10414), 1,
      anon_sym_DQUOTE,
    ACTIONS(10418), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10420), 1,
      anon_sym_BQUOTE,
    ACTIONS(10422), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10426), 1,
      sym__comment_word,
    ACTIONS(10624), 1,
      anon_sym_DOLLAR,
    ACTIONS(10412), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10424), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10416), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4511), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212624] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2073), 1,
      aux_sym_number_token1,
    ACTIONS(2075), 1,
      aux_sym_number_token2,
    ACTIONS(2079), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2093), 1,
      sym__brace_start,
    ACTIONS(7908), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7910), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7914), 1,
      anon_sym_DQUOTE,
    ACTIONS(7918), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7920), 1,
      anon_sym_BQUOTE,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10626), 1,
      sym_word,
    ACTIONS(10628), 1,
      anon_sym_DOLLAR,
    ACTIONS(10634), 1,
      sym__comment_word,
    ACTIONS(7924), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10630), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10632), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1618), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212691] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10640), 1,
      anon_sym_LPAREN,
    ACTIONS(10642), 1,
      aux_sym__c_word_token1,
    ACTIONS(10644), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10648), 1,
      anon_sym_DQUOTE,
    ACTIONS(10650), 1,
      aux_sym_number_token1,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(10654), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10658), 1,
      anon_sym_BQUOTE,
    ACTIONS(10660), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(4149), 1,
      sym__c_terminator,
    STATE(6267), 1,
      sym__c_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    STATE(6712), 1,
      sym__for_body,
    ACTIONS(10636), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(10638), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [212766] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(107), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(109), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(115), 1,
      anon_sym_DQUOTE,
    ACTIONS(119), 1,
      aux_sym_number_token1,
    ACTIONS(121), 1,
      aux_sym_number_token2,
    ACTIONS(123), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(125), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(127), 1,
      anon_sym_BQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(139), 1,
      sym__brace_start,
    ACTIONS(10662), 1,
      sym_word,
    ACTIONS(10664), 1,
      anon_sym_DOLLAR,
    ACTIONS(10670), 1,
      sym__comment_word,
    ACTIONS(131), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10666), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10668), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(486), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212833] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10672), 1,
      sym_word,
    ACTIONS(10674), 1,
      sym__special_character,
    ACTIONS(10678), 1,
      sym_test_operator,
    STATE(4353), 1,
      aux_sym__literal_repeat1,
    STATE(4901), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10676), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4570), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212904] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10674), 1,
      sym__special_character,
    ACTIONS(10680), 1,
      sym_word,
    ACTIONS(10684), 1,
      sym_test_operator,
    STATE(4371), 1,
      aux_sym__literal_repeat1,
    STATE(4761), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10682), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4574), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [212975] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10686), 1,
      sym_word,
    ACTIONS(10688), 1,
      sym__special_character,
    ACTIONS(10692), 1,
      sym_test_operator,
    STATE(4260), 1,
      aux_sym__literal_repeat1,
    STATE(4557), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10690), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4459), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213046] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10688), 1,
      sym__special_character,
    ACTIONS(10694), 1,
      sym_word,
    ACTIONS(10698), 1,
      sym_test_operator,
    STATE(4213), 1,
      aux_sym__literal_repeat1,
    STATE(4518), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10696), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4461), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213117] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7978), 1,
      anon_sym_DOLLAR,
    ACTIONS(7980), 1,
      sym__special_character,
    ACTIONS(7982), 1,
      anon_sym_DQUOTE,
    ACTIONS(7986), 1,
      aux_sym_number_token1,
    ACTIONS(7988), 1,
      aux_sym_number_token2,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7992), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8006), 1,
      sym__brace_start,
    ACTIONS(10700), 1,
      sym_word,
    ACTIONS(10704), 1,
      sym_test_operator,
    STATE(3449), 1,
      aux_sym__literal_repeat1,
    STATE(3696), 1,
      sym_concatenation,
    ACTIONS(7998), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10702), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(3356), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213188] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2073), 1,
      aux_sym_number_token1,
    ACTIONS(2075), 1,
      aux_sym_number_token2,
    ACTIONS(2079), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2093), 1,
      sym__brace_start,
    ACTIONS(7908), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7910), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7914), 1,
      anon_sym_DQUOTE,
    ACTIONS(7918), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7920), 1,
      anon_sym_BQUOTE,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10626), 1,
      sym_word,
    ACTIONS(10634), 1,
      sym__comment_word,
    ACTIONS(10706), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10630), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10632), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1618), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213255] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7982), 1,
      anon_sym_DQUOTE,
    ACTIONS(7986), 1,
      aux_sym_number_token1,
    ACTIONS(7988), 1,
      aux_sym_number_token2,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7992), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8006), 1,
      sym__brace_start,
    ACTIONS(10578), 1,
      sym_word,
    ACTIONS(10586), 1,
      sym__comment_word,
    ACTIONS(10708), 1,
      anon_sym_DOLLAR,
    ACTIONS(7998), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10582), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10584), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(3402), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213322] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7978), 1,
      anon_sym_DOLLAR,
    ACTIONS(7980), 1,
      sym__special_character,
    ACTIONS(7982), 1,
      anon_sym_DQUOTE,
    ACTIONS(7986), 1,
      aux_sym_number_token1,
    ACTIONS(7988), 1,
      aux_sym_number_token2,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7992), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8006), 1,
      sym__brace_start,
    ACTIONS(10710), 1,
      sym_word,
    ACTIONS(10714), 1,
      sym_test_operator,
    STATE(3432), 1,
      aux_sym__literal_repeat1,
    STATE(3520), 1,
      sym_concatenation,
    ACTIONS(7998), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10712), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(3351), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213393] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      aux_sym_number_token2,
    ACTIONS(2631), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2641), 1,
      sym__brace_start,
    ACTIONS(9742), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9744), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9748), 1,
      anon_sym_DQUOTE,
    ACTIONS(9752), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9754), 1,
      anon_sym_BQUOTE,
    ACTIONS(9756), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10428), 1,
      sym_word,
    ACTIONS(10434), 1,
      sym__comment_word,
    ACTIONS(10716), 1,
      anon_sym_DOLLAR,
    ACTIONS(9758), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10430), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10432), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1526), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213460] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2625), 1,
      aux_sym_number_token1,
    ACTIONS(2627), 1,
      aux_sym_number_token2,
    ACTIONS(2631), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2641), 1,
      sym__brace_start,
    ACTIONS(9742), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9744), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9748), 1,
      anon_sym_DQUOTE,
    ACTIONS(9752), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9754), 1,
      anon_sym_BQUOTE,
    ACTIONS(9756), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10428), 1,
      sym_word,
    ACTIONS(10434), 1,
      sym__comment_word,
    ACTIONS(10718), 1,
      anon_sym_DOLLAR,
    ACTIONS(9758), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10430), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10432), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1526), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213527] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2683), 1,
      sym__brace_start,
    ACTIONS(10720), 1,
      sym_word,
    ACTIONS(10722), 1,
      anon_sym_DOLLAR,
    ACTIONS(10728), 1,
      sym__comment_word,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10724), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10726), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2222), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213594] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2067), 1,
      anon_sym_DOLLAR,
    ACTIONS(2073), 1,
      aux_sym_number_token1,
    ACTIONS(2075), 1,
      aux_sym_number_token2,
    ACTIONS(2079), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2093), 1,
      sym__brace_start,
    ACTIONS(7908), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7910), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7914), 1,
      anon_sym_DQUOTE,
    ACTIONS(7918), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7920), 1,
      anon_sym_BQUOTE,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10626), 1,
      sym_word,
    ACTIONS(10634), 1,
      sym__comment_word,
    ACTIONS(7924), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10630), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10632), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1618), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213661] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1597), 1,
      aux_sym_number_token1,
    ACTIONS(1599), 1,
      aux_sym_number_token2,
    ACTIONS(1603), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1617), 1,
      sym__brace_start,
    ACTIONS(8160), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8162), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8166), 1,
      anon_sym_DQUOTE,
    ACTIONS(8170), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8172), 1,
      anon_sym_BQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10114), 1,
      sym_word,
    ACTIONS(10120), 1,
      sym__comment_word,
    ACTIONS(10730), 1,
      anon_sym_DOLLAR,
    ACTIONS(8176), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10116), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10118), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1171), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213728] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(107), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(109), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(115), 1,
      anon_sym_DQUOTE,
    ACTIONS(119), 1,
      aux_sym_number_token1,
    ACTIONS(121), 1,
      aux_sym_number_token2,
    ACTIONS(123), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(125), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(127), 1,
      anon_sym_BQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(139), 1,
      sym__brace_start,
    ACTIONS(10662), 1,
      sym_word,
    ACTIONS(10670), 1,
      sym__comment_word,
    ACTIONS(10732), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10666), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10668), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(486), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213795] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2683), 1,
      sym__brace_start,
    ACTIONS(10720), 1,
      sym_word,
    ACTIONS(10728), 1,
      sym__comment_word,
    ACTIONS(10734), 1,
      anon_sym_DOLLAR,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10724), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10726), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2222), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213862] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10736), 1,
      sym_word,
    ACTIONS(10738), 1,
      sym__special_character,
    ACTIONS(10742), 1,
      sym_test_operator,
    STATE(4260), 1,
      aux_sym__literal_repeat1,
    STATE(4557), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10740), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4382), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [213933] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10738), 1,
      sym__special_character,
    ACTIONS(10744), 1,
      sym_word,
    ACTIONS(10748), 1,
      sym_test_operator,
    STATE(4213), 1,
      aux_sym__literal_repeat1,
    STATE(4518), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10746), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4342), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214004] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10750), 1,
      sym_word,
    ACTIONS(10752), 1,
      sym__special_character,
    ACTIONS(10756), 1,
      sym_test_operator,
    STATE(4353), 1,
      aux_sym__literal_repeat1,
    STATE(4901), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10754), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4878), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214075] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10752), 1,
      sym__special_character,
    ACTIONS(10758), 1,
      sym_word,
    ACTIONS(10762), 1,
      sym_test_operator,
    STATE(4371), 1,
      aux_sym__literal_repeat1,
    STATE(4761), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10760), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4882), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214146] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10764), 1,
      sym_word,
    ACTIONS(10766), 1,
      sym__special_character,
    ACTIONS(10770), 1,
      sym_test_operator,
    STATE(4260), 1,
      aux_sym__literal_repeat1,
    STATE(4557), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10768), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4630), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214217] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10766), 1,
      sym__special_character,
    ACTIONS(10772), 1,
      sym_word,
    ACTIONS(10776), 1,
      sym_test_operator,
    STATE(4213), 1,
      aux_sym__literal_repeat1,
    STATE(4518), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10774), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4632), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214288] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2343), 1,
      aux_sym_number_token1,
    ACTIONS(2345), 1,
      aux_sym_number_token2,
    ACTIONS(2349), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2359), 1,
      sym__brace_start,
    ACTIONS(9628), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9630), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9634), 1,
      anon_sym_DQUOTE,
    ACTIONS(9638), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9640), 1,
      anon_sym_BQUOTE,
    ACTIONS(9642), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10226), 1,
      sym_word,
    ACTIONS(10232), 1,
      sym__comment_word,
    ACTIONS(10778), 1,
      anon_sym_DOLLAR,
    ACTIONS(9644), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10228), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10230), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1329), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214355] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(47), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(57), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      aux_sym_number_token2,
    ACTIONS(61), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(63), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(65), 1,
      anon_sym_BQUOTE,
    ACTIONS(67), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(79), 1,
      sym__brace_start,
    ACTIONS(10192), 1,
      sym_word,
    ACTIONS(10200), 1,
      sym__comment_word,
    ACTIONS(10780), 1,
      anon_sym_DOLLAR,
    ACTIONS(69), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10196), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10198), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1110), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214422] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8188), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8190), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8196), 1,
      anon_sym_DQUOTE,
    ACTIONS(8200), 1,
      aux_sym_number_token1,
    ACTIONS(8202), 1,
      aux_sym_number_token2,
    ACTIONS(8204), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8206), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8208), 1,
      anon_sym_BQUOTE,
    ACTIONS(8210), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8220), 1,
      sym__brace_start,
    ACTIONS(10274), 1,
      sym_word,
    ACTIONS(10280), 1,
      sym__comment_word,
    ACTIONS(10782), 1,
      anon_sym_DOLLAR,
    ACTIONS(8212), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10276), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10278), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4200), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214489] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1597), 1,
      aux_sym_number_token1,
    ACTIONS(1599), 1,
      aux_sym_number_token2,
    ACTIONS(1603), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1617), 1,
      sym__brace_start,
    ACTIONS(8160), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8162), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8166), 1,
      anon_sym_DQUOTE,
    ACTIONS(8170), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8172), 1,
      anon_sym_BQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10114), 1,
      sym_word,
    ACTIONS(10120), 1,
      sym__comment_word,
    ACTIONS(10784), 1,
      anon_sym_DOLLAR,
    ACTIONS(8176), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10116), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10118), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1171), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214556] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(10786), 1,
      sym_word,
    ACTIONS(10788), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10790), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10792), 1,
      anon_sym_DOLLAR,
    ACTIONS(10796), 1,
      anon_sym_DQUOTE,
    ACTIONS(10800), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10802), 1,
      anon_sym_BQUOTE,
    ACTIONS(10804), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10808), 1,
      sym__comment_word,
    ACTIONS(10794), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10806), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10798), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1855), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214623] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7866), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7868), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7870), 1,
      anon_sym_DOLLAR,
    ACTIONS(7872), 1,
      sym__special_character,
    ACTIONS(7874), 1,
      anon_sym_DQUOTE,
    ACTIONS(7878), 1,
      aux_sym_number_token1,
    ACTIONS(7880), 1,
      aux_sym_number_token2,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7884), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7898), 1,
      sym__brace_start,
    ACTIONS(10810), 1,
      sym_word,
    ACTIONS(10814), 1,
      sym_test_operator,
    STATE(1818), 1,
      aux_sym__literal_repeat1,
    STATE(2034), 1,
      sym_concatenation,
    ACTIONS(7890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10812), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1357), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214694] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3350), 1,
      aux_sym_number_token1,
    ACTIONS(3352), 1,
      aux_sym_number_token2,
    ACTIONS(3356), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3366), 1,
      sym__brace_start,
    ACTIONS(10436), 1,
      sym_word,
    ACTIONS(10438), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10440), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10444), 1,
      anon_sym_DQUOTE,
    ACTIONS(10448), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10450), 1,
      anon_sym_BQUOTE,
    ACTIONS(10452), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10456), 1,
      sym__comment_word,
    ACTIONS(10816), 1,
      anon_sym_DOLLAR,
    ACTIONS(10442), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10454), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10446), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4339), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214761] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10818), 1,
      sym_word,
    ACTIONS(10820), 1,
      sym__special_character,
    ACTIONS(10824), 1,
      sym_test_operator,
    STATE(4353), 1,
      aux_sym__literal_repeat1,
    STATE(4901), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10822), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4652), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214832] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10820), 1,
      sym__special_character,
    ACTIONS(10826), 1,
      sym_word,
    ACTIONS(10830), 1,
      sym_test_operator,
    STATE(4371), 1,
      aux_sym__literal_repeat1,
    STATE(4761), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10828), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4656), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214903] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10832), 1,
      sym_word,
    ACTIONS(10834), 1,
      sym__special_character,
    ACTIONS(10838), 1,
      sym_test_operator,
    STATE(4260), 1,
      aux_sym__literal_repeat1,
    STATE(4557), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10836), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4499), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [214974] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10834), 1,
      sym__special_character,
    ACTIONS(10840), 1,
      sym_word,
    ACTIONS(10844), 1,
      sym_test_operator,
    STATE(4213), 1,
      aux_sym__literal_repeat1,
    STATE(4518), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10842), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4501), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215045] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7866), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7868), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7870), 1,
      anon_sym_DOLLAR,
    ACTIONS(7874), 1,
      anon_sym_DQUOTE,
    ACTIONS(7878), 1,
      aux_sym_number_token1,
    ACTIONS(7880), 1,
      aux_sym_number_token2,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7884), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7898), 1,
      sym__brace_start,
    ACTIONS(10846), 1,
      sym_word,
    ACTIONS(10852), 1,
      sym__comment_word,
    ACTIONS(7890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10848), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10850), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1527), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215112] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1039), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1041), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1047), 1,
      anon_sym_DQUOTE,
    ACTIONS(1051), 1,
      aux_sym_number_token1,
    ACTIONS(1053), 1,
      aux_sym_number_token2,
    ACTIONS(1055), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1057), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1059), 1,
      anon_sym_BQUOTE,
    ACTIONS(1061), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1069), 1,
      sym__brace_start,
    ACTIONS(10854), 1,
      sym_word,
    ACTIONS(10856), 1,
      anon_sym_DOLLAR,
    ACTIONS(10862), 1,
      sym__comment_word,
    ACTIONS(1063), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10858), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10860), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2144), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215179] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3312), 1,
      anon_sym_DOLLAR,
    ACTIONS(3318), 1,
      aux_sym_number_token1,
    ACTIONS(3320), 1,
      aux_sym_number_token2,
    ACTIONS(3324), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3336), 1,
      sym__brace_start,
    ACTIONS(10292), 1,
      sym_word,
    ACTIONS(10294), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10296), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10302), 1,
      anon_sym_DQUOTE,
    ACTIONS(10306), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10308), 1,
      anon_sym_BQUOTE,
    ACTIONS(10310), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10314), 1,
      sym__comment_word,
    ACTIONS(10300), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10312), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10304), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1841), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215246] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9896), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9898), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9904), 1,
      anon_sym_DQUOTE,
    ACTIONS(9908), 1,
      aux_sym_number_token1,
    ACTIONS(9910), 1,
      aux_sym_number_token2,
    ACTIONS(9912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9914), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(9916), 1,
      anon_sym_BQUOTE,
    ACTIONS(9918), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9924), 1,
      sym__brace_start,
    ACTIONS(10864), 1,
      sym_word,
    ACTIONS(10866), 1,
      anon_sym_DOLLAR,
    ACTIONS(10872), 1,
      sym__comment_word,
    ACTIONS(9920), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10868), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10870), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2333), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215313] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10874), 1,
      sym_word,
    ACTIONS(10876), 1,
      sym__special_character,
    ACTIONS(10880), 1,
      sym_test_operator,
    STATE(4353), 1,
      aux_sym__literal_repeat1,
    STATE(4901), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10878), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5239), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215384] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10876), 1,
      sym__special_character,
    ACTIONS(10882), 1,
      sym_word,
    ACTIONS(10886), 1,
      sym_test_operator,
    STATE(4371), 1,
      aux_sym__literal_repeat1,
    STATE(4761), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10884), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5243), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215455] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10888), 1,
      sym_word,
    ACTIONS(10890), 1,
      sym__special_character,
    ACTIONS(10894), 1,
      sym_test_operator,
    STATE(4260), 1,
      aux_sym__literal_repeat1,
    STATE(4557), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10892), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5112), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215526] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10890), 1,
      sym__special_character,
    ACTIONS(10896), 1,
      sym_word,
    ACTIONS(10900), 1,
      sym_test_operator,
    STATE(4213), 1,
      aux_sym__literal_repeat1,
    STATE(4518), 1,
      sym_concatenation,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10898), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5067), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215597] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10070), 1,
      sym__special_character,
    ACTIONS(10902), 1,
      sym_word,
    ACTIONS(10906), 1,
      sym_test_operator,
    STATE(1463), 1,
      aux_sym__literal_repeat1,
    STATE(1628), 1,
      sym_concatenation,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10904), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1106), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215668] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1039), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1041), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1047), 1,
      anon_sym_DQUOTE,
    ACTIONS(1051), 1,
      aux_sym_number_token1,
    ACTIONS(1053), 1,
      aux_sym_number_token2,
    ACTIONS(1055), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1057), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1059), 1,
      anon_sym_BQUOTE,
    ACTIONS(1061), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1069), 1,
      sym__brace_start,
    ACTIONS(10854), 1,
      sym_word,
    ACTIONS(10862), 1,
      sym__comment_word,
    ACTIONS(10908), 1,
      anon_sym_DOLLAR,
    ACTIONS(1063), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10858), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10860), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2144), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215735] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10070), 1,
      sym__special_character,
    ACTIONS(10910), 1,
      sym_word,
    ACTIONS(10914), 1,
      sym_test_operator,
    STATE(1387), 1,
      aux_sym__literal_repeat1,
    STATE(1635), 1,
      sym_concatenation,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10912), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1108), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215806] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8188), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8190), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8196), 1,
      anon_sym_DQUOTE,
    ACTIONS(8200), 1,
      aux_sym_number_token1,
    ACTIONS(8202), 1,
      aux_sym_number_token2,
    ACTIONS(8204), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8206), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8208), 1,
      anon_sym_BQUOTE,
    ACTIONS(8210), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8220), 1,
      sym__brace_start,
    ACTIONS(10274), 1,
      sym_word,
    ACTIONS(10280), 1,
      sym__comment_word,
    ACTIONS(10916), 1,
      anon_sym_DOLLAR,
    ACTIONS(8212), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10276), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10278), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4200), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215873] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9896), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9898), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9904), 1,
      anon_sym_DQUOTE,
    ACTIONS(9908), 1,
      aux_sym_number_token1,
    ACTIONS(9910), 1,
      aux_sym_number_token2,
    ACTIONS(9912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9914), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(9916), 1,
      anon_sym_BQUOTE,
    ACTIONS(9918), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9924), 1,
      sym__brace_start,
    ACTIONS(10864), 1,
      sym_word,
    ACTIONS(10872), 1,
      sym__comment_word,
    ACTIONS(10918), 1,
      anon_sym_DOLLAR,
    ACTIONS(9920), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10868), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10870), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2333), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [215940] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DOLLAR,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(10920), 1,
      sym_word,
    ACTIONS(10926), 1,
      sym__comment_word,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10922), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10924), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(997), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216007] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2343), 1,
      aux_sym_number_token1,
    ACTIONS(2345), 1,
      aux_sym_number_token2,
    ACTIONS(2349), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2359), 1,
      sym__brace_start,
    ACTIONS(9628), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9630), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9634), 1,
      anon_sym_DQUOTE,
    ACTIONS(9638), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9640), 1,
      anon_sym_BQUOTE,
    ACTIONS(9642), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10226), 1,
      sym_word,
    ACTIONS(10232), 1,
      sym__comment_word,
    ACTIONS(10928), 1,
      anon_sym_DOLLAR,
    ACTIONS(9644), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10228), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10230), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1329), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216074] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10102), 1,
      anon_sym_LT_LT_LT,
    STATE(4815), 1,
      sym_herestring_redirect,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [216117] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4175), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(10102), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(10934), 1,
      sym_file_descriptor,
    STATE(4815), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4169), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(4171), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(2503), 4,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [216174] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      anon_sym_DOLLAR,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1478), 1,
      sym__brace_start,
    ACTIONS(9648), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9650), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9654), 1,
      anon_sym_DQUOTE,
    ACTIONS(9658), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9660), 1,
      anon_sym_BQUOTE,
    ACTIONS(9662), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10936), 1,
      sym_word,
    ACTIONS(10942), 1,
      sym__comment_word,
    ACTIONS(9664), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10938), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10940), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1249), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216241] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5216), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5218), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5220), 1,
      anon_sym_DOLLAR,
    ACTIONS(5224), 1,
      anon_sym_DQUOTE,
    ACTIONS(5228), 1,
      aux_sym_number_token1,
    ACTIONS(5230), 1,
      aux_sym_number_token2,
    ACTIONS(5232), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5234), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5236), 1,
      anon_sym_BQUOTE,
    ACTIONS(5238), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5244), 1,
      sym__brace_start,
    ACTIONS(10944), 1,
      sym_word,
    ACTIONS(10946), 1,
      sym__special_character,
    ACTIONS(10950), 1,
      sym_test_operator,
    STATE(5263), 1,
      aux_sym__literal_repeat1,
    STATE(5502), 1,
      sym_concatenation,
    ACTIONS(5240), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10948), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5118), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216312] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5216), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5218), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5220), 1,
      anon_sym_DOLLAR,
    ACTIONS(5224), 1,
      anon_sym_DQUOTE,
    ACTIONS(5228), 1,
      aux_sym_number_token1,
    ACTIONS(5230), 1,
      aux_sym_number_token2,
    ACTIONS(5232), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5234), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5236), 1,
      anon_sym_BQUOTE,
    ACTIONS(5238), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5244), 1,
      sym__brace_start,
    ACTIONS(10946), 1,
      sym__special_character,
    ACTIONS(10952), 1,
      sym_word,
    ACTIONS(10956), 1,
      sym_test_operator,
    STATE(5276), 1,
      aux_sym__literal_repeat1,
    STATE(5505), 1,
      sym_concatenation,
    ACTIONS(5240), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10954), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5122), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216383] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2934), 1,
      aux_sym_number_token1,
    ACTIONS(2936), 1,
      aux_sym_number_token2,
    ACTIONS(2940), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2950), 1,
      sym__brace_start,
    ACTIONS(10234), 1,
      sym_word,
    ACTIONS(10236), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10238), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10242), 1,
      anon_sym_DQUOTE,
    ACTIONS(10246), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10248), 1,
      anon_sym_BQUOTE,
    ACTIONS(10250), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10254), 1,
      sym__comment_word,
    ACTIONS(10958), 1,
      anon_sym_DOLLAR,
    ACTIONS(10240), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10252), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10244), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4301), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216450] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2934), 1,
      aux_sym_number_token1,
    ACTIONS(2936), 1,
      aux_sym_number_token2,
    ACTIONS(2940), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2950), 1,
      sym__brace_start,
    ACTIONS(10234), 1,
      sym_word,
    ACTIONS(10236), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10238), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10242), 1,
      anon_sym_DQUOTE,
    ACTIONS(10246), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10248), 1,
      anon_sym_BQUOTE,
    ACTIONS(10250), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10254), 1,
      sym__comment_word,
    ACTIONS(10960), 1,
      anon_sym_DOLLAR,
    ACTIONS(10240), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10252), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10244), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4301), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216517] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10316), 1,
      sym_word,
    ACTIONS(10318), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10320), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10326), 1,
      anon_sym_DQUOTE,
    ACTIONS(10330), 1,
      aux_sym_number_token1,
    ACTIONS(10332), 1,
      aux_sym_number_token2,
    ACTIONS(10334), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10336), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10338), 1,
      anon_sym_BQUOTE,
    ACTIONS(10340), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10344), 1,
      sym__comment_word,
    ACTIONS(10346), 1,
      sym__brace_start,
    ACTIONS(10962), 1,
      anon_sym_DOLLAR,
    ACTIONS(10324), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10342), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10328), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6138), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216584] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3350), 1,
      aux_sym_number_token1,
    ACTIONS(3352), 1,
      aux_sym_number_token2,
    ACTIONS(3356), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3366), 1,
      sym__brace_start,
    ACTIONS(10436), 1,
      sym_word,
    ACTIONS(10438), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10440), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10444), 1,
      anon_sym_DQUOTE,
    ACTIONS(10448), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10450), 1,
      anon_sym_BQUOTE,
    ACTIONS(10452), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10456), 1,
      sym__comment_word,
    ACTIONS(10964), 1,
      anon_sym_DOLLAR,
    ACTIONS(10442), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10454), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10446), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4339), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216651] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10318), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10320), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10326), 1,
      anon_sym_DQUOTE,
    ACTIONS(10330), 1,
      aux_sym_number_token1,
    ACTIONS(10332), 1,
      aux_sym_number_token2,
    ACTIONS(10334), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10336), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10338), 1,
      anon_sym_BQUOTE,
    ACTIONS(10340), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10346), 1,
      sym__brace_start,
    ACTIONS(10962), 1,
      anon_sym_DOLLAR,
    ACTIONS(10966), 1,
      sym_word,
    ACTIONS(10968), 1,
      sym__special_character,
    ACTIONS(10972), 1,
      sym_test_operator,
    STATE(6136), 1,
      aux_sym__literal_repeat1,
    STATE(6301), 1,
      sym_concatenation,
    ACTIONS(10342), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10970), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6108), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216722] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(10920), 1,
      sym_word,
    ACTIONS(10926), 1,
      sym__comment_word,
    ACTIONS(10974), 1,
      anon_sym_DOLLAR,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10922), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10924), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(997), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216789] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(10920), 1,
      sym_word,
    ACTIONS(10926), 1,
      sym__comment_word,
    ACTIONS(10976), 1,
      anon_sym_DOLLAR,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10922), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10924), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(997), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216856] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(10920), 1,
      sym_word,
    ACTIONS(10926), 1,
      sym__comment_word,
    ACTIONS(10978), 1,
      anon_sym_DOLLAR,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10922), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10924), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(997), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216923] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(373), 1,
      anon_sym_DOLLAR,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9680), 1,
      sym__comment_word,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9684), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [216990] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(10920), 1,
      sym_word,
    ACTIONS(10926), 1,
      sym__comment_word,
    ACTIONS(10980), 1,
      anon_sym_DOLLAR,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10922), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10924), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(997), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217057] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DOLLAR,
    ACTIONS(2659), 1,
      sym__special_character,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2683), 1,
      sym__brace_start,
    ACTIONS(10982), 1,
      sym_word,
    ACTIONS(10986), 1,
      sym_test_operator,
    STATE(2323), 1,
      aux_sym__literal_repeat1,
    STATE(2497), 1,
      sym_concatenation,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10984), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2114), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217128] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(10988), 1,
      anon_sym_DOLLAR,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217195] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DOLLAR,
    ACTIONS(2659), 1,
      sym__special_character,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2683), 1,
      sym__brace_start,
    ACTIONS(10990), 1,
      sym_word,
    ACTIONS(10994), 1,
      sym_test_operator,
    STATE(2329), 1,
      aux_sym__literal_repeat1,
    STATE(2509), 1,
      sym_concatenation,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10992), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2117), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217266] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(10996), 1,
      anon_sym_DOLLAR,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217333] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3600), 1,
      aux_sym_number_token1,
    ACTIONS(3602), 1,
      aux_sym_number_token2,
    ACTIONS(3606), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3616), 1,
      sym__brace_start,
    ACTIONS(9706), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9708), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9712), 1,
      anon_sym_DQUOTE,
    ACTIONS(9716), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9718), 1,
      anon_sym_BQUOTE,
    ACTIONS(9720), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10998), 1,
      sym_word,
    ACTIONS(11000), 1,
      anon_sym_DOLLAR,
    ACTIONS(11006), 1,
      sym__comment_word,
    ACTIONS(9722), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11002), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11004), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1910), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217400] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11008), 1,
      sym_word,
    ACTIONS(11010), 1,
      anon_sym_DOLLAR,
    ACTIONS(11016), 1,
      sym__comment_word,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11012), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11014), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1664), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217467] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11008), 1,
      sym_word,
    ACTIONS(11016), 1,
      sym__comment_word,
    ACTIONS(11018), 1,
      anon_sym_DOLLAR,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11012), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11014), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1664), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217534] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(10786), 1,
      sym_word,
    ACTIONS(10788), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10790), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_DQUOTE,
    ACTIONS(10800), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10802), 1,
      anon_sym_BQUOTE,
    ACTIONS(10804), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10808), 1,
      sym__comment_word,
    ACTIONS(11020), 1,
      anon_sym_DOLLAR,
    ACTIONS(10794), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10806), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10798), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1855), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217601] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3600), 1,
      aux_sym_number_token1,
    ACTIONS(3602), 1,
      aux_sym_number_token2,
    ACTIONS(3606), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3616), 1,
      sym__brace_start,
    ACTIONS(9706), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9708), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9712), 1,
      anon_sym_DQUOTE,
    ACTIONS(9716), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9718), 1,
      anon_sym_BQUOTE,
    ACTIONS(9720), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10998), 1,
      sym_word,
    ACTIONS(11006), 1,
      sym__comment_word,
    ACTIONS(11022), 1,
      anon_sym_DOLLAR,
    ACTIONS(9722), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11002), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11004), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1910), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217668] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11008), 1,
      sym_word,
    ACTIONS(11016), 1,
      sym__comment_word,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11012), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11014), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1664), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217735] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10104), 1,
      sym_word,
    ACTIONS(10112), 1,
      sym__comment_word,
    ACTIONS(11024), 1,
      anon_sym_DOLLAR,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10108), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10110), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1703), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217802] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4835), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4839), 1,
      anon_sym_DOLLAR,
    ACTIONS(4843), 1,
      anon_sym_DQUOTE,
    ACTIONS(4847), 1,
      aux_sym_number_token1,
    ACTIONS(4849), 1,
      aux_sym_number_token2,
    ACTIONS(4851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4853), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4855), 1,
      anon_sym_BQUOTE,
    ACTIONS(4857), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4863), 1,
      sym__brace_start,
    ACTIONS(11026), 1,
      sym_word,
    ACTIONS(11028), 1,
      sym__special_character,
    ACTIONS(11032), 1,
      sym_test_operator,
    STATE(5134), 1,
      aux_sym__literal_repeat1,
    STATE(5407), 1,
      sym_concatenation,
    ACTIONS(4859), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11030), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5045), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217873] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10104), 1,
      sym_word,
    ACTIONS(10112), 1,
      sym__comment_word,
    ACTIONS(11034), 1,
      anon_sym_DOLLAR,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10108), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10110), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1703), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [217940] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7866), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7868), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7874), 1,
      anon_sym_DQUOTE,
    ACTIONS(7878), 1,
      aux_sym_number_token1,
    ACTIONS(7880), 1,
      aux_sym_number_token2,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7884), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7898), 1,
      sym__brace_start,
    ACTIONS(10846), 1,
      sym_word,
    ACTIONS(10852), 1,
      sym__comment_word,
    ACTIONS(11036), 1,
      anon_sym_DOLLAR,
    ACTIONS(7890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10848), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10850), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1527), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218007] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4835), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4839), 1,
      anon_sym_DOLLAR,
    ACTIONS(4843), 1,
      anon_sym_DQUOTE,
    ACTIONS(4847), 1,
      aux_sym_number_token1,
    ACTIONS(4849), 1,
      aux_sym_number_token2,
    ACTIONS(4851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4853), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4855), 1,
      anon_sym_BQUOTE,
    ACTIONS(4857), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4863), 1,
      sym__brace_start,
    ACTIONS(11028), 1,
      sym__special_character,
    ACTIONS(11038), 1,
      sym_word,
    ACTIONS(11042), 1,
      sym_test_operator,
    STATE(5137), 1,
      aux_sym__literal_repeat1,
    STATE(5415), 1,
      sym_concatenation,
    ACTIONS(4859), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11040), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5048), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218078] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(10786), 1,
      sym_word,
    ACTIONS(10788), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10790), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_DQUOTE,
    ACTIONS(10800), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10802), 1,
      anon_sym_BQUOTE,
    ACTIONS(10804), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10808), 1,
      sym__comment_word,
    ACTIONS(11044), 1,
      anon_sym_DOLLAR,
    ACTIONS(10794), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10806), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10798), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1855), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218145] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(10786), 1,
      sym_word,
    ACTIONS(10788), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10790), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_DQUOTE,
    ACTIONS(10800), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10802), 1,
      anon_sym_BQUOTE,
    ACTIONS(10804), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10808), 1,
      sym__comment_word,
    ACTIONS(11046), 1,
      anon_sym_DOLLAR,
    ACTIONS(10794), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10806), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10798), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1855), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218212] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11048), 1,
      sym_word,
    ACTIONS(11050), 1,
      anon_sym_DOLLAR,
    ACTIONS(11056), 1,
      sym__comment_word,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11052), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11054), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1154), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218279] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11048), 1,
      sym_word,
    ACTIONS(11056), 1,
      sym__comment_word,
    ACTIONS(11058), 1,
      anon_sym_DOLLAR,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11052), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11054), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1154), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218346] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_DOLLAR,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10104), 1,
      sym_word,
    ACTIONS(10112), 1,
      sym__comment_word,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10108), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10110), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1703), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218413] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(11060), 1,
      anon_sym_DOLLAR,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218480] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7828), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7830), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7832), 1,
      anon_sym_DOLLAR,
    ACTIONS(7834), 1,
      sym__special_character,
    ACTIONS(7836), 1,
      anon_sym_DQUOTE,
    ACTIONS(7840), 1,
      aux_sym_number_token1,
    ACTIONS(7842), 1,
      aux_sym_number_token2,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7860), 1,
      sym__brace_start,
    ACTIONS(11062), 1,
      sym_word,
    ACTIONS(11066), 1,
      sym_test_operator,
    STATE(2632), 1,
      aux_sym__literal_repeat1,
    STATE(2871), 1,
      sym_concatenation,
    ACTIONS(7852), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11064), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2391), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218551] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(11068), 1,
      anon_sym_DOLLAR,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218618] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7828), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7830), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7832), 1,
      anon_sym_DOLLAR,
    ACTIONS(7834), 1,
      sym__special_character,
    ACTIONS(7836), 1,
      anon_sym_DQUOTE,
    ACTIONS(7840), 1,
      aux_sym_number_token1,
    ACTIONS(7842), 1,
      aux_sym_number_token2,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7860), 1,
      sym__brace_start,
    ACTIONS(11070), 1,
      sym_word,
    ACTIONS(11074), 1,
      sym_test_operator,
    STATE(2633), 1,
      aux_sym__literal_repeat1,
    STATE(2874), 1,
      sym_concatenation,
    ACTIONS(7852), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11072), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2423), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218689] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(11076), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218756] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5091), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5093), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5099), 1,
      anon_sym_DQUOTE,
    ACTIONS(5103), 1,
      aux_sym_number_token1,
    ACTIONS(5105), 1,
      aux_sym_number_token2,
    ACTIONS(5107), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5109), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5111), 1,
      anon_sym_BQUOTE,
    ACTIONS(5113), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5119), 1,
      sym__brace_start,
    ACTIONS(10086), 1,
      sym_word,
    ACTIONS(10092), 1,
      sym__comment_word,
    ACTIONS(11078), 1,
      anon_sym_DOLLAR,
    ACTIONS(5115), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10088), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10090), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5342), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218823] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(11080), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218890] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(11082), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [218957] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(11084), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219024] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3085), 1,
      anon_sym_DOLLAR,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(10786), 1,
      sym_word,
    ACTIONS(10788), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10790), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_DQUOTE,
    ACTIONS(10800), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10802), 1,
      anon_sym_BQUOTE,
    ACTIONS(10804), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10808), 1,
      sym__comment_word,
    ACTIONS(10794), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10806), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10798), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1855), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219091] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(11086), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219158] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(11088), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219225] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8370), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8372), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8378), 1,
      anon_sym_DQUOTE,
    ACTIONS(8382), 1,
      aux_sym_number_token1,
    ACTIONS(8384), 1,
      aux_sym_number_token2,
    ACTIONS(8386), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8388), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8390), 1,
      anon_sym_BQUOTE,
    ACTIONS(8392), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8402), 1,
      sym__brace_start,
    ACTIONS(10460), 1,
      sym_word,
    ACTIONS(10466), 1,
      sym__comment_word,
    ACTIONS(11090), 1,
      anon_sym_DOLLAR,
    ACTIONS(8394), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10462), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10464), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4362), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219292] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8370), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8372), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8378), 1,
      anon_sym_DQUOTE,
    ACTIONS(8382), 1,
      aux_sym_number_token1,
    ACTIONS(8384), 1,
      aux_sym_number_token2,
    ACTIONS(8386), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8388), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8390), 1,
      anon_sym_BQUOTE,
    ACTIONS(8392), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8402), 1,
      sym__brace_start,
    ACTIONS(10460), 1,
      sym_word,
    ACTIONS(10466), 1,
      sym__comment_word,
    ACTIONS(11092), 1,
      anon_sym_DOLLAR,
    ACTIONS(8394), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10462), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10464), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4362), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219359] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5767), 1,
      anon_sym_DOLLAR,
    ACTIONS(5773), 1,
      aux_sym_number_token1,
    ACTIONS(5775), 1,
      aux_sym_number_token2,
    ACTIONS(5779), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5789), 1,
      sym__brace_start,
    ACTIONS(10602), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10604), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10610), 1,
      anon_sym_DQUOTE,
    ACTIONS(10614), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10616), 1,
      anon_sym_BQUOTE,
    ACTIONS(10618), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11094), 1,
      sym_word,
    ACTIONS(11096), 1,
      sym__special_character,
    ACTIONS(11100), 1,
      sym_test_operator,
    STATE(5596), 1,
      aux_sym__literal_repeat1,
    STATE(5614), 1,
      sym_concatenation,
    ACTIONS(10620), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11098), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5525), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219430] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7732), 1,
      anon_sym_SLASH,
    ACTIONS(7734), 1,
      anon_sym_PERCENT,
    ACTIONS(7736), 1,
      anon_sym_COLON,
    ACTIONS(7822), 1,
      anon_sym_AT,
    ACTIONS(8880), 1,
      anon_sym_LBRACK,
    STATE(7037), 1,
      sym__expansion_max_length,
    STATE(7105), 1,
      sym__expansion_operator,
    STATE(7315), 1,
      sym__expansion_expression,
    STATE(7344), 1,
      sym__expansion_regex,
    STATE(7405), 1,
      sym__expansion_regex_replacement,
    STATE(7507), 1,
      sym__expansion_regex_removal,
    ACTIONS(7730), 2,
      anon_sym_COMMA,
      anon_sym_CARET,
    ACTIONS(7750), 2,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
    ACTIONS(7738), 3,
      sym__immediate_double_hash,
      anon_sym_POUND,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7748), 3,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
    ACTIONS(7746), 8,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
  [219495] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5767), 1,
      anon_sym_DOLLAR,
    ACTIONS(5773), 1,
      aux_sym_number_token1,
    ACTIONS(5775), 1,
      aux_sym_number_token2,
    ACTIONS(5779), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5789), 1,
      sym__brace_start,
    ACTIONS(10602), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10604), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10610), 1,
      anon_sym_DQUOTE,
    ACTIONS(10614), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10616), 1,
      anon_sym_BQUOTE,
    ACTIONS(10618), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11096), 1,
      sym__special_character,
    ACTIONS(11102), 1,
      sym_word,
    ACTIONS(11106), 1,
      sym_test_operator,
    STATE(5600), 1,
      aux_sym__literal_repeat1,
    STATE(5611), 1,
      sym_concatenation,
    ACTIONS(10620), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11104), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5513), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219566] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9680), 1,
      sym__comment_word,
    ACTIONS(11108), 1,
      anon_sym_DOLLAR,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9684), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219633] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11008), 1,
      sym_word,
    ACTIONS(11016), 1,
      sym__comment_word,
    ACTIONS(11110), 1,
      anon_sym_DOLLAR,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11012), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11014), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1664), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219700] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(47), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(57), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      aux_sym_number_token2,
    ACTIONS(61), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(63), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(65), 1,
      anon_sym_BQUOTE,
    ACTIONS(67), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(79), 1,
      sym__brace_start,
    ACTIONS(10192), 1,
      sym_word,
    ACTIONS(10200), 1,
      sym__comment_word,
    ACTIONS(69), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10196), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10198), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1110), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219767] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(11112), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219834] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11048), 1,
      sym_word,
    ACTIONS(11056), 1,
      sym__comment_word,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11052), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11054), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1154), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219901] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(11114), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [219968] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5319), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5321), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5323), 1,
      anon_sym_DOLLAR,
    ACTIONS(5325), 1,
      sym__special_character,
    ACTIONS(5327), 1,
      anon_sym_DQUOTE,
    ACTIONS(5331), 1,
      aux_sym_number_token1,
    ACTIONS(5333), 1,
      aux_sym_number_token2,
    ACTIONS(5335), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5337), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5339), 1,
      anon_sym_BQUOTE,
    ACTIONS(5341), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5347), 1,
      sym__brace_start,
    ACTIONS(11116), 1,
      sym_word,
    ACTIONS(11120), 1,
      sym_test_operator,
    STATE(5434), 1,
      aux_sym__literal_repeat1,
    STATE(5543), 1,
      sym_concatenation,
    ACTIONS(5343), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11118), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5253), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220039] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9680), 1,
      sym__comment_word,
    ACTIONS(11122), 1,
      anon_sym_DOLLAR,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9684), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220106] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5319), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5321), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5323), 1,
      anon_sym_DOLLAR,
    ACTIONS(5325), 1,
      sym__special_character,
    ACTIONS(5327), 1,
      anon_sym_DQUOTE,
    ACTIONS(5331), 1,
      aux_sym_number_token1,
    ACTIONS(5333), 1,
      aux_sym_number_token2,
    ACTIONS(5335), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5337), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5339), 1,
      anon_sym_BQUOTE,
    ACTIONS(5341), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5347), 1,
      sym__brace_start,
    ACTIONS(11124), 1,
      sym_word,
    ACTIONS(11128), 1,
      sym_test_operator,
    STATE(5444), 1,
      aux_sym__literal_repeat1,
    STATE(5581), 1,
      sym_concatenation,
    ACTIONS(5343), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11126), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220177] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11008), 1,
      sym_word,
    ACTIONS(11016), 1,
      sym__comment_word,
    ACTIONS(11130), 1,
      anon_sym_DOLLAR,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11012), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11014), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1664), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220244] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8226), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8228), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8234), 1,
      anon_sym_DQUOTE,
    ACTIONS(8238), 1,
      aux_sym_number_token1,
    ACTIONS(8240), 1,
      aux_sym_number_token2,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8244), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8258), 1,
      sym__brace_start,
    ACTIONS(10284), 1,
      sym_word,
    ACTIONS(10290), 1,
      sym__comment_word,
    ACTIONS(11132), 1,
      anon_sym_DOLLAR,
    ACTIONS(8250), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10286), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10288), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1441), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220311] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11134), 1,
      sym_word,
    ACTIONS(11136), 1,
      anon_sym_DOLLAR,
    ACTIONS(11142), 1,
      sym__comment_word,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11138), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11140), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1783), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220378] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9896), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9898), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9900), 1,
      anon_sym_DOLLAR,
    ACTIONS(9902), 1,
      sym__special_character,
    ACTIONS(9904), 1,
      anon_sym_DQUOTE,
    ACTIONS(9908), 1,
      aux_sym_number_token1,
    ACTIONS(9910), 1,
      aux_sym_number_token2,
    ACTIONS(9912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9914), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(9916), 1,
      anon_sym_BQUOTE,
    ACTIONS(9918), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9924), 1,
      sym__brace_start,
    ACTIONS(11144), 1,
      sym_word,
    ACTIONS(11148), 1,
      sym_test_operator,
    STATE(2436), 1,
      aux_sym__literal_repeat1,
    STATE(2665), 1,
      sym_concatenation,
    ACTIONS(9920), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11146), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2238), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220449] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11008), 1,
      sym_word,
    ACTIONS(11016), 1,
      sym__comment_word,
    ACTIONS(11150), 1,
      anon_sym_DOLLAR,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11012), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11014), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1664), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220516] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3213), 1,
      aux_sym_number_token1,
    ACTIONS(3215), 1,
      aux_sym_number_token2,
    ACTIONS(3219), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3229), 1,
      sym__brace_start,
    ACTIONS(9834), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9836), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9840), 1,
      anon_sym_DQUOTE,
    ACTIONS(9844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9846), 1,
      anon_sym_BQUOTE,
    ACTIONS(9848), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11152), 1,
      sym_word,
    ACTIONS(11154), 1,
      anon_sym_DOLLAR,
    ACTIONS(11160), 1,
      sym__comment_word,
    ACTIONS(9850), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11156), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11158), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1740), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220583] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7978), 1,
      anon_sym_DOLLAR,
    ACTIONS(7982), 1,
      anon_sym_DQUOTE,
    ACTIONS(7986), 1,
      aux_sym_number_token1,
    ACTIONS(7988), 1,
      aux_sym_number_token2,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7992), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8006), 1,
      sym__brace_start,
    ACTIONS(10578), 1,
      sym_word,
    ACTIONS(10586), 1,
      sym__comment_word,
    ACTIONS(7998), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10582), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10584), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(3402), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220650] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9896), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9898), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9900), 1,
      anon_sym_DOLLAR,
    ACTIONS(9902), 1,
      sym__special_character,
    ACTIONS(9904), 1,
      anon_sym_DQUOTE,
    ACTIONS(9908), 1,
      aux_sym_number_token1,
    ACTIONS(9910), 1,
      aux_sym_number_token2,
    ACTIONS(9912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9914), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(9916), 1,
      anon_sym_BQUOTE,
    ACTIONS(9918), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9924), 1,
      sym__brace_start,
    ACTIONS(11162), 1,
      sym_word,
    ACTIONS(11166), 1,
      sym_test_operator,
    STATE(2569), 1,
      aux_sym__literal_repeat1,
    STATE(2686), 1,
      sym_concatenation,
    ACTIONS(9920), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11164), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2306), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220721] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10104), 1,
      sym_word,
    ACTIONS(10112), 1,
      sym__comment_word,
    ACTIONS(11168), 1,
      anon_sym_DOLLAR,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10108), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10110), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1703), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220788] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3213), 1,
      aux_sym_number_token1,
    ACTIONS(3215), 1,
      aux_sym_number_token2,
    ACTIONS(3219), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3229), 1,
      sym__brace_start,
    ACTIONS(9834), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9836), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9840), 1,
      anon_sym_DQUOTE,
    ACTIONS(9844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9846), 1,
      anon_sym_BQUOTE,
    ACTIONS(9848), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11152), 1,
      sym_word,
    ACTIONS(11160), 1,
      sym__comment_word,
    ACTIONS(11170), 1,
      anon_sym_DOLLAR,
    ACTIONS(9850), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11156), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11158), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1740), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220855] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5091), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5093), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5095), 1,
      anon_sym_DOLLAR,
    ACTIONS(5097), 1,
      sym__special_character,
    ACTIONS(5099), 1,
      anon_sym_DQUOTE,
    ACTIONS(5103), 1,
      aux_sym_number_token1,
    ACTIONS(5105), 1,
      aux_sym_number_token2,
    ACTIONS(5107), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5109), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5111), 1,
      anon_sym_BQUOTE,
    ACTIONS(5113), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5119), 1,
      sym__brace_start,
    ACTIONS(11172), 1,
      sym_word,
    ACTIONS(11176), 1,
      sym_test_operator,
    STATE(5312), 1,
      aux_sym__literal_repeat1,
    STATE(5504), 1,
      sym_concatenation,
    ACTIONS(5115), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11174), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5202), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220926] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3318), 1,
      aux_sym_number_token1,
    ACTIONS(3320), 1,
      aux_sym_number_token2,
    ACTIONS(3324), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3336), 1,
      sym__brace_start,
    ACTIONS(10292), 1,
      sym_word,
    ACTIONS(10294), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10296), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10302), 1,
      anon_sym_DQUOTE,
    ACTIONS(10306), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10308), 1,
      anon_sym_BQUOTE,
    ACTIONS(10310), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10314), 1,
      sym__comment_word,
    ACTIONS(11178), 1,
      anon_sym_DOLLAR,
    ACTIONS(10300), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10312), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10304), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1841), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [220993] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8226), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8228), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8234), 1,
      anon_sym_DQUOTE,
    ACTIONS(8238), 1,
      aux_sym_number_token1,
    ACTIONS(8240), 1,
      aux_sym_number_token2,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8244), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8258), 1,
      sym__brace_start,
    ACTIONS(10284), 1,
      sym_word,
    ACTIONS(10290), 1,
      sym__comment_word,
    ACTIONS(11180), 1,
      anon_sym_DOLLAR,
    ACTIONS(8250), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10286), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10288), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1441), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221060] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      aux_sym_number_token1,
    ACTIONS(2041), 1,
      aux_sym_number_token2,
    ACTIONS(2045), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2059), 1,
      sym__brace_start,
    ACTIONS(8012), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8018), 1,
      anon_sym_DQUOTE,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10104), 1,
      sym_word,
    ACTIONS(10112), 1,
      sym__comment_word,
    ACTIONS(11182), 1,
      anon_sym_DOLLAR,
    ACTIONS(8028), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10108), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10110), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1703), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221127] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(10786), 1,
      sym_word,
    ACTIONS(10788), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10790), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_DQUOTE,
    ACTIONS(10800), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10802), 1,
      anon_sym_BQUOTE,
    ACTIONS(10804), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10808), 1,
      sym__comment_word,
    ACTIONS(11184), 1,
      anon_sym_DOLLAR,
    ACTIONS(10794), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10806), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10798), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1855), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221194] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9896), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9898), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9900), 1,
      anon_sym_DOLLAR,
    ACTIONS(9904), 1,
      anon_sym_DQUOTE,
    ACTIONS(9908), 1,
      aux_sym_number_token1,
    ACTIONS(9910), 1,
      aux_sym_number_token2,
    ACTIONS(9912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9914), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(9916), 1,
      anon_sym_BQUOTE,
    ACTIONS(9918), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(9924), 1,
      sym__brace_start,
    ACTIONS(10864), 1,
      sym_word,
    ACTIONS(10872), 1,
      sym__comment_word,
    ACTIONS(9920), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10868), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10870), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2333), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221261] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3091), 1,
      aux_sym_number_token1,
    ACTIONS(3093), 1,
      aux_sym_number_token2,
    ACTIONS(3097), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3109), 1,
      sym__brace_start,
    ACTIONS(10786), 1,
      sym_word,
    ACTIONS(10788), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10790), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_DQUOTE,
    ACTIONS(10800), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10802), 1,
      anon_sym_BQUOTE,
    ACTIONS(10804), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10808), 1,
      sym__comment_word,
    ACTIONS(11186), 1,
      anon_sym_DOLLAR,
    ACTIONS(10794), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10806), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10798), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1855), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221328] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8114), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8116), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8118), 1,
      anon_sym_DOLLAR,
    ACTIONS(8120), 1,
      sym__special_character,
    ACTIONS(8122), 1,
      anon_sym_DQUOTE,
    ACTIONS(8126), 1,
      aux_sym_number_token1,
    ACTIONS(8128), 1,
      aux_sym_number_token2,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8146), 1,
      sym__brace_start,
    ACTIONS(11188), 1,
      sym_word,
    ACTIONS(11192), 1,
      sym_test_operator,
    STATE(1391), 1,
      aux_sym__literal_repeat1,
    STATE(1547), 1,
      sym_concatenation,
    ACTIONS(8138), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11190), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1009), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221399] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5773), 1,
      aux_sym_number_token1,
    ACTIONS(5775), 1,
      aux_sym_number_token2,
    ACTIONS(5779), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5789), 1,
      sym__brace_start,
    ACTIONS(10600), 1,
      sym_word,
    ACTIONS(10602), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10604), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10610), 1,
      anon_sym_DQUOTE,
    ACTIONS(10614), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10616), 1,
      anon_sym_BQUOTE,
    ACTIONS(10618), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10622), 1,
      sym__comment_word,
    ACTIONS(11194), 1,
      anon_sym_DOLLAR,
    ACTIONS(10608), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10620), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10612), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5559), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221466] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8114), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8116), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8118), 1,
      anon_sym_DOLLAR,
    ACTIONS(8120), 1,
      sym__special_character,
    ACTIONS(8122), 1,
      anon_sym_DQUOTE,
    ACTIONS(8126), 1,
      aux_sym_number_token1,
    ACTIONS(8128), 1,
      aux_sym_number_token2,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8146), 1,
      sym__brace_start,
    ACTIONS(11196), 1,
      sym_word,
    ACTIONS(11200), 1,
      sym_test_operator,
    STATE(1448), 1,
      aux_sym__literal_repeat1,
    STATE(1644), 1,
      sym_concatenation,
    ACTIONS(8138), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11198), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1019), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221537] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4538), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4540), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4546), 1,
      anon_sym_DQUOTE,
    ACTIONS(4550), 1,
      aux_sym_number_token1,
    ACTIONS(4552), 1,
      aux_sym_number_token2,
    ACTIONS(4554), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4556), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4560), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4566), 1,
      sym__brace_start,
    ACTIONS(10388), 1,
      sym_word,
    ACTIONS(10396), 1,
      sym__comment_word,
    ACTIONS(11202), 1,
      anon_sym_DOLLAR,
    ACTIONS(4562), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10392), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10394), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2580), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221604] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11048), 1,
      sym_word,
    ACTIONS(11056), 1,
      sym__comment_word,
    ACTIONS(11204), 1,
      anon_sym_DOLLAR,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11052), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11054), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1154), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221671] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(11206), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221738] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11048), 1,
      sym_word,
    ACTIONS(11056), 1,
      sym__comment_word,
    ACTIONS(11208), 1,
      anon_sym_DOLLAR,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11052), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11054), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1154), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221805] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(107), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(109), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(111), 1,
      anon_sym_DOLLAR,
    ACTIONS(115), 1,
      anon_sym_DQUOTE,
    ACTIONS(119), 1,
      aux_sym_number_token1,
    ACTIONS(121), 1,
      aux_sym_number_token2,
    ACTIONS(123), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(125), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(127), 1,
      anon_sym_BQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(139), 1,
      sym__brace_start,
    ACTIONS(10662), 1,
      sym_word,
    ACTIONS(10670), 1,
      sym__comment_word,
    ACTIONS(131), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10666), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10668), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(486), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221872] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(11210), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [221939] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(187), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(189), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(195), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      aux_sym_number_token1,
    ACTIONS(201), 1,
      aux_sym_number_token2,
    ACTIONS(203), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(205), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(207), 1,
      anon_sym_BQUOTE,
    ACTIONS(209), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(219), 1,
      sym__brace_start,
    ACTIONS(11212), 1,
      sym_word,
    ACTIONS(11214), 1,
      anon_sym_DOLLAR,
    ACTIONS(11220), 1,
      sym__comment_word,
    ACTIONS(211), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11216), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11218), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(508), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222006] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3123), 1,
      anon_sym_DOLLAR,
    ACTIONS(3129), 1,
      aux_sym_number_token1,
    ACTIONS(3131), 1,
      aux_sym_number_token2,
    ACTIONS(3135), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3145), 1,
      sym__brace_start,
    ACTIONS(10204), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10206), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10210), 1,
      anon_sym_DQUOTE,
    ACTIONS(10214), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10216), 1,
      anon_sym_BQUOTE,
    ACTIONS(10218), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11222), 1,
      sym_word,
    ACTIONS(11224), 1,
      sym__special_character,
    ACTIONS(11228), 1,
      sym_test_operator,
    STATE(4429), 1,
      aux_sym__literal_repeat1,
    STATE(4714), 1,
      sym_concatenation,
    ACTIONS(10220), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11226), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4258), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222077] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3123), 1,
      anon_sym_DOLLAR,
    ACTIONS(3129), 1,
      aux_sym_number_token1,
    ACTIONS(3131), 1,
      aux_sym_number_token2,
    ACTIONS(3135), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3145), 1,
      sym__brace_start,
    ACTIONS(10204), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10206), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10210), 1,
      anon_sym_DQUOTE,
    ACTIONS(10214), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10216), 1,
      anon_sym_BQUOTE,
    ACTIONS(10218), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11224), 1,
      sym__special_character,
    ACTIONS(11230), 1,
      sym_word,
    ACTIONS(11234), 1,
      sym_test_operator,
    STATE(4356), 1,
      aux_sym__literal_repeat1,
    STATE(4935), 1,
      sym_concatenation,
    ACTIONS(10220), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11232), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4235), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222148] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11008), 1,
      sym_word,
    ACTIONS(11016), 1,
      sym__comment_word,
    ACTIONS(11236), 1,
      anon_sym_DOLLAR,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11012), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11014), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1664), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222215] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1398), 1,
      sym__brace_start,
    ACTIONS(10042), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10044), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10048), 1,
      anon_sym_DQUOTE,
    ACTIONS(10052), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10054), 1,
      anon_sym_BQUOTE,
    ACTIONS(10056), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10166), 1,
      sym_word,
    ACTIONS(10172), 1,
      sym__comment_word,
    ACTIONS(11238), 1,
      anon_sym_DOLLAR,
    ACTIONS(10058), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10168), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10170), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(889), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222282] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4064), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4066), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4068), 1,
      anon_sym_DOLLAR,
    ACTIONS(4072), 1,
      anon_sym_DQUOTE,
    ACTIONS(4076), 1,
      aux_sym_number_token1,
    ACTIONS(4078), 1,
      aux_sym_number_token2,
    ACTIONS(4080), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4082), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4084), 1,
      anon_sym_BQUOTE,
    ACTIONS(4086), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4096), 1,
      sym__brace_start,
    ACTIONS(10174), 1,
      sym_word,
    ACTIONS(10182), 1,
      sym__comment_word,
    ACTIONS(4088), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10178), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10180), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2446), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222349] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11134), 1,
      sym_word,
    ACTIONS(11142), 1,
      sym__comment_word,
    ACTIONS(11240), 1,
      anon_sym_DOLLAR,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11138), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11140), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1783), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222416] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1398), 1,
      sym__brace_start,
    ACTIONS(10042), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10044), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10046), 1,
      sym__special_character,
    ACTIONS(10048), 1,
      anon_sym_DQUOTE,
    ACTIONS(10052), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10054), 1,
      anon_sym_BQUOTE,
    ACTIONS(10056), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11242), 1,
      sym_word,
    ACTIONS(11246), 1,
      sym_test_operator,
    STATE(1027), 1,
      aux_sym__literal_repeat1,
    STATE(1150), 1,
      sym_concatenation,
    ACTIONS(10058), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11244), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(838), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222487] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(187), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(189), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(195), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      aux_sym_number_token1,
    ACTIONS(201), 1,
      aux_sym_number_token2,
    ACTIONS(203), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(205), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(207), 1,
      anon_sym_BQUOTE,
    ACTIONS(209), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(219), 1,
      sym__brace_start,
    ACTIONS(11212), 1,
      sym_word,
    ACTIONS(11220), 1,
      sym__comment_word,
    ACTIONS(11248), 1,
      anon_sym_DOLLAR,
    ACTIONS(211), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11216), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11218), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(508), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222554] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5319), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5321), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5327), 1,
      anon_sym_DQUOTE,
    ACTIONS(5331), 1,
      aux_sym_number_token1,
    ACTIONS(5333), 1,
      aux_sym_number_token2,
    ACTIONS(5335), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5337), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5339), 1,
      anon_sym_BQUOTE,
    ACTIONS(5341), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5347), 1,
      sym__brace_start,
    ACTIONS(11250), 1,
      sym_word,
    ACTIONS(11252), 1,
      anon_sym_DOLLAR,
    ACTIONS(11258), 1,
      sym__comment_word,
    ACTIONS(5343), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11254), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11256), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5420), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222621] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1398), 1,
      sym__brace_start,
    ACTIONS(10042), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10044), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10046), 1,
      sym__special_character,
    ACTIONS(10048), 1,
      anon_sym_DQUOTE,
    ACTIONS(10052), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10054), 1,
      anon_sym_BQUOTE,
    ACTIONS(10056), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11260), 1,
      sym_word,
    ACTIONS(11264), 1,
      sym_test_operator,
    STATE(1029), 1,
      aux_sym__literal_repeat1,
    STATE(1153), 1,
      sym_concatenation,
    ACTIONS(10058), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11262), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(818), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222692] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11266), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11268), 1,
      sym__concat,
    STATE(4136), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [222735] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(11270), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222802] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(11272), 1,
      sym_word,
    ACTIONS(11274), 1,
      anon_sym_DOLLAR,
    ACTIONS(11280), 1,
      sym__comment_word,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11276), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11278), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5127), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222869] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4629), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4631), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4633), 1,
      anon_sym_DOLLAR,
    ACTIONS(4637), 1,
      anon_sym_DQUOTE,
    ACTIONS(4641), 1,
      aux_sym_number_token1,
    ACTIONS(4643), 1,
      aux_sym_number_token2,
    ACTIONS(4645), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4647), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4649), 1,
      anon_sym_BQUOTE,
    ACTIONS(4651), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4659), 1,
      sym__brace_start,
    ACTIONS(10548), 1,
      sym_word,
    ACTIONS(10556), 1,
      sym__comment_word,
    ACTIONS(4653), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10552), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10554), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2740), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [222936] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9680), 1,
      sym__comment_word,
    ACTIONS(11282), 1,
      anon_sym_DOLLAR,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9684), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223003] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(11272), 1,
      sym_word,
    ACTIONS(11280), 1,
      sym__comment_word,
    ACTIONS(11284), 1,
      anon_sym_DOLLAR,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11276), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11278), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5127), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223070] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2928), 1,
      anon_sym_DOLLAR,
    ACTIONS(2934), 1,
      aux_sym_number_token1,
    ACTIONS(2936), 1,
      aux_sym_number_token2,
    ACTIONS(2940), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2950), 1,
      sym__brace_start,
    ACTIONS(10236), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10238), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10242), 1,
      anon_sym_DQUOTE,
    ACTIONS(10246), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10248), 1,
      anon_sym_BQUOTE,
    ACTIONS(10250), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11286), 1,
      sym_word,
    ACTIONS(11288), 1,
      sym__special_character,
    ACTIONS(11292), 1,
      sym_test_operator,
    STATE(4291), 1,
      aux_sym__literal_repeat1,
    STATE(4579), 1,
      sym_concatenation,
    ACTIONS(10252), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11290), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4158), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223141] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2928), 1,
      anon_sym_DOLLAR,
    ACTIONS(2934), 1,
      aux_sym_number_token1,
    ACTIONS(2936), 1,
      aux_sym_number_token2,
    ACTIONS(2940), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2950), 1,
      sym__brace_start,
    ACTIONS(10236), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10238), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10242), 1,
      anon_sym_DQUOTE,
    ACTIONS(10246), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10248), 1,
      anon_sym_BQUOTE,
    ACTIONS(10250), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11288), 1,
      sym__special_character,
    ACTIONS(11294), 1,
      sym_word,
    ACTIONS(11298), 1,
      sym_test_operator,
    STATE(4175), 1,
      aux_sym__literal_repeat1,
    STATE(4616), 1,
      sym_concatenation,
    ACTIONS(10252), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11296), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4138), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223212] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(701), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(703), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(709), 1,
      anon_sym_DQUOTE,
    ACTIONS(713), 1,
      aux_sym_number_token1,
    ACTIONS(715), 1,
      aux_sym_number_token2,
    ACTIONS(717), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(719), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(721), 1,
      anon_sym_BQUOTE,
    ACTIONS(723), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(733), 1,
      sym__brace_start,
    ACTIONS(10266), 1,
      sym_word,
    ACTIONS(10272), 1,
      sym__comment_word,
    ACTIONS(11300), 1,
      anon_sym_DOLLAR,
    ACTIONS(725), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10268), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10270), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(897), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223279] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2653), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(2655), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DOLLAR,
    ACTIONS(2661), 1,
      anon_sym_DQUOTE,
    ACTIONS(2665), 1,
      aux_sym_number_token1,
    ACTIONS(2667), 1,
      aux_sym_number_token2,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2671), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(2683), 1,
      sym__brace_start,
    ACTIONS(10720), 1,
      sym_word,
    ACTIONS(10728), 1,
      sym__comment_word,
    ACTIONS(2677), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10724), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10726), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2222), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223346] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(10920), 1,
      sym_word,
    ACTIONS(10926), 1,
      sym__comment_word,
    ACTIONS(11302), 1,
      anon_sym_DOLLAR,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10922), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10924), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(997), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223413] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8226), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8228), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8230), 1,
      anon_sym_DOLLAR,
    ACTIONS(8232), 1,
      sym__special_character,
    ACTIONS(8234), 1,
      anon_sym_DQUOTE,
    ACTIONS(8238), 1,
      aux_sym_number_token1,
    ACTIONS(8240), 1,
      aux_sym_number_token2,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8244), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8258), 1,
      sym__brace_start,
    ACTIONS(11304), 1,
      sym_word,
    ACTIONS(11308), 1,
      sym_test_operator,
    STATE(1502), 1,
      aux_sym__literal_repeat1,
    STATE(1765), 1,
      sym_concatenation,
    ACTIONS(8250), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11306), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1291), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223484] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4257), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(10102), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(10934), 1,
      sym_file_descriptor,
    STATE(4815), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4171), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4253), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4255), 4,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [223541] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8226), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8228), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8230), 1,
      anon_sym_DOLLAR,
    ACTIONS(8232), 1,
      sym__special_character,
    ACTIONS(8234), 1,
      anon_sym_DQUOTE,
    ACTIONS(8238), 1,
      aux_sym_number_token1,
    ACTIONS(8240), 1,
      aux_sym_number_token2,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8244), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8258), 1,
      sym__brace_start,
    ACTIONS(11310), 1,
      sym_word,
    ACTIONS(11314), 1,
      sym_test_operator,
    STATE(1508), 1,
      aux_sym__literal_repeat1,
    STATE(1802), 1,
      sym_concatenation,
    ACTIONS(8250), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11312), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1223), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223612] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1039), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1041), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1043), 1,
      anon_sym_DOLLAR,
    ACTIONS(1047), 1,
      anon_sym_DQUOTE,
    ACTIONS(1051), 1,
      aux_sym_number_token1,
    ACTIONS(1053), 1,
      aux_sym_number_token2,
    ACTIONS(1055), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1057), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1059), 1,
      anon_sym_BQUOTE,
    ACTIONS(1061), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(1069), 1,
      sym__brace_start,
    ACTIONS(10854), 1,
      sym_word,
    ACTIONS(10862), 1,
      sym__comment_word,
    ACTIONS(1063), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10858), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10860), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2144), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223679] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(701), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(703), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(709), 1,
      anon_sym_DQUOTE,
    ACTIONS(713), 1,
      aux_sym_number_token1,
    ACTIONS(715), 1,
      aux_sym_number_token2,
    ACTIONS(717), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(719), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(721), 1,
      anon_sym_BQUOTE,
    ACTIONS(723), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(733), 1,
      sym__brace_start,
    ACTIONS(10266), 1,
      sym_word,
    ACTIONS(10272), 1,
      sym__comment_word,
    ACTIONS(11316), 1,
      anon_sym_DOLLAR,
    ACTIONS(725), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10268), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10270), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(897), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223746] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3478), 1,
      anon_sym_DOLLAR,
    ACTIONS(3484), 1,
      aux_sym_number_token1,
    ACTIONS(3486), 1,
      aux_sym_number_token2,
    ACTIONS(3490), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3500), 1,
      sym__brace_start,
    ACTIONS(10408), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10410), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10414), 1,
      anon_sym_DQUOTE,
    ACTIONS(10418), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10420), 1,
      anon_sym_BQUOTE,
    ACTIONS(10422), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11318), 1,
      sym_word,
    ACTIONS(11320), 1,
      sym__special_character,
    ACTIONS(11324), 1,
      sym_test_operator,
    STATE(4640), 1,
      aux_sym__literal_repeat1,
    STATE(4970), 1,
      sym_concatenation,
    ACTIONS(10424), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11322), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4489), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223817] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10132), 1,
      sym_word,
    ACTIONS(10140), 1,
      sym__comment_word,
    ACTIONS(11326), 1,
      anon_sym_DOLLAR,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10136), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10138), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4898), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223884] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10132), 1,
      sym_word,
    ACTIONS(10140), 1,
      sym__comment_word,
    ACTIONS(11328), 1,
      anon_sym_DOLLAR,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10136), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10138), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4898), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [223951] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2295), 1,
      aux_sym_number_token1,
    ACTIONS(2297), 1,
      aux_sym_number_token2,
    ACTIONS(2301), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2313), 1,
      sym__brace_start,
    ACTIONS(10142), 1,
      sym_word,
    ACTIONS(10144), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10146), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10150), 1,
      anon_sym_DQUOTE,
    ACTIONS(10154), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10156), 1,
      anon_sym_BQUOTE,
    ACTIONS(10158), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10162), 1,
      sym__comment_word,
    ACTIONS(11330), 1,
      anon_sym_DOLLAR,
    ACTIONS(10148), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10160), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10152), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1304), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224018] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3478), 1,
      anon_sym_DOLLAR,
    ACTIONS(3484), 1,
      aux_sym_number_token1,
    ACTIONS(3486), 1,
      aux_sym_number_token2,
    ACTIONS(3490), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3500), 1,
      sym__brace_start,
    ACTIONS(10408), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10410), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10414), 1,
      anon_sym_DQUOTE,
    ACTIONS(10418), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10420), 1,
      anon_sym_BQUOTE,
    ACTIONS(10422), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11320), 1,
      sym__special_character,
    ACTIONS(11332), 1,
      sym_word,
    ACTIONS(11336), 1,
      sym_test_operator,
    STATE(4598), 1,
      aux_sym__literal_repeat1,
    STATE(5003), 1,
      sym_concatenation,
    ACTIONS(10424), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11334), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4325), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224089] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3594), 1,
      anon_sym_DOLLAR,
    ACTIONS(3600), 1,
      aux_sym_number_token1,
    ACTIONS(3602), 1,
      aux_sym_number_token2,
    ACTIONS(3606), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3616), 1,
      sym__brace_start,
    ACTIONS(9706), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9708), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9712), 1,
      anon_sym_DQUOTE,
    ACTIONS(9716), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9718), 1,
      anon_sym_BQUOTE,
    ACTIONS(9720), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10998), 1,
      sym_word,
    ACTIONS(11006), 1,
      sym__comment_word,
    ACTIONS(9722), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11002), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11004), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1910), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224156] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(187), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(189), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(191), 1,
      anon_sym_DOLLAR,
    ACTIONS(195), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      aux_sym_number_token1,
    ACTIONS(201), 1,
      aux_sym_number_token2,
    ACTIONS(203), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(205), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(207), 1,
      anon_sym_BQUOTE,
    ACTIONS(209), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(219), 1,
      sym__brace_start,
    ACTIONS(11212), 1,
      sym_word,
    ACTIONS(11220), 1,
      sym__comment_word,
    ACTIONS(211), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11216), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11218), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(508), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224223] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4162), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [224266] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1414), 1,
      anon_sym_DOLLAR,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1438), 1,
      sym__brace_start,
    ACTIONS(9762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9766), 1,
      sym__special_character,
    ACTIONS(9768), 1,
      anon_sym_DQUOTE,
    ACTIONS(9772), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9774), 1,
      anon_sym_BQUOTE,
    ACTIONS(9776), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11342), 1,
      sym_word,
    ACTIONS(11346), 1,
      sym_test_operator,
    STATE(1245), 1,
      aux_sym__literal_repeat1,
    STATE(1369), 1,
      sym_concatenation,
    ACTIONS(9778), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11344), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(879), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224337] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(11348), 1,
      anon_sym_DOLLAR,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224404] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1414), 1,
      anon_sym_DOLLAR,
    ACTIONS(1420), 1,
      aux_sym_number_token1,
    ACTIONS(1422), 1,
      aux_sym_number_token2,
    ACTIONS(1426), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1438), 1,
      sym__brace_start,
    ACTIONS(9762), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9764), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9766), 1,
      sym__special_character,
    ACTIONS(9768), 1,
      anon_sym_DQUOTE,
    ACTIONS(9772), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9774), 1,
      anon_sym_BQUOTE,
    ACTIONS(9776), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11350), 1,
      sym_word,
    ACTIONS(11354), 1,
      sym_test_operator,
    STATE(1258), 1,
      aux_sym__literal_repeat1,
    STATE(1408), 1,
      sym_concatenation,
    ACTIONS(9778), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11352), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(882), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224475] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224542] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8114), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8116), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8122), 1,
      anon_sym_DQUOTE,
    ACTIONS(8126), 1,
      aux_sym_number_token1,
    ACTIONS(8128), 1,
      aux_sym_number_token2,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8146), 1,
      sym__brace_start,
    ACTIONS(10094), 1,
      sym_word,
    ACTIONS(10100), 1,
      sym__comment_word,
    ACTIONS(11356), 1,
      anon_sym_DOLLAR,
    ACTIONS(8138), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10096), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10098), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1172), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224609] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(11358), 1,
      anon_sym_DOLLAR,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224676] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3344), 1,
      anon_sym_DOLLAR,
    ACTIONS(3350), 1,
      aux_sym_number_token1,
    ACTIONS(3352), 1,
      aux_sym_number_token2,
    ACTIONS(3356), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3366), 1,
      sym__brace_start,
    ACTIONS(10438), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10440), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10444), 1,
      anon_sym_DQUOTE,
    ACTIONS(10448), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10450), 1,
      anon_sym_BQUOTE,
    ACTIONS(10452), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11360), 1,
      sym_word,
    ACTIONS(11362), 1,
      sym__special_character,
    ACTIONS(11366), 1,
      sym_test_operator,
    STATE(4347), 1,
      aux_sym__literal_repeat1,
    STATE(4848), 1,
      sym_concatenation,
    ACTIONS(10454), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11364), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4300), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224747] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(11368), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224814] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3344), 1,
      anon_sym_DOLLAR,
    ACTIONS(3350), 1,
      aux_sym_number_token1,
    ACTIONS(3352), 1,
      aux_sym_number_token2,
    ACTIONS(3356), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3366), 1,
      sym__brace_start,
    ACTIONS(10438), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10440), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10444), 1,
      anon_sym_DQUOTE,
    ACTIONS(10448), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10450), 1,
      anon_sym_BQUOTE,
    ACTIONS(10452), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11362), 1,
      sym__special_character,
    ACTIONS(11370), 1,
      sym_word,
    ACTIONS(11374), 1,
      sym_test_operator,
    STATE(4350), 1,
      aux_sym__literal_repeat1,
    STATE(4915), 1,
      sym_concatenation,
    ACTIONS(10454), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11372), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4193), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224885] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1380), 1,
      aux_sym_number_token1,
    ACTIONS(1382), 1,
      aux_sym_number_token2,
    ACTIONS(1386), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1398), 1,
      sym__brace_start,
    ACTIONS(10042), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10044), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10048), 1,
      anon_sym_DQUOTE,
    ACTIONS(10052), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10054), 1,
      anon_sym_BQUOTE,
    ACTIONS(10056), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10166), 1,
      sym_word,
    ACTIONS(10172), 1,
      sym__comment_word,
    ACTIONS(11376), 1,
      anon_sym_DOLLAR,
    ACTIONS(10058), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10168), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10170), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(889), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [224952] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10568), 1,
      sym_word,
    ACTIONS(10576), 1,
      sym__comment_word,
    ACTIONS(11378), 1,
      anon_sym_DOLLAR,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10572), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10574), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1924), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225019] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(11380), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225086] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3207), 1,
      anon_sym_DOLLAR,
    ACTIONS(3213), 1,
      aux_sym_number_token1,
    ACTIONS(3215), 1,
      aux_sym_number_token2,
    ACTIONS(3219), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3229), 1,
      sym__brace_start,
    ACTIONS(9834), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9836), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9840), 1,
      anon_sym_DQUOTE,
    ACTIONS(9844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9846), 1,
      anon_sym_BQUOTE,
    ACTIONS(9848), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11152), 1,
      sym_word,
    ACTIONS(11160), 1,
      sym__comment_word,
    ACTIONS(9850), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11156), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11158), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1740), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225153] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10568), 1,
      sym_word,
    ACTIONS(10576), 1,
      sym__comment_word,
    ACTIONS(11382), 1,
      anon_sym_DOLLAR,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10572), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10574), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1924), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225220] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8114), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8116), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8122), 1,
      anon_sym_DQUOTE,
    ACTIONS(8126), 1,
      aux_sym_number_token1,
    ACTIONS(8128), 1,
      aux_sym_number_token2,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8132), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8146), 1,
      sym__brace_start,
    ACTIONS(10094), 1,
      sym_word,
    ACTIONS(10100), 1,
      sym__comment_word,
    ACTIONS(11384), 1,
      anon_sym_DOLLAR,
    ACTIONS(8138), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10096), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10098), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1172), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225287] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(11386), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225354] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(11388), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225421] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(11390), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225488] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_DOLLAR,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225555] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(11392), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225622] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10488), 1,
      sym_word,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10510), 1,
      sym__comment_word,
    ACTIONS(11394), 1,
      anon_sym_DOLLAR,
    ACTIONS(10496), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10500), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4352), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225689] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1889), 1,
      aux_sym_number_token1,
    ACTIONS(1891), 1,
      aux_sym_number_token2,
    ACTIONS(1895), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1909), 1,
      sym__brace_start,
    ACTIONS(8264), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8266), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8270), 1,
      anon_sym_DQUOTE,
    ACTIONS(8274), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8276), 1,
      anon_sym_BQUOTE,
    ACTIONS(8278), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10348), 1,
      sym_word,
    ACTIONS(10354), 1,
      sym__comment_word,
    ACTIONS(11396), 1,
      anon_sym_DOLLAR,
    ACTIONS(8280), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10350), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10352), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225756] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8637), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8639), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8641), 1,
      anon_sym_DOLLAR,
    ACTIONS(8645), 1,
      anon_sym_DQUOTE,
    ACTIONS(8649), 1,
      aux_sym_number_token1,
    ACTIONS(8651), 1,
      aux_sym_number_token2,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8655), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8665), 1,
      sym__brace_start,
    ACTIONS(11272), 1,
      sym_word,
    ACTIONS(11280), 1,
      sym__comment_word,
    ACTIONS(8661), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11276), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11278), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5127), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225823] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11398), 1,
      sym_word,
    ACTIONS(11400), 1,
      sym__special_character,
    ACTIONS(11404), 1,
      sym_test_operator,
    STATE(4353), 1,
      aux_sym__literal_repeat1,
    STATE(4901), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11402), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4535), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225894] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10316), 1,
      sym_word,
    ACTIONS(10318), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10320), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10326), 1,
      anon_sym_DQUOTE,
    ACTIONS(10330), 1,
      aux_sym_number_token1,
    ACTIONS(10332), 1,
      aux_sym_number_token2,
    ACTIONS(10334), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10336), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10338), 1,
      anon_sym_BQUOTE,
    ACTIONS(10340), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10344), 1,
      sym__comment_word,
    ACTIONS(10346), 1,
      sym__brace_start,
    ACTIONS(11406), 1,
      anon_sym_DOLLAR,
    ACTIONS(10324), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10342), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10328), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6138), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [225961] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11134), 1,
      sym_word,
    ACTIONS(11142), 1,
      sym__comment_word,
    ACTIONS(11408), 1,
      anon_sym_DOLLAR,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11138), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11140), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1783), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226028] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_DOLLAR,
    ACTIONS(3564), 1,
      aux_sym_number_token1,
    ACTIONS(3566), 1,
      aux_sym_number_token2,
    ACTIONS(3570), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3582), 1,
      sym__brace_start,
    ACTIONS(9786), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9788), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9792), 1,
      anon_sym_DQUOTE,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10132), 1,
      sym_word,
    ACTIONS(10140), 1,
      sym__comment_word,
    ACTIONS(9802), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10136), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10138), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4898), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226095] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1889), 1,
      aux_sym_number_token1,
    ACTIONS(1891), 1,
      aux_sym_number_token2,
    ACTIONS(1895), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1909), 1,
      sym__brace_start,
    ACTIONS(8264), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8266), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8270), 1,
      anon_sym_DQUOTE,
    ACTIONS(8274), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8276), 1,
      anon_sym_BQUOTE,
    ACTIONS(8278), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10348), 1,
      sym_word,
    ACTIONS(10354), 1,
      sym__comment_word,
    ACTIONS(11410), 1,
      anon_sym_DOLLAR,
    ACTIONS(8280), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10350), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10352), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1309), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226162] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11134), 1,
      sym_word,
    ACTIONS(11142), 1,
      sym__comment_word,
    ACTIONS(11412), 1,
      anon_sym_DOLLAR,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11138), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11140), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1783), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226229] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(11414), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226296] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3638), 1,
      anon_sym_DOLLAR,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10568), 1,
      sym_word,
    ACTIONS(10576), 1,
      sym__comment_word,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10572), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10574), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1924), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226363] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10568), 1,
      sym_word,
    ACTIONS(10576), 1,
      sym__comment_word,
    ACTIONS(11416), 1,
      anon_sym_DOLLAR,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10572), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10574), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1924), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226430] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3644), 1,
      aux_sym_number_token1,
    ACTIONS(3646), 1,
      aux_sym_number_token2,
    ACTIONS(3650), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3660), 1,
      sym__brace_start,
    ACTIONS(9804), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9806), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9810), 1,
      anon_sym_DQUOTE,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10568), 1,
      sym_word,
    ACTIONS(10576), 1,
      sym__comment_word,
    ACTIONS(11418), 1,
      anon_sym_DOLLAR,
    ACTIONS(9820), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10572), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10574), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1924), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226497] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(3946), 1,
      anon_sym_DOLLAR,
    ACTIONS(3952), 1,
      aux_sym_number_token1,
    ACTIONS(3954), 1,
      aux_sym_number_token2,
    ACTIONS(3958), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3968), 1,
      sym__brace_start,
    ACTIONS(10490), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10498), 1,
      anon_sym_DQUOTE,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11400), 1,
      sym__special_character,
    ACTIONS(11420), 1,
      sym_word,
    ACTIONS(11424), 1,
      sym_test_operator,
    STATE(4371), 1,
      aux_sym__literal_repeat1,
    STATE(4761), 1,
      sym_concatenation,
    ACTIONS(10508), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11422), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4646), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226568] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5319), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5321), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5327), 1,
      anon_sym_DQUOTE,
    ACTIONS(5331), 1,
      aux_sym_number_token1,
    ACTIONS(5333), 1,
      aux_sym_number_token2,
    ACTIONS(5335), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5337), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5339), 1,
      anon_sym_BQUOTE,
    ACTIONS(5341), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5347), 1,
      sym__brace_start,
    ACTIONS(11250), 1,
      sym_word,
    ACTIONS(11258), 1,
      sym__comment_word,
    ACTIONS(11426), 1,
      anon_sym_DOLLAR,
    ACTIONS(5343), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11254), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11256), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5420), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226635] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3010), 1,
      anon_sym_DOLLAR,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11134), 1,
      sym_word,
    ACTIONS(11142), 1,
      sym__comment_word,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11138), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11140), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1783), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226702] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2807), 1,
      aux_sym_number_token1,
    ACTIONS(2809), 1,
      aux_sym_number_token2,
    ACTIONS(2813), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2823), 1,
      sym__brace_start,
    ACTIONS(9930), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9932), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9936), 1,
      anon_sym_DQUOTE,
    ACTIONS(9940), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_BQUOTE,
    ACTIONS(9944), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10184), 1,
      sym_word,
    ACTIONS(10190), 1,
      sym__comment_word,
    ACTIONS(11428), 1,
      anon_sym_DOLLAR,
    ACTIONS(9946), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10186), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10188), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1467), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226769] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6390), 1,
      anon_sym_DOLLAR,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11430), 1,
      sym_word,
    ACTIONS(11436), 1,
      sym__comment_word,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11432), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11434), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6447), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226836] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3514), 1,
      aux_sym_number_token1,
    ACTIONS(3516), 1,
      aux_sym_number_token2,
    ACTIONS(3520), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3530), 1,
      sym__brace_start,
    ACTIONS(10514), 1,
      sym_word,
    ACTIONS(10516), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10518), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10524), 1,
      anon_sym_DQUOTE,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10536), 1,
      sym__comment_word,
    ACTIONS(11438), 1,
      anon_sym_DOLLAR,
    ACTIONS(10522), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10534), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10526), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4229), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226903] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11134), 1,
      sym_word,
    ACTIONS(11142), 1,
      sym__comment_word,
    ACTIONS(11440), 1,
      anon_sym_DOLLAR,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11138), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11140), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1783), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [226970] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(369), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(381), 1,
      aux_sym_number_token1,
    ACTIONS(383), 1,
      aux_sym_number_token2,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(387), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(397), 1,
      sym__brace_start,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(9676), 1,
      sym_word,
    ACTIONS(9680), 1,
      sym__comment_word,
    ACTIONS(11442), 1,
      anon_sym_DOLLAR,
    ACTIONS(393), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(9684), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(9682), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2517), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227037] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3016), 1,
      aux_sym_number_token1,
    ACTIONS(3018), 1,
      aux_sym_number_token2,
    ACTIONS(3022), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3032), 1,
      sym__brace_start,
    ACTIONS(9686), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9688), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9692), 1,
      anon_sym_DQUOTE,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11134), 1,
      sym_word,
    ACTIONS(11142), 1,
      sym__comment_word,
    ACTIONS(11444), 1,
      anon_sym_DOLLAR,
    ACTIONS(9702), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11138), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11140), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1783), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227104] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10318), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10320), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10326), 1,
      anon_sym_DQUOTE,
    ACTIONS(10330), 1,
      aux_sym_number_token1,
    ACTIONS(10332), 1,
      aux_sym_number_token2,
    ACTIONS(10334), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10336), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10338), 1,
      anon_sym_BQUOTE,
    ACTIONS(10340), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10346), 1,
      sym__brace_start,
    ACTIONS(10962), 1,
      anon_sym_DOLLAR,
    ACTIONS(10968), 1,
      sym__special_character,
    ACTIONS(11446), 1,
      sym_word,
    ACTIONS(11450), 1,
      sym_test_operator,
    STATE(6112), 1,
      aux_sym__literal_repeat1,
    STATE(6331), 1,
      sym_concatenation,
    ACTIONS(10342), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11448), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6103), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227175] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10640), 1,
      anon_sym_LPAREN,
    ACTIONS(10642), 1,
      aux_sym__c_word_token1,
    ACTIONS(10644), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10648), 1,
      anon_sym_DQUOTE,
    ACTIONS(10650), 1,
      aux_sym_number_token1,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(10654), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10658), 1,
      anon_sym_BQUOTE,
    ACTIONS(10660), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(4149), 1,
      sym__c_terminator,
    STATE(6267), 1,
      sym__c_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    STATE(7360), 1,
      sym__for_body,
    ACTIONS(10636), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(10638), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [227250] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7828), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7830), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7832), 1,
      anon_sym_DOLLAR,
    ACTIONS(7836), 1,
      anon_sym_DQUOTE,
    ACTIONS(7840), 1,
      aux_sym_number_token1,
    ACTIONS(7842), 1,
      aux_sym_number_token2,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7860), 1,
      sym__brace_start,
    ACTIONS(11452), 1,
      sym_word,
    ACTIONS(11458), 1,
      sym__comment_word,
    ACTIONS(7852), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11454), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11456), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2468), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227317] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11048), 1,
      sym_word,
    ACTIONS(11056), 1,
      sym__comment_word,
    ACTIONS(11460), 1,
      anon_sym_DOLLAR,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11052), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11054), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1154), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227384] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2295), 1,
      aux_sym_number_token1,
    ACTIONS(2297), 1,
      aux_sym_number_token2,
    ACTIONS(2301), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2313), 1,
      sym__brace_start,
    ACTIONS(10142), 1,
      sym_word,
    ACTIONS(10144), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10146), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10150), 1,
      anon_sym_DQUOTE,
    ACTIONS(10154), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10156), 1,
      anon_sym_BQUOTE,
    ACTIONS(10158), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10162), 1,
      sym__comment_word,
    ACTIONS(11462), 1,
      anon_sym_DOLLAR,
    ACTIONS(10148), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10160), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10152), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1304), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227451] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11048), 1,
      sym_word,
    ACTIONS(11056), 1,
      sym__comment_word,
    ACTIONS(11464), 1,
      anon_sym_DOLLAR,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11052), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11054), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1154), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227518] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2807), 1,
      aux_sym_number_token1,
    ACTIONS(2809), 1,
      aux_sym_number_token2,
    ACTIONS(2813), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2823), 1,
      sym__brace_start,
    ACTIONS(9930), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9932), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9936), 1,
      anon_sym_DQUOTE,
    ACTIONS(9940), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_BQUOTE,
    ACTIONS(9944), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10184), 1,
      sym_word,
    ACTIONS(10190), 1,
      sym__comment_word,
    ACTIONS(11466), 1,
      anon_sym_DOLLAR,
    ACTIONS(9946), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10186), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10188), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1467), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227585] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11430), 1,
      sym_word,
    ACTIONS(11436), 1,
      sym__comment_word,
    ACTIONS(11468), 1,
      anon_sym_DOLLAR,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11432), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11434), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6447), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227652] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7866), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7868), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7874), 1,
      anon_sym_DQUOTE,
    ACTIONS(7878), 1,
      aux_sym_number_token1,
    ACTIONS(7880), 1,
      aux_sym_number_token2,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7884), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7898), 1,
      sym__brace_start,
    ACTIONS(10846), 1,
      sym_word,
    ACTIONS(10852), 1,
      sym__comment_word,
    ACTIONS(11470), 1,
      anon_sym_DOLLAR,
    ACTIONS(7890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10848), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10850), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1527), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227719] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6396), 1,
      aux_sym_number_token1,
    ACTIONS(6398), 1,
      aux_sym_number_token2,
    ACTIONS(6402), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(6414), 1,
      sym__brace_start,
    ACTIONS(7508), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7510), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7514), 1,
      anon_sym_DQUOTE,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11430), 1,
      sym_word,
    ACTIONS(11436), 1,
      sym__comment_word,
    ACTIONS(11472), 1,
      anon_sym_DOLLAR,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11432), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11434), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6447), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227786] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5011), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5013), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    ACTIONS(5023), 1,
      aux_sym_number_token1,
    ACTIONS(5025), 1,
      aux_sym_number_token2,
    ACTIONS(5027), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5031), 1,
      anon_sym_BQUOTE,
    ACTIONS(5033), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5039), 1,
      sym__brace_start,
    ACTIONS(10356), 1,
      sym_word,
    ACTIONS(10364), 1,
      sym__comment_word,
    ACTIONS(11474), 1,
      anon_sym_DOLLAR,
    ACTIONS(5035), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10360), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10362), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2834), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227853] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4803), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4805), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_DOLLAR,
    ACTIONS(4811), 1,
      anon_sym_DQUOTE,
    ACTIONS(4815), 1,
      aux_sym_number_token1,
    ACTIONS(4817), 1,
      aux_sym_number_token2,
    ACTIONS(4819), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4821), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4823), 1,
      anon_sym_BQUOTE,
    ACTIONS(4825), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4831), 1,
      sym__brace_start,
    ACTIONS(11476), 1,
      sym_word,
    ACTIONS(11482), 1,
      sym__comment_word,
    ACTIONS(4827), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11478), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11480), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2780), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227920] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7828), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7830), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7836), 1,
      anon_sym_DQUOTE,
    ACTIONS(7840), 1,
      aux_sym_number_token1,
    ACTIONS(7842), 1,
      aux_sym_number_token2,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7860), 1,
      sym__brace_start,
    ACTIONS(11452), 1,
      sym_word,
    ACTIONS(11458), 1,
      sym__comment_word,
    ACTIONS(11484), 1,
      anon_sym_DOLLAR,
    ACTIONS(7852), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11454), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11456), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2468), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [227987] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7828), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7830), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7836), 1,
      anon_sym_DQUOTE,
    ACTIONS(7840), 1,
      aux_sym_number_token1,
    ACTIONS(7842), 1,
      aux_sym_number_token2,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7846), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7860), 1,
      sym__brace_start,
    ACTIONS(11452), 1,
      sym_word,
    ACTIONS(11458), 1,
      sym__comment_word,
    ACTIONS(11486), 1,
      anon_sym_DOLLAR,
    ACTIONS(7852), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11454), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11456), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2468), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228054] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(447), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(453), 1,
      anon_sym_DQUOTE,
    ACTIONS(457), 1,
      aux_sym_number_token1,
    ACTIONS(459), 1,
      aux_sym_number_token2,
    ACTIONS(461), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(463), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(465), 1,
      anon_sym_BQUOTE,
    ACTIONS(467), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(477), 1,
      sym__brace_start,
    ACTIONS(11488), 1,
      sym_word,
    ACTIONS(11490), 1,
      anon_sym_DOLLAR,
    ACTIONS(11496), 1,
      sym__comment_word,
    ACTIONS(469), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11492), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11494), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(853), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228121] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8068), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8070), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8076), 1,
      anon_sym_DQUOTE,
    ACTIONS(8080), 1,
      aux_sym_number_token1,
    ACTIONS(8082), 1,
      aux_sym_number_token2,
    ACTIONS(8084), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8088), 1,
      anon_sym_BQUOTE,
    ACTIONS(8090), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8100), 1,
      sym__brace_start,
    ACTIONS(10122), 1,
      sym_word,
    ACTIONS(10130), 1,
      sym__comment_word,
    ACTIONS(11498), 1,
      anon_sym_DOLLAR,
    ACTIONS(8092), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10126), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10128), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5281), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228188] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5216), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5218), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5220), 1,
      anon_sym_DOLLAR,
    ACTIONS(5224), 1,
      anon_sym_DQUOTE,
    ACTIONS(5228), 1,
      aux_sym_number_token1,
    ACTIONS(5230), 1,
      aux_sym_number_token2,
    ACTIONS(5232), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5234), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5236), 1,
      anon_sym_BQUOTE,
    ACTIONS(5238), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5244), 1,
      sym__brace_start,
    ACTIONS(11500), 1,
      sym_word,
    ACTIONS(11506), 1,
      sym__comment_word,
    ACTIONS(5240), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11502), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11504), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5328), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228255] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(310), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(316), 1,
      anon_sym_DQUOTE,
    ACTIONS(320), 1,
      aux_sym_number_token1,
    ACTIONS(322), 1,
      aux_sym_number_token2,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(326), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(340), 1,
      sym__brace_start,
    ACTIONS(10920), 1,
      sym_word,
    ACTIONS(10926), 1,
      sym__comment_word,
    ACTIONS(11508), 1,
      anon_sym_DOLLAR,
    ACTIONS(332), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10922), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10924), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(997), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228322] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(447), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(453), 1,
      anon_sym_DQUOTE,
    ACTIONS(457), 1,
      aux_sym_number_token1,
    ACTIONS(459), 1,
      aux_sym_number_token2,
    ACTIONS(461), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(463), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(465), 1,
      anon_sym_BQUOTE,
    ACTIONS(467), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(477), 1,
      sym__brace_start,
    ACTIONS(11488), 1,
      sym_word,
    ACTIONS(11496), 1,
      sym__comment_word,
    ACTIONS(11510), 1,
      anon_sym_DOLLAR,
    ACTIONS(469), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11492), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11494), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(853), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228389] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1478), 1,
      sym__brace_start,
    ACTIONS(9648), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9650), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9654), 1,
      anon_sym_DQUOTE,
    ACTIONS(9658), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9660), 1,
      anon_sym_BQUOTE,
    ACTIONS(9662), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10936), 1,
      sym_word,
    ACTIONS(10942), 1,
      sym__comment_word,
    ACTIONS(11512), 1,
      anon_sym_DOLLAR,
    ACTIONS(9664), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10938), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10940), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1249), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228456] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4803), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4805), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4811), 1,
      anon_sym_DQUOTE,
    ACTIONS(4815), 1,
      aux_sym_number_token1,
    ACTIONS(4817), 1,
      aux_sym_number_token2,
    ACTIONS(4819), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4821), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4823), 1,
      anon_sym_BQUOTE,
    ACTIONS(4825), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4831), 1,
      sym__brace_start,
    ACTIONS(11476), 1,
      sym_word,
    ACTIONS(11482), 1,
      sym__comment_word,
    ACTIONS(11514), 1,
      anon_sym_DOLLAR,
    ACTIONS(4827), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11478), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11480), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2780), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228523] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4803), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4805), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4811), 1,
      anon_sym_DQUOTE,
    ACTIONS(4815), 1,
      aux_sym_number_token1,
    ACTIONS(4817), 1,
      aux_sym_number_token2,
    ACTIONS(4819), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4821), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4823), 1,
      anon_sym_BQUOTE,
    ACTIONS(4825), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4831), 1,
      sym__brace_start,
    ACTIONS(11476), 1,
      sym_word,
    ACTIONS(11482), 1,
      sym__comment_word,
    ACTIONS(11516), 1,
      anon_sym_DOLLAR,
    ACTIONS(4827), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11478), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11480), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2780), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228590] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8306), 1,
      sym__special_character,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11518), 1,
      sym_word,
    ACTIONS(11522), 1,
      sym_test_operator,
    STATE(1834), 1,
      aux_sym__literal_repeat1,
    STATE(2055), 1,
      sym_concatenation,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11520), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1669), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228661] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4323), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4325), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4327), 1,
      anon_sym_DOLLAR,
    ACTIONS(4331), 1,
      anon_sym_DQUOTE,
    ACTIONS(4335), 1,
      aux_sym_number_token1,
    ACTIONS(4337), 1,
      aux_sym_number_token2,
    ACTIONS(4339), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4341), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4343), 1,
      anon_sym_BQUOTE,
    ACTIONS(4345), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4351), 1,
      sym__brace_start,
    ACTIONS(11524), 1,
      sym_word,
    ACTIONS(11530), 1,
      sym__comment_word,
    ACTIONS(4347), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11526), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11528), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2521), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228728] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8306), 1,
      sym__special_character,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(11532), 1,
      sym_word,
    ACTIONS(11536), 1,
      sym_test_operator,
    STATE(1905), 1,
      aux_sym__literal_repeat1,
    STATE(2210), 1,
      sym_concatenation,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11534), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1676), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228799] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4835), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4839), 1,
      anon_sym_DOLLAR,
    ACTIONS(4843), 1,
      anon_sym_DQUOTE,
    ACTIONS(4847), 1,
      aux_sym_number_token1,
    ACTIONS(4849), 1,
      aux_sym_number_token2,
    ACTIONS(4851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4853), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4855), 1,
      anon_sym_BQUOTE,
    ACTIONS(4857), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4863), 1,
      sym__brace_start,
    ACTIONS(11538), 1,
      sym_word,
    ACTIONS(11544), 1,
      sym__comment_word,
    ACTIONS(4859), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11540), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11542), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5179), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228866] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9978), 1,
      sym__special_character,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11546), 1,
      sym_word,
    ACTIONS(11550), 1,
      sym_test_operator,
    STATE(1463), 1,
      aux_sym__literal_repeat1,
    STATE(1628), 1,
      sym_concatenation,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11548), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1280), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [228937] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9978), 1,
      sym__special_character,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11552), 1,
      sym_word,
    ACTIONS(11556), 1,
      sym_test_operator,
    STATE(1387), 1,
      aux_sym__literal_repeat1,
    STATE(1635), 1,
      sym_concatenation,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11554), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1282), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229008] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7940), 1,
      anon_sym_DOLLAR,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229075] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3129), 1,
      aux_sym_number_token1,
    ACTIONS(3131), 1,
      aux_sym_number_token2,
    ACTIONS(3135), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3145), 1,
      sym__brace_start,
    ACTIONS(10202), 1,
      sym_word,
    ACTIONS(10204), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10206), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10210), 1,
      anon_sym_DQUOTE,
    ACTIONS(10214), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10216), 1,
      anon_sym_BQUOTE,
    ACTIONS(10218), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10222), 1,
      sym__comment_word,
    ACTIONS(11558), 1,
      anon_sym_DOLLAR,
    ACTIONS(10208), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10220), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10212), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4466), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229142] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10318), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10320), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10326), 1,
      anon_sym_DQUOTE,
    ACTIONS(10330), 1,
      aux_sym_number_token1,
    ACTIONS(10332), 1,
      aux_sym_number_token2,
    ACTIONS(10334), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10336), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10338), 1,
      anon_sym_BQUOTE,
    ACTIONS(10340), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10346), 1,
      sym__brace_start,
    ACTIONS(10962), 1,
      anon_sym_DOLLAR,
    ACTIONS(10968), 1,
      sym__special_character,
    ACTIONS(11560), 1,
      sym_word,
    ACTIONS(11564), 1,
      sym_test_operator,
    STATE(6117), 1,
      aux_sym__literal_repeat1,
    STATE(6359), 1,
      sym_concatenation,
    ACTIONS(10342), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11562), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6093), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229213] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10640), 1,
      anon_sym_LPAREN,
    ACTIONS(10642), 1,
      aux_sym__c_word_token1,
    ACTIONS(10644), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10648), 1,
      anon_sym_DQUOTE,
    ACTIONS(10650), 1,
      aux_sym_number_token1,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(10654), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10658), 1,
      anon_sym_BQUOTE,
    ACTIONS(10660), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(4149), 1,
      sym__c_terminator,
    STATE(6267), 1,
      sym__c_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    STATE(7009), 1,
      sym__for_body,
    ACTIONS(10636), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(10638), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [229288] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5216), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5218), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5224), 1,
      anon_sym_DQUOTE,
    ACTIONS(5228), 1,
      aux_sym_number_token1,
    ACTIONS(5230), 1,
      aux_sym_number_token2,
    ACTIONS(5232), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5234), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5236), 1,
      anon_sym_BQUOTE,
    ACTIONS(5238), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5244), 1,
      sym__brace_start,
    ACTIONS(11500), 1,
      sym_word,
    ACTIONS(11506), 1,
      sym__comment_word,
    ACTIONS(11566), 1,
      anon_sym_DOLLAR,
    ACTIONS(5240), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11502), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11504), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5328), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229355] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5216), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5218), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5224), 1,
      anon_sym_DQUOTE,
    ACTIONS(5228), 1,
      aux_sym_number_token1,
    ACTIONS(5230), 1,
      aux_sym_number_token2,
    ACTIONS(5232), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5234), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5236), 1,
      anon_sym_BQUOTE,
    ACTIONS(5238), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5244), 1,
      sym__brace_start,
    ACTIONS(11500), 1,
      sym_word,
    ACTIONS(11506), 1,
      sym__comment_word,
    ACTIONS(11568), 1,
      anon_sym_DOLLAR,
    ACTIONS(5240), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11502), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11504), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5328), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229422] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3129), 1,
      aux_sym_number_token1,
    ACTIONS(3131), 1,
      aux_sym_number_token2,
    ACTIONS(3135), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(3145), 1,
      sym__brace_start,
    ACTIONS(10202), 1,
      sym_word,
    ACTIONS(10204), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10206), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10210), 1,
      anon_sym_DQUOTE,
    ACTIONS(10214), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10216), 1,
      anon_sym_BQUOTE,
    ACTIONS(10218), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10222), 1,
      sym__comment_word,
    ACTIONS(11570), 1,
      anon_sym_DOLLAR,
    ACTIONS(10208), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10220), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10212), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4466), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229489] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8068), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8070), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8072), 1,
      anon_sym_DOLLAR,
    ACTIONS(8076), 1,
      anon_sym_DQUOTE,
    ACTIONS(8080), 1,
      aux_sym_number_token1,
    ACTIONS(8082), 1,
      aux_sym_number_token2,
    ACTIONS(8084), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8088), 1,
      anon_sym_BQUOTE,
    ACTIONS(8090), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8100), 1,
      sym__brace_start,
    ACTIONS(10122), 1,
      sym_word,
    ACTIONS(10130), 1,
      sym__comment_word,
    ACTIONS(8092), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10126), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10128), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5281), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229556] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4323), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4325), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4331), 1,
      anon_sym_DQUOTE,
    ACTIONS(4335), 1,
      aux_sym_number_token1,
    ACTIONS(4337), 1,
      aux_sym_number_token2,
    ACTIONS(4339), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4341), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4343), 1,
      anon_sym_BQUOTE,
    ACTIONS(4345), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4351), 1,
      sym__brace_start,
    ACTIONS(11524), 1,
      sym_word,
    ACTIONS(11530), 1,
      sym__comment_word,
    ACTIONS(11572), 1,
      anon_sym_DOLLAR,
    ACTIONS(4347), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11526), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11528), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2521), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229623] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8344), 1,
      sym__special_character,
    ACTIONS(11574), 1,
      sym_word,
    ACTIONS(11578), 1,
      sym_test_operator,
    STATE(1834), 1,
      aux_sym__literal_repeat1,
    STATE(2055), 1,
      sym_concatenation,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11576), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1374), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229694] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4323), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4325), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4331), 1,
      anon_sym_DQUOTE,
    ACTIONS(4335), 1,
      aux_sym_number_token1,
    ACTIONS(4337), 1,
      aux_sym_number_token2,
    ACTIONS(4339), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4341), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4343), 1,
      anon_sym_BQUOTE,
    ACTIONS(4345), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4351), 1,
      sym__brace_start,
    ACTIONS(11524), 1,
      sym_word,
    ACTIONS(11530), 1,
      sym__comment_word,
    ACTIONS(11580), 1,
      anon_sym_DOLLAR,
    ACTIONS(4347), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11526), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11528), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2521), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229761] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5091), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5093), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5099), 1,
      anon_sym_DQUOTE,
    ACTIONS(5103), 1,
      aux_sym_number_token1,
    ACTIONS(5105), 1,
      aux_sym_number_token2,
    ACTIONS(5107), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5109), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5111), 1,
      anon_sym_BQUOTE,
    ACTIONS(5113), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5119), 1,
      sym__brace_start,
    ACTIONS(10086), 1,
      sym_word,
    ACTIONS(10092), 1,
      sym__comment_word,
    ACTIONS(11582), 1,
      anon_sym_DOLLAR,
    ACTIONS(5115), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10088), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10090), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5342), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229828] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(11584), 1,
      anon_sym_DOLLAR,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229895] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(11586), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [229962] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5625), 1,
      anon_sym_DOLLAR,
    ACTIONS(5631), 1,
      aux_sym_number_token1,
    ACTIONS(5633), 1,
      aux_sym_number_token2,
    ACTIONS(5637), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5647), 1,
      sym__brace_start,
    ACTIONS(9874), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9876), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9880), 1,
      anon_sym_DQUOTE,
    ACTIONS(9884), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9886), 1,
      anon_sym_BQUOTE,
    ACTIONS(9888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10470), 1,
      sym_word,
    ACTIONS(10478), 1,
      sym__comment_word,
    ACTIONS(9890), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10474), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10476), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(3342), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230029] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8344), 1,
      sym__special_character,
    ACTIONS(11588), 1,
      sym_word,
    ACTIONS(11592), 1,
      sym_test_operator,
    STATE(1905), 1,
      aux_sym__literal_repeat1,
    STATE(2210), 1,
      sym_concatenation,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11590), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1456), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230100] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4835), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4843), 1,
      anon_sym_DQUOTE,
    ACTIONS(4847), 1,
      aux_sym_number_token1,
    ACTIONS(4849), 1,
      aux_sym_number_token2,
    ACTIONS(4851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4853), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4855), 1,
      anon_sym_BQUOTE,
    ACTIONS(4857), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4863), 1,
      sym__brace_start,
    ACTIONS(11538), 1,
      sym_word,
    ACTIONS(11544), 1,
      sym__comment_word,
    ACTIONS(11594), 1,
      anon_sym_DOLLAR,
    ACTIONS(4859), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11540), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11542), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5179), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230167] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4835), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4843), 1,
      anon_sym_DQUOTE,
    ACTIONS(4847), 1,
      aux_sym_number_token1,
    ACTIONS(4849), 1,
      aux_sym_number_token2,
    ACTIONS(4851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4853), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4855), 1,
      anon_sym_BQUOTE,
    ACTIONS(4857), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4863), 1,
      sym__brace_start,
    ACTIONS(11538), 1,
      sym_word,
    ACTIONS(11544), 1,
      sym__comment_word,
    ACTIONS(11596), 1,
      anon_sym_DOLLAR,
    ACTIONS(4859), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11540), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11542), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5179), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230234] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1460), 1,
      aux_sym_number_token1,
    ACTIONS(1462), 1,
      aux_sym_number_token2,
    ACTIONS(1466), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1478), 1,
      sym__brace_start,
    ACTIONS(9648), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9650), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9654), 1,
      anon_sym_DQUOTE,
    ACTIONS(9658), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9660), 1,
      anon_sym_BQUOTE,
    ACTIONS(9662), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10936), 1,
      sym_word,
    ACTIONS(10942), 1,
      sym__comment_word,
    ACTIONS(11598), 1,
      anon_sym_DOLLAR,
    ACTIONS(9664), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10938), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10940), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1249), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230301] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5767), 1,
      anon_sym_DOLLAR,
    ACTIONS(5773), 1,
      aux_sym_number_token1,
    ACTIONS(5775), 1,
      aux_sym_number_token2,
    ACTIONS(5779), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5789), 1,
      sym__brace_start,
    ACTIONS(10600), 1,
      sym_word,
    ACTIONS(10602), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10604), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10610), 1,
      anon_sym_DQUOTE,
    ACTIONS(10614), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10616), 1,
      anon_sym_BQUOTE,
    ACTIONS(10618), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10622), 1,
      sym__comment_word,
    ACTIONS(10608), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10620), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10612), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5559), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230368] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2546), 1,
      aux_sym_number_token1,
    ACTIONS(2548), 1,
      aux_sym_number_token2,
    ACTIONS(2552), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2564), 1,
      sym__brace_start,
    ACTIONS(10366), 1,
      sym_word,
    ACTIONS(10368), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10370), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10374), 1,
      anon_sym_DQUOTE,
    ACTIONS(10378), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10380), 1,
      anon_sym_BQUOTE,
    ACTIONS(10382), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10386), 1,
      sym__comment_word,
    ACTIONS(11600), 1,
      anon_sym_DOLLAR,
    ACTIONS(10372), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10384), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10376), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1498), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230435] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(447), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(449), 1,
      anon_sym_DOLLAR,
    ACTIONS(453), 1,
      anon_sym_DQUOTE,
    ACTIONS(457), 1,
      aux_sym_number_token1,
    ACTIONS(459), 1,
      aux_sym_number_token2,
    ACTIONS(461), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(463), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(465), 1,
      anon_sym_BQUOTE,
    ACTIONS(467), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(477), 1,
      sym__brace_start,
    ACTIONS(11488), 1,
      sym_word,
    ACTIONS(11496), 1,
      sym__comment_word,
    ACTIONS(469), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11492), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11494), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(853), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230502] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(11602), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230569] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8352), 1,
      sym__special_character,
    ACTIONS(11604), 1,
      sym_word,
    ACTIONS(11608), 1,
      sym_test_operator,
    STATE(1834), 1,
      aux_sym__literal_repeat1,
    STATE(2055), 1,
      sym_concatenation,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11606), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2292), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230640] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5011), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5013), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5015), 1,
      anon_sym_DOLLAR,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    ACTIONS(5023), 1,
      aux_sym_number_token1,
    ACTIONS(5025), 1,
      aux_sym_number_token2,
    ACTIONS(5027), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5031), 1,
      anon_sym_BQUOTE,
    ACTIONS(5033), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5039), 1,
      sym__brace_start,
    ACTIONS(10356), 1,
      sym_word,
    ACTIONS(10364), 1,
      sym__comment_word,
    ACTIONS(5035), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10360), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10362), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2834), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230707] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8300), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(8302), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(8304), 1,
      anon_sym_DOLLAR,
    ACTIONS(8308), 1,
      anon_sym_DQUOTE,
    ACTIONS(8312), 1,
      aux_sym_number_token1,
    ACTIONS(8314), 1,
      aux_sym_number_token2,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8318), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(8332), 1,
      sym__brace_start,
    ACTIONS(8352), 1,
      sym__special_character,
    ACTIONS(11610), 1,
      sym_word,
    ACTIONS(11614), 1,
      sym_test_operator,
    STATE(1905), 1,
      aux_sym__literal_repeat1,
    STATE(2210), 1,
      sym_concatenation,
    ACTIONS(8324), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11612), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2295), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230778] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2546), 1,
      aux_sym_number_token1,
    ACTIONS(2548), 1,
      aux_sym_number_token2,
    ACTIONS(2552), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(2564), 1,
      sym__brace_start,
    ACTIONS(10366), 1,
      sym_word,
    ACTIONS(10368), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10370), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10374), 1,
      anon_sym_DQUOTE,
    ACTIONS(10378), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10380), 1,
      anon_sym_BQUOTE,
    ACTIONS(10382), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10386), 1,
      sym__comment_word,
    ACTIONS(11616), 1,
      anon_sym_DOLLAR,
    ACTIONS(10372), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10384), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10376), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1498), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230845] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5319), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5321), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5323), 1,
      anon_sym_DOLLAR,
    ACTIONS(5327), 1,
      anon_sym_DQUOTE,
    ACTIONS(5331), 1,
      aux_sym_number_token1,
    ACTIONS(5333), 1,
      aux_sym_number_token2,
    ACTIONS(5335), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5337), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5339), 1,
      anon_sym_BQUOTE,
    ACTIONS(5341), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5347), 1,
      sym__brace_start,
    ACTIONS(11250), 1,
      sym_word,
    ACTIONS(11258), 1,
      sym__comment_word,
    ACTIONS(5343), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11254), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(11256), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5420), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230912] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10034), 1,
      sym__special_character,
    ACTIONS(11618), 1,
      sym_word,
    ACTIONS(11622), 1,
      sym_test_operator,
    STATE(1463), 1,
      aux_sym__literal_repeat1,
    STATE(1628), 1,
      sym_concatenation,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11620), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1899), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [230983] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_DOLLAR,
    ACTIONS(1557), 1,
      aux_sym_number_token1,
    ACTIONS(1559), 1,
      aux_sym_number_token2,
    ACTIONS(1563), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(1575), 1,
      sym__brace_start,
    ACTIONS(9974), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(9980), 1,
      anon_sym_DQUOTE,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10034), 1,
      sym__special_character,
    ACTIONS(11624), 1,
      sym_word,
    ACTIONS(11628), 1,
      sym_test_operator,
    STATE(1387), 1,
      aux_sym__literal_repeat1,
    STATE(1635), 1,
      sym_concatenation,
    ACTIONS(9990), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11626), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(1901), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [231054] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10318), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(10320), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(10326), 1,
      anon_sym_DQUOTE,
    ACTIONS(10330), 1,
      aux_sym_number_token1,
    ACTIONS(10332), 1,
      aux_sym_number_token2,
    ACTIONS(10334), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10336), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10338), 1,
      anon_sym_BQUOTE,
    ACTIONS(10340), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(10346), 1,
      sym__brace_start,
    ACTIONS(10962), 1,
      anon_sym_DOLLAR,
    ACTIONS(10968), 1,
      sym__special_character,
    ACTIONS(11630), 1,
      sym_word,
    ACTIONS(11634), 1,
      sym_test_operator,
    STATE(6133), 1,
      aux_sym__literal_repeat1,
    STATE(6373), 1,
      sym_concatenation,
    ACTIONS(10342), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11632), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(6106), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [231125] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10640), 1,
      anon_sym_LPAREN,
    ACTIONS(10642), 1,
      aux_sym__c_word_token1,
    ACTIONS(10644), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10648), 1,
      anon_sym_DQUOTE,
    ACTIONS(10650), 1,
      aux_sym_number_token1,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(10654), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10658), 1,
      anon_sym_BQUOTE,
    ACTIONS(10660), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(4149), 1,
      sym__c_terminator,
    STATE(6267), 1,
      sym__c_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    STATE(6861), 1,
      sym__for_body,
    ACTIONS(10636), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(10638), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [231200] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7936), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(7944), 1,
      anon_sym_DQUOTE,
    ACTIONS(7948), 1,
      aux_sym_number_token1,
    ACTIONS(7950), 1,
      aux_sym_number_token2,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7954), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7968), 1,
      sym__brace_start,
    ACTIONS(10076), 1,
      sym_word,
    ACTIONS(10084), 1,
      sym__comment_word,
    ACTIONS(11636), 1,
      anon_sym_DOLLAR,
    ACTIONS(7960), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10080), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10082), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(4271), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [231267] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4538), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4540), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4542), 1,
      anon_sym_DOLLAR,
    ACTIONS(4546), 1,
      anon_sym_DQUOTE,
    ACTIONS(4550), 1,
      aux_sym_number_token1,
    ACTIONS(4552), 1,
      aux_sym_number_token2,
    ACTIONS(4554), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4556), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4560), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4566), 1,
      sym__brace_start,
    ACTIONS(10388), 1,
      sym_word,
    ACTIONS(10396), 1,
      sym__comment_word,
    ACTIONS(4562), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10392), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10394), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2580), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [231334] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      aux_sym_number_token1,
    ACTIONS(264), 1,
      aux_sym_number_token2,
    ACTIONS(268), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(282), 1,
      sym__brace_start,
    ACTIONS(1109), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(1117), 1,
      anon_sym_DQUOTE,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(10480), 1,
      sym_word,
    ACTIONS(10486), 1,
      sym__comment_word,
    ACTIONS(11638), 1,
      anon_sym_DOLLAR,
    ACTIONS(1125), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10482), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10484), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2224), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [231401] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4064), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(4066), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(4072), 1,
      anon_sym_DQUOTE,
    ACTIONS(4076), 1,
      aux_sym_number_token1,
    ACTIONS(4078), 1,
      aux_sym_number_token2,
    ACTIONS(4080), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4082), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(4084), 1,
      anon_sym_BQUOTE,
    ACTIONS(4086), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(4096), 1,
      sym__brace_start,
    ACTIONS(10174), 1,
      sym_word,
    ACTIONS(10182), 1,
      sym__comment_word,
    ACTIONS(11640), 1,
      anon_sym_DOLLAR,
    ACTIONS(4088), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(10178), 2,
      sym_test_operator,
      sym__special_character,
    ACTIONS(10180), 3,
      sym__bare_dollar,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(2446), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [231468] = 20,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5091), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(5093), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(5095), 1,
      anon_sym_DOLLAR,
    ACTIONS(5097), 1,
      sym__special_character,
    ACTIONS(5099), 1,
      anon_sym_DQUOTE,
    ACTIONS(5103), 1,
      aux_sym_number_token1,
    ACTIONS(5105), 1,
      aux_sym_number_token2,
    ACTIONS(5107), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5109), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(5111), 1,
      anon_sym_BQUOTE,
    ACTIONS(5113), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5119), 1,
      sym__brace_start,
    ACTIONS(11642), 1,
      sym_word,
    ACTIONS(11646), 1,
      sym_test_operator,
    STATE(5299), 1,
      aux_sym__literal_repeat1,
    STATE(5521), 1,
      sym_concatenation,
    ACTIONS(5115), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(11644), 2,
      sym_raw_string,
      sym_ansi_c_string,
    STATE(5197), 9,
      sym_arithmetic_expansion,
      sym_brace_expression,
      sym_string,
      sym_translated_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [231539] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4142), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [231581] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4239), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [231623] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4162), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [231665] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11266), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11652), 1,
      sym__concat,
    STATE(4143), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [231707] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11266), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11654), 1,
      sym__concat,
    STATE(4143), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [231749] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4142), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [231791] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11660), 1,
      sym_variable_name,
    STATE(6669), 1,
      sym_subscript,
    ACTIONS(11658), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4139), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11656), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [231833] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4296), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11667), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11669), 1,
      sym_file_descriptor,
    STATE(4950), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4290), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(4292), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(2503), 3,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [231889] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11679), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11681), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11684), 1,
      sym_file_descriptor,
    ACTIONS(11676), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4141), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11673), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11671), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [231935] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11687), 1,
      sym__concat,
    STATE(4166), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [231977] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11689), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11692), 1,
      sym__concat,
    STATE(4143), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [232019] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11695), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11697), 1,
      sym__concat,
    STATE(4212), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [232061] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11699), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11702), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [232103] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11667), 1,
      anon_sym_LT_LT_LT,
    STATE(4950), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [232147] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4162), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [232189] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11266), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11268), 1,
      sym__concat,
    STATE(4137), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [232231] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10640), 1,
      anon_sym_LPAREN,
    ACTIONS(10642), 1,
      aux_sym__c_word_token1,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10648), 1,
      anon_sym_DQUOTE,
    ACTIONS(10650), 1,
      aux_sym_number_token1,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(10654), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10658), 1,
      anon_sym_BQUOTE,
    ACTIONS(10660), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11707), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(4600), 1,
      sym__c_terminator,
    STATE(6242), 1,
      sym__c_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    ACTIONS(10638), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(11705), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [232303] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4515), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11667), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11669), 1,
      sym_file_descriptor,
    STATE(4950), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4292), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4513), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4255), 3,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [232359] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10640), 1,
      anon_sym_LPAREN,
    ACTIONS(10642), 1,
      aux_sym__c_word_token1,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10648), 1,
      anon_sym_DQUOTE,
    ACTIONS(10650), 1,
      aux_sym_number_token1,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(10654), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10658), 1,
      anon_sym_BQUOTE,
    ACTIONS(10660), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11711), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(4508), 1,
      sym__c_terminator,
    STATE(6240), 1,
      sym__c_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    ACTIONS(10638), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(11709), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [232431] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11719), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11721), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11723), 1,
      sym_file_descriptor,
    ACTIONS(11717), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4141), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11715), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11713), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [232477] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11667), 1,
      anon_sym_LT_LT_LT,
    STATE(4950), 1,
      sym_herestring_redirect,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [232519] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10640), 1,
      anon_sym_LPAREN,
    ACTIONS(10642), 1,
      aux_sym__c_word_token1,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10648), 1,
      anon_sym_DQUOTE,
    ACTIONS(10650), 1,
      aux_sym_number_token1,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(10654), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(10658), 1,
      anon_sym_BQUOTE,
    ACTIONS(10660), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(11727), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(4673), 1,
      sym__c_terminator,
    STATE(6188), 1,
      sym__c_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    ACTIONS(10638), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(11725), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [232591] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [232633] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11733), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11736), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [232675] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4162), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [232717] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4142), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [232759] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11743), 1,
      sym_variable_name,
    STATE(6669), 1,
      sym_subscript,
    ACTIONS(11741), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4139), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11739), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [232801] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_file_descriptor,
    ACTIONS(5771), 1,
      anon_sym_DQUOTE,
    ACTIONS(11749), 1,
      sym_variable_name,
    STATE(5555), 1,
      sym_string,
    ACTIONS(11747), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(11745), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1195), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [232847] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4162), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [232889] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11751), 1,
      sym__concat,
    STATE(4166), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [232931] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11266), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11268), 1,
      sym__concat,
    STATE(4136), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [232973] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      sym_file_descriptor,
    ACTIONS(5771), 1,
      anon_sym_DQUOTE,
    ACTIONS(11749), 1,
      sym_variable_name,
    STATE(5555), 1,
      sym_string,
    ACTIONS(11747), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(11745), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
    ACTIONS(1183), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      aux_sym_heredoc_redirect_token1,
      anon_sym_LT_LT_LT,
  [233019] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11338), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11340), 1,
      sym__concat,
    STATE(4142), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [233061] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11753), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11756), 1,
      sym__concat,
    STATE(4166), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [233103] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [233138] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [233179] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
      anon_sym_BQUOTE,
  [233220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [233255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [233290] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11763), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [233331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [233366] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11765), 1,
      sym_variable_name,
    STATE(6702), 1,
      sym_subscript,
    ACTIONS(11741), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4205), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11739), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [233407] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11767), 1,
      sym__special_character,
    STATE(4253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [233446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [233481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [233516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [233551] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11769), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11772), 1,
      sym__concat,
    STATE(4179), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [233592] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4175), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11775), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4169), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(4171), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(2503), 4,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [233643] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11777), 1,
      sym__special_character,
    STATE(4181), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [233682] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11775), 1,
      sym_file_descriptor,
    ACTIONS(11782), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4269), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11780), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
  [233727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [233762] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11784), 1,
      sym__concat,
    ACTIONS(6653), 5,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
    ACTIONS(6651), 21,
      sym__immediate_double_hash,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_POUND,
      anon_sym_RBRACE3,
      anon_sym_AT,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
      anon_sym_PERCENT_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
  [233799] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4431), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [233840] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10102), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11794), 1,
      sym_file_descriptor,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4908), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11790), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [233885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [233920] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [233955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [233990] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [234025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [234060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [234095] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4262), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [234136] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11796), 1,
      sym__concat,
    STATE(4179), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [234177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [234212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [234247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [234282] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11767), 1,
      sym__special_character,
    STATE(4253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [234321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [234356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [234391] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [234426] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_RPAREN,
    ACTIONS(4296), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11763), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11802), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4797), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4290), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [234481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [234516] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11804), 1,
      sym__concat,
    STATE(4179), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [234557] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11806), 1,
      sym_variable_name,
    STATE(6702), 1,
      sym_subscript,
    ACTIONS(11658), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4205), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11656), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [234598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [234633] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [234668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [234703] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [234738] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4239), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [234779] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11809), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [234820] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11695), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11811), 1,
      sym__concat,
    STATE(4244), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [234861] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11813), 1,
      sym__special_character,
    STATE(4318), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [234900] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11815), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11818), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [234941] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11821), 1,
      sym__concat,
    ACTIONS(6641), 5,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
    ACTIONS(6639), 21,
      sym__immediate_double_hash,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_POUND,
      anon_sym_RBRACE3,
      anon_sym_AT,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
      anon_sym_PERCENT_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
  [234978] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [235013] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11719), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11827), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11829), 1,
      sym_file_descriptor,
    ACTIONS(11825), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4246), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11823), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11713), 11,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [235058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [235093] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [235128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [235163] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [235204] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11695), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11831), 1,
      sym__concat,
    STATE(4244), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [235245] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11833), 1,
      sym__special_character,
    STATE(4294), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [235284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [235319] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4523), 1,
      ts_builtin_sym_end,
    ACTIONS(4531), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11839), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11841), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4527), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4525), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [235374] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [235409] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [235444] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [235479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [235514] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4326), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [235555] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [235590] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [235625] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [235662] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4262), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [235703] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [235744] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11813), 1,
      sym__special_character,
    STATE(4318), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [235783] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11695), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11697), 1,
      sym__concat,
    STATE(4222), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [235824] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [235863] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11847), 1,
      sym__concat,
    STATE(4292), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [235904] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [235939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [235974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [236009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [236044] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11849), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11852), 1,
      sym__concat,
    STATE(4244), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [236085] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11767), 1,
      sym__special_character,
    STATE(4253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [236124] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11679), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11861), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11864), 1,
      sym_file_descriptor,
    ACTIONS(11858), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4246), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11855), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11671), 11,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [236169] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4239), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [236210] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [236245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [236280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [236315] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4239), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [236356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [236391] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11867), 1,
      sym__special_character,
    STATE(4253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [236430] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4262), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [236471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [236506] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [236547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [236582] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [236623] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [236658] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11813), 1,
      sym__special_character,
    STATE(4318), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [236697] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [236732] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11870), 1,
      sym__concat,
    STATE(4292), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [236773] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [236808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [236843] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11813), 1,
      sym__special_character,
    STATE(4318), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [236882] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [236917] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [236952] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4204), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [236993] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11883), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11885), 1,
      sym_file_descriptor,
    ACTIONS(11877), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11880), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4269), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11874), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11872), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
  [237038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [237073] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [237108] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11763), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 18,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [237151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [237186] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11888), 1,
      sym__concat,
    ACTIONS(6675), 5,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
    ACTIONS(6673), 21,
      sym__immediate_double_hash,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_POUND,
      anon_sym_RBRACE3,
      anon_sym_AT,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
      anon_sym_PERCENT_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
  [237223] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11890), 1,
      sym__concat,
    ACTIONS(6705), 5,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
    ACTIONS(6703), 21,
      sym__immediate_double_hash,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_POUND,
      anon_sym_RBRACE3,
      anon_sym_AT,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
      anon_sym_PERCENT_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
  [237260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [237295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [237330] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [237365] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4255), 1,
      anon_sym_RPAREN,
    ACTIONS(4515), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11763), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11802), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4797), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4513), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [237420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [237455] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11695), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11697), 1,
      sym__concat,
    STATE(4212), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [237496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [237531] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [237566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [237601] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11839), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4268), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [237642] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10102), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11794), 1,
      sym_file_descriptor,
    ACTIONS(11894), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4773), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11892), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [237687] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4255), 1,
      anon_sym_BQUOTE,
    ACTIONS(5212), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11809), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11900), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4993), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5210), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [237742] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10102), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11794), 1,
      sym_file_descriptor,
    ACTIONS(11904), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4785), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11902), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [237787] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4477), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [237828] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4322), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
      anon_sym_BQUOTE,
  [237869] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11767), 1,
      sym__special_character,
    STATE(4253), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [237908] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11906), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11909), 1,
      sym__concat,
    STATE(4292), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [237949] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4257), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11775), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4171), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4253), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4255), 4,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [238000] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11912), 1,
      sym__special_character,
    STATE(4294), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [238039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [238074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [238109] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4239), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [238150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [238185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [238220] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11648), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11650), 1,
      sym__concat,
    STATE(4262), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [238261] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [238296] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4370), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [238337] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4344), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [238378] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [238413] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11809), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 18,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [238456] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [238491] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_BQUOTE,
    ACTIONS(4995), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11809), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11900), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4993), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4991), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [238546] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [238581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [238616] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2505), 1,
      ts_builtin_sym_end,
    ACTIONS(4792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11839), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11841), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4527), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4790), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [238671] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [238712] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [238747] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11839), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 17,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [238790] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [238825] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11729), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11731), 1,
      sym__concat,
    STATE(4194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [238866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 5,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [238901] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11915), 1,
      sym__special_character,
    STATE(4181), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [238940] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11917), 1,
      sym__special_character,
    STATE(4318), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [238979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [239014] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [239049] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11719), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11924), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11926), 1,
      sym_file_descriptor,
    ACTIONS(11922), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4504), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11920), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11713), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [239093] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11928), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [239133] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11930), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [239173] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4326), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [239213] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4331), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [239253] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11932), 1,
      sym__concat,
    STATE(4354), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [239293] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [239327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [239361] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4370), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [239401] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11667), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11934), 1,
      sym_file_descriptor,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4987), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11790), 11,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [239445] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11936), 1,
      sym__concat,
    STATE(4354), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [239485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [239519] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11942), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11944), 1,
      sym_file_descriptor,
    ACTIONS(11719), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11940), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4365), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11938), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11713), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [239563] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11946), 1,
      sym_variable_name,
    STATE(6675), 1,
      sym_subscript,
    STATE(4334), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11658), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11656), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [239603] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5208), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11955), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5206), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [239655] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11957), 1,
      sym__special_character,
    STATE(4420), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [239693] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11955), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5285), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [239745] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [239779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [239813] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4326), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [239853] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11959), 1,
      sym_variable_name,
    STATE(6675), 1,
      sym_subscript,
    STATE(4334), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11741), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11739), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [239893] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4374), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [239933] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4331), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [239973] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11961), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [240013] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11963), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [240053] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11965), 1,
      sym__special_character,
    STATE(4346), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [240091] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11957), 1,
      sym__special_character,
    STATE(4420), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [240129] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11968), 1,
      sym__special_character,
    STATE(4376), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [240167] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [240201] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11957), 1,
      sym__special_character,
    STATE(4420), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [240239] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [240273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [240307] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11968), 1,
      sym__special_character,
    STATE(4376), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [240345] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11970), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11973), 1,
      sym__concat,
    STATE(4354), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [240385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [240419] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11976), 1,
      sym__special_character,
    STATE(4346), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [240457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [240491] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11782), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11978), 1,
      sym_file_descriptor,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4388), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11780), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
  [240535] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [240569] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [240603] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4296), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11978), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4290), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(4292), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(2503), 3,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [240653] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [240687] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11719), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11984), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11986), 1,
      sym_file_descriptor,
    ACTIONS(11982), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4409), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11980), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11713), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [240731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [240765] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11994), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11997), 1,
      sym_file_descriptor,
    ACTIONS(11679), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11991), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4365), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11988), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11671), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [240809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [240843] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [240877] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11968), 1,
      sym__special_character,
    STATE(4376), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [240915] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4667), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [240955] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12004), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [240995] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11968), 1,
      sym__special_character,
    STATE(4376), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [241033] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [241067] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4477), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [241107] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12006), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [241147] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4479), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [241187] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12008), 1,
      sym__special_character,
    STATE(4376), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [241225] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [241259] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4670), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [241299] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5182), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11955), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5180), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [241351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [241385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [241419] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4374), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [241459] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [241493] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [241527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [241561] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [241595] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [241633] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11883), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12020), 1,
      sym_file_descriptor,
    ACTIONS(12014), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(12017), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4388), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12011), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11872), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
  [241677] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [241711] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [241747] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [241781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [241815] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [241849] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [241883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [241917] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
      anon_sym_BQUOTE,
  [241951] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [241985] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [242019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [242053] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11957), 1,
      sym__special_character,
    STATE(4420), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [242091] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [242125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [242159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [242193] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4326), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [242233] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11976), 1,
      sym__special_character,
    STATE(4346), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [242271] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [242305] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12023), 1,
      sym__special_character,
    STATE(4442), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5266), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [242343] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [242377] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11679), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12031), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12034), 1,
      sym_file_descriptor,
    ACTIONS(12028), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4409), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(12025), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11671), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [242421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [242455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [242489] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4515), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11978), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4292), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4513), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4255), 3,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [242539] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [242573] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4331), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [242613] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [242647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [242681] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [242715] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [242749] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11976), 1,
      sym__special_character,
    STATE(4346), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [242787] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12037), 1,
      sym__special_character,
    STATE(4420), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [242825] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4672), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
      anon_sym_BQUOTE,
  [242865] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4345), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [242905] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [242939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [242973] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [243007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym_file_descriptor,
      sym__concat,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
      anon_sym_BQUOTE,
  [243041] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243109] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11976), 1,
      sym__special_character,
    STATE(4346), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [243147] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4521), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [243187] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12040), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [243227] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12042), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [243267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243369] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12044), 1,
      sym_variable_name,
    STATE(6703), 1,
      sym_subscript,
    ACTIONS(11741), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4438), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11739), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [243409] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 17,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [243451] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12046), 1,
      sym_variable_name,
    STATE(6703), 1,
      sym_subscript,
    ACTIONS(11658), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4438), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11656), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [243491] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [243531] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4370), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [243571] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4374), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [243611] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12049), 1,
      sym__special_character,
    STATE(4442), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [243649] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [243683] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [243717] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [243751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [243785] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [243819] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243853] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [243955] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11667), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11894), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11934), 1,
      sym_file_descriptor,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4991), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11892), 11,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [243999] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4431), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244039] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4432), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244079] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4431), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244119] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4432), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [244193] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4431), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244233] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4432), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244273] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4431), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244313] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4432), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244353] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [244387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [244421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [244455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 24,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [244489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [244523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [244557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [244591] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [244625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [244659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [244693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [244727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6653), 5,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
    ACTIONS(6651), 21,
      sym__immediate_double_hash,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_POUND,
      anon_sym_RBRACE3,
      anon_sym_AT,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
      anon_sym_PERCENT_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
  [244761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6641), 5,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
    ACTIONS(6639), 21,
      sym__immediate_double_hash,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_POUND,
      anon_sym_RBRACE3,
      anon_sym_AT,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
      anon_sym_PERCENT_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
  [244795] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4370), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244835] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4374), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [244875] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12052), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [244915] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11667), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11904), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11934), 1,
      sym_file_descriptor,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4975), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11902), 11,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [244959] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12054), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [244999] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6726), 5,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
    ACTIONS(6724), 21,
      sym__immediate_double_hash,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_POUND,
      anon_sym_RBRACE3,
      anon_sym_AT,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
      anon_sym_PERCENT_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
  [245033] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6730), 5,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
    ACTIONS(6728), 21,
      sym__immediate_double_hash,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_POUND,
      anon_sym_RBRACE3,
      anon_sym_AT,
      anon_sym_EQ2,
      anon_sym_COLON_EQ,
      anon_sym_DASH3,
      anon_sym_COLON_DASH,
      anon_sym_PLUS3,
      anon_sym_COLON_PLUS,
      anon_sym_QMARK2,
      anon_sym_COLON_QMARK,
      anon_sym_PERCENT_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_SLASH_POUND,
      anon_sym_SLASH_PERCENT,
      anon_sym_COMMA_COMMA,
      anon_sym_CARET_CARET,
  [245067] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4619), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [245107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [245141] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [245175] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5163), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11955), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5159), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [245227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [245261] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4326), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [245301] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12056), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [245341] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11843), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11845), 1,
      sym__concat,
    STATE(4331), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [245381] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12058), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [245421] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4370), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [245461] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12060), 1,
      sym_variable_name,
    STATE(6672), 1,
      sym_subscript,
    ACTIONS(11741), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4493), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11739), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [245501] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12062), 1,
      sym_variable_name,
    STATE(6672), 1,
      sym_subscript,
    ACTIONS(11658), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4493), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11656), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [245541] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4322), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [245581] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4323), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [245621] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4322), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [245661] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4323), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [245701] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4322), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [245741] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4323), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [245781] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4322), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [245821] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4323), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [245861] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4488), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [245901] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4490), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [245941] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11679), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12071), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12074), 1,
      sym_file_descriptor,
    ACTIONS(12068), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4504), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(12065), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11671), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [245985] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
      anon_sym_BQUOTE,
  [246019] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4344), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [246059] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4672), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [246098] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12077), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6580), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [246163] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12101), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12103), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [246196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [246229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [246262] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [246295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
      anon_sym_BQUOTE,
  [246328] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12107), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12105), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [246361] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [246394] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_RPAREN,
    ACTIONS(4296), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12109), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4797), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4290), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [246443] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12111), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [246482] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [246515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12113), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12115), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [246548] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12117), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6585), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [246613] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12119), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [246652] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12121), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12123), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [246685] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12125), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [246724] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12127), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12129), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [246757] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5516), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12133), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12136), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12131), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [246794] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [246829] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12138), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [246868] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12140), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12142), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [246901] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11719), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12148), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12150), 1,
      sym_file_descriptor,
    ACTIONS(12146), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4531), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(12144), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11713), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [246944] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4667), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [246983] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11679), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12158), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12161), 1,
      sym_file_descriptor,
    ACTIONS(12155), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4531), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(12152), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11671), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [247026] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [247059] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11883), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12173), 1,
      sym_file_descriptor,
    ACTIONS(12167), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(12170), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4533), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11872), 8,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
    ACTIONS(12164), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [247102] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11839), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12176), 1,
      sym_file_descriptor,
    ACTIONS(11792), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4817), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11790), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [247145] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [247184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12180), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12178), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [247217] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11763), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11904), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12182), 1,
      sym_file_descriptor,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4678), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11902), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [247260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [247293] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [247326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [247359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12140), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12142), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [247392] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [247425] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12127), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12129), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [247458] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12184), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12186), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [247491] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [247524] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4546), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12136), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12188), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12131), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [247561] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [247594] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4175), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11775), 1,
      sym_file_descriptor,
    ACTIONS(4169), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(4171), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(2503), 4,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [247641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [247674] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11809), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12191), 1,
      sym_file_descriptor,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4817), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11790), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [247717] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11809), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11894), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12191), 1,
      sym_file_descriptor,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4709), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11892), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [247760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12184), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12186), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [247793] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12199), 1,
      sym_file_descriptor,
    ACTIONS(11883), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12167), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(12196), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4553), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11872), 7,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
    ACTIONS(12193), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [247836] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11839), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12176), 1,
      sym_file_descriptor,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(11904), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(4678), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11902), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [247879] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4523), 1,
      ts_builtin_sym_end,
    ACTIONS(4531), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12202), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4527), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4525), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [247928] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11763), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12182), 1,
      sym_file_descriptor,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4817), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11790), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [247971] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [248004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [248037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [248070] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [248103] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11809), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11904), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12191), 1,
      sym_file_descriptor,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4678), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11902), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [248146] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5516), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12133), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12136), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12131), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [248183] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12204), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6482), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [248248] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12208), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12206), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [248281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [248314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [248347] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4521), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248386] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4523), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248425] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4521), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248464] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4523), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248503] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4521), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248542] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4523), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248581] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4521), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248620] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4523), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12121), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12123), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [248692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12210), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12212), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [248725] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12216), 1,
      sym__concat,
    STATE(4591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 19,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [248764] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [248797] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [248830] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [248863] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4546), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12220), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12222), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12218), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [248900] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12224), 1,
      sym__concat,
    STATE(4591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 19,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [248939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [248972] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_BQUOTE,
    ACTIONS(4995), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12226), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4993), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4991), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [249021] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12228), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12230), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [249054] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12232), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12234), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [249087] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 17,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249124] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11839), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12176), 1,
      sym_file_descriptor,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(11894), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(4709), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11892), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [249167] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2505), 1,
      ts_builtin_sym_end,
    ACTIONS(4792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12202), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4527), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4790), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [249216] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 18,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [249253] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12236), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12239), 1,
      sym__concat,
    STATE(4591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 19,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [249292] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4255), 1,
      anon_sym_BQUOTE,
    ACTIONS(5212), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12226), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4993), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5210), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [249341] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12242), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12244), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [249374] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [249409] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [249442] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12246), 1,
      sym__special_character,
    STATE(4596), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249479] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249514] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12249), 1,
      sym__special_character,
    STATE(4596), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249551] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11763), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(11894), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12182), 1,
      sym_file_descriptor,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4709), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11892), 10,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [249594] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12251), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6605), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [249659] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11883), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12259), 1,
      sym_file_descriptor,
    ACTIONS(12167), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(12256), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4601), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11872), 8,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_BQUOTE,
    ACTIONS(12253), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [249702] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4670), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249741] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(4517), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249813] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12262), 1,
      sym_variable_name,
    STATE(6701), 1,
      sym_subscript,
    ACTIONS(11741), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4606), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11739), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249852] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12264), 1,
      sym_variable_name,
    STATE(6701), 1,
      sym_subscript,
    ACTIONS(11658), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4606), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11656), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249891] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12249), 1,
      sym__special_character,
    STATE(4596), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [249928] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [249961] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [249994] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12267), 1,
      sym__concat,
    STATE(4577), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5132), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 19,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [250033] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4257), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11775), 1,
      sym_file_descriptor,
    ACTIONS(4171), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4173), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4253), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(10932), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4255), 4,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(10930), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [250080] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11782), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12226), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4601), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11780), 8,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_BQUOTE,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [250123] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12208), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12206), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [250156] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12267), 1,
      sym__concat,
    STATE(4582), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5136), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5134), 19,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [250195] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [250228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250261] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4255), 1,
      anon_sym_RPAREN,
    ACTIONS(4515), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12109), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4797), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4513), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [250310] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4866), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [250349] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12269), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250388] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12271), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [250460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12242), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12244), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250493] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12273), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6565), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [250558] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4619), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250597] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4620), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250636] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4619), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250675] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4620), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250714] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12210), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12212), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250747] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4619), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250786] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4620), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250825] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4619), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250864] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(4620), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250903] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4667), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [250942] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12228), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12230), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [250975] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [251014] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4667), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [251053] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [251092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12107), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12105), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [251125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12101), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12103), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [251158] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12249), 1,
      sym__special_character,
    STATE(4596), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [251195] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4667), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [251234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [251267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [251300] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12275), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6466), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [251365] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12202), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11782), 2,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4553), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11780), 7,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [251408] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [251447] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [251480] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12180), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12178), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [251513] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12277), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [251552] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4649), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [251591] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4672), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [251630] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4649), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [251669] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4672), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [251708] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4649), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [251747] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4672), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [251786] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4649), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [251825] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12232), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12234), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [251858] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12281), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12279), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [251891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [251924] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12283), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6532), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [251989] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12267), 1,
      sym__concat,
    STATE(4577), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 19,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [252028] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12249), 1,
      sym__special_character,
    STATE(4596), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [252065] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12113), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12115), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [252098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 23,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [252131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12281), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12279), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      anon_sym_BQUOTE,
  [252164] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 18,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [252201] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12285), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [252240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 4,
      sym_file_descriptor,
      sym_variable_name,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [252273] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11782), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12109), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4533), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11780), 8,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [252316] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12287), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [252355] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12289), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6578), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [252420] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12291), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 20,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [252459] = 19,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12293), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6464), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [252524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12297), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12295), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [252556] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      aux_sym__c_word_token1,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    STATE(6499), 1,
      sym__c_expression,
    STATE(6692), 1,
      sym__c_variable_assignment,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3164), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [252618] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12325), 1,
      anon_sym_RBRACE3,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6939), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [252676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [252708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12341), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12343), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [252740] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12345), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6915), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [252798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12347), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12349), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [252830] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12351), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12353), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [252862] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12121), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12123), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [252894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12357), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12355), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [252926] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12359), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7326), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [252984] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12361), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12363), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [253016] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12365), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7228), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12361), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12363), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [253106] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [253138] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12367), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7120), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12121), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12123), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [253228] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12369), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6944), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253286] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12371), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7036), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12373), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12375), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [253376] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [253408] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12377), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7071), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [253498] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12379), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6868), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253556] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      aux_sym__c_word_token1,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    STATE(6562), 1,
      sym__c_expression,
    STATE(6692), 1,
      sym__c_variable_assignment,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3164), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [253618] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12381), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7073), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5270), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [253708] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12383), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7161), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12385), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12387), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [253798] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12389), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7570), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12393), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12391), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [253888] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12397), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12395), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [253920] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12399), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7268), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [253978] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12127), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12129), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [254010] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12397), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12395), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [254042] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12401), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12403), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254074] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4296), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11978), 1,
      sym_file_descriptor,
    ACTIONS(4290), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(4292), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(2503), 3,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [254120] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12405), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7176), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [254178] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12407), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7374), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [254236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12409), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12411), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254268] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [254300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12373), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12375), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254332] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4716), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12136), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12413), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12131), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [254368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12101), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12103), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5707), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5705), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [254432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12208), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12206), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [254464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12418), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12416), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [254496] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12420), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6722), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [254554] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12422), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7237), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [254612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12385), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12387), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [254644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5856), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12424), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12426), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5856), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254740] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12428), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7238), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [254798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12140), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12142), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254830] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12430), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6781), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [254888] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12397), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12395), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [254920] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11782), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4741), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11780), 7,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [254962] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12436), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12434), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [254994] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12438), 1,
      sym_file_descriptor,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4817), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11790), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [255036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12180), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12178), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [255068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [255100] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 17,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [255136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12418), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12416), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [255168] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12440), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7295), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [255226] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [255260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [255292] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11883), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12448), 1,
      sym_file_descriptor,
    ACTIONS(12167), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(12445), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4741), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11872), 7,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
    ACTIONS(12442), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [255334] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11894), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12438), 1,
      sym_file_descriptor,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4709), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11892), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [255376] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12121), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12123), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [255408] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11904), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11953), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12438), 1,
      sym_file_descriptor,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4678), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
    ACTIONS(11902), 9,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
  [255450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [255482] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12451), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12453), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [255514] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [255546] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12281), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12279), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [255578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12393), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12391), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [255610] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12455), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12457), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [255642] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12459), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7300), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [255700] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12180), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12178), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [255732] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [255764] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12461), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7346), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [255822] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12463), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6917), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [255880] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12469), 1,
      aux_sym__c_word_token1,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    STATE(6429), 1,
      sym__c_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [255942] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12483), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6819), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [256000] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12469), 1,
      aux_sym__c_word_token1,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    STATE(6395), 1,
      sym__c_variable_assignment,
    STATE(6439), 1,
      sym__c_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2902), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [256062] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [256094] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12485), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6897), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [256152] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12487), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12489), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256216] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12281), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12279), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256248] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [256280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [256312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12493), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12491), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [256344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12140), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12142), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [256376] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [256408] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12210), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12212), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12281), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12279), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [256472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12361), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12363), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [256504] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12357), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12355), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256536] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12401), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12403), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [256568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12497), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12495), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [256600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [256632] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12107), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12105), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256664] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12501), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12499), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [256696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12505), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12503), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [256728] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12507), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7365), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [256786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12511), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12509), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [256818] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12513), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6847), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [256876] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12493), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12491), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256908] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12505), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12503), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12397), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12395), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [256972] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12341), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12343), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [257004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12501), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12499), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [257036] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12515), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7433), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [257094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12487), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12489), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [257126] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5856), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [257158] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12517), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6873), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [257216] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      aux_sym__c_word_token1,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    STATE(6534), 1,
      sym__c_expression,
    STATE(6692), 1,
      sym__c_variable_assignment,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3164), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [257278] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12519), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12521), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [257310] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12523), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6797), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [257368] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6646), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [257430] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12527), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12525), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [257462] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12529), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6901), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [257520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12533), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12531), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [257552] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5182), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5180), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [257598] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12535), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7135), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [257656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12511), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12509), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [257688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12539), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12537), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [257720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12140), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12142), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [257752] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12541), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6924), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [257810] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12543), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6788), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [257868] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5856), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [257900] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12083), 1,
      aux_sym__c_word_token1,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    STATE(6685), 1,
      sym__c_expression,
    STATE(6686), 1,
      sym__c_variable_assignment,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3195), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [257962] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12545), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6984), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [258020] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5516), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12133), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12136), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12131), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258056] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12547), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7504), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [258114] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12549), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6957), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [258172] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4515), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(11978), 1,
      sym_file_descriptor,
    ACTIONS(4292), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4294), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4513), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
    ACTIONS(11665), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4255), 3,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11663), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [258218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12242), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12244), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258250] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12210), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12212), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258282] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12551), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6716), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [258340] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12555), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12553), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258372] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12557), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6992), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [258430] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12559), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12561), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [258462] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12424), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12426), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [258494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12519), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12521), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258526] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12539), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12537), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258558] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4716), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12222), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12563), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12218), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258594] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12565), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7389), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [258652] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [258684] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [258716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [258748] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12567), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7026), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [258806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12409), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12411), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12424), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12426), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258870] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12527), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12525), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [258902] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12569), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7246), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [258960] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12424), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12426), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [258992] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12571), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7054), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [259050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12113), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12115), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [259082] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12573), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7118), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [259140] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [259172] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12575), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7076), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [259230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12579), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12577), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [259262] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12107), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12105), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [259294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12228), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12230), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [259326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12497), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12495), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [259358] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12180), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12178), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [259390] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12579), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12577), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [259422] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12436), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12434), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [259454] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      aux_sym__c_word_token1,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    STATE(6659), 1,
      sym__c_expression,
    STATE(6692), 1,
      sym__c_variable_assignment,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3164), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [259516] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12581), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6802), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [259574] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12184), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12186), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [259606] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12583), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7090), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [259664] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [259696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12511), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12509), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [259728] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12585), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7047), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [259786] = 18,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      aux_sym__c_word_token1,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    STATE(6628), 1,
      sym__c_expression,
    STATE(6692), 1,
      sym__c_variable_assignment,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3164), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [259848] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12347), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12349), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [259880] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12228), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12230), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [259912] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12587), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6736), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [259970] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12589), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7107), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [260028] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12593), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12591), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260060] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12595), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7124), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [260118] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12599), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12597), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12455), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12457), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [260214] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12451), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12453), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12347), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12349), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260278] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12601), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7013), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [260336] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12603), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7432), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [260394] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12605), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6825), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [260452] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12607), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260490] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12609), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260528] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12611), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7148), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [260586] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12107), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12105), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260618] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12613), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7151), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [260676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12228), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12230), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260708] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12615), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7168), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [260766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12101), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12103), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [260830] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4866), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260868] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4867), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260906] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4866), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260944] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4867), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [260982] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4866), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [261020] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4867), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [261058] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4866), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [261096] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(4867), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 19,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [261134] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12617), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7359), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [261192] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12619), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7184), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [261250] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12599), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12597), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [261282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [261314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12242), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12244), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [261346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12511), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12509), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [261378] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12621), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7086), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [261436] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12623), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7199), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [261494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12101), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12103), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [261526] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12625), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7213), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [261584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12361), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12363), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [261616] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5163), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5159), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [261662] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12627), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6846), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [261720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [261752] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12232), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12234), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [261784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [261816] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5208), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5206), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [261862] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12629), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7229), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [261920] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [261952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12347), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12349), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [261984] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12631), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7251), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [262042] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12633), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6717), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [262100] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12635), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7274), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [262158] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12639), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12637), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [262190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12643), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12641), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [262222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12559), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12561), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [262254] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12645), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6865), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [262312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [262344] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12647), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7043), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [262402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12351), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12353), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [262434] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12649), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7293), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [262492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12210), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12212), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [262524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [262556] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5285), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [262602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [262634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12242), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12244), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [262666] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12297), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12295), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [262698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12593), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12591), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [262730] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5888), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5886), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [262762] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12539), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12537), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [262794] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 4,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 20,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [262826] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12651), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6752), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [262884] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12653), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6810), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [262942] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12655), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6741), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [263000] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12639), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12637), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [263032] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12533), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12531), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [263064] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12657), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6804), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [263122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12418), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12416), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [263154] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12659), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6770), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [263212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12539), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12537), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [263244] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12643), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12641), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [263276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12418), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12416), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [263308] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263340] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12373), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12375), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12555), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12553), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [263404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12373), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12375), 22,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_esac,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263436] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12661), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(7313), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [263494] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12327), 1,
      anon_sym_BANG2,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12337), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(12339), 1,
      sym_variable_name,
    ACTIONS(12663), 1,
      anon_sym_RBRACE3,
    STATE(3386), 1,
      sym_subscript,
    STATE(6311), 1,
      aux_sym__expansion_body_repeat1,
    STATE(6377), 1,
      sym_command_substitution,
    STATE(6863), 1,
      sym__expansion_body,
    ACTIONS(12329), 2,
      anon_sym_POUND2,
      anon_sym_EQ2,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
    ACTIONS(12321), 4,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_QMARK,
      anon_sym_AT2,
    ACTIONS(12323), 4,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym__,
  [263552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12511), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12509), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12347), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12349), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263614] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12665), 1,
      sym__special_character,
    STATE(4943), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 18,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [263649] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12373), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12375), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263680] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4957), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12668), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12222), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12218), 17,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263715] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12121), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12123), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263746] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5852), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12674), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12676), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5845), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [263793] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12373), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12375), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12107), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12105), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12555), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12553), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12593), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12591), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263917] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4523), 1,
      ts_builtin_sym_end,
    ACTIONS(4531), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12202), 1,
      sym_file_descriptor,
    ACTIONS(4527), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4525), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [263962] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5856), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [263993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12519), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12521), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12397), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12395), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12357), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12355), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264086] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4957), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12678), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12136), 3,
      sym_file_descriptor,
      ts_builtin_sym_end,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12131), 17,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264121] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12281), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12279), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264152] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12397), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12395), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264183] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12385), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12387), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264214] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12639), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12637), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12451), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12453), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12418), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12416), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264307] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12643), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12641), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264338] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4980), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12222), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12681), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12218), 18,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264373] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12418), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12416), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12487), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12489), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12527), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12525), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12505), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12503), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264528] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4255), 1,
      anon_sym_BQUOTE,
    ACTIONS(5212), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12226), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4993), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5210), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [264573] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12497), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12495), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264604] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12599), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12597), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264635] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_BQUOTE,
    ACTIONS(4995), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12226), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4993), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11898), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4991), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11896), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [264680] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12341), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12343), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264711] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12140), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12142), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264742] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12436), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12434), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264773] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12533), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12531), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264804] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264835] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4980), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12136), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12683), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12131), 18,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RPAREN,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264870] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12347), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12349), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264901] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12686), 1,
      sym__special_character,
    STATE(4943), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5132), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5130), 18,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [264936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12501), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12499), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12455), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12457), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [264998] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12511), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12509), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12539), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12537), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12559), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12561), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265091] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5078), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 18,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [265128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12210), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12212), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12297), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12295), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12401), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12403), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265221] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5006), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12222), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12688), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12218), 18,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [265256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5858), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5856), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12539), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12537), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12361), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12363), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12361), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12363), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265380] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12393), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12391), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265411] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12409), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12411), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265442] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5847), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12674), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12676), 1,
      sym_file_descriptor,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5845), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [265489] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(5103), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [265526] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12180), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12178), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12424), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12426), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265619] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265650] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12242), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12244), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265681] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5006), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12136), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12690), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12131), 18,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_BQUOTE,
  [265716] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5068), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 8,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      sym__special_character,
    ACTIONS(1225), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [265751] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4255), 1,
      anon_sym_RPAREN,
    ACTIONS(4515), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12109), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4797), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4513), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [265796] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2505), 1,
      ts_builtin_sym_end,
    ACTIONS(4792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12202), 1,
      sym_file_descriptor,
    ACTIONS(4527), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(11837), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4790), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11835), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [265841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12101), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12103), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265872] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12228), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12230), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265903] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      anon_sym_RPAREN,
    ACTIONS(4296), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12109), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(4797), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11800), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(4290), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11798), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [265948] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12351), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12353), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [265979] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12674), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [266018] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12424), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12426), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [266049] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12579), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12577), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [266080] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12674), 1,
      anon_sym_LT_LT_LT,
    STATE(4937), 1,
      sym_herestring_redirect,
    ACTIONS(4268), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [266117] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12493), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12491), 21,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [266148] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5181), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [266184] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5039), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12695), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5130), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5132), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [266218] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5040), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12695), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5134), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(5136), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [266252] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12697), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3105), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266308] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12699), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3107), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266364] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12701), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3114), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266420] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12703), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3119), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266476] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12705), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3120), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266532] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12707), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3122), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266588] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12709), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3123), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266644] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12711), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3125), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266700] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12713), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3127), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266756] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12715), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3131), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266812] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12717), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3133), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266868] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12719), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3135), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [266924] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5068), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5687), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5689), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [266958] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5069), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2158), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [266992] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5068), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5563), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [267026] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5069), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2162), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [267060] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12727), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12729), 1,
      sym_file_descriptor,
    ACTIONS(11713), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(12725), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12723), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5049), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11719), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_LT_LT_DASH,
    ACTIONS(12721), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [267102] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12695), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12731), 1,
      sym__concat,
    STATE(5041), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1229), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [267138] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12695), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12733), 1,
      sym__concat,
    STATE(5041), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1209), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [267174] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5041), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12735), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [267208] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12267), 1,
      sym__concat,
    STATE(5053), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12740), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12738), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [267244] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12267), 1,
      sym__concat,
    STATE(5054), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12744), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12742), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [267280] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5068), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4282), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [267314] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5069), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4437), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4439), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [267348] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5039), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12695), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1225), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [267382] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5068), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4307), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4309), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [267416] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5069), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12693), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4311), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4313), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [267450] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12755), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12758), 1,
      sym_file_descriptor,
    ACTIONS(11671), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(12752), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12749), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5049), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11679), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_LT_LT_DASH,
    ACTIONS(12746), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [267492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 19,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [267522] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5285), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [267564] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12761), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2931), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [267620] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12763), 1,
      sym__concat,
    STATE(4591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [267656] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12765), 1,
      sym__concat,
    STATE(4591), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [267692] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12214), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12267), 1,
      sym__concat,
    STATE(5053), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [267728] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12767), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2978), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [267784] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11719), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12773), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12775), 1,
      sym_file_descriptor,
    ACTIONS(12771), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5058), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11713), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT_LT,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(12769), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [267824] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11679), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12783), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12786), 1,
      sym_file_descriptor,
    ACTIONS(12780), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5058), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11671), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT_LT,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(12777), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [267864] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12789), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2984), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [267920] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12791), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2985), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [267976] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(12793), 1,
      anon_sym_LT_LT_LT,
    STATE(5583), 1,
      sym_herestring_redirect,
    STATE(5381), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4159), 9,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [268016] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12795), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2996), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268072] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12797), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2919), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268128] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12799), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2807), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268184] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12801), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2820), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268240] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12803), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2826), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268296] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5079), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [268332] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12693), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12805), 1,
      sym__concat,
    STATE(5072), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1229), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [268368] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12693), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12807), 1,
      sym__concat,
    STATE(5072), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1209), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [268404] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12809), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3047), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268460] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12811), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3049), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268516] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5072), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12813), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [268550] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12816), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3051), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268606] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12818), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3053), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268662] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12820), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3056), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268718] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(5103), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5266), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5264), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [268754] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11761), 1,
      sym__concat,
    STATE(5104), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5270), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5268), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [268790] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12822), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [268826] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12824), 1,
      sym__concat,
    STATE(4145), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [268862] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12826), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3059), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268918] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12828), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3064), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [268974] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12830), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3066), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269030] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12832), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3068), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269086] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12834), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3070), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269142] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12836), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3077), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269198] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12838), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3078), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269254] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12840), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2829), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269310] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12842), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2835), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269366] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12844), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2836), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269422] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10646), 1,
      anon_sym_DOLLAR,
    ACTIONS(10652), 1,
      aux_sym_number_token2,
    ACTIONS(12467), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      anon_sym_DQUOTE,
    ACTIONS(12473), 1,
      aux_sym_number_token1,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12846), 1,
      aux_sym__c_word_token1,
    STATE(2838), 1,
      sym__c_postfix_expression,
    STATE(2905), 1,
      sym__c_unary_expression,
    STATE(2906), 1,
      sym__c_binary_expression,
    ACTIONS(12465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2837), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269478] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5163), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5159), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [269520] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12305), 1,
      anon_sym_DOLLAR,
    ACTIONS(12307), 1,
      anon_sym_DQUOTE,
    ACTIONS(12309), 1,
      aux_sym_number_token1,
    ACTIONS(12311), 1,
      aux_sym_number_token2,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12848), 1,
      aux_sym__c_word_token1,
    STATE(3165), 1,
      sym__c_unary_expression,
    STATE(3170), 1,
      sym__c_binary_expression,
    STATE(3171), 1,
      sym__c_postfix_expression,
    ACTIONS(12299), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3263), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269576] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5190), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12850), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1225), 12,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [269610] = 13,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(12858), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12860), 1,
      sym_file_descriptor,
    STATE(5460), 1,
      sym_herestring_redirect,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [269660] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5208), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5206), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [269702] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5182), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5161), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(11951), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(5180), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [269744] = 16,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12081), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      anon_sym_DOLLAR,
    ACTIONS(12087), 1,
      anon_sym_DQUOTE,
    ACTIONS(12089), 1,
      aux_sym_number_token1,
    ACTIONS(12091), 1,
      aux_sym_number_token2,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12862), 1,
      aux_sym__c_word_token1,
    STATE(3196), 1,
      sym__c_unary_expression,
    STATE(3199), 1,
      sym__c_binary_expression,
    STATE(3201), 1,
      sym__c_postfix_expression,
    ACTIONS(12079), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(3275), 7,
      sym__c_expression_not_assignment,
      sym__c_parenthesized_expression,
      sym_string,
      sym_number,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269800] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5099), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12222), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12864), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12218), 17,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [269834] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5099), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12136), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12866), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12131), 17,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI_SEMI,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [269868] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5218), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1225), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [269902] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12793), 1,
      anon_sym_LT_LT_LT,
    STATE(5583), 1,
      sym_herestring_redirect,
    STATE(5381), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4157), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4268), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [269938] = 15,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7760), 1,
      anon_sym_LPAREN,
    ACTIONS(7770), 1,
      anon_sym_DQUOTE,
    ACTIONS(7778), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7790), 1,
      sym_variable_name,
    ACTIONS(12873), 1,
      anon_sym_DOLLAR,
    ACTIONS(12875), 1,
      anon_sym_RBRACE3,
    ACTIONS(12877), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12879), 1,
      anon_sym_BQUOTE,
    ACTIONS(12881), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(6567), 1,
      sym_process_substitution,
    STATE(7221), 1,
      sym__concatenation_in_expansion,
    ACTIONS(7524), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(12871), 4,
      sym__expansion_word,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(6437), 5,
      sym_string,
      sym_array,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [269992] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12883), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270028] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11759), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12885), 1,
      sym__concat,
    STATE(4156), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 3,
      sym_file_descriptor,
      sym_variable_name,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270064] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12887), 1,
      sym_variable_name,
    STATE(6633), 1,
      sym_subscript,
    ACTIONS(11741), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(5106), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11739), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270100] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12889), 1,
      sym_variable_name,
    STATE(6633), 1,
      sym_subscript,
    ACTIONS(11658), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(5106), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11656), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270136] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5078), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [270172] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5079), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [270208] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5078), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [270244] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5079), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [270280] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5078), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [270316] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5079), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [270352] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11786), 1,
      aux_sym_concatenation_token1,
    ACTIONS(11788), 1,
      sym__concat,
    STATE(5078), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [270388] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5158), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 8,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      sym__special_character,
    ACTIONS(1225), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270422] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5852), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12894), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5845), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [270463] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12900), 1,
      anon_sym_esac,
    ACTIONS(12896), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12898), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [270494] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5158), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4282), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270527] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5159), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4437), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4439), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270560] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(12902), 1,
      anon_sym_LPAREN,
    ACTIONS(12904), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12906), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(12908), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(12910), 1,
      anon_sym_DOLLAR,
    ACTIONS(12912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12914), 1,
      anon_sym_RBRACE3,
    ACTIONS(12916), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12918), 1,
      anon_sym_BQUOTE,
    ACTIONS(12920), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12922), 1,
      aux_sym__simple_variable_name_token1,
    STATE(5452), 1,
      sym_simple_expansion,
    STATE(6253), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6323), 1,
      sym__expansion_max_length_expression,
    STATE(6208), 2,
      sym_number,
      sym_expansion,
    STATE(7371), 3,
      sym_parenthesized_expression,
      sym_arithmetic_expansion,
      sym_command_substitution,
  [270621] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12928), 1,
      anon_sym_esac,
    ACTIONS(12924), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12926), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [270652] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5158), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4307), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4309), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270685] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5159), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4311), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4313), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270718] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5190), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12850), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5264), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5266), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270751] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5192), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12850), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5268), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5270), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [270784] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1254), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [270813] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1286), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [270842] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1215), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [270871] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12928), 1,
      anon_sym_esac,
    ACTIONS(12924), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12926), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [270902] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1314), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [270931] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1310), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [270960] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(11780), 1,
      anon_sym_PIPE,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5171), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11782), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [271003] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1262), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271032] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1270), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271061] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12932), 1,
      sym__special_character,
    STATE(5193), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4282), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [271094] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12934), 1,
      sym_variable_name,
    STATE(6657), 1,
      sym_subscript,
    STATE(5173), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11739), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(11741), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [271129] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12940), 1,
      anon_sym_esac,
    ACTIONS(12936), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12938), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271160] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12932), 1,
      sym__special_character,
    STATE(5193), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4307), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4309), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [271193] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5158), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5687), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5689), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [271226] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5159), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2158), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [271259] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5218), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5687), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5689), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [271292] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5219), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2158), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [271325] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1274), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271354] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1266), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271383] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1282), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271412] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1250), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271441] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1258), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271470] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5218), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5563), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [271503] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5219), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2162), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [271536] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1278), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271565] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1290), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271594] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12946), 1,
      anon_sym_esac,
    ACTIONS(12942), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12944), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271625] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1294), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271654] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1298), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271683] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271712] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1306), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271741] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 6,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      sym_word,
    ACTIONS(1302), 15,
      sym__concat,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_concatenation_token1,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [271770] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(12902), 1,
      anon_sym_LPAREN,
    ACTIONS(12906), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(12908), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(12910), 1,
      anon_sym_DOLLAR,
    ACTIONS(12912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12916), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12918), 1,
      anon_sym_BQUOTE,
    ACTIONS(12920), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12948), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12950), 1,
      anon_sym_RBRACE3,
    ACTIONS(12952), 1,
      aux_sym__simple_variable_name_token1,
    STATE(5454), 1,
      sym_simple_expansion,
    STATE(6265), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6323), 1,
      sym__expansion_max_length_expression,
    STATE(6239), 2,
      sym_number,
      sym_expansion,
    STATE(6980), 3,
      sym_parenthesized_expression,
      sym_arithmetic_expansion,
      sym_command_substitution,
  [271831] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12892), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12954), 1,
      sym__concat,
    STATE(5161), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1229), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [271866] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12892), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12956), 1,
      sym__concat,
    STATE(5161), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1209), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [271901] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(12902), 1,
      anon_sym_LPAREN,
    ACTIONS(12906), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(12908), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(12910), 1,
      anon_sym_DOLLAR,
    ACTIONS(12912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12916), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12918), 1,
      anon_sym_BQUOTE,
    ACTIONS(12920), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(12958), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12960), 1,
      anon_sym_RBRACE3,
    ACTIONS(12962), 1,
      aux_sym__simple_variable_name_token1,
    STATE(5432), 1,
      sym_simple_expansion,
    STATE(6173), 1,
      sym_number,
    STATE(6174), 1,
      sym_expansion,
    STATE(6175), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6323), 1,
      sym__expansion_max_length_expression,
    STATE(7132), 1,
      sym_parenthesized_expression,
    STATE(7134), 1,
      sym_arithmetic_expansion,
    STATE(7158), 1,
      sym_command_substitution,
  [271968] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5161), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12964), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272001] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12946), 1,
      anon_sym_esac,
    ACTIONS(12942), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12944), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [272032] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11782), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12894), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5167), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11780), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [272071] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11792), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12674), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12967), 1,
      sym_file_descriptor,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4817), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11790), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT_LT,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [272110] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272143] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4159), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272174] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11883), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12975), 1,
      sym_file_descriptor,
    ACTIONS(12167), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(12972), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5167), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11872), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12969), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [272213] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11894), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12674), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12967), 1,
      sym_file_descriptor,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4709), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11892), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT_LT,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [272252] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11904), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12674), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(12967), 1,
      sym_file_descriptor,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(4678), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(11902), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT_LT,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [272291] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5847), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12894), 1,
      sym_file_descriptor,
    ACTIONS(4157), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5845), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [272332] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(11872), 1,
      anon_sym_PIPE,
    ACTIONS(12981), 1,
      anon_sym_LT_LT,
    ACTIONS(12990), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(12993), 1,
      sym_file_descriptor,
    ACTIONS(12987), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12984), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5171), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11883), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
    ACTIONS(12978), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [272375] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5158), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5563), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272408] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12996), 1,
      sym_variable_name,
    STATE(6657), 1,
      sym_subscript,
    STATE(5173), 2,
      sym_variable_assignment,
      aux_sym_variable_assignments_repeat1,
    ACTIONS(11656), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(11658), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272443] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5159), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12892), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2162), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272476] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(7117), 1,
      anon_sym_RBRACK,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [272523] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1254), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [272552] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12900), 1,
      anon_sym_esac,
    ACTIONS(12896), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12898), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [272583] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1286), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [272612] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [272641] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1314), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [272670] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12999), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272705] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13001), 1,
      sym__concat,
    STATE(4214), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272740] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1310), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [272769] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13007), 1,
      anon_sym_esac,
    ACTIONS(13003), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13005), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [272800] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12940), 1,
      anon_sym_esac,
    ACTIONS(12936), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12938), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [272831] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13013), 1,
      anon_sym_esac,
    ACTIONS(13009), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13011), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [272862] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12932), 1,
      sym__special_character,
    STATE(5193), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5563), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [272895] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1270), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [272924] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13019), 1,
      anon_sym_esac,
    ACTIONS(13015), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13017), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [272955] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12850), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13021), 1,
      sym__concat,
    STATE(5194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1229), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [272990] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(7277), 1,
      anon_sym_RBRACK,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [273037] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12850), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13023), 1,
      sym__concat,
    STATE(5194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1209), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [273072] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13025), 1,
      sym__special_character,
    STATE(5193), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1318), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [273105] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5194), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13028), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [273138] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13035), 1,
      anon_sym_esac,
    ACTIONS(13031), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13033), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [273169] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5218), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4282), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [273202] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5219), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4437), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4439), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [273235] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13041), 1,
      anon_sym_esac,
    ACTIONS(13037), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13039), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [273266] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(7129), 1,
      anon_sym_RBRACK,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [273313] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5218), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4307), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4309), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [273346] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1274), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273375] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5219), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(12869), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4311), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4313), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [273408] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1266), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273437] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1282), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273466] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13019), 1,
      anon_sym_esac,
    ACTIONS(13015), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13017), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [273497] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1250), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273526] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1258), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273555] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1278), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273584] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1290), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273613] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1294), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273642] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1298), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273671] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(7299), 1,
      anon_sym_RBRACK,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [273718] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13013), 1,
      anon_sym_esac,
    ACTIONS(13009), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13011), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [273749] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273778] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1306), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273807] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [273836] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5329), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1223), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1225), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [273869] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12869), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13045), 1,
      sym__concat,
    STATE(5220), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1229), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [273904] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12869), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13047), 1,
      sym__concat,
    STATE(5220), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1209), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [273939] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5220), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13049), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [273972] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(7309), 1,
      anon_sym_RBRACK,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [274019] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13058), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(13060), 1,
      sym_file_descriptor,
    ACTIONS(11713), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(13056), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13054), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5235), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11719), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(13052), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [274060] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13066), 1,
      anon_sym_esac,
    ACTIONS(13062), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13064), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274091] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(7043), 1,
      anon_sym_RBRACK,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [274138] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12932), 1,
      sym__special_character,
    STATE(5193), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5687), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5689), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [274171] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13072), 1,
      anon_sym_esac,
    ACTIONS(13068), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13070), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274202] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13078), 1,
      anon_sym_esac,
    ACTIONS(13074), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13076), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274233] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(7107), 1,
      anon_sym_RBRACK,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [274280] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13084), 1,
      anon_sym_esac,
    ACTIONS(13080), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13082), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274311] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13090), 1,
      anon_sym_esac,
    ACTIONS(13086), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13088), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274342] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13096), 1,
      anon_sym_esac,
    ACTIONS(13092), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13094), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274373] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13102), 1,
      anon_sym_esac,
    ACTIONS(13098), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13100), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274404] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13102), 1,
      anon_sym_esac,
    ACTIONS(13098), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13100), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274435] = 12,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(7111), 1,
      anon_sym_RBRACK,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [274482] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13113), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(13116), 1,
      sym_file_descriptor,
    ACTIONS(11671), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(13110), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13107), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5235), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(11679), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(13104), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [274523] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5181), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274558] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5182), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274593] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5181), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274628] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5182), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274663] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5181), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274698] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5182), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274733] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5181), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274768] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 1,
      aux_sym_concatenation_token1,
    ACTIONS(12002), 1,
      sym__concat,
    STATE(5182), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274803] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13078), 1,
      anon_sym_esac,
    ACTIONS(13074), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13076), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274834] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1262), 14,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [274863] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1306), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [274891] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13119), 1,
      sym__special_character,
    STATE(5247), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1318), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [274923] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13122), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13124), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [274951] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1298), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [274979] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13126), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13128), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275007] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13126), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13128), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275035] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5329), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4282), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [275067] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5331), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4437), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4439), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [275099] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13092), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13094), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275127] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13126), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13128), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275155] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1258), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [275183] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13098), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13100), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275211] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13126), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13128), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275239] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13098), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13100), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275267] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1282), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [275295] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13130), 1,
      sym__special_character,
    STATE(5359), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5687), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5689), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [275327] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13132), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13134), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275355] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13136), 1,
      sym__special_character,
    STATE(5247), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4282), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [275387] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13122), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13124), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275415] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13122), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13124), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275443] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13136), 1,
      sym__special_character,
    STATE(5247), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5687), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5689), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [275475] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13138), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13140), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275503] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13074), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13076), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275531] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13138), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13140), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275559] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5329), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4307), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4309), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [275591] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5331), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(4311), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4313), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [275623] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12896), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12898), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275651] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13003), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13005), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275679] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12936), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12938), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275707] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1254), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [275735] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13136), 1,
      sym__special_character,
    STATE(5247), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4307), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4309), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [275767] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13062), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13064), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275795] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 8,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      sym__special_character,
    ACTIONS(1225), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [275823] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13130), 1,
      sym__special_character,
    STATE(5359), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5563), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [275855] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1286), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [275883] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [275911] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12924), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12926), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275939] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13142), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13144), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [275967] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1314), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [275995] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1310), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276023] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1274), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276051] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13146), 1,
      sym__special_character,
    STATE(5303), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5264), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5266), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [276083] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13148), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13150), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276111] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1266), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276139] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1282), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276167] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1250), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276195] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12793), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(13158), 1,
      sym_file_descriptor,
    ACTIONS(11892), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(13156), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5591), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(13154), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(11894), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(13152), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [276235] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13122), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13124), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276263] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1258), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276291] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [276319] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13142), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13144), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276347] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1278), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276375] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1290), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276403] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13130), 1,
      sym__special_character,
    STATE(5359), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4282), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [276435] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13160), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13162), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276463] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13164), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13166), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276491] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1294), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276519] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13168), 1,
      sym__special_character,
    STATE(5303), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1318), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [276551] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1306), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [276579] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1262), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276607] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [276651] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1298), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276679] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1270), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [276707] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [276735] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12793), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(13158), 1,
      sym_file_descriptor,
    ACTIONS(11790), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(13156), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5601), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(13154), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(11792), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(13152), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [276775] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13171), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13173), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276803] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13130), 1,
      sym__special_character,
    STATE(5359), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4307), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4309), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [276835] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12924), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12926), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276863] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13171), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13173), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276891] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12936), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12938), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276919] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12942), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12944), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276947] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13142), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13144), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [276975] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277003] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1306), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277031] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277059] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1254), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277087] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12942), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12944), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [277115] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13171), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13173), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [277143] = 11,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7760), 1,
      anon_sym_LPAREN,
    ACTIONS(7770), 1,
      anon_sym_DQUOTE,
    ACTIONS(7778), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12873), 1,
      anon_sym_DOLLAR,
    ACTIONS(12877), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12879), 1,
      anon_sym_BQUOTE,
    ACTIONS(12881), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(7788), 2,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
    ACTIONS(13175), 5,
      sym_variable_name,
      sym__expansion_word,
      sym_raw_string,
      sym_ansi_c_string,
      sym_word,
    STATE(6435), 6,
      sym_string,
      sym_array,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      sym_process_substitution,
  [277187] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12793), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(13158), 1,
      sym_file_descriptor,
    ACTIONS(11902), 2,
      anon_sym_PIPE,
      anon_sym_LT_LT,
    ACTIONS(13156), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5590), 2,
      sym_file_redirect,
      sym_herestring_redirect,
    ACTIONS(13154), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(11904), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
      anon_sym_LT_LT_DASH,
    ACTIONS(13152), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [277227] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13142), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13144), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [277255] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1286), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277283] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277311] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13043), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13177), 1,
      sym__concat,
    STATE(5332), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1229), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [277345] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1250), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [277373] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13043), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13179), 1,
      sym__concat,
    STATE(5332), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1209), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [277407] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5332), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13181), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [277439] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13160), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13162), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [277467] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1274), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [277495] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13009), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13011), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [277523] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13160), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13162), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [277551] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1274), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277579] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12686), 1,
      sym__special_character,
    STATE(4943), 1,
      aux_sym__literal_repeat1,
    ACTIONS(12740), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12738), 15,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [277611] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13015), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13017), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [277639] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1282), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277667] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1286), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [277695] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [277723] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1314), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277751] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13015), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13017), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [277779] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1278), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277807] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1290), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [277835] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1254), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [277863] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5329), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5687), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5689), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [277895] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1314), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [277923] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5331), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2158), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [277955] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1310), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [277983] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1262), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [278011] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(12902), 1,
      anon_sym_LPAREN,
    ACTIONS(12906), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(12908), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(12912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12916), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12918), 1,
      anon_sym_BQUOTE,
    ACTIONS(12920), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13184), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13186), 1,
      anon_sym_COLON,
    ACTIONS(13188), 1,
      anon_sym_RBRACE3,
    ACTIONS(13190), 1,
      aux_sym__simple_variable_name_token1,
    STATE(6147), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6323), 1,
      sym__expansion_max_length_expression,
    STATE(6135), 2,
      sym_number,
      sym_expansion,
    STATE(6661), 3,
      sym_parenthesized_expression,
      sym_arithmetic_expansion,
      sym_command_substitution,
  [278069] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13009), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13011), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278097] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1270), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [278125] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13160), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13162), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278153] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1266), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [278181] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1294), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [278209] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13192), 1,
      sym__special_character,
    STATE(5359), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1318), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [278241] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1310), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [278269] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13138), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13140), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278297] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13138), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13140), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278325] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13195), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13197), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278353] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13171), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13173), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278381] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1250), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [278409] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13199), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13201), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278437] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1298), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [278465] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13199), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13201), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278493] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13031), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13033), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278521] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1258), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [278549] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4157), 1,
      anon_sym_PIPE,
    ACTIONS(4268), 1,
      anon_sym_PIPE_AMP,
    STATE(5381), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4159), 9,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [278583] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13203), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13205), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278611] = 4,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5381), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(4155), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4159), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [278641] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13207), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13209), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278669] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1266), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [278697] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13211), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13213), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278725] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1278), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [278753] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13215), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13217), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278781] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13215), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13217), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278809] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13199), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13201), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278837] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(11780), 1,
      anon_sym_PIPE,
    ACTIONS(13219), 1,
      anon_sym_LT_LT,
    ACTIONS(13221), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13223), 1,
      sym_file_descriptor,
    ACTIONS(13156), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(11782), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
    ACTIONS(13154), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5396), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(13152), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [278879] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [278907] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13199), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13201), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278935] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 13,
      sym_file_descriptor,
      sym__concat,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [278963] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13215), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13217), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [278991] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1290), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [279019] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13215), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13217), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279047] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13225), 1,
      sym__special_character,
    STATE(5390), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5130), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(5132), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279079] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13068), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13070), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279107] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13227), 1,
      sym__special_character,
    STATE(5390), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1318), 13,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279139] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1262), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [279167] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1294), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [279195] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1270), 13,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [279223] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13136), 1,
      sym__special_character,
    STATE(5247), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5563), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [279255] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5329), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(5561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5563), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [279287] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(11872), 1,
      anon_sym_PIPE,
    ACTIONS(13233), 1,
      anon_sym_LT_LT,
    ACTIONS(13242), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13245), 1,
      sym_file_descriptor,
    ACTIONS(13239), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(11883), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_AMP,
    ACTIONS(13236), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5396), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(13230), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [279329] = 5,
    ACTIONS(71), 1,
      sym_comment,
    STATE(5331), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(13043), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2162), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [279361] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13074), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13076), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279389] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13080), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13082), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279417] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13086), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13088), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279445] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13248), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13250), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279473] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13037), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(13039), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279501] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12896), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(12898), 15,
      sym_test_operator,
      sym_extglob_pattern,
      sym__brace_start,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279529] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1306), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [279556] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13252), 1,
      sym__special_character,
    STATE(5431), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5687), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5689), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [279587] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1278), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [279614] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4437), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4439), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [279641] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2162), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [279668] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 5,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LPAREN,
      sym_word,
    ACTIONS(1225), 14,
      sym_test_operator,
      sym__brace_start,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
  [279695] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13254), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(7205), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [279734] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1225), 12,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [279761] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5847), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12894), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5845), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [279798] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13252), 1,
      sym__special_character,
    STATE(5431), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5563), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [279829] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [279862] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4311), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4313), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [279889] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5852), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12894), 1,
      sym_file_descriptor,
    ACTIONS(4529), 2,
      anon_sym_LT_LT,
      anon_sym_LT_LT_DASH,
    ACTIONS(5845), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12672), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12670), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [279926] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13260), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6960), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [279965] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13262), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6965), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [280004] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1284), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1286), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280031] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1213), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1215), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280058] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13264), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(7417), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [280097] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1252), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1254), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280124] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1312), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1314), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280151] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1256), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1258), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280178] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1308), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1310), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280205] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13266), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(7420), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [280244] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 8,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      sym__special_character,
    ACTIONS(1225), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [280271] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1298), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280298] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1260), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1262), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280325] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1268), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1270), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280352] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13268), 1,
      sym__special_character,
    STATE(5431), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1318), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [280383] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(12902), 1,
      anon_sym_LPAREN,
    ACTIONS(12906), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(12908), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(12912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12916), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12918), 1,
      anon_sym_BQUOTE,
    ACTIONS(12920), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13271), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13273), 1,
      anon_sym_RBRACE3,
    ACTIONS(13275), 1,
      aux_sym__simple_variable_name_token1,
    STATE(6205), 1,
      sym_number,
    STATE(6216), 1,
      sym_expansion,
    STATE(6249), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6323), 1,
      sym__expansion_max_length_expression,
    STATE(6707), 1,
      sym_parenthesized_expression,
    STATE(6749), 1,
      sym_arithmetic_expansion,
    STATE(7028), 1,
      sym_command_substitution,
  [280444] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2158), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [280471] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13252), 1,
      sym__special_character,
    STATE(5431), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4282), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [280502] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13277), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(7146), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [280541] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13279), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(7160), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [280580] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1290), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280607] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1225), 12,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [280634] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280661] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1264), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1266), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280688] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5443), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12222), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13281), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12218), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [280719] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1302), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280746] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5443), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12136), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13283), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(12131), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [280777] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13252), 1,
      sym__special_character,
    STATE(5431), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4307), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4309), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [280808] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13286), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(7309), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [280847] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13288), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(7342), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [280886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12744), 3,
      sym_test_operator,
      sym__brace_start,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(12742), 16,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      sym__special_character,
      anon_sym_DQUOTE,
      sym_raw_string,
      sym_ansi_c_string,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      anon_sym_LT_LPAREN,
      anon_sym_GT_LPAREN,
      sym_word,
  [280913] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1272), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1274), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280940] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1294), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280967] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1280), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1282), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [280994] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(3578), 1,
      sym_file_descriptor,
    ACTIONS(13290), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6991), 1,
      sym__heredoc_expression,
    ACTIONS(3542), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(3548), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(3546), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [281033] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(12902), 1,
      anon_sym_LPAREN,
    ACTIONS(12906), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(12908), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(12912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12916), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12918), 1,
      anon_sym_BQUOTE,
    ACTIONS(12920), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13292), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13294), 1,
      anon_sym_RBRACE3,
    ACTIONS(13296), 1,
      aux_sym__simple_variable_name_token1,
    STATE(6165), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6323), 1,
      sym__expansion_max_length_expression,
    STATE(6157), 2,
      sym_number,
      sym_expansion,
    STATE(7092), 3,
      sym_parenthesized_expression,
      sym_arithmetic_expansion,
      sym_command_substitution,
  [281088] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1248), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1250), 12,
      sym_file_descriptor,
      sym__concat,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      aux_sym_concatenation_token1,
  [281115] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(12902), 1,
      anon_sym_LPAREN,
    ACTIONS(12906), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(12908), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(12912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12916), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12918), 1,
      anon_sym_BQUOTE,
    ACTIONS(12920), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13298), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13300), 1,
      anon_sym_RBRACE3,
    ACTIONS(13302), 1,
      aux_sym__simple_variable_name_token1,
    STATE(6161), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6323), 1,
      sym__expansion_max_length_expression,
    STATE(6159), 2,
      sym_number,
      sym_expansion,
    STATE(7163), 3,
      sym_parenthesized_expression,
      sym_arithmetic_expansion,
      sym_command_substitution,
  [281170] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12411), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12409), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281196] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12186), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12184), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [281222] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11679), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13310), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(13313), 1,
      sym_file_descriptor,
    ACTIONS(11671), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13307), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    STATE(5457), 3,
      sym_file_redirect,
      sym_herestring_redirect,
      aux_sym_redirected_statement_repeat2,
    ACTIONS(13304), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
  [281258] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4529), 1,
      anon_sym_LT_LT,
    ACTIONS(12109), 1,
      sym_file_descriptor,
    ACTIONS(13322), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13316), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13320), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13318), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(4669), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11798), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [281296] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12453), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12451), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281322] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12553), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12555), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281348] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2158), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281374] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13324), 1,
      sym__concat,
    STATE(5483), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1207), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [281406] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12234), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12232), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [281432] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2162), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281458] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12295), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12297), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281484] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12637), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12639), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281510] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12641), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12643), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281536] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12353), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12351), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281562] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12375), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12373), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281588] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12375), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12373), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281614] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12395), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12397), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281640] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12395), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12397), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281666] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12489), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12487), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281692] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12115), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12113), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [281718] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12434), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12436), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281744] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12509), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12511), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281770] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12509), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12511), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281796] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12537), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12539), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281822] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12537), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12539), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281848] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12426), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12424), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281874] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12426), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12424), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [281900] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2158), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [281926] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13326), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13329), 1,
      sym__concat,
    STATE(5483), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [281958] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12105), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12107), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [281984] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12230), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12228), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282010] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [282042] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12349), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12347), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [282068] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12349), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12347), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [282094] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5462), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [282126] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13334), 6,
      anon_sym_DASH2,
      anon_sym_PLUS2,
      anon_sym_DOLLAR,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym__simple_variable_name_token1,
    ACTIONS(13332), 12,
      sym_variable_name,
      anon_sym_LPAREN,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS2,
      anon_sym_DASH_DASH2,
      anon_sym_TILDE,
      anon_sym_DQUOTE,
      sym_raw_string,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [282152] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13219), 1,
      anon_sym_LT_LT,
    ACTIONS(13221), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13223), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13156), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13154), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5381), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(13152), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [282190] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(1225), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      sym__special_character,
  [282216] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12178), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12180), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282242] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13338), 1,
      anon_sym_DQUOTE,
    ACTIONS(13342), 1,
      sym_variable_name,
    STATE(6110), 1,
      sym_string,
    ACTIONS(13340), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1195), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13336), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [282276] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5705), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5707), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [282302] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [282334] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12244), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12242), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282360] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5462), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [282392] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13338), 1,
      anon_sym_DQUOTE,
    ACTIONS(13342), 1,
      sym_variable_name,
    STATE(6110), 1,
      sym_string,
    ACTIONS(13340), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1183), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(13336), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [282426] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4529), 1,
      anon_sym_LT_LT,
    ACTIONS(12894), 1,
      sym_file_descriptor,
    ACTIONS(13322), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13344), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13348), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13346), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5163), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12670), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [282464] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4529), 1,
      anon_sym_LT_LT,
    ACTIONS(12226), 1,
      sym_file_descriptor,
    ACTIONS(13322), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13350), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13354), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13352), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(4612), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11896), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [282502] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4437), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4439), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [282528] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [282560] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4311), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4313), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282586] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4311), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4313), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_RBRACK,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [282612] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2162), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282638] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5268), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5270), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [282664] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12279), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12281), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282690] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12133), 1,
      anon_sym_PIPE,
    ACTIONS(13356), 1,
      anon_sym_PIPE_AMP,
    STATE(5516), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12131), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12136), 9,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [282722] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4173), 1,
      anon_sym_LT_LT,
    ACTIONS(11775), 1,
      sym_file_descriptor,
    ACTIONS(13365), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13359), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13363), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13361), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(4182), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(10930), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [282760] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12142), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12140), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282786] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4529), 1,
      anon_sym_LT_LT,
    ACTIONS(12432), 1,
      sym_file_descriptor,
    ACTIONS(13322), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13367), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13371), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13369), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(4731), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11949), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [282824] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5462), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [282856] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12212), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12210), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282882] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12206), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12208), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [282908] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13373), 1,
      anon_sym_PIPE,
    ACTIONS(13375), 1,
      anon_sym_PIPE_AMP,
    STATE(5518), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12218), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12222), 9,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [282940] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5925), 1,
      anon_sym_LT_LT,
    ACTIONS(5927), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(12930), 1,
      sym_file_descriptor,
    ACTIONS(5923), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(12856), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(12854), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(5131), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(12852), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [282978] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13377), 1,
      anon_sym_PIPE,
    ACTIONS(13380), 1,
      anon_sym_PIPE_AMP,
    STATE(5518), 1,
      aux_sym_pipeline_repeat1,
    ACTIONS(12131), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12136), 9,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283010] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4294), 1,
      anon_sym_LT_LT,
    ACTIONS(11978), 1,
      sym_file_descriptor,
    ACTIONS(13389), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13383), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13387), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13385), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(4358), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11663), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [283048] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4529), 1,
      anon_sym_LT_LT,
    ACTIONS(12202), 1,
      sym_file_descriptor,
    ACTIONS(13322), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(13391), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(13395), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(13393), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    STATE(4645), 3,
      sym_file_redirect,
      sym_heredoc_redirect,
      aux_sym_redirected_statement_repeat1,
    ACTIONS(11835), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [283086] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4437), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4439), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [283112] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5886), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5888), 11,
      sym_file_descriptor,
      sym_variable_name,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283138] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12129), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12127), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [283164] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5527), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [283196] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13258), 1,
      sym__concat,
    STATE(5462), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [283228] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12123), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12121), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [283254] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13256), 1,
      aux_sym_concatenation_token1,
    ACTIONS(13397), 1,
      sym__concat,
    STATE(5483), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1227), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [283286] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12103), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12101), 11,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_LT_LT_LT,
  [283312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [283337] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12531), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12533), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283362] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [283387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [283412] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12142), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12140), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283437] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [283462] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12363), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12361), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283487] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12416), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12418), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283512] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12363), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12361), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283537] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12123), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12121), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283562] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12457), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12455), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283587] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12105), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12107), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [283637] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12391), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12393), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283662] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4437), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4439), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283687] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12416), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12418), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283712] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [283737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [283762] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12395), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12397), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283787] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12503), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12505), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283812] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12525), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12527), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283837] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12349), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12347), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283862] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12489), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12487), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283887] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13399), 1,
      sym__special_character,
    STATE(5552), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1316), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [283916] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12395), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12397), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283941] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12509), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12511), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [283966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [283991] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [284016] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [284041] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13402), 1,
      sym__special_character,
    STATE(5552), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5563), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5561), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [284070] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [284095] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12178), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12180), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284120] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [284145] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12453), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12451), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284170] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12279), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12281), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284195] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12537), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12539), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284220] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12295), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12297), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284245] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12537), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12539), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284270] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5856), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5858), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284295] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12495), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12497), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284320] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12521), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12519), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284345] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12387), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12385), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284370] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [284395] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [284420] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12434), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12436), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284445] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12637), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12639), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284470] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12591), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12593), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284495] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12230), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12228), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284520] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12509), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12511), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284545] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12641), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12643), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284570] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12244), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12242), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284595] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12355), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12357), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284620] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4311), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(4313), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284645] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12411), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12409), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284670] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12553), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12555), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284695] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5856), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(5858), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284720] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12597), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12599), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284745] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12353), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12351), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284770] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12103), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12101), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284795] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12375), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12373), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284820] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2160), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2162), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284845] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12343), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12341), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284870] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12403), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12401), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284895] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12426), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12424), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284920] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12577), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12579), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284945] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2156), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(2158), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [284970] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13402), 1,
      sym__special_character,
    STATE(5552), 1,
      aux_sym__literal_repeat1,
    ACTIONS(5689), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(5687), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [284999] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13402), 1,
      sym__special_character,
    STATE(5552), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4282), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4280), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [285028] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12491), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12493), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [285053] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [285078] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12499), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12501), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [285103] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13402), 1,
      sym__special_character,
    STATE(5552), 1,
      aux_sym__literal_repeat1,
    ACTIONS(4309), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4307), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [285132] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12561), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12559), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [285157] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12426), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12424), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [285182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [285207] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12349), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12347), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [285232] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12375), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12373), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [285257] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [285282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [285307] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12212), 7,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_LT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
    ACTIONS(12210), 10,
      sym_file_descriptor,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_GT,
      anon_sym_PIPE_AMP,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_DASH,
  [285332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 3,
      sym_file_descriptor,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      aux_sym_concatenation_token1,
  [285357] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
      sym__special_character,
  [285381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4313), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4311), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [285404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2156), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [285427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(2160), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [285450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4439), 2,
      sym_file_descriptor,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(4437), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_AMP_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
      anon_sym_GT_PIPE,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
      anon_sym_LT_LT_LT,
  [285473] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(13408), 1,
      sym_variable_name,
    STATE(6445), 1,
      sym_string,
    ACTIONS(1183), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
    ACTIONS(13406), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(13404), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [285504] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13414), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(13416), 1,
      sym_variable_name,
    ACTIONS(13412), 2,
      anon_sym_DOLLAR,
      anon_sym__,
    STATE(6305), 2,
      sym_subscript,
      sym_command_substitution,
    ACTIONS(13410), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_POUND,
      anon_sym_AT2,
  [285539] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(13408), 1,
      sym_variable_name,
    STATE(6445), 1,
      sym_string,
    ACTIONS(1195), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
    ACTIONS(13406), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(13404), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [285570] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12331), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12333), 1,
      anon_sym_BQUOTE,
    ACTIONS(12335), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13422), 1,
      aux_sym__simple_variable_name_token1,
    ACTIONS(13424), 1,
      sym_variable_name,
    STATE(3378), 1,
      sym_subscript,
    STATE(6305), 1,
      sym_command_substitution,
    ACTIONS(13420), 2,
      anon_sym_DOLLAR,
      anon_sym__,
    ACTIONS(13418), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_POUND,
      anon_sym_AT2,
  [285607] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13430), 1,
      anon_sym_DOLLAR,
    ACTIONS(13432), 1,
      anon_sym_DQUOTE,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285647] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13444), 1,
      anon_sym_DOLLAR,
    ACTIONS(13446), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285687] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13448), 1,
      anon_sym_DOLLAR,
    ACTIONS(13450), 1,
      anon_sym_DQUOTE,
    STATE(5622), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285727] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13452), 1,
      anon_sym_DOLLAR,
    ACTIONS(13454), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285767] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13456), 1,
      anon_sym_DOLLAR,
    ACTIONS(13458), 1,
      anon_sym_DQUOTE,
    STATE(5626), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285807] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13460), 1,
      anon_sym_DOLLAR,
    ACTIONS(13462), 1,
      anon_sym_DQUOTE,
    STATE(5641), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285847] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13464), 1,
      anon_sym_DOLLAR,
    ACTIONS(13466), 1,
      anon_sym_DQUOTE,
    STATE(5653), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285887] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13468), 1,
      anon_sym_DOLLAR,
    ACTIONS(13470), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285927] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13472), 1,
      anon_sym_DOLLAR,
    ACTIONS(13474), 1,
      anon_sym_DQUOTE,
    STATE(5628), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [285967] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13476), 1,
      anon_sym_DOLLAR,
    ACTIONS(13478), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286007] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13480), 1,
      anon_sym_DOLLAR,
    ACTIONS(13482), 1,
      anon_sym_DQUOTE,
    STATE(5630), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286047] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13484), 1,
      anon_sym_DOLLAR,
    ACTIONS(13486), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286087] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13488), 1,
      anon_sym_DOLLAR,
    ACTIONS(13490), 1,
      anon_sym_DQUOTE,
    STATE(5632), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286127] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13492), 1,
      anon_sym_DOLLAR,
    ACTIONS(13494), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286167] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13496), 1,
      anon_sym_DOLLAR,
    ACTIONS(13498), 1,
      anon_sym_DQUOTE,
    STATE(5634), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286207] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13500), 1,
      anon_sym_DOLLAR,
    ACTIONS(13502), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286247] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13504), 1,
      anon_sym_DOLLAR,
    ACTIONS(13506), 1,
      anon_sym_DQUOTE,
    STATE(5637), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286287] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13508), 1,
      anon_sym_DOLLAR,
    ACTIONS(13510), 1,
      anon_sym_DQUOTE,
    STATE(5654), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286327] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13512), 1,
      anon_sym_DOLLAR,
    ACTIONS(13514), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286367] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13516), 1,
      anon_sym_DOLLAR,
    ACTIONS(13518), 1,
      anon_sym_DQUOTE,
    STATE(5639), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286407] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13520), 1,
      anon_sym_DOLLAR,
    ACTIONS(13522), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286447] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13524), 1,
      anon_sym_DOLLAR,
    ACTIONS(13526), 1,
      anon_sym_DQUOTE,
    STATE(5642), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286487] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13528), 1,
      anon_sym_DOLLAR,
    ACTIONS(13530), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286527] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13532), 1,
      anon_sym_DOLLAR,
    ACTIONS(13534), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286567] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13536), 1,
      anon_sym_DOLLAR,
    ACTIONS(13538), 1,
      anon_sym_DQUOTE,
    STATE(5644), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286607] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13540), 1,
      anon_sym_DOLLAR,
    ACTIONS(13542), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286647] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13544), 1,
      anon_sym_DOLLAR,
    ACTIONS(13546), 1,
      anon_sym_DQUOTE,
    STATE(5646), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286687] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13548), 1,
      anon_sym_DOLLAR,
    ACTIONS(13550), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286727] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13552), 1,
      anon_sym_DOLLAR,
    ACTIONS(13554), 1,
      anon_sym_DQUOTE,
    STATE(5619), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286767] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13556), 1,
      anon_sym_DOLLAR,
    ACTIONS(13558), 1,
      anon_sym_DQUOTE,
    STATE(5649), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286807] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13560), 1,
      anon_sym_DOLLAR,
    ACTIONS(13562), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286847] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13564), 1,
      anon_sym_DOLLAR,
    ACTIONS(13566), 1,
      anon_sym_DQUOTE,
    STATE(5651), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286887] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13568), 1,
      anon_sym_DOLLAR,
    ACTIONS(13570), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286927] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13572), 1,
      anon_sym_DOLLAR,
    ACTIONS(13574), 1,
      anon_sym_DQUOTE,
    STATE(5655), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [286967] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13576), 1,
      anon_sym_DOLLAR,
    ACTIONS(13578), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287007] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13580), 1,
      anon_sym_DOLLAR,
    ACTIONS(13582), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287047] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13584), 1,
      anon_sym_DOLLAR,
    ACTIONS(13586), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287087] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13588), 1,
      anon_sym_DOLLAR,
    ACTIONS(13590), 1,
      anon_sym_DQUOTE,
    STATE(5657), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287127] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13592), 1,
      anon_sym_DOLLAR,
    ACTIONS(13594), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287167] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13596), 1,
      anon_sym_DOLLAR,
    ACTIONS(13598), 1,
      anon_sym_DQUOTE,
    STATE(5671), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287207] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13600), 1,
      anon_sym_DOLLAR,
    ACTIONS(13602), 1,
      anon_sym_DQUOTE,
    STATE(5661), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287247] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13604), 1,
      anon_sym_DOLLAR,
    ACTIONS(13606), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287287] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13608), 1,
      anon_sym_DOLLAR,
    ACTIONS(13610), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287327] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13612), 1,
      anon_sym_DOLLAR,
    ACTIONS(13614), 1,
      anon_sym_DQUOTE,
    STATE(5668), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287367] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13616), 1,
      anon_sym_DOLLAR,
    ACTIONS(13618), 1,
      anon_sym_DQUOTE,
    STATE(5664), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287407] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13620), 1,
      anon_sym_DOLLAR,
    ACTIONS(13622), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287447] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13624), 1,
      anon_sym_DOLLAR,
    ACTIONS(13626), 1,
      anon_sym_DQUOTE,
    STATE(5666), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287487] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13628), 1,
      anon_sym_DOLLAR,
    ACTIONS(13630), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287527] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13632), 1,
      anon_sym_DOLLAR,
    ACTIONS(13634), 1,
      anon_sym_DQUOTE,
    STATE(5669), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287567] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13636), 1,
      anon_sym_DOLLAR,
    ACTIONS(13638), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287607] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13640), 1,
      anon_sym_DOLLAR,
    ACTIONS(13642), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287647] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13644), 1,
      anon_sym_DOLLAR,
    ACTIONS(13646), 1,
      anon_sym_DQUOTE,
    STATE(5672), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287687] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13648), 1,
      anon_sym_DOLLAR,
    ACTIONS(13650), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287727] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13652), 1,
      anon_sym_DOLLAR,
    ACTIONS(13654), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287767] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13656), 1,
      anon_sym_DOLLAR,
    ACTIONS(13658), 1,
      anon_sym_DQUOTE,
    STATE(5674), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287807] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13660), 1,
      anon_sym_DOLLAR,
    ACTIONS(13662), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287847] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13664), 1,
      anon_sym_DOLLAR,
    ACTIONS(13666), 1,
      anon_sym_DQUOTE,
    STATE(5686), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287887] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13668), 1,
      anon_sym_DOLLAR,
    ACTIONS(13670), 1,
      anon_sym_DQUOTE,
    STATE(5677), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287927] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13672), 1,
      anon_sym_DOLLAR,
    ACTIONS(13674), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [287967] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13676), 1,
      anon_sym_DOLLAR,
    ACTIONS(13678), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288007] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13680), 1,
      anon_sym_DOLLAR,
    ACTIONS(13682), 1,
      anon_sym_DQUOTE,
    STATE(5680), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288047] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13684), 1,
      anon_sym_DOLLAR,
    ACTIONS(13686), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288087] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13688), 1,
      anon_sym_DOLLAR,
    ACTIONS(13690), 1,
      anon_sym_DQUOTE,
    STATE(5682), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288127] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13692), 1,
      anon_sym_DOLLAR,
    ACTIONS(13694), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288167] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13696), 1,
      anon_sym_DOLLAR,
    ACTIONS(13698), 1,
      anon_sym_DQUOTE,
    STATE(5684), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288207] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13700), 1,
      anon_sym_DOLLAR,
    ACTIONS(13702), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288247] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13704), 1,
      anon_sym_DOLLAR,
    ACTIONS(13706), 1,
      anon_sym_DQUOTE,
    STATE(5687), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288287] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13708), 1,
      anon_sym_DOLLAR,
    ACTIONS(13710), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288327] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13712), 1,
      anon_sym_DOLLAR,
    ACTIONS(13714), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288367] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13716), 1,
      anon_sym_DOLLAR,
    ACTIONS(13718), 1,
      anon_sym_DQUOTE,
    STATE(5690), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288407] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13720), 1,
      anon_sym_DOLLAR,
    ACTIONS(13722), 1,
      anon_sym_DQUOTE,
    STATE(5759), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288447] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13724), 1,
      anon_sym_DOLLAR,
    ACTIONS(13726), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288487] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13728), 1,
      anon_sym_DOLLAR,
    ACTIONS(13730), 1,
      anon_sym_DQUOTE,
    STATE(5705), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288527] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13732), 1,
      anon_sym_DOLLAR,
    ACTIONS(13734), 1,
      anon_sym_DQUOTE,
    STATE(5694), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288567] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13736), 1,
      anon_sym_DOLLAR,
    ACTIONS(13738), 1,
      anon_sym_DQUOTE,
    STATE(5697), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288607] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13740), 1,
      anon_sym_DOLLAR,
    ACTIONS(13742), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288647] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13744), 1,
      anon_sym_DOLLAR,
    ACTIONS(13746), 1,
      anon_sym_DQUOTE,
    STATE(5696), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288687] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13748), 1,
      anon_sym_DOLLAR,
    ACTIONS(13750), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288727] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13752), 1,
      anon_sym_DOLLAR,
    ACTIONS(13754), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288767] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13756), 1,
      anon_sym_DOLLAR,
    ACTIONS(13758), 1,
      anon_sym_DQUOTE,
    STATE(5699), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288807] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13760), 1,
      anon_sym_DOLLAR,
    ACTIONS(13762), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288847] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13764), 1,
      anon_sym_DOLLAR,
    ACTIONS(13766), 1,
      anon_sym_DQUOTE,
    STATE(5702), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288887] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13768), 1,
      anon_sym_DOLLAR,
    ACTIONS(13770), 1,
      anon_sym_DQUOTE,
    STATE(5725), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288927] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13772), 1,
      anon_sym_DOLLAR,
    ACTIONS(13774), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [288967] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13776), 1,
      anon_sym_DOLLAR,
    ACTIONS(13778), 1,
      anon_sym_DQUOTE,
    STATE(5620), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289007] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13780), 1,
      anon_sym_DOLLAR,
    ACTIONS(13782), 1,
      anon_sym_DQUOTE,
    STATE(5706), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289047] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13784), 1,
      anon_sym_DOLLAR,
    ACTIONS(13786), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289087] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13788), 1,
      anon_sym_DOLLAR,
    ACTIONS(13790), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289127] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13792), 1,
      anon_sym_DOLLAR,
    ACTIONS(13794), 1,
      anon_sym_DQUOTE,
    STATE(5708), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289167] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13796), 1,
      anon_sym_DOLLAR,
    ACTIONS(13798), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289207] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13800), 1,
      anon_sym_DOLLAR,
    ACTIONS(13802), 1,
      anon_sym_DQUOTE,
    STATE(5710), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289247] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13804), 1,
      anon_sym_DOLLAR,
    ACTIONS(13806), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289287] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13808), 1,
      anon_sym_DOLLAR,
    ACTIONS(13810), 1,
      anon_sym_DQUOTE,
    STATE(5716), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289327] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13812), 1,
      anon_sym_DOLLAR,
    ACTIONS(13814), 1,
      anon_sym_DQUOTE,
    STATE(5713), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289367] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13816), 1,
      anon_sym_DOLLAR,
    ACTIONS(13818), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289407] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13820), 1,
      anon_sym_DOLLAR,
    ACTIONS(13822), 1,
      anon_sym_DQUOTE,
    STATE(5715), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289447] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13824), 1,
      anon_sym_DOLLAR,
    ACTIONS(13826), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289487] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13828), 1,
      anon_sym_DOLLAR,
    ACTIONS(13830), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289527] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13832), 1,
      anon_sym_DOLLAR,
    ACTIONS(13834), 1,
      anon_sym_DQUOTE,
    STATE(5719), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289567] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13836), 1,
      anon_sym_DOLLAR,
    ACTIONS(13838), 1,
      anon_sym_DQUOTE,
    STATE(5721), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289607] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13840), 1,
      anon_sym_DOLLAR,
    ACTIONS(13842), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289647] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13844), 1,
      anon_sym_DOLLAR,
    ACTIONS(13846), 1,
      anon_sym_DQUOTE,
    STATE(5723), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289687] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13848), 1,
      anon_sym_DOLLAR,
    ACTIONS(13850), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289727] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13852), 1,
      anon_sym_DOLLAR,
    ACTIONS(13854), 1,
      anon_sym_DQUOTE,
    STATE(5727), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289767] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13856), 1,
      anon_sym_DOLLAR,
    ACTIONS(13858), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289807] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13860), 1,
      anon_sym_DOLLAR,
    ACTIONS(13862), 1,
      anon_sym_DQUOTE,
    STATE(5726), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289847] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13864), 1,
      anon_sym_DOLLAR,
    ACTIONS(13866), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289887] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13868), 1,
      anon_sym_DOLLAR,
    ACTIONS(13870), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289927] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13872), 1,
      anon_sym_DOLLAR,
    ACTIONS(13874), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [289967] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13876), 1,
      anon_sym_DOLLAR,
    ACTIONS(13878), 1,
      anon_sym_DQUOTE,
    STATE(5729), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290007] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13880), 1,
      anon_sym_DOLLAR,
    ACTIONS(13882), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290047] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13884), 1,
      anon_sym_DOLLAR,
    ACTIONS(13886), 1,
      anon_sym_DQUOTE,
    STATE(5731), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290087] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13888), 1,
      anon_sym_DOLLAR,
    ACTIONS(13890), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290127] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13892), 1,
      anon_sym_DOLLAR,
    ACTIONS(13894), 1,
      anon_sym_DQUOTE,
    STATE(5733), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290167] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13896), 1,
      anon_sym_DOLLAR,
    ACTIONS(13898), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290207] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13900), 1,
      anon_sym_DOLLAR,
    ACTIONS(13902), 1,
      anon_sym_DQUOTE,
    STATE(5735), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290247] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13904), 1,
      anon_sym_DOLLAR,
    ACTIONS(13906), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290287] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13908), 1,
      anon_sym_DOLLAR,
    ACTIONS(13910), 1,
      anon_sym_DQUOTE,
    STATE(5738), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290327] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13912), 1,
      anon_sym_DOLLAR,
    ACTIONS(13914), 1,
      anon_sym_DQUOTE,
    STATE(5740), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290367] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13916), 1,
      anon_sym_DOLLAR,
    ACTIONS(13918), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290407] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13920), 1,
      anon_sym_DOLLAR,
    ACTIONS(13922), 1,
      anon_sym_DQUOTE,
    STATE(5752), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290447] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13924), 1,
      anon_sym_DOLLAR,
    ACTIONS(13926), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290487] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13928), 1,
      anon_sym_DOLLAR,
    ACTIONS(13930), 1,
      anon_sym_DQUOTE,
    STATE(5742), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290527] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13932), 1,
      anon_sym_DOLLAR,
    ACTIONS(13934), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290567] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13936), 1,
      anon_sym_DOLLAR,
    ACTIONS(13938), 1,
      anon_sym_DQUOTE,
    STATE(5746), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290607] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13940), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13943), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13946), 1,
      anon_sym_DOLLAR,
    ACTIONS(13949), 1,
      anon_sym_DQUOTE,
    ACTIONS(13951), 1,
      sym_string_content,
    ACTIONS(13954), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13957), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13960), 1,
      anon_sym_BQUOTE,
    ACTIONS(13963), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290647] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13966), 1,
      anon_sym_DOLLAR,
    ACTIONS(13968), 1,
      anon_sym_DQUOTE,
    STATE(5748), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290687] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13970), 1,
      anon_sym_DOLLAR,
    ACTIONS(13972), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290727] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13974), 1,
      anon_sym_DOLLAR,
    ACTIONS(13976), 1,
      anon_sym_DQUOTE,
    STATE(5750), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290767] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13978), 1,
      anon_sym_DOLLAR,
    ACTIONS(13980), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290807] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13982), 1,
      anon_sym_DOLLAR,
    ACTIONS(13984), 1,
      anon_sym_DQUOTE,
    STATE(5768), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290847] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13986), 1,
      anon_sym_DOLLAR,
    ACTIONS(13988), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290887] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13990), 1,
      anon_sym_DOLLAR,
    ACTIONS(13992), 1,
      anon_sym_DQUOTE,
    STATE(5754), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290927] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13994), 1,
      anon_sym_DOLLAR,
    ACTIONS(13996), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [290967] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(13998), 1,
      anon_sym_DOLLAR,
    ACTIONS(14000), 1,
      anon_sym_DQUOTE,
    STATE(5756), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291007] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14002), 1,
      anon_sym_DOLLAR,
    ACTIONS(14004), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291047] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14006), 1,
      anon_sym_DOLLAR,
    ACTIONS(14008), 1,
      anon_sym_DQUOTE,
    STATE(5757), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291087] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14010), 1,
      anon_sym_DOLLAR,
    ACTIONS(14012), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291127] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14014), 1,
      anon_sym_DOLLAR,
    ACTIONS(14016), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291167] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14018), 1,
      anon_sym_DOLLAR,
    ACTIONS(14020), 1,
      anon_sym_DQUOTE,
    STATE(5761), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291207] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14022), 1,
      anon_sym_DOLLAR,
    ACTIONS(14024), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291247] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14026), 1,
      anon_sym_DOLLAR,
    ACTIONS(14028), 1,
      anon_sym_DQUOTE,
    STATE(5764), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291287] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14030), 1,
      anon_sym_DOLLAR,
    ACTIONS(14032), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291327] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14034), 1,
      anon_sym_DOLLAR,
    ACTIONS(14036), 1,
      anon_sym_DQUOTE,
    STATE(5771), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291367] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14038), 1,
      anon_sym_DOLLAR,
    ACTIONS(14040), 1,
      anon_sym_DQUOTE,
    STATE(5765), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291407] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14042), 1,
      anon_sym_DOLLAR,
    ACTIONS(14044), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291447] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14046), 1,
      anon_sym_DOLLAR,
    ACTIONS(14048), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291487] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14050), 1,
      anon_sym_DOLLAR,
    ACTIONS(14052), 1,
      anon_sym_DQUOTE,
    STATE(5767), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291527] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14054), 1,
      anon_sym_DOLLAR,
    ACTIONS(14056), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291567] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14058), 1,
      anon_sym_DOLLAR,
    ACTIONS(14060), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291607] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14062), 1,
      anon_sym_DOLLAR,
    ACTIONS(14064), 1,
      anon_sym_DQUOTE,
    STATE(5770), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291647] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14066), 1,
      anon_sym_DOLLAR,
    ACTIONS(14068), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291687] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14070), 1,
      anon_sym_DOLLAR,
    ACTIONS(14072), 1,
      anon_sym_DQUOTE,
    STATE(5744), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291727] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14074), 1,
      anon_sym_DOLLAR,
    ACTIONS(14076), 1,
      anon_sym_DQUOTE,
    STATE(5660), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291767] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 1,
      anon_sym_DOLLAR_LPAREN_LPAREN,
    ACTIONS(13428), 1,
      anon_sym_DOLLAR_LBRACK,
    ACTIONS(13434), 1,
      sym_string_content,
    ACTIONS(13436), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(13438), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(13440), 1,
      anon_sym_BQUOTE,
    ACTIONS(13442), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14078), 1,
      anon_sym_DOLLAR,
    ACTIONS(14080), 1,
      anon_sym_DQUOTE,
    STATE(5678), 1,
      aux_sym_string_repeat1,
    STATE(6063), 4,
      sym_arithmetic_expansion,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
  [291807] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13502), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [291834] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13494), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [291861] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14090), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [291888] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9622), 1,
      anon_sym_DQUOTE,
    ACTIONS(9626), 1,
      sym_variable_name,
    STATE(5125), 1,
      sym_string,
    ACTIONS(9624), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9620), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [291915] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14102), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14098), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14096), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14092), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [291944] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13622), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [291971] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14104), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [291998] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3562), 1,
      anon_sym_DQUOTE,
    ACTIONS(8294), 1,
      sym_variable_name,
    STATE(4874), 1,
      sym_string,
    ACTIONS(8292), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(8290), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292025] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14106), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292052] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13630), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292079] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13454), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292106] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14114), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14112), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14110), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14108), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [292135] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14116), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292162] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13638), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292189] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3642), 1,
      anon_sym_DQUOTE,
    ACTIONS(3980), 1,
      sym_variable_name,
    STATE(1912), 1,
      sym_string,
    ACTIONS(3978), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3976), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292216] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13642), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292243] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13606), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292270] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13650), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292297] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14118), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292324] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3014), 1,
      anon_sym_DQUOTE,
    ACTIONS(3817), 1,
      sym_variable_name,
    STATE(1777), 1,
      sym_string,
    ACTIONS(3815), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3813), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292351] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14120), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292378] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14122), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292405] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14124), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292432] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14132), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14130), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14128), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14126), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [292461] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13654), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292488] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3598), 1,
      anon_sym_DQUOTE,
    ACTIONS(4054), 1,
      sym_variable_name,
    STATE(1986), 1,
      sym_string,
    ACTIONS(4052), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4050), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292515] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14134), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292542] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6394), 1,
      anon_sym_DQUOTE,
    ACTIONS(13408), 1,
      sym_variable_name,
    STATE(6445), 1,
      sym_string,
    ACTIONS(13406), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(13404), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292569] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13662), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292596] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14136), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292623] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4621), 1,
      anon_sym_DQUOTE,
    ACTIONS(4625), 1,
      sym_variable_name,
    STATE(2404), 1,
      sym_string,
    ACTIONS(4623), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4619), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292650] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14138), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292677] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13514), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292704] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5194), 1,
      anon_sym_DQUOTE,
    ACTIONS(5198), 1,
      sym_variable_name,
    STATE(2456), 1,
      sym_string,
    ACTIONS(5196), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(5192), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292731] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13446), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292758] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13674), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292785] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14140), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292812] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14142), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292839] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4947), 1,
      anon_sym_DQUOTE,
    ACTIONS(4951), 1,
      sym_variable_name,
    STATE(2777), 1,
      sym_string,
    ACTIONS(4949), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4945), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292866] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13686), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292893] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14144), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292920] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9610), 1,
      anon_sym_DQUOTE,
    ACTIONS(9614), 1,
      sym_variable_name,
    STATE(5321), 1,
      sym_string,
    ACTIONS(9612), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9608), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292947] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13522), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [292974] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13694), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293001] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14146), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293028] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14148), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293055] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4759), 1,
      anon_sym_DQUOTE,
    ACTIONS(4763), 1,
      sym_variable_name,
    STATE(2498), 1,
      sym_string,
    ACTIONS(4761), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4757), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293082] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13530), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293109] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13702), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293136] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14150), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293163] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14152), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293190] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13710), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293217] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8452), 1,
      anon_sym_DQUOTE,
    ACTIONS(8456), 1,
      sym_variable_name,
    STATE(5176), 1,
      sym_string,
    ACTIONS(8454), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(8450), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293244] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13714), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293271] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13534), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293298] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14154), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293325] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      anon_sym_DQUOTE,
    ACTIONS(2263), 1,
      sym_variable_name,
    STATE(1246), 1,
      sym_string,
    ACTIONS(2261), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(2259), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293352] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7591), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym_variable_name,
    STATE(4267), 1,
      sym_string,
    ACTIONS(7593), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7589), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293379] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13470), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293406] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14156), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293433] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13726), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293460] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14158), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293487] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1187), 1,
      anon_sym_DQUOTE,
    ACTIONS(1193), 1,
      sym_variable_name,
    STATE(470), 1,
      sym_string,
    ACTIONS(1189), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1185), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293514] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14160), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293541] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14162), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293568] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9998), 1,
      anon_sym_DQUOTE,
    ACTIONS(10002), 1,
      sym_variable_name,
    STATE(5275), 1,
      sym_string,
    ACTIONS(10000), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9996), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293595] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14164), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293622] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      anon_sym_DQUOTE,
    ACTIONS(4145), 1,
      sym_variable_name,
    STATE(1694), 1,
      sym_string,
    ACTIONS(4143), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4141), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293649] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3620), 1,
      anon_sym_DQUOTE,
    ACTIONS(3624), 1,
      sym_variable_name,
    STATE(1625), 1,
      sym_string,
    ACTIONS(3622), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3618), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293676] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13542), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293703] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13742), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293730] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14166), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293757] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14170), 1,
      anon_sym_DQUOTE,
    ACTIONS(14174), 1,
      sym_variable_name,
    STATE(6671), 1,
      sym_string,
    ACTIONS(14172), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14168), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293784] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13750), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293811] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14176), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293838] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14178), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293865] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5629), 1,
      anon_sym_DQUOTE,
    ACTIONS(5713), 1,
      sym_variable_name,
    STATE(3346), 1,
      sym_string,
    ACTIONS(5711), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(5709), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293892] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2099), 1,
      anon_sym_DQUOTE,
    ACTIONS(2103), 1,
      sym_variable_name,
    STATE(1087), 1,
      sym_string,
    ACTIONS(2101), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(2097), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293919] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13754), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293946] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14180), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [293973] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14188), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14186), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14184), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14182), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [294002] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13762), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294029] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13550), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294056] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14190), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294083] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 1,
      anon_sym_DQUOTE,
    ACTIONS(11749), 1,
      sym_variable_name,
    STATE(5555), 1,
      sym_string,
    ACTIONS(11747), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(11745), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294110] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7484), 1,
      anon_sym_DQUOTE,
    ACTIONS(7488), 1,
      sym_variable_name,
    STATE(4380), 1,
      sym_string,
    ACTIONS(7486), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7482), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294137] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13578), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294164] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13678), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294191] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13774), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294218] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14192), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294245] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14194), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294272] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14196), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294299] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 1,
      anon_sym_DQUOTE,
    ACTIONS(1682), 1,
      sym_variable_name,
    STATE(857), 1,
      sym_string,
    ACTIONS(1680), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1676), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294326] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    ACTIONS(7601), 1,
      sym_variable_name,
    STATE(4349), 1,
      sym_string,
    ACTIONS(7599), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7597), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294353] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13786), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294380] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13432), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294407] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13790), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294434] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14198), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294461] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14200), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294488] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5381), 1,
      anon_sym_DQUOTE,
    ACTIONS(5385), 1,
      sym_variable_name,
    STATE(2864), 1,
      sym_string,
    ACTIONS(5383), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(5379), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294515] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14202), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294542] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13798), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294569] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14204), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294596] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10006), 1,
      anon_sym_DQUOTE,
    ACTIONS(10010), 1,
      sym_variable_name,
    STATE(5422), 1,
      sym_string,
    ACTIONS(10008), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(10004), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294623] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13806), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294650] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13562), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294677] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5486), 1,
      anon_sym_DQUOTE,
    ACTIONS(5490), 1,
      sym_variable_name,
    STATE(2462), 1,
      sym_string,
    ACTIONS(5488), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(5484), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294704] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14206), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294731] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13478), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294758] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5174), 1,
      anon_sym_DQUOTE,
    ACTIONS(5178), 1,
      sym_variable_name,
    STATE(2581), 1,
      sym_string,
    ACTIONS(5176), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(5172), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294785] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13818), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294812] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14208), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294839] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14210), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294866] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9376), 1,
      anon_sym_DQUOTE,
    ACTIONS(9380), 1,
      sym_variable_name,
    STATE(5347), 1,
      sym_string,
    ACTIONS(9378), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(9374), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294893] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14212), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294920] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13830), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294947] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13826), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [294974] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14214), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295001] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13570), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295028] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2781), 1,
      anon_sym_DQUOTE,
    ACTIONS(2785), 1,
      sym_variable_name,
    STATE(1143), 1,
      sym_string,
    ACTIONS(2783), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(2779), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295055] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14216), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295082] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2217), 1,
      anon_sym_DQUOTE,
    ACTIONS(2221), 1,
      sym_variable_name,
    STATE(983), 1,
      sym_string,
    ACTIONS(2219), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(2215), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295109] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14218), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295136] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13842), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295163] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14220), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295190] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14222), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295217] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5351), 1,
      anon_sym_DQUOTE,
    ACTIONS(5355), 1,
      sym_variable_name,
    STATE(2736), 1,
      sym_string,
    ACTIONS(5353), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(5349), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295244] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1595), 1,
      anon_sym_DQUOTE,
    ACTIONS(3421), 1,
      sym_variable_name,
    STATE(1202), 1,
      sym_string,
    ACTIONS(3419), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3417), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295271] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13850), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295298] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14226), 1,
      anon_sym_LT_LT,
    ACTIONS(14232), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14234), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14230), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14228), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14224), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [295327] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13858), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295354] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14236), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295381] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2293), 1,
      anon_sym_DQUOTE,
    ACTIONS(3427), 1,
      sym_variable_name,
    STATE(1404), 1,
      sym_string,
    ACTIONS(3425), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3423), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295408] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13866), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295435] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14238), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295462] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13870), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295489] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13874), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295516] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14240), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295543] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1378), 1,
      anon_sym_DQUOTE,
    ACTIONS(1767), 1,
      sym_variable_name,
    STATE(890), 1,
      sym_string,
    ACTIONS(1765), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1763), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295570] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14242), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295597] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14244), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295624] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13882), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295651] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14246), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295678] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2805), 1,
      anon_sym_DQUOTE,
    ACTIONS(3433), 1,
      sym_variable_name,
    STATE(1473), 1,
      sym_string,
    ACTIONS(3431), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3429), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295705] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13890), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295732] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14024), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295759] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14248), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295786] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_DQUOTE,
    ACTIONS(7190), 1,
      sym_variable_name,
    STATE(4397), 1,
      sym_string,
    ACTIONS(7188), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7186), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295813] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13898), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295840] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13582), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295867] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14250), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295894] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2793), 1,
      sym_variable_name,
    STATE(1340), 1,
      sym_string,
    ACTIONS(2791), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(2789), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295921] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13906), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295948] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14252), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [295975] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2932), 1,
      anon_sym_DQUOTE,
    ACTIONS(6820), 1,
      sym_variable_name,
    STATE(4240), 1,
      sym_string,
    ACTIONS(6818), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(6816), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296002] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4247), 1,
      anon_sym_DQUOTE,
    ACTIONS(4251), 1,
      sym_variable_name,
    STATE(2251), 1,
      sym_string,
    ACTIONS(4249), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4245), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296029] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13338), 1,
      anon_sym_DQUOTE,
    ACTIONS(13342), 1,
      sym_variable_name,
    STATE(6110), 1,
      sym_string,
    ACTIONS(13340), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(13336), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296056] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13918), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296083] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13926), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296110] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14260), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14258), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14256), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14254), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [296139] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14262), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296166] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1757), 1,
      anon_sym_DQUOTE,
    ACTIONS(1761), 1,
      sym_variable_name,
    STATE(898), 1,
      sym_string,
    ACTIONS(1759), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1755), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296193] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14264), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296220] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13934), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296247] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14266), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296274] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14268), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296301] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7265), 1,
      anon_sym_DQUOTE,
    ACTIONS(7269), 1,
      sym_variable_name,
    STATE(4167), 1,
      sym_string,
    ACTIONS(7267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7263), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296328] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13586), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296355] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13486), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296382] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13972), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296409] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1201), 1,
      anon_sym_DQUOTE,
    ACTIONS(1205), 1,
      sym_variable_name,
    STATE(516), 1,
      sym_string,
    ACTIONS(1203), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(1199), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296436] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14270), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296463] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14272), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296490] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14274), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296517] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3089), 1,
      anon_sym_DQUOTE,
    ACTIONS(3986), 1,
      sym_variable_name,
    STATE(1710), 1,
      sym_string,
    ACTIONS(3984), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3982), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296544] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3437), 1,
      anon_sym_DQUOTE,
    ACTIONS(3441), 1,
      sym_variable_name,
    STATE(1296), 1,
      sym_string,
    ACTIONS(3439), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3435), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296571] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13980), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296598] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3211), 1,
      anon_sym_DQUOTE,
    ACTIONS(3905), 1,
      sym_variable_name,
    STATE(1724), 1,
      sym_string,
    ACTIONS(3903), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3901), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296625] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14276), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296652] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13996), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296679] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13988), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296706] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14278), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296733] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 1,
      anon_sym_DQUOTE,
    ACTIONS(3809), 1,
      sym_variable_name,
    STATE(1336), 1,
      sym_string,
    ACTIONS(3807), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3805), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296760] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_DQUOTE,
    ACTIONS(4957), 1,
      sym_variable_name,
    STATE(2219), 1,
      sym_string,
    ACTIONS(4955), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4953), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296787] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14280), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296814] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14004), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296841] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14282), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296868] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14284), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296895] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2544), 1,
      anon_sym_DQUOTE,
    ACTIONS(3889), 1,
      sym_variable_name,
    STATE(1503), 1,
      sym_string,
    ACTIONS(3887), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3885), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296922] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14012), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [296949] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14288), 1,
      anon_sym_LT_LT,
    ACTIONS(14294), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14296), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14292), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14290), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14286), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [296978] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14016), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297005] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14298), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297032] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14300), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297059] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      anon_sym_DQUOTE,
    ACTIONS(2025), 1,
      sym_variable_name,
    STATE(1012), 1,
      sym_string,
    ACTIONS(2023), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(2021), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297086] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13594), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297113] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2071), 1,
      anon_sym_DQUOTE,
    ACTIONS(3974), 1,
      sym_variable_name,
    STATE(1616), 1,
      sym_string,
    ACTIONS(3972), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3970), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297140] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14032), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297167] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_DQUOTE,
    ACTIONS(2269), 1,
      sym_variable_name,
    STATE(1273), 1,
      sym_string,
    ACTIONS(2267), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(2265), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297194] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4044), 1,
      anon_sym_DQUOTE,
    ACTIONS(4048), 1,
      sym_variable_name,
    STATE(2111), 1,
      sym_string,
    ACTIONS(4046), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4042), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297221] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14302), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297248] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3909), 1,
      anon_sym_DQUOTE,
    ACTIONS(3913), 1,
      sym_variable_name,
    STATE(1657), 1,
      sym_string,
    ACTIONS(3911), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3907), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297275] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3241), 1,
      anon_sym_DQUOTE,
    ACTIONS(3803), 1,
      sym_variable_name,
    STATE(1839), 1,
      sym_string,
    ACTIONS(3801), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3799), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297302] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14304), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297329] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14044), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297356] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14306), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297383] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14310), 1,
      anon_sym_LT_LT,
    ACTIONS(14316), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14318), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14314), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14312), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14308), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [297412] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14320), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297439] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14048), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297466] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14322), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297493] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14060), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297520] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3482), 1,
      anon_sym_DQUOTE,
    ACTIONS(7480), 1,
      sym_variable_name,
    STATE(4595), 1,
      sym_string,
    ACTIONS(7478), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7476), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297547] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3512), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      sym_variable_name,
    STATE(4218), 1,
      sym_string,
    ACTIONS(7418), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7416), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297574] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14056), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297601] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4927), 1,
      anon_sym_DQUOTE,
    ACTIONS(4931), 1,
      sym_variable_name,
    STATE(2500), 1,
      sym_string,
    ACTIONS(4929), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(4925), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297628] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14324), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297655] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2623), 1,
      anon_sym_DQUOTE,
    ACTIONS(3115), 1,
      sym_variable_name,
    STATE(1528), 1,
      sym_string,
    ACTIONS(3113), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3111), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297682] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14326), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297709] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14072), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297736] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14068), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297763] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6344), 1,
      anon_sym_DQUOTE,
    ACTIONS(6348), 1,
      sym_variable_name,
    STATE(3422), 1,
      sym_string,
    ACTIONS(6346), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(6342), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297790] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3316), 1,
      anon_sym_DQUOTE,
    ACTIONS(3938), 1,
      sym_variable_name,
    STATE(1838), 1,
      sym_string,
    ACTIONS(3936), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(3934), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297817] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13610), 1,
      anon_sym_DQUOTE,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297844] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14328), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297871] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3348), 1,
      anon_sym_DQUOTE,
    ACTIONS(7275), 1,
      sym_variable_name,
    STATE(4355), 1,
      sym_string,
    ACTIONS(7273), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(7271), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297898] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14330), 1,
      anon_sym_DQUOTE,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [297925] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14112), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14110), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14108), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [297951] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14098), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14096), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14092), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [297977] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14258), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14256), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14254), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298003] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14130), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14128), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14126), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 11,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_RBRACE3,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      aux_sym__simple_variable_name_token1,
  [298049] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 11,
      anon_sym_LPAREN,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      aux_sym_number_token1,
      aux_sym_number_token2,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_RBRACE3,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
      aux_sym__simple_variable_name_token1,
  [298069] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14094), 1,
      anon_sym_LT_LT,
    ACTIONS(14100), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14186), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14184), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14182), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298095] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14334), 1,
      anon_sym_LT_LT,
    ACTIONS(14340), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14338), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14336), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14332), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298121] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14226), 1,
      anon_sym_LT_LT,
    ACTIONS(14232), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14230), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14228), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14224), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298147] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14288), 1,
      anon_sym_LT_LT,
    ACTIONS(14294), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14292), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14290), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14286), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298173] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      sym_string_content,
    ACTIONS(14088), 1,
      sym_variable_name,
    ACTIONS(14086), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14082), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [298197] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14310), 1,
      anon_sym_LT_LT,
    ACTIONS(14316), 1,
      anon_sym_LT_LT_DASH,
    ACTIONS(14314), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14312), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14308), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298223] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14348), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14346), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14344), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14342), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298246] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14350), 1,
      anon_sym_DOLLAR,
    ACTIONS(14352), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(14354), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(14356), 1,
      anon_sym_BQUOTE,
    ACTIONS(14358), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14360), 1,
      sym_heredoc_content,
    ACTIONS(14362), 1,
      sym_heredoc_end,
    STATE(6023), 4,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      aux_sym_heredoc_body_repeat1,
  [298277] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14114), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14112), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14110), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14108), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298300] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14364), 1,
      anon_sym_RBRACE3,
    ACTIONS(14366), 10,
      anon_sym_U,
      anon_sym_u,
      anon_sym_L,
      anon_sym_Q,
      anon_sym_E,
      anon_sym_P,
      anon_sym_A,
      anon_sym_K,
      anon_sym_a,
      anon_sym_k,
  [298319] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14372), 1,
      sym_variable_name,
    ACTIONS(14370), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14368), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [298340] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14380), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14378), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14376), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14374), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298363] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14388), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14386), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14384), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14382), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298386] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14394), 1,
      sym_variable_name,
    ACTIONS(14392), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14390), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [298407] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14396), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14338), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14336), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14332), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298430] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14404), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14402), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14400), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14398), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298453] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14412), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14410), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14408), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14406), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298476] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14414), 1,
      anon_sym_DOLLAR,
    ACTIONS(14417), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(14420), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(14423), 1,
      anon_sym_BQUOTE,
    ACTIONS(14426), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14429), 1,
      sym_heredoc_content,
    ACTIONS(14432), 1,
      sym_heredoc_end,
    STATE(6023), 4,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      aux_sym_heredoc_body_repeat1,
  [298507] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14174), 1,
      sym_variable_name,
    ACTIONS(14172), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14168), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [298528] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14296), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14292), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14290), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14286), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298551] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14188), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14186), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14184), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14182), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298574] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14102), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14098), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14096), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14092), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298597] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14438), 1,
      sym_variable_name,
    ACTIONS(14436), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14434), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [298618] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14446), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14444), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14442), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14440), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298641] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14452), 1,
      sym_variable_name,
    ACTIONS(14450), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14448), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [298662] = 9,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14350), 1,
      anon_sym_DOLLAR,
    ACTIONS(14352), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(14354), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(14356), 1,
      anon_sym_BQUOTE,
    ACTIONS(14358), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14454), 1,
      sym_heredoc_content,
    ACTIONS(14456), 1,
      sym_heredoc_end,
    STATE(6013), 4,
      sym_simple_expansion,
      sym_expansion,
      sym_command_substitution,
      aux_sym_heredoc_body_repeat1,
  [298693] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14462), 1,
      sym_variable_name,
    ACTIONS(14460), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14458), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [298714] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14260), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14258), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14256), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14254), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298737] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14318), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14314), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14312), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14308), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298760] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14470), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14468), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14466), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14464), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298783] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14478), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14476), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14474), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14472), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298806] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14132), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14130), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14128), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14126), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298829] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14486), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14484), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14482), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14480), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298852] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14494), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14492), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14490), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14488), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298875] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14502), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14500), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14498), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14496), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298898] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14508), 1,
      sym_variable_name,
    ACTIONS(14506), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14504), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [298919] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14516), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14514), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14512), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14510), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298942] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14524), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14522), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14520), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14518), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298965] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14532), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14530), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14528), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14526), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [298988] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14538), 1,
      sym_variable_name,
    ACTIONS(14536), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14534), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [299009] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14546), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14544), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14542), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14540), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [299032] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14554), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14552), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14550), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14548), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [299055] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14562), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14560), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14558), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14556), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [299078] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14570), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14568), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14566), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14564), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [299101] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14576), 1,
      sym_variable_name,
    ACTIONS(14574), 2,
      aux_sym__simple_variable_name_token1,
      aux_sym__multiline_variable_name_token1,
    ACTIONS(14572), 8,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      anon_sym_AT2,
      anon_sym__,
  [299122] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14584), 1,
      anon_sym_LT_LT_LT,
    ACTIONS(14582), 2,
      anon_sym_LT_AMP_DASH,
      anon_sym_GT_AMP_DASH,
    ACTIONS(14580), 3,
      anon_sym_GT_GT,
      anon_sym_AMP_GT_GT,
      anon_sym_GT_PIPE,
    ACTIONS(14578), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP_GT,
      anon_sym_LT_AMP,
      anon_sym_GT_AMP,
  [299145] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4551), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299173] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14598), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14600), 1,
      anon_sym_LPAREN,
    ACTIONS(14602), 1,
      anon_sym_if,
    ACTIONS(14604), 1,
      anon_sym_LBRACE,
    ACTIONS(14606), 1,
      anon_sym_LBRACK,
    ACTIONS(14608), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5310), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299201] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4537), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 1,
      sym__concat,
    ACTIONS(1300), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 1,
      sym__concat,
    ACTIONS(1304), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299265] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14610), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14612), 1,
      anon_sym_LPAREN,
    ACTIONS(14614), 1,
      anon_sym_if,
    ACTIONS(14616), 1,
      anon_sym_LBRACE,
    ACTIONS(14618), 1,
      anon_sym_LBRACK,
    ACTIONS(14620), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4330), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299293] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14610), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14614), 1,
      anon_sym_if,
    ACTIONS(14616), 1,
      anon_sym_LBRACE,
    ACTIONS(14618), 1,
      anon_sym_LBRACK,
    ACTIONS(14620), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14622), 1,
      anon_sym_LPAREN,
    STATE(4452), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299321] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4588), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 1,
      sym__concat,
    ACTIONS(1300), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299367] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14598), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14602), 1,
      anon_sym_if,
    ACTIONS(14604), 1,
      anon_sym_LBRACE,
    ACTIONS(14606), 1,
      anon_sym_LBRACK,
    ACTIONS(14608), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14624), 1,
      anon_sym_LPAREN,
    STATE(5292), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299395] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4744), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14628), 1,
      sym__concat,
    ACTIONS(14626), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299441] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14630), 1,
      anon_sym_LPAREN,
    STATE(4534), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299469] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14632), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14634), 1,
      anon_sym_LPAREN,
    ACTIONS(14636), 1,
      anon_sym_if,
    ACTIONS(14638), 1,
      anon_sym_LBRACE,
    ACTIONS(14640), 1,
      anon_sym_LBRACK,
    ACTIONS(14642), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4286), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299497] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14598), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14602), 1,
      anon_sym_if,
    ACTIONS(14604), 1,
      anon_sym_LBRACE,
    ACTIONS(14606), 1,
      anon_sym_LBRACK,
    ACTIONS(14608), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14624), 1,
      anon_sym_LPAREN,
    STATE(5325), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299525] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4561), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299553] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14632), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14634), 1,
      anon_sym_LPAREN,
    ACTIONS(14636), 1,
      anon_sym_if,
    ACTIONS(14638), 1,
      anon_sym_LBRACE,
    ACTIONS(14640), 1,
      anon_sym_LBRACK,
    ACTIONS(14642), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4288), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14644), 1,
      sym__concat,
    ACTIONS(13949), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 1,
      sym__concat,
    ACTIONS(1296), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299617] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4554), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299645] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14610), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14614), 1,
      anon_sym_if,
    ACTIONS(14616), 1,
      anon_sym_LBRACE,
    ACTIONS(14618), 1,
      anon_sym_LBRACK,
    ACTIONS(14620), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14622), 1,
      anon_sym_LPAREN,
    STATE(4478), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299673] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14646), 1,
      anon_sym_LPAREN,
    STATE(5164), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299701] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5168), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      sym__concat,
    ACTIONS(1268), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299747] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14648), 1,
      anon_sym_DQUOTE,
    ACTIONS(14650), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(14652), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(14654), 1,
      anon_sym_BQUOTE,
    ACTIONS(14656), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5147), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
    STATE(6538), 3,
      sym_string,
      sym_expansion,
      sym_command_substitution,
  [299775] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 1,
      sym__concat,
    ACTIONS(1288), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299793] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14658), 1,
      anon_sym_LPAREN,
    STATE(4556), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299821] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14660), 1,
      anon_sym_LPAREN,
    STATE(4733), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299849] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 1,
      sym__concat,
    ACTIONS(1292), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299867] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14632), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14636), 1,
      anon_sym_if,
    ACTIONS(14638), 1,
      anon_sym_LBRACE,
    ACTIONS(14640), 1,
      anon_sym_LBRACK,
    ACTIONS(14642), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14662), 1,
      anon_sym_LPAREN,
    STATE(4186), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299895] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 1,
      sym__concat,
    ACTIONS(1260), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299913] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 1,
      sym__concat,
    ACTIONS(1276), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [299931] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4742), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [299959] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14366), 10,
      anon_sym_U,
      anon_sym_u,
      anon_sym_L,
      anon_sym_Q,
      anon_sym_E,
      anon_sym_P,
      anon_sym_A,
      anon_sym_K,
      anon_sym_a,
      anon_sym_k,
  [299975] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(14664), 1,
      anon_sym_LPAREN,
    STATE(4550), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [300003] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(4599), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [300031] = 8,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14586), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(14588), 1,
      anon_sym_LPAREN,
    ACTIONS(14590), 1,
      anon_sym_if,
    ACTIONS(14592), 1,
      anon_sym_LBRACE,
    ACTIONS(14594), 1,
      anon_sym_LBRACK,
    ACTIONS(14596), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5169), 4,
      sym_if_statement,
      sym_compound_statement,
      sym_subshell,
      sym_test_command,
  [300059] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13949), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [300074] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    STATE(6101), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1223), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      sym__special_character,
  [300097] = 10,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14670), 1,
      anon_sym_SLASH,
    ACTIONS(14672), 1,
      anon_sym_DQUOTE,
    ACTIONS(14674), 1,
      anon_sym_RBRACE3,
    ACTIONS(14676), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(14678), 1,
      anon_sym_BQUOTE,
    ACTIONS(14680), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14682), 1,
      sym__regex_no_slash,
    STATE(6543), 1,
      sym_string,
    STATE(6638), 1,
      sym_command_substitution,
  [300128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14684), 9,
      anon_sym_DOLLAR_LPAREN_LPAREN,
      anon_sym_DOLLAR_LBRACK,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      sym_string_content,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [300143] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    ACTIONS(14686), 1,
      anon_sym_in,
    ACTIONS(14690), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6099), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14688), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300167] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14692), 1,
      anon_sym_RPAREN,
    ACTIONS(14694), 1,
      anon_sym_DQUOTE,
    ACTIONS(14696), 1,
      sym_raw_string,
    ACTIONS(14698), 1,
      anon_sym_RBRACE3,
    ACTIONS(14700), 1,
      aux_sym__expansion_regex_token1,
    ACTIONS(14702), 1,
      sym_regex,
    STATE(6097), 2,
      sym_string,
      aux_sym__expansion_regex_repeat1,
  [300193] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(14704), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(14706), 1,
      aux_sym__simple_variable_name_token1,
    STATE(6151), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6128), 3,
      sym_number,
      sym_expansion,
      sym__expansion_max_length_expression,
  [300217] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    ACTIONS(14708), 1,
      anon_sym_in,
    ACTIONS(14712), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6101), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14710), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300241] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14714), 1,
      anon_sym_RPAREN,
    ACTIONS(14717), 1,
      anon_sym_DQUOTE,
    ACTIONS(14720), 1,
      sym_raw_string,
    ACTIONS(14723), 1,
      anon_sym_RBRACE3,
    ACTIONS(14725), 1,
      aux_sym__expansion_regex_token1,
    ACTIONS(14728), 1,
      sym_regex,
    STATE(6097), 2,
      sym_string,
      aux_sym__expansion_regex_repeat1,
  [300267] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14731), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14734), 1,
      sym__concat,
    STATE(6098), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1213), 4,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300289] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1209), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14737), 1,
      sym__concat,
    STATE(6098), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1207), 4,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300311] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14692), 1,
      anon_sym_RPAREN,
    ACTIONS(14694), 1,
      anon_sym_DQUOTE,
    ACTIONS(14700), 1,
      aux_sym__expansion_regex_token1,
    ACTIONS(14739), 1,
      sym_raw_string,
    ACTIONS(14741), 1,
      anon_sym_RBRACE3,
    ACTIONS(14743), 1,
      sym_regex,
    STATE(6094), 2,
      sym_string,
      aux_sym__expansion_regex_repeat1,
  [300337] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1229), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14745), 1,
      sym__concat,
    STATE(6098), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1227), 4,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300359] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    ACTIONS(14747), 1,
      anon_sym_in,
    ACTIONS(14751), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6101), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14749), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300383] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    ACTIONS(14753), 1,
      anon_sym_in,
    ACTIONS(14757), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6099), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14755), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300407] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7774), 1,
      aux_sym_number_token1,
    ACTIONS(7776), 1,
      aux_sym_number_token2,
    ACTIONS(14704), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(14759), 1,
      aux_sym__simple_variable_name_token1,
    STATE(6151), 1,
      sym__expansion_max_length_binary_expression,
    STATE(6130), 3,
      sym_number,
      sym_expansion,
      sym__expansion_max_length_expression,
  [300431] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    ACTIONS(14761), 1,
      anon_sym_in,
    ACTIONS(14765), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6101), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14763), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300455] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    ACTIONS(14767), 1,
      anon_sym_in,
    ACTIONS(14771), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6099), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14769), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300479] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    ACTIONS(14773), 1,
      anon_sym_in,
    ACTIONS(14777), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6101), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14775), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300503] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14666), 1,
      aux_sym_concatenation_token1,
    ACTIONS(14668), 1,
      sym__concat,
    ACTIONS(14779), 1,
      anon_sym_in,
    ACTIONS(14783), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6099), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14781), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300527] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1298), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [300540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1252), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300555] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1296), 1,
      anon_sym_DOLLAR,
    ACTIONS(1298), 6,
      sym_heredoc_content,
      sym_heredoc_end,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [300570] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14708), 1,
      anon_sym_in,
    ACTIONS(14712), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14785), 1,
      sym__special_character,
    STATE(6121), 1,
      aux_sym__literal_repeat1,
    ACTIONS(14710), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300591] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1272), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300606] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [300619] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1306), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [300632] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [300645] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14773), 1,
      anon_sym_in,
    ACTIONS(14777), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14785), 1,
      sym__special_character,
    STATE(6121), 1,
      aux_sym__literal_repeat1,
    ACTIONS(14775), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300666] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 1,
      anon_sym_DOLLAR,
    ACTIONS(1302), 6,
      sym_heredoc_content,
      sym_heredoc_end,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [300681] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1304), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 6,
      sym_heredoc_content,
      sym_heredoc_end,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [300696] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1300), 1,
      anon_sym_DOLLAR,
    ACTIONS(1302), 6,
      sym_heredoc_content,
      sym_heredoc_end,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [300711] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1318), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14787), 1,
      sym__special_character,
    STATE(6121), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1316), 4,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300730] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1312), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300745] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1248), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1296), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300775] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300790] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1304), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300805] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1300), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300820] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14792), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(14790), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [300835] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1294), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [300848] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14790), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [300861] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1256), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300876] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1260), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300891] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14747), 1,
      anon_sym_in,
    ACTIONS(14751), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14785), 1,
      sym__special_character,
    STATE(6121), 1,
      aux_sym__literal_repeat1,
    ACTIONS(14749), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1268), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300927] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14796), 1,
      anon_sym_COLON,
    ACTIONS(14798), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [300944] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14761), 1,
      anon_sym_in,
    ACTIONS(14765), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14785), 1,
      sym__special_character,
    STATE(6121), 1,
      aux_sym__literal_repeat1,
    ACTIONS(14763), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [300965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1284), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300980] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1213), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [300995] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1274), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [301008] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1282), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [301021] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1276), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [301036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1288), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [301051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1264), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [301066] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_DOLLAR,
    ACTIONS(1278), 6,
      sym_heredoc_content,
      sym_heredoc_end,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [301081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1280), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [301096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1292), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [301111] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14802), 1,
      anon_sym_COLON,
    ACTIONS(14804), 1,
      anon_sym_RBRACE3,
    ACTIONS(14800), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301128] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1292), 1,
      anon_sym_DOLLAR,
    ACTIONS(1294), 6,
      sym_heredoc_content,
      sym_heredoc_end,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [301143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 2,
      sym__concat,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1308), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      aux_sym_concatenation_token1,
  [301158] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1288), 1,
      anon_sym_DOLLAR,
    ACTIONS(1290), 6,
      sym_heredoc_content,
      sym_heredoc_end,
      anon_sym_DOLLAR_LBRACE,
      anon_sym_DOLLAR_LPAREN,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_BQUOTE,
  [301173] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14800), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [301186] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14808), 1,
      anon_sym_RPAREN,
    STATE(6303), 1,
      aux_sym_concatenation_repeat1,
    STATE(6614), 1,
      aux_sym_case_item_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [301206] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14812), 1,
      anon_sym_RPAREN,
    STATE(6303), 1,
      aux_sym_concatenation_repeat1,
    STATE(6500), 1,
      aux_sym_case_item_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [301226] = 6,
    ACTIONS(61), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(65), 1,
      anon_sym_BQUOTE,
    ACTIONS(67), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14814), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1090), 2,
      sym_expansion,
      sym_command_substitution,
  [301246] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(324), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(328), 1,
      anon_sym_BQUOTE,
    ACTIONS(330), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14816), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1069), 2,
      sym_expansion,
      sym_command_substitution,
  [301266] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9696), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9698), 1,
      anon_sym_BQUOTE,
    ACTIONS(9700), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14818), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1807), 2,
      sym_expansion,
      sym_command_substitution,
  [301286] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14820), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301300] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(385), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(391), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5375), 1,
      anon_sym_BQUOTE,
    ACTIONS(14822), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2525), 2,
      sym_expansion,
      sym_command_substitution,
  [301320] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14824), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301334] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4080), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4084), 1,
      anon_sym_BQUOTE,
    ACTIONS(4086), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14826), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2511), 2,
      sym_expansion,
      sym_command_substitution,
  [301354] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14828), 1,
      anon_sym_RBRACE3,
    ACTIONS(14800), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301368] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7518), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7520), 1,
      anon_sym_BQUOTE,
    ACTIONS(7522), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14830), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(6402), 2,
      sym_expansion,
      sym_command_substitution,
  [301388] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4554), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4560), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14832), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2601), 2,
      sym_expansion,
      sym_command_substitution,
  [301408] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8386), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8390), 1,
      anon_sym_BQUOTE,
    ACTIONS(8392), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14834), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4393), 2,
      sym_expansion,
      sym_command_substitution,
  [301428] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14836), 1,
      anon_sym_RBRACE3,
    ACTIONS(14800), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301442] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8653), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8657), 1,
      anon_sym_BQUOTE,
    ACTIONS(8659), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14838), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(5144), 2,
      sym_expansion,
      sym_command_substitution,
  [301462] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4645), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4649), 1,
      anon_sym_BQUOTE,
    ACTIONS(4651), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14840), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2755), 2,
      sym_expansion,
      sym_command_substitution,
  [301482] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14844), 1,
      anon_sym_COMMA,
    ACTIONS(14846), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4520), 1,
      sym__c_terminator,
    STATE(6361), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(14842), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [301502] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10502), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10504), 1,
      anon_sym_BQUOTE,
    ACTIONS(10506), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14848), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4395), 2,
      sym_expansion,
      sym_command_substitution,
  [301522] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9912), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9916), 1,
      anon_sym_BQUOTE,
    ACTIONS(9918), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14850), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2339), 2,
      sym_expansion,
      sym_command_substitution,
  [301542] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14852), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301556] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10154), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10156), 1,
      anon_sym_BQUOTE,
    ACTIONS(10158), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14854), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1413), 2,
      sym_expansion,
      sym_command_substitution,
  [301576] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14852), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301590] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14852), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301604] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14856), 1,
      anon_sym_RBRACE3,
    ACTIONS(14800), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301618] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(667), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(685), 1,
      anon_sym_LBRACE,
    ACTIONS(14858), 1,
      anon_sym_SEMI,
    ACTIONS(14860), 1,
      anon_sym_do,
    STATE(4963), 1,
      sym_do_group,
    STATE(4966), 1,
      sym_compound_statement,
  [301640] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14862), 1,
      anon_sym_fi,
    ACTIONS(14864), 1,
      anon_sym_elif,
    ACTIONS(14866), 1,
      anon_sym_else,
    STATE(7173), 1,
      sym_else_clause,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [301660] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14844), 1,
      anon_sym_COMMA,
    ACTIONS(14870), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4151), 1,
      sym__c_terminator,
    STATE(6361), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(14868), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [301680] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12313), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12315), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12317), 1,
      anon_sym_BQUOTE,
    ACTIONS(12319), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3215), 2,
      sym_expansion,
      sym_command_substitution,
  [301700] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7952), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7956), 1,
      anon_sym_BQUOTE,
    ACTIONS(7958), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14872), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4261), 2,
      sym_expansion,
      sym_command_substitution,
  [301720] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14864), 1,
      anon_sym_elif,
    ACTIONS(14866), 1,
      anon_sym_else,
    ACTIONS(14874), 1,
      anon_sym_fi,
    STATE(7187), 1,
      sym_else_clause,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [301740] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8617), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8621), 1,
      anon_sym_BQUOTE,
    ACTIONS(8623), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3092), 2,
      sym_expansion,
      sym_command_substitution,
  [301760] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10052), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10054), 1,
      anon_sym_BQUOTE,
    ACTIONS(10056), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14876), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(904), 2,
      sym_expansion,
      sym_command_substitution,
  [301780] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10306), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10308), 1,
      anon_sym_BQUOTE,
    ACTIONS(10310), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14878), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1856), 2,
      sym_expansion,
      sym_command_substitution,
  [301800] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10448), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10450), 1,
      anon_sym_BQUOTE,
    ACTIONS(10452), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14880), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4384), 2,
      sym_expansion,
      sym_command_substitution,
  [301820] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9846), 1,
      anon_sym_BQUOTE,
    ACTIONS(9848), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14882), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1758), 2,
      sym_expansion,
      sym_command_substitution,
  [301840] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7844), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7848), 1,
      anon_sym_BQUOTE,
    ACTIONS(7850), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14884), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2450), 2,
      sym_expansion,
      sym_command_substitution,
  [301860] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14844), 1,
      anon_sym_COMMA,
    ACTIONS(14888), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4671), 1,
      sym__c_terminator,
    STATE(6227), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(14886), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [301880] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12093), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12095), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12097), 1,
      anon_sym_BQUOTE,
    ACTIONS(12099), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3117), 2,
      sym_expansion,
      sym_command_substitution,
  [301900] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14890), 1,
      anon_sym_RPAREN,
    STATE(6383), 1,
      aux_sym_concatenation_repeat1,
    STATE(6609), 1,
      aux_sym_case_item_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [301920] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14892), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [301934] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8022), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8024), 1,
      anon_sym_BQUOTE,
    ACTIONS(8026), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14894), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1563), 2,
      sym_expansion,
      sym_command_substitution,
  [301954] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10334), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10338), 1,
      anon_sym_BQUOTE,
    ACTIONS(10340), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14896), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(6145), 2,
      sym_expansion,
      sym_command_substitution,
  [301974] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(405), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(429), 1,
      anon_sym_LBRACE,
    ACTIONS(14898), 1,
      anon_sym_SEMI,
    ACTIONS(14900), 1,
      anon_sym_do,
    STATE(4720), 1,
      sym_do_group,
    STATE(4737), 1,
      sym_compound_statement,
  [301996] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10418), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10420), 1,
      anon_sym_BQUOTE,
    ACTIONS(10422), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14902), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4647), 2,
      sym_expansion,
      sym_command_substitution,
  [302016] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9772), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9774), 1,
      anon_sym_BQUOTE,
    ACTIONS(9776), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14904), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1025), 2,
      sym_expansion,
      sym_command_substitution,
  [302036] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14906), 1,
      anon_sym_SLASH,
    ACTIONS(14910), 1,
      anon_sym_RBRACE3,
    ACTIONS(14912), 1,
      sym__expansion_word,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [302056] = 4,
    ACTIONS(71), 1,
      sym_comment,
    STATE(6383), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(1225), 3,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      sym__special_character,
  [302072] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14914), 1,
      anon_sym_RPAREN,
    STATE(6383), 1,
      aux_sym_concatenation_repeat1,
    STATE(6498), 1,
      aux_sym_case_item_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [302092] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14864), 1,
      anon_sym_elif,
    ACTIONS(14866), 1,
      anon_sym_else,
    ACTIONS(14916), 1,
      anon_sym_fi,
    STATE(7430), 1,
      sym_else_clause,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [302112] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9940), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_BQUOTE,
    ACTIONS(9944), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14918), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1493), 2,
      sym_expansion,
      sym_command_substitution,
  [302132] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8084), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8088), 1,
      anon_sym_BQUOTE,
    ACTIONS(8090), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14920), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(5340), 2,
      sym_expansion,
      sym_command_substitution,
  [302152] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9984), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9986), 1,
      anon_sym_BQUOTE,
    ACTIONS(9988), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14922), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1152), 2,
      sym_expansion,
      sym_command_substitution,
  [302172] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14924), 1,
      anon_sym_RPAREN,
    STATE(6383), 1,
      aux_sym_concatenation_repeat1,
    STATE(6518), 1,
      aux_sym_case_item_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [302192] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14892), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [302206] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14844), 1,
      anon_sym_COMMA,
    ACTIONS(14928), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4660), 1,
      sym__c_terminator,
    STATE(6361), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(14926), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [302226] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4851), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4855), 1,
      anon_sym_BQUOTE,
    ACTIONS(4857), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14930), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(5204), 2,
      sym_expansion,
      sym_command_substitution,
  [302246] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14932), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [302260] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4819), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4823), 1,
      anon_sym_BQUOTE,
    ACTIONS(4825), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14934), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2796), 2,
      sym_expansion,
      sym_command_substitution,
  [302280] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9734), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9736), 1,
      anon_sym_BQUOTE,
    ACTIONS(9738), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14936), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1714), 2,
      sym_expansion,
      sym_command_substitution,
  [302300] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(2673), 1,
      anon_sym_BQUOTE,
    ACTIONS(2675), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14938), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2272), 2,
      sym_expansion,
      sym_command_substitution,
  [302320] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10800), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10802), 1,
      anon_sym_BQUOTE,
    ACTIONS(10804), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14940), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1881), 2,
      sym_expansion,
      sym_command_substitution,
  [302340] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10214), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10216), 1,
      anon_sym_BQUOTE,
    ACTIONS(10218), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14942), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4484), 2,
      sym_expansion,
      sym_command_substitution,
  [302360] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5107), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5111), 1,
      anon_sym_BQUOTE,
    ACTIONS(5113), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14944), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(5260), 2,
      sym_expansion,
      sym_command_substitution,
  [302380] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9884), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9886), 1,
      anon_sym_BQUOTE,
    ACTIONS(9888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14946), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(3329), 2,
      sym_expansion,
      sym_command_substitution,
  [302400] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14892), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [302414] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9796), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9798), 1,
      anon_sym_BQUOTE,
    ACTIONS(9800), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14948), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4747), 2,
      sym_expansion,
      sym_command_substitution,
  [302434] = 7,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(147), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(163), 1,
      anon_sym_LBRACE,
    ACTIONS(14950), 1,
      anon_sym_SEMI,
    ACTIONS(14952), 1,
      anon_sym_do,
    STATE(5536), 1,
      sym_do_group,
    STATE(5544), 1,
      sym_compound_statement,
  [302456] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14864), 1,
      anon_sym_elif,
    ACTIONS(14866), 1,
      anon_sym_else,
    ACTIONS(14954), 1,
      anon_sym_fi,
    STATE(6803), 1,
      sym_else_clause,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [302476] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9638), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9640), 1,
      anon_sym_BQUOTE,
    ACTIONS(9642), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14956), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1388), 2,
      sym_expansion,
      sym_command_substitution,
  [302496] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8426), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8428), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8430), 1,
      anon_sym_BQUOTE,
    ACTIONS(8432), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2745), 2,
      sym_expansion,
      sym_command_substitution,
  [302516] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14864), 1,
      anon_sym_elif,
    ACTIONS(14866), 1,
      anon_sym_else,
    ACTIONS(14958), 1,
      anon_sym_fi,
    STATE(7014), 1,
      sym_else_clause,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [302536] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14960), 1,
      anon_sym_RPAREN,
    STATE(6303), 1,
      aux_sym_concatenation_repeat1,
    STATE(6458), 1,
      aux_sym_case_item_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [302556] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14962), 1,
      anon_sym_SLASH,
    ACTIONS(14964), 1,
      anon_sym_RBRACE3,
    ACTIONS(14966), 1,
      sym__expansion_word,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [302576] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 2,
      sym_regex,
      aux_sym__expansion_regex_token1,
    ACTIONS(1264), 4,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
      sym_raw_string,
      anon_sym_RBRACE3,
  [302590] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12475), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(12477), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(12479), 1,
      anon_sym_BQUOTE,
    ACTIONS(12481), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(2882), 2,
      sym_expansion,
      sym_command_substitution,
  [302610] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14844), 1,
      anon_sym_COMMA,
    ACTIONS(14970), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4563), 1,
      sym__c_terminator,
    STATE(6361), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(14968), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [302630] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10378), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10380), 1,
      anon_sym_BQUOTE,
    ACTIONS(10382), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14972), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1540), 2,
      sym_expansion,
      sym_command_substitution,
  [302650] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14864), 1,
      anon_sym_elif,
    ACTIONS(14866), 1,
      anon_sym_else,
    ACTIONS(14974), 1,
      anon_sym_fi,
    STATE(6734), 1,
      sym_else_clause,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [302670] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7882), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7886), 1,
      anon_sym_BQUOTE,
    ACTIONS(7888), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14976), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1650), 2,
      sym_expansion,
      sym_command_substitution,
  [302690] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10246), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10248), 1,
      anon_sym_BQUOTE,
    ACTIONS(10250), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14978), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4248), 2,
      sym_expansion,
      sym_command_substitution,
  [302710] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14980), 1,
      anon_sym_SLASH,
    ACTIONS(14982), 1,
      anon_sym_RBRACE3,
    ACTIONS(14984), 1,
      sym__expansion_word,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [302730] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(1223), 5,
      anon_sym_in,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
      sym__special_character,
  [302744] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10614), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10616), 1,
      anon_sym_BQUOTE,
    ACTIONS(10618), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14986), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(5546), 2,
      sym_expansion,
      sym_command_substitution,
  [302764] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1121), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(5755), 1,
      anon_sym_BQUOTE,
    ACTIONS(14988), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2236), 2,
      sym_expansion,
      sym_command_substitution,
  [302784] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(10528), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(10530), 1,
      anon_sym_BQUOTE,
    ACTIONS(10532), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14990), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4177), 2,
      sym_expansion,
      sym_command_substitution,
  [302804] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8585), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8587), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(8589), 1,
      anon_sym_BQUOTE,
    ACTIONS(8591), 1,
      anon_sym_DOLLAR_BQUOTE,
    STATE(3177), 2,
      sym_expansion,
      sym_command_substitution,
  [302824] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8130), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8134), 1,
      anon_sym_BQUOTE,
    ACTIONS(8136), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14992), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1168), 2,
      sym_expansion,
      sym_command_substitution,
  [302844] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14994), 1,
      anon_sym_RBRACE3,
    ACTIONS(14794), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [302858] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14844), 1,
      anon_sym_COMMA,
    ACTIONS(14998), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4623), 1,
      sym__c_terminator,
    STATE(6206), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(14996), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [302878] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5335), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5339), 1,
      anon_sym_BQUOTE,
    ACTIONS(5341), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15000), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(5450), 2,
      sym_expansion,
      sym_command_substitution,
  [302898] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14844), 1,
      anon_sym_COMMA,
    ACTIONS(15004), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4644), 1,
      sym__c_terminator,
    STATE(6168), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(15002), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [302918] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(717), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(721), 1,
      anon_sym_BQUOTE,
    ACTIONS(723), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15006), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(914), 2,
      sym_expansion,
      sym_command_substitution,
  [302938] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(123), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(127), 1,
      anon_sym_BQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15008), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(477), 2,
      sym_expansion,
      sym_command_substitution,
  [302958] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 2,
      sym_regex,
      aux_sym__expansion_regex_token1,
    ACTIONS(1248), 4,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
      sym_raw_string,
      anon_sym_RBRACE3,
  [302972] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15010), 1,
      anon_sym_RPAREN,
    STATE(6383), 1,
      aux_sym_concatenation_repeat1,
    STATE(6575), 1,
      aux_sym_case_item_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [302992] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14864), 1,
      anon_sym_elif,
    ACTIONS(14866), 1,
      anon_sym_else,
    ACTIONS(15012), 1,
      anon_sym_fi,
    STATE(7030), 1,
      sym_else_clause,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [303012] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15014), 1,
      anon_sym_RPAREN,
    STATE(6303), 1,
      aux_sym_concatenation_repeat1,
    STATE(6490), 1,
      aux_sym_case_item_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [303032] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15016), 1,
      anon_sym_RBRACE3,
    ACTIONS(14800), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [303046] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14676), 1,
      anon_sym_DOLLAR_LPAREN,
    ACTIONS(14678), 1,
      anon_sym_BQUOTE,
    ACTIONS(14680), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(14704), 1,
      anon_sym_DOLLAR_LBRACE,
    STATE(6140), 2,
      sym_expansion,
      sym_command_substitution,
  [303066] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8274), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8276), 1,
      anon_sym_BQUOTE,
    ACTIONS(8278), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15018), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1333), 2,
      sym_expansion,
      sym_command_substitution,
  [303086] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5232), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5236), 1,
      anon_sym_BQUOTE,
    ACTIONS(5238), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15020), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(5290), 2,
      sym_expansion,
      sym_command_substitution,
  [303106] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15022), 1,
      anon_sym_RBRACE3,
    ACTIONS(14800), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [303120] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8316), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8320), 1,
      anon_sym_BQUOTE,
    ACTIONS(8322), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15024), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1495), 2,
      sym_expansion,
      sym_command_substitution,
  [303140] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(461), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(465), 1,
      anon_sym_BQUOTE,
    ACTIONS(467), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15026), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(812), 2,
      sym_expansion,
      sym_command_substitution,
  [303160] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 2,
      sym_regex,
      aux_sym__expansion_regex_token1,
    ACTIONS(1256), 4,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
      sym_raw_string,
      anon_sym_RBRACE3,
  [303174] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8204), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8208), 1,
      anon_sym_BQUOTE,
    ACTIONS(8210), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15028), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(4241), 2,
      sym_expansion,
      sym_command_substitution,
  [303194] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8170), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8172), 1,
      anon_sym_BQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15030), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1173), 2,
      sym_expansion,
      sym_command_substitution,
  [303214] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9716), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9718), 1,
      anon_sym_BQUOTE,
    ACTIONS(9720), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15032), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2021), 2,
      sym_expansion,
      sym_command_substitution,
  [303234] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1055), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1059), 1,
      anon_sym_BQUOTE,
    ACTIONS(1061), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15034), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1985), 2,
      sym_expansion,
      sym_command_substitution,
  [303254] = 7,
    ACTIONS(13), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(29), 1,
      anon_sym_LBRACE,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15036), 1,
      anon_sym_SEMI,
    ACTIONS(15038), 1,
      anon_sym_do,
    STATE(4930), 1,
      sym_do_group,
    STATE(4934), 1,
      sym_compound_statement,
  [303276] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9658), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9660), 1,
      anon_sym_BQUOTE,
    ACTIONS(9662), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15040), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1262), 2,
      sym_expansion,
      sym_command_substitution,
  [303296] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8242), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(8246), 1,
      anon_sym_BQUOTE,
    ACTIONS(8248), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15042), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1439), 2,
      sym_expansion,
      sym_command_substitution,
  [303316] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7990), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7994), 1,
      anon_sym_BQUOTE,
    ACTIONS(7996), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15044), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(3406), 2,
      sym_expansion,
      sym_command_substitution,
  [303336] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15046), 1,
      anon_sym_RBRACE3,
    ACTIONS(14800), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [303350] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9752), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9754), 1,
      anon_sym_BQUOTE,
    ACTIONS(9756), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15048), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1554), 2,
      sym_expansion,
      sym_command_substitution,
  [303370] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14844), 1,
      anon_sym_COMMA,
    ACTIONS(15052), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(4154), 1,
      sym__c_terminator,
    STATE(6178), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(15050), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [303390] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9814), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(9816), 1,
      anon_sym_BQUOTE,
    ACTIONS(9818), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15054), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2008), 2,
      sym_expansion,
      sym_command_substitution,
  [303410] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7918), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7920), 1,
      anon_sym_BQUOTE,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15056), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(1633), 2,
      sym_expansion,
      sym_command_substitution,
  [303430] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14864), 1,
      anon_sym_elif,
    ACTIONS(14866), 1,
      anon_sym_else,
    ACTIONS(15058), 1,
      anon_sym_fi,
    STATE(6820), 1,
      sym_else_clause,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [303450] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(4339), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(4343), 1,
      anon_sym_BQUOTE,
    ACTIONS(4345), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15060), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2463), 2,
      sym_expansion,
      sym_command_substitution,
  [303470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15064), 2,
      sym_regex,
      aux_sym__expansion_regex_token1,
    ACTIONS(15062), 4,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
      sym_raw_string,
      anon_sym_RBRACE3,
  [303484] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5027), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5031), 1,
      anon_sym_BQUOTE,
    ACTIONS(5033), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15066), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(2860), 2,
      sym_expansion,
      sym_command_substitution,
  [303504] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(203), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(207), 1,
      anon_sym_BQUOTE,
    ACTIONS(209), 1,
      anon_sym_DOLLAR_BQUOTE,
    ACTIONS(15068), 1,
      anon_sym_DOLLAR_LPAREN,
    STATE(506), 2,
      sym_expansion,
      sym_command_substitution,
  [303524] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15070), 1,
      anon_sym_SLASH,
    ACTIONS(15072), 1,
      anon_sym_RBRACE3,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [303541] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15074), 1,
      sym__concat,
    ACTIONS(6651), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [303554] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [303569] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14890), 1,
      anon_sym_RPAREN,
    ACTIONS(15078), 1,
      sym__special_character,
    STATE(6394), 1,
      aux_sym__literal_repeat1,
    STATE(6622), 1,
      aux_sym_case_item_repeat1,
  [303588] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(7267), 1,
      sym_heredoc_body,
    STATE(4962), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [303605] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(7267), 1,
      sym_heredoc_body,
    STATE(4990), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [303622] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(7267), 1,
      sym_heredoc_body,
    STATE(5013), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [303639] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(4944), 1,
      sym__heredoc_body,
    STATE(4948), 1,
      sym__simple_heredoc_body,
    STATE(7267), 1,
      sym_heredoc_body,
  [303658] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(4955), 1,
      sym__heredoc_body,
    STATE(4959), 1,
      sym__simple_heredoc_body,
    STATE(7267), 1,
      sym_heredoc_body,
  [303677] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(7267), 1,
      sym_heredoc_body,
    STATE(4967), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [303694] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(7267), 1,
      sym_heredoc_body,
    STATE(4977), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [303711] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(4941), 1,
      sym__heredoc_body,
    STATE(4985), 1,
      sym__simple_heredoc_body,
    STATE(7267), 1,
      sym_heredoc_body,
  [303730] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(4986), 1,
      sym__heredoc_body,
    STATE(4994), 1,
      sym__simple_heredoc_body,
    STATE(7267), 1,
      sym_heredoc_body,
  [303749] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(7267), 1,
      sym_heredoc_body,
    STATE(4998), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [303766] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(5002), 1,
      sym__heredoc_body,
    STATE(5015), 1,
      sym__simple_heredoc_body,
    STATE(7267), 1,
      sym_heredoc_body,
  [303785] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15080), 1,
      sym_simple_heredoc_body,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    STATE(4942), 1,
      sym__simple_heredoc_body,
    STATE(4981), 1,
      sym__heredoc_body,
    STATE(7267), 1,
      sym_heredoc_body,
  [303804] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(5478), 1,
      sym__heredoc_body,
    STATE(5479), 1,
      sym__simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
  [303823] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15086), 1,
      anon_sym_SLASH,
    ACTIONS(15088), 1,
      anon_sym_RBRACE3,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [303840] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
    STATE(5562), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [303857] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [303872] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [303887] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15092), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [303902] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
    STATE(5455), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [303919] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(5480), 1,
      sym__heredoc_body,
    STATE(5481), 1,
      sym__simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
  [303938] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(5487), 1,
      sym__heredoc_body,
    STATE(5488), 1,
      sym__simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
  [303957] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(405), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(429), 1,
      anon_sym_LBRACE,
    ACTIONS(14900), 1,
      anon_sym_do,
    STATE(4771), 1,
      sym_do_group,
    STATE(4893), 1,
      sym_compound_statement,
  [303976] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14779), 1,
      anon_sym_in,
    ACTIONS(14783), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14781), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [303991] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
    STATE(5459), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304008] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14810), 1,
      aux_sym_concatenation_token1,
    ACTIONS(15094), 1,
      sym__concat,
    STATE(6324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1209), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [304025] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1306), 5,
      sym__concat,
      sym__expansion_word,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [304036] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7740), 1,
      anon_sym_RBRACE3,
    STATE(6294), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [304051] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15096), 1,
      sym__concat,
    ACTIONS(6703), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [304064] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14914), 1,
      anon_sym_RPAREN,
    ACTIONS(15078), 1,
      sym__special_character,
    STATE(6394), 1,
      aux_sym__literal_repeat1,
    STATE(6502), 1,
      aux_sym_case_item_repeat1,
  [304083] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(147), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(163), 1,
      anon_sym_LBRACE,
    ACTIONS(14952), 1,
      anon_sym_do,
    STATE(5535), 1,
      sym_do_group,
    STATE(5537), 1,
      sym_compound_statement,
  [304102] = 4,
    ACTIONS(71), 1,
      sym_comment,
    STATE(6314), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(15098), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [304117] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15100), 1,
      anon_sym_SLASH,
    ACTIONS(15102), 1,
      anon_sym_RBRACE3,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [304134] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15104), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [304149] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14980), 1,
      anon_sym_SLASH,
    ACTIONS(14982), 1,
      anon_sym_RBRACE3,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [304166] = 4,
    ACTIONS(71), 1,
      sym_comment,
    STATE(6303), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(15106), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [304181] = 4,
    ACTIONS(71), 1,
      sym_comment,
    STATE(6314), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(15108), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
    ACTIONS(15110), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [304196] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14962), 1,
      anon_sym_SLASH,
    ACTIONS(14964), 1,
      anon_sym_RBRACE3,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [304213] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym__concat,
      sym__expansion_word,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [304224] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [304239] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15115), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [304254] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
    STATE(4919), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304271] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15119), 1,
      anon_sym_in,
    ACTIONS(15123), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(15121), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [304286] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
    STATE(4861), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304303] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
    STATE(4746), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304320] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15127), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(14792), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [304333] = 4,
    ACTIONS(71), 1,
      sym_comment,
    STATE(6324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1215), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
    ACTIONS(15129), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [304348] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 5,
      sym__concat,
      sym__expansion_word,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [304359] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(667), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(685), 1,
      anon_sym_LBRACE,
    ACTIONS(14860), 1,
      anon_sym_do,
    STATE(4995), 1,
      sym_do_group,
    STATE(4996), 1,
      sym_compound_statement,
  [304378] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15132), 1,
      anon_sym_in,
    ACTIONS(15136), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(15134), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [304393] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
    STATE(4843), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304410] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(4849), 1,
      sym__heredoc_body,
    STATE(4888), 1,
      sym__simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
  [304429] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
    STATE(4674), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304446] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14753), 1,
      anon_sym_in,
    ACTIONS(14757), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14755), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [304461] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(4936), 1,
      sym__heredoc_body,
    STATE(4938), 1,
      sym__simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
  [304480] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(4705), 1,
      sym__heredoc_body,
    STATE(4708), 1,
      sym__simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
  [304499] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15138), 1,
      sym__concat,
    ACTIONS(6673), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [304512] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15142), 1,
      anon_sym_elif,
    ACTIONS(15140), 2,
      anon_sym_fi,
      anon_sym_else,
    STATE(6335), 2,
      sym_elif_clause,
      aux_sym_if_statement_repeat1,
  [304527] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
    STATE(4788), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304544] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
    STATE(4732), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304561] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(4780), 1,
      sym__heredoc_body,
    STATE(4800), 1,
      sym__simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
  [304580] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(4801), 1,
      sym__heredoc_body,
    STATE(4820), 1,
      sym__simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
  [304599] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
    STATE(4827), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304616] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(8288), 1,
      anon_sym_RBRACE3,
    STATE(6296), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [304631] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(4828), 1,
      sym__heredoc_body,
    STATE(4831), 1,
      sym__simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
  [304650] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(4852), 1,
      sym__heredoc_body,
    STATE(4862), 1,
      sym__simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
  [304669] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(4922), 1,
      sym__heredoc_body,
    STATE(4932), 1,
      sym__simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
  [304688] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15092), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [304703] = 6,
    ACTIONS(13), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(29), 1,
      anon_sym_LBRACE,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15038), 1,
      anon_sym_do,
    STATE(4685), 1,
      sym_do_group,
    STATE(4687), 1,
      sym_compound_statement,
  [304722] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14924), 1,
      anon_sym_RPAREN,
    ACTIONS(15078), 1,
      sym__special_character,
    STATE(6394), 1,
      aux_sym__literal_repeat1,
    STATE(6511), 1,
      aux_sym_case_item_repeat1,
  [304741] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
    STATE(5565), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304758] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [304773] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
    STATE(4713), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304790] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
    STATE(5586), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304807] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
    STATE(4681), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304824] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(5588), 1,
      sym__heredoc_body,
    STATE(5605), 1,
      sym__simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
  [304843] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(5547), 1,
      sym__simple_heredoc_body,
    STATE(5553), 1,
      sym__heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
  [304862] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
    STATE(5551), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304879] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15010), 1,
      anon_sym_RPAREN,
    ACTIONS(15078), 1,
      sym__special_character,
    STATE(6394), 1,
      aux_sym__literal_repeat1,
    STATE(6617), 1,
      aux_sym_case_item_repeat1,
  [304898] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
    STATE(5573), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [304915] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(5554), 1,
      sym__heredoc_body,
    STATE(5577), 1,
      sym__simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
  [304934] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14686), 1,
      anon_sym_in,
    ACTIONS(14690), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14688), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [304949] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(4680), 1,
      sym__simple_heredoc_body,
    STATE(4902), 1,
      sym__heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
  [304968] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15147), 1,
      anon_sym_COMMA,
    ACTIONS(15150), 1,
      aux_sym_heredoc_redirect_token1,
    STATE(6361), 1,
      aux_sym__for_body_repeat1,
    ACTIONS(15145), 2,
      anon_sym_SEMI,
      anon_sym_AMP,
  [304985] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
    STATE(5465), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [305002] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
    STATE(5468), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [305019] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15152), 1,
      anon_sym_in,
    ACTIONS(15156), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(15154), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [305034] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(5564), 1,
      sym__simple_heredoc_body,
    STATE(5566), 1,
      sym__heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
  [305053] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(4693), 1,
      sym__heredoc_body,
    STATE(4715), 1,
      sym__simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
  [305072] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
    STATE(5582), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [305089] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(5592), 1,
      sym__heredoc_body,
    STATE(5602), 1,
      sym__simple_heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
  [305108] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15090), 1,
      sym_simple_heredoc_body,
    STATE(5550), 1,
      sym__simple_heredoc_body,
    STATE(5604), 1,
      sym__heredoc_body,
    STATE(7024), 1,
      sym_heredoc_body,
  [305127] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(5469), 1,
      sym__heredoc_body,
    STATE(5470), 1,
      sym__simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
  [305146] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14906), 1,
      anon_sym_SLASH,
    ACTIONS(14910), 1,
      anon_sym_RBRACE3,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [305163] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(4730), 1,
      sym__heredoc_body,
    STATE(4784), 1,
      sym__simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
  [305182] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14767), 1,
      anon_sym_in,
    ACTIONS(14771), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(14769), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [305197] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15158), 1,
      sym__concat,
    ACTIONS(6639), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305210] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15160), 1,
      anon_sym_in,
    ACTIONS(15164), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(15162), 3,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_SEMI_SEMI,
  [305225] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(5471), 1,
      sym__heredoc_body,
    STATE(5472), 1,
      sym__simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
  [305244] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7902), 1,
      anon_sym_RBRACE3,
    STATE(6349), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(7752), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [305259] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
    STATE(5473), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [305276] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15166), 1,
      anon_sym_RBRACE3,
    STATE(6379), 1,
      aux_sym__expansion_body_repeat1,
    ACTIONS(15168), 3,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
  [305291] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
    STATE(5475), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [305308] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(4725), 1,
      sym__heredoc_body,
    STATE(4818), 1,
      sym__simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
  [305327] = 4,
    ACTIONS(71), 1,
      sym_comment,
    STATE(6383), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(14810), 2,
      sym__concat,
      aux_sym_concatenation_token1,
    ACTIONS(15171), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [305342] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14810), 1,
      aux_sym_concatenation_token1,
    ACTIONS(15173), 1,
      sym__concat,
    STATE(6324), 1,
      aux_sym_concatenation_repeat1,
    ACTIONS(1229), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [305359] = 6,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15084), 1,
      sym_simple_heredoc_body,
    STATE(5476), 1,
      sym__heredoc_body,
    STATE(5477), 1,
      sym__simple_heredoc_body,
    STATE(6814), 1,
      sym_heredoc_body,
  [305378] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15117), 1,
      sym_simple_heredoc_body,
    STATE(6932), 1,
      sym_heredoc_body,
    STATE(4762), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [305395] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15082), 1,
      sym__heredoc_body_beginning,
    ACTIONS(15125), 1,
      sym_simple_heredoc_body,
    STATE(7181), 1,
      sym_heredoc_body,
    STATE(4912), 2,
      sym__heredoc_body,
      sym__simple_heredoc_body,
  [305412] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1274), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305422] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1310), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305432] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1262), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305442] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1270), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305452] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305462] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1306), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305472] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305482] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15175), 1,
      sym__special_character,
    STATE(6394), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [305496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15180), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(15178), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
  [305508] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6639), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305518] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15182), 1,
      anon_sym_esac,
    ACTIONS(15184), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15186), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15188), 1,
      anon_sym_SEMI_SEMI_AMP,
  [305534] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7768), 1,
      sym__special_character,
    ACTIONS(15086), 1,
      anon_sym_SLASH,
    ACTIONS(15088), 1,
      anon_sym_RBRACE3,
    STATE(6419), 1,
      aux_sym__literal_repeat1,
  [305550] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6724), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305560] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6728), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305570] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1266), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305580] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1282), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305590] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1250), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305600] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1258), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305610] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1278), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305620] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1290), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305630] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1294), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305640] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1298), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305650] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15190), 1,
      anon_sym_esac,
    ACTIONS(15192), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15194), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15196), 1,
      anon_sym_SEMI_SEMI_AMP,
  [305666] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305676] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1306), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305686] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305696] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15078), 1,
      sym__special_character,
    STATE(6394), 1,
      aux_sym__literal_repeat1,
    ACTIONS(15171), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [305710] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15198), 1,
      anon_sym_esac,
    ACTIONS(15200), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15202), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
  [305724] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1314), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [305734] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15204), 1,
      anon_sym_esac,
    ACTIONS(15206), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15208), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
  [305748] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15190), 1,
      anon_sym_esac,
    ACTIONS(15210), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15212), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15214), 1,
      anon_sym_SEMI_SEMI_AMP,
  [305764] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15216), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305774] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15218), 1,
      sym__special_character,
    STATE(6419), 1,
      aux_sym__literal_repeat1,
    ACTIONS(1318), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [305788] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7768), 1,
      sym__special_character,
    ACTIONS(15100), 1,
      anon_sym_SLASH,
    ACTIONS(15102), 1,
      anon_sym_RBRACE3,
    STATE(6419), 1,
      aux_sym__literal_repeat1,
  [305804] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1278), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305814] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1290), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305824] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15182), 1,
      anon_sym_esac,
    ACTIONS(15221), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15223), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15225), 1,
      anon_sym_SEMI_SEMI_AMP,
  [305840] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1266), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305850] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1294), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305860] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1250), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305870] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1298), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305880] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1258), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305890] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15229), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(15227), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
  [305902] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305912] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1306), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305922] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305932] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7768), 1,
      sym__special_character,
    ACTIONS(15070), 1,
      anon_sym_SLASH,
    ACTIONS(15072), 1,
      anon_sym_RBRACE3,
    STATE(6419), 1,
      aux_sym__literal_repeat1,
  [305948] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5888), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305958] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15108), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [305968] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6651), 4,
      sym__external_expansion_sym_hash,
      sym__external_expansion_sym_bang,
      sym__external_expansion_sym_equal,
      anon_sym_RBRACE3,
  [305978] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15231), 1,
      anon_sym_RBRACE3,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [305992] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(5707), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [306002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15150), 1,
      aux_sym_heredoc_redirect_token1,
    ACTIONS(15145), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
  [306014] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15233), 1,
      anon_sym_esac,
    ACTIONS(15235), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15237), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15239), 1,
      anon_sym_SEMI_SEMI_AMP,
  [306030] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15241), 1,
      anon_sym_esac,
    ACTIONS(15243), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15245), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
  [306044] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15247), 1,
      anon_sym_esac,
    ACTIONS(15249), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15251), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
  [306058] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15253), 1,
      anon_sym_esac,
    ACTIONS(15255), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15257), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15259), 1,
      anon_sym_SEMI_SEMI_AMP,
  [306074] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15253), 1,
      anon_sym_esac,
    ACTIONS(15261), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15263), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15265), 1,
      anon_sym_SEMI_SEMI_AMP,
  [306090] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1254), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [306100] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1286), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [306110] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1215), 4,
      sym__concat,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      aux_sym_concatenation_token1,
  [306120] = 5,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15233), 1,
      anon_sym_esac,
    ACTIONS(15267), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15269), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15271), 1,
      anon_sym_SEMI_SEMI_AMP,
  [306136] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1314), 4,
      sym__concat,
      anon_sym_SLASH,
      aux_sym_concatenation_token1,
      anon_sym_RBRACE3,
  [306146] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15273), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306159] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306172] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15277), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306185] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15279), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306198] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15281), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306211] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15223), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15225), 1,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(15283), 1,
      anon_sym_SEMI_SEMI,
  [306224] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14812), 1,
      anon_sym_RPAREN,
    STATE(6501), 1,
      aux_sym_case_item_repeat1,
  [306237] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15285), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306248] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15289), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306261] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15291), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306274] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15293), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306285] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15295), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306298] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12681), 1,
      anon_sym_PIPE,
    ACTIONS(15297), 1,
      anon_sym_PIPE_AMP,
    STATE(4965), 1,
      aux_sym_pipeline_repeat1,
  [306311] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15299), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306322] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15301), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    STATE(6579), 1,
      aux_sym__for_body_repeat1,
  [306335] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15305), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306346] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15307), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6584), 1,
      aux_sym__for_body_repeat1,
  [306359] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15309), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306372] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15311), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [306385] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15313), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306396] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15315), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306407] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15317), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306420] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15319), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [306433] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15321), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15208), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
  [306444] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15323), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306455] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15325), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [306468] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15327), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306479] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15150), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(15329), 1,
      anon_sym_COMMA,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [306492] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15332), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [306505] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1262), 3,
      anon_sym_SLASH,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [306514] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15334), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306525] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15336), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306536] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15338), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6478), 1,
      aux_sym__for_body_repeat1,
  [306549] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15340), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306562] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1225), 3,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      sym__special_character,
  [306571] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1270), 3,
      anon_sym_SLASH,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [306580] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15342), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306591] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15344), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306604] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15346), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306617] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15348), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306628] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15350), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306641] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15352), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306652] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1223), 1,
      sym__special_character,
    ACTIONS(1225), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [306663] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15354), 1,
      anon_sym_PIPE,
    ACTIONS(15357), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306676] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15359), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306689] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15361), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306700] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15363), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [306711] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15365), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306724] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15367), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306737] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15369), 1,
      anon_sym_COMMA,
    ACTIONS(15371), 1,
      anon_sym_RPAREN,
    STATE(6504), 1,
      aux_sym__for_body_repeat1,
  [306750] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15373), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306763] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15375), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306776] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15377), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306789] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15379), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306802] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15369), 1,
      anon_sym_COMMA,
    ACTIONS(15381), 1,
      anon_sym_RPAREN,
    STATE(6510), 1,
      aux_sym__for_body_repeat1,
  [306815] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15383), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306828] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15385), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306841] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15387), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306854] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15389), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306867] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15391), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306880] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15150), 1,
      anon_sym_RPAREN,
    ACTIONS(15393), 1,
      anon_sym_COMMA,
    STATE(6510), 1,
      aux_sym__for_body_repeat1,
  [306893] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15396), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306906] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(7184), 1,
      anon_sym_RPAREN_RPAREN,
    ACTIONS(15398), 1,
      anon_sym_COMMA,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306919] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14808), 1,
      anon_sym_RPAREN,
    STATE(6615), 1,
      aux_sym_case_item_repeat1,
  [306932] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15401), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306945] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15403), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306958] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15405), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306971] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15407), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [306984] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15409), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [306997] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15411), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307010] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13373), 1,
      anon_sym_PIPE,
    ACTIONS(13375), 1,
      anon_sym_PIPE_AMP,
    STATE(5516), 1,
      aux_sym_pipeline_repeat1,
  [307023] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15413), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [307036] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15415), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307049] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15417), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307062] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15419), 1,
      sym__concat,
    ACTIONS(6651), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [307073] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15421), 1,
      sym__concat,
    ACTIONS(6639), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [307084] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15423), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307097] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15425), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307110] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1266), 3,
      sym__regex_no_slash,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [307119] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15427), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307132] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15429), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307145] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15431), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307158] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15433), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6551), 1,
      aux_sym__for_body_repeat1,
  [307171] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1250), 3,
      sym__regex_no_slash,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [307180] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15369), 1,
      anon_sym_COMMA,
    ACTIONS(15435), 1,
      anon_sym_RPAREN,
    STATE(6539), 1,
      aux_sym__for_body_repeat1,
  [307193] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1258), 3,
      sym__regex_no_slash,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [307202] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15437), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307215] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15369), 1,
      anon_sym_COMMA,
    ACTIONS(15439), 1,
      anon_sym_RPAREN,
    STATE(6510), 1,
      aux_sym__for_body_repeat1,
  [307228] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15441), 1,
      sym_extglob_pattern,
    ACTIONS(6468), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307239] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15369), 1,
      anon_sym_COMMA,
    ACTIONS(15443), 1,
      anon_sym_RPAREN,
    STATE(6510), 1,
      aux_sym__for_body_repeat1,
  [307252] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15445), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307265] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15257), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15259), 1,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(15447), 1,
      anon_sym_SEMI_SEMI,
  [307278] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15449), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307291] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15451), 1,
      anon_sym_SLASH,
    ACTIONS(15453), 1,
      anon_sym_RBRACE3,
    ACTIONS(15455), 1,
      sym__regex_no_slash,
  [307304] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15457), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307317] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15263), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15265), 1,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(15459), 1,
      anon_sym_SEMI_SEMI,
  [307330] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15269), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15271), 1,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(15461), 1,
      anon_sym_SEMI_SEMI,
  [307343] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15463), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307356] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15465), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307369] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15467), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307382] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15469), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307395] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15471), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [307408] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15473), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307421] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15475), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307434] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15477), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307447] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12688), 1,
      anon_sym_PIPE,
    ACTIONS(15479), 1,
      anon_sym_PIPE_AMP,
    STATE(4992), 1,
      aux_sym_pipeline_repeat1,
  [307460] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15481), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [307471] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15483), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307484] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15485), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307497] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15487), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [307508] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15489), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307521] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15491), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15202), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
  [307532] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15369), 1,
      anon_sym_COMMA,
    ACTIONS(15493), 1,
      anon_sym_RPAREN,
    STATE(6537), 1,
      aux_sym__for_body_repeat1,
  [307545] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15495), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307558] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15497), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307571] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15499), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6521), 1,
      aux_sym__for_body_repeat1,
  [307584] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15501), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307597] = 3,
    ACTIONS(71), 1,
      sym_comment,
    STATE(6309), 1,
      aux_sym__concatenation_in_expansion_repeat1,
    ACTIONS(14908), 2,
      sym__concat,
      aux_sym_concatenation_token1,
  [307608] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15503), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307621] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1266), 3,
      sym_extglob_pattern,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307630] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1294), 3,
      sym_extglob_pattern,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307639] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15186), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15188), 1,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(15505), 1,
      anon_sym_SEMI_SEMI,
  [307652] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15507), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307665] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12220), 1,
      anon_sym_PIPE,
    ACTIONS(15509), 1,
      anon_sym_PIPE_AMP,
    STATE(4581), 1,
      aux_sym_pipeline_repeat1,
  [307678] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1250), 3,
      sym_extglob_pattern,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307687] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15511), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [307700] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1298), 3,
      sym_extglob_pattern,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307709] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1258), 3,
      sym_extglob_pattern,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307718] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15513), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6621), 1,
      aux_sym__for_body_repeat1,
  [307731] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15515), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [307744] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15517), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6472), 1,
      aux_sym__for_body_repeat1,
  [307757] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15519), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307770] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15521), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307783] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12864), 1,
      anon_sym_PIPE,
    ACTIONS(15523), 1,
      anon_sym_PIPE_AMP,
    STATE(5098), 1,
      aux_sym_pipeline_repeat1,
  [307796] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15525), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [307809] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15527), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6475), 1,
      aux_sym__for_body_repeat1,
  [307822] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15529), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307835] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15531), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [307846] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15533), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [307857] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15237), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15239), 1,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(15535), 1,
      anon_sym_SEMI_SEMI,
  [307870] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15537), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15245), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
  [307881] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_extglob_pattern,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307890] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12563), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_PIPE_AMP,
    STATE(4821), 1,
      aux_sym_pipeline_repeat1,
  [307903] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1306), 3,
      sym_extglob_pattern,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307912] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1302), 3,
      sym_extglob_pattern,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [307921] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15541), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [307932] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15543), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307945] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15545), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307958] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15547), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307971] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(14960), 1,
      anon_sym_RPAREN,
    STATE(6488), 1,
      aux_sym_case_item_repeat1,
  [307984] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15549), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [307997] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15551), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308010] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15194), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15196), 1,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(15553), 1,
      anon_sym_SEMI_SEMI,
  [308023] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15555), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308036] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(13281), 1,
      anon_sym_PIPE,
    ACTIONS(15557), 1,
      anon_sym_PIPE_AMP,
    STATE(5441), 1,
      aux_sym_pipeline_repeat1,
  [308049] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15559), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6468), 1,
      aux_sym__for_body_repeat1,
  [308062] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15561), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308075] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15563), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308086] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15565), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308097] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15567), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [308110] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15569), 1,
      sym__concat,
    ACTIONS(6673), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308121] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15014), 1,
      anon_sym_RPAREN,
    STATE(6453), 1,
      aux_sym_case_item_repeat1,
  [308134] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15571), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308147] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15573), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308160] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15575), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [308173] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15577), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [308186] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15579), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308199] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15581), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [308212] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12668), 1,
      anon_sym_PIPE,
    ACTIONS(15583), 1,
      anon_sym_PIPE_AMP,
    STATE(4945), 1,
      aux_sym_pipeline_repeat1,
  [308225] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15585), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(15251), 2,
      anon_sym_SEMI_AMP,
      anon_sym_SEMI_SEMI_AMP,
  [308236] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15212), 1,
      anon_sym_SEMI_AMP,
    ACTIONS(15214), 1,
      anon_sym_SEMI_SEMI_AMP,
    ACTIONS(15587), 1,
      anon_sym_SEMI_SEMI,
  [308249] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_COMMA,
    ACTIONS(15589), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6477), 1,
      aux_sym__for_body_repeat1,
  [308262] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14806), 1,
      anon_sym_PIPE,
    ACTIONS(15591), 1,
      anon_sym_RPAREN,
    STATE(6493), 1,
      aux_sym_case_item_repeat1,
  [308275] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15593), 1,
      sym__concat,
    ACTIONS(6703), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308286] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15287), 1,
      anon_sym_LBRACK,
    ACTIONS(15595), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308297] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15597), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308310] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15599), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308323] = 4,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6824), 1,
      anon_sym_COMMA,
    ACTIONS(15601), 1,
      anon_sym_RPAREN_RPAREN,
    STATE(6512), 1,
      aux_sym_arithmetic_expansion_repeat1,
  [308336] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15150), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [308344] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15603), 1,
      anon_sym_RBRACE3,
    ACTIONS(15605), 1,
      sym_regex,
  [308354] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14952), 1,
      anon_sym_do,
    STATE(5569), 1,
      sym_do_group,
  [308364] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6639), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308372] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14900), 1,
      anon_sym_do,
    STATE(4819), 1,
      sym_do_group,
  [308382] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15334), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308390] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15487), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308398] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12180), 2,
      sym__concat,
      anon_sym_RBRACK,
  [308406] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15293), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308414] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15313), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308422] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15451), 1,
      anon_sym_SLASH,
    ACTIONS(15453), 1,
      anon_sym_RBRACE3,
  [308432] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6589), 1,
      anon_sym_RBRACK,
    ACTIONS(6844), 1,
      sym__concat,
  [308442] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15086), 1,
      anon_sym_SLASH,
    ACTIONS(15088), 1,
      anon_sym_RBRACE3,
  [308452] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15481), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308460] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1310), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [308468] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6728), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308476] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14952), 1,
      anon_sym_do,
    STATE(5542), 1,
      sym_do_group,
  [308486] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15607), 1,
      anon_sym_SLASH,
    ACTIONS(15609), 1,
      anon_sym_RBRACE3,
  [308496] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15229), 2,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
  [308504] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12101), 2,
      sym__concat,
      anon_sym_RBRACK,
  [308512] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1250), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [308520] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12107), 2,
      sym__concat,
      anon_sym_RBRACK,
  [308528] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15531), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308536] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15336), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308544] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15533), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308552] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15611), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(15613), 1,
      aux_sym__simple_variable_name_token1,
  [308562] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14900), 1,
      anon_sym_do,
    STATE(4704), 1,
      sym_do_group,
  [308572] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15363), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308580] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15285), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308588] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15315), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308596] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14962), 1,
      anon_sym_SLASH,
    ACTIONS(14964), 1,
      anon_sym_RBRACE3,
  [308606] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15229), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [308614] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15106), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [308622] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14796), 1,
      anon_sym_COLON,
    ACTIONS(14798), 1,
      anon_sym_RBRACE3,
  [308632] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(12228), 2,
      sym__concat,
      anon_sym_RBRACK,
  [308640] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6489), 1,
      anon_sym_RBRACK,
    ACTIONS(6998), 1,
      sym__concat,
  [308650] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15541), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308658] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14906), 1,
      anon_sym_SLASH,
    ACTIONS(14910), 1,
      anon_sym_RBRACE3,
  [308668] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6483), 1,
      anon_sym_RBRACK,
    ACTIONS(6848), 1,
      sym__concat,
  [308678] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6472), 1,
      anon_sym_RBRACK,
    ACTIONS(6834), 1,
      sym__concat,
  [308688] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6605), 1,
      anon_sym_RBRACK,
    ACTIONS(6838), 1,
      sym__concat,
  [308698] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15342), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308706] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15615), 1,
      anon_sym_SLASH,
    ACTIONS(15617), 1,
      anon_sym_RBRACE3,
  [308716] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1254), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [308724] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15323), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308732] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15348), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308740] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1258), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [308748] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15595), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308756] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15038), 1,
      anon_sym_do,
    STATE(4749), 1,
      sym_do_group,
  [308766] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15100), 1,
      anon_sym_SLASH,
    ACTIONS(15102), 1,
      anon_sym_RBRACE3,
  [308776] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6667), 2,
      anon_sym_COLON,
      anon_sym_RBRACE3,
  [308784] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15563), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308792] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15038), 1,
      anon_sym_do,
    STATE(4792), 1,
      sym_do_group,
  [308802] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15565), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308810] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15619), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(15621), 1,
      aux_sym__simple_variable_name_token1,
  [308820] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14980), 1,
      anon_sym_SLASH,
    ACTIONS(14982), 1,
      anon_sym_RBRACE3,
  [308830] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15623), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(15625), 1,
      aux_sym__simple_variable_name_token1,
  [308840] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15150), 2,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
  [308848] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15180), 2,
      anon_sym_RPAREN_RPAREN,
      anon_sym_COMMA,
  [308856] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6495), 1,
      anon_sym_RBRACK,
    ACTIONS(6840), 1,
      sym__concat,
  [308866] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6663), 2,
      anon_sym_PIPE,
      anon_sym_RPAREN,
  [308874] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14860), 1,
      anon_sym_do,
    STATE(4954), 1,
      sym_do_group,
  [308884] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15627), 1,
      anon_sym_LPAREN_LPAREN,
    ACTIONS(15629), 1,
      aux_sym__simple_variable_name_token1,
  [308894] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(1266), 2,
      anon_sym_SLASH,
      anon_sym_RBRACE3,
  [308902] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15180), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [308910] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6724), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308918] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15631), 1,
      anon_sym_SLASH,
    ACTIONS(15633), 1,
      anon_sym_RBRACE3,
  [308928] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15352), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308936] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15070), 1,
      anon_sym_SLASH,
    ACTIONS(15072), 1,
      anon_sym_RBRACE3,
  [308946] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15327), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308954] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14860), 1,
      anon_sym_do,
    STATE(4997), 1,
      sym_do_group,
  [308964] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(6651), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308972] = 3,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15635), 1,
      anon_sym_SLASH,
    ACTIONS(15637), 1,
      anon_sym_RBRACE3,
  [308982] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15305), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308990] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15361), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [308998] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15299), 2,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
  [309006] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [309013] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15639), 1,
      anon_sym_BQUOTE,
  [309020] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15641), 1,
      anon_sym_RPAREN,
  [309027] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14892), 1,
      anon_sym_RBRACE3,
  [309034] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15643), 1,
      anon_sym_RBRACE3,
  [309041] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15645), 1,
      anon_sym_RPAREN,
  [309048] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15647), 1,
      aux_sym_brace_expression_token1,
  [309055] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15649), 1,
      anon_sym_BQUOTE,
  [309062] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15651), 1,
      anon_sym_RPAREN_RPAREN,
  [309069] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [309076] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15653), 1,
      anon_sym_BQUOTE,
  [309083] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [309090] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15655), 1,
      anon_sym_RBRACE3,
  [309097] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15657), 1,
      anon_sym_RBRACE3,
  [309104] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15659), 1,
      anon_sym_RPAREN,
  [309111] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15661), 1,
      aux_sym_brace_expression_token1,
  [309118] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15663), 1,
      anon_sym_RBRACE3,
  [309125] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15665), 1,
      anon_sym_BQUOTE,
  [309132] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15667), 1,
      anon_sym_RBRACE3,
  [309139] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15669), 1,
      anon_sym_RPAREN,
  [309146] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [309153] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15659), 1,
      anon_sym_BQUOTE,
  [309160] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15671), 1,
      anon_sym_BQUOTE,
  [309167] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15673), 1,
      anon_sym_RPAREN,
  [309174] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15675), 1,
      aux_sym_brace_expression_token1,
  [309181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15677), 1,
      aux_sym_heredoc_redirect_token1,
  [309188] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15679), 1,
      anon_sym_RPAREN,
  [309195] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15681), 1,
      anon_sym_RPAREN,
  [309202] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15683), 1,
      anon_sym_RBRACE2,
  [309209] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15669), 1,
      anon_sym_BQUOTE,
  [309216] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15685), 1,
      anon_sym_fi,
  [309223] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15687), 1,
      anon_sym_RBRACE2,
  [309230] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15689), 1,
      anon_sym_RBRACE3,
  [309237] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15691), 1,
      aux_sym_brace_expression_token1,
  [309244] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15693), 1,
      anon_sym_RPAREN,
  [309251] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15695), 1,
      anon_sym_RPAREN,
  [309258] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15697), 1,
      anon_sym_BQUOTE,
  [309265] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15699), 1,
      anon_sym_RBRACE3,
  [309272] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15701), 1,
      anon_sym_BQUOTE,
  [309279] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15703), 1,
      anon_sym_RBRACE2,
  [309286] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15693), 1,
      anon_sym_BQUOTE,
  [309293] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15705), 1,
      anon_sym_RPAREN,
  [309300] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15707), 1,
      aux_sym_brace_expression_token1,
  [309307] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15709), 1,
      anon_sym_RPAREN,
  [309314] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15711), 1,
      anon_sym_RPAREN,
  [309321] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14892), 1,
      anon_sym_RBRACE3,
  [309328] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15713), 1,
      anon_sym_RBRACE2,
  [309335] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15715), 1,
      anon_sym_BQUOTE,
  [309342] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15717), 1,
      anon_sym_RBRACE3,
  [309349] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15711), 1,
      anon_sym_BQUOTE,
  [309356] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15719), 1,
      anon_sym_RPAREN,
  [309363] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15721), 1,
      aux_sym_brace_expression_token1,
  [309370] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15092), 1,
      anon_sym_RBRACE3,
  [309377] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15723), 1,
      anon_sym_BQUOTE,
  [309384] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15719), 1,
      anon_sym_BQUOTE,
  [309391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15725), 1,
      aux_sym_heredoc_redirect_token1,
  [309398] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15679), 1,
      anon_sym_BQUOTE,
  [309405] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15727), 1,
      anon_sym_RPAREN,
  [309412] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15729), 1,
      anon_sym_RPAREN,
  [309419] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15731), 1,
      anon_sym_esac,
  [309426] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15733), 1,
      aux_sym_brace_expression_token1,
  [309433] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15735), 1,
      anon_sym_RBRACE2,
  [309440] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [309447] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15737), 1,
      anon_sym_RPAREN,
  [309454] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [309461] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15739), 1,
      anon_sym_esac,
  [309468] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15741), 1,
      anon_sym_RBRACE3,
  [309475] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15743), 1,
      anon_sym_RBRACE2,
  [309482] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15092), 1,
      anon_sym_RBRACE3,
  [309489] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15745), 1,
      aux_sym_brace_expression_token1,
  [309496] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15747), 1,
      anon_sym_RBRACE2,
  [309503] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15749), 1,
      anon_sym_RPAREN,
  [309510] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9852), 1,
      anon_sym_RBRACK,
  [309517] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9784), 1,
      anon_sym_RBRACK,
  [309524] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15751), 1,
      anon_sym_RBRACE2,
  [309531] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15753), 1,
      sym_word,
  [309538] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15755), 1,
      aux_sym_brace_expression_token1,
  [309545] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15757), 1,
      anon_sym_RBRACE3,
  [309552] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15759), 1,
      anon_sym_RPAREN,
  [309559] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15761), 1,
      anon_sym_RBRACE2,
  [309566] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [309573] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14954), 1,
      anon_sym_fi,
  [309580] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15763), 1,
      anon_sym_RPAREN,
  [309587] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15765), 1,
      aux_sym_brace_expression_token1,
  [309594] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15767), 1,
      anon_sym_RBRACE3,
  [309601] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15769), 1,
      anon_sym_esac,
  [309608] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [309615] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15771), 1,
      anon_sym_BQUOTE,
  [309622] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15773), 1,
      anon_sym_esac,
  [309629] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15763), 1,
      anon_sym_BQUOTE,
  [309636] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15775), 1,
      aux_sym_brace_expression_token1,
  [309643] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15777), 1,
      anon_sym_RPAREN,
  [309650] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15779), 1,
      anon_sym_RPAREN,
  [309657] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15781), 1,
      anon_sym_RBRACE3,
  [309664] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15783), 1,
      anon_sym_RBRACE2,
  [309671] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14892), 1,
      anon_sym_RBRACE3,
  [309678] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15785), 1,
      anon_sym_RBRACE2,
  [309685] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15787), 1,
      aux_sym_brace_expression_token1,
  [309692] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15789), 1,
      anon_sym_RBRACE3,
  [309699] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15058), 1,
      anon_sym_fi,
  [309706] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15791), 1,
      anon_sym_RBRACE3,
  [309713] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15793), 1,
      anon_sym_esac,
  [309720] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15795), 1,
      anon_sym_RPAREN,
  [309727] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15797), 1,
      anon_sym_esac,
  [309734] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15799), 1,
      aux_sym_brace_expression_token1,
  [309741] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15801), 1,
      anon_sym_BQUOTE,
  [309748] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15803), 1,
      anon_sym_RBRACE3,
  [309755] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [309762] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15805), 1,
      anon_sym_RBRACK_RBRACK,
  [309769] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15807), 1,
      sym_heredoc_end,
  [309776] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15809), 1,
      sym_heredoc_end,
  [309783] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15811), 1,
      aux_sym_brace_expression_token1,
  [309790] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15813), 1,
      anon_sym_RPAREN,
  [309797] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15815), 1,
      anon_sym_RBRACK_RBRACK,
  [309804] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15817), 1,
      anon_sym_BQUOTE,
  [309811] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15819), 1,
      anon_sym_RBRACE3,
  [309818] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15821), 1,
      anon_sym_fi,
  [309825] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15823), 1,
      anon_sym_esac,
  [309832] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15825), 1,
      aux_sym_brace_expression_token1,
  [309839] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15827), 1,
      anon_sym_esac,
  [309846] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15829), 1,
      anon_sym_RPAREN,
  [309853] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15831), 1,
      anon_sym_RBRACE3,
  [309860] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15833), 1,
      anon_sym_BQUOTE,
  [309867] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15829), 1,
      anon_sym_BQUOTE,
  [309874] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15835), 1,
      anon_sym_RPAREN,
  [309881] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15837), 1,
      aux_sym_brace_expression_token1,
  [309888] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15839), 1,
      anon_sym_esac,
  [309895] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15841), 1,
      anon_sym_esac,
  [309902] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15843), 1,
      anon_sym_BQUOTE,
  [309909] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15845), 1,
      anon_sym_RPAREN,
  [309916] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15847), 1,
      anon_sym_RBRACE2,
  [309923] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15813), 1,
      anon_sym_BQUOTE,
  [309930] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15849), 1,
      aux_sym_brace_expression_token1,
  [309937] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15851), 1,
      anon_sym_BQUOTE,
  [309944] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15845), 1,
      anon_sym_BQUOTE,
  [309951] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15853), 1,
      anon_sym_RPAREN,
  [309958] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15795), 1,
      anon_sym_BQUOTE,
  [309965] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15855), 1,
      anon_sym_RPAREN,
  [309972] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15857), 1,
      anon_sym_RPAREN,
  [309979] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15859), 1,
      aux_sym_brace_expression_token1,
  [309986] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15861), 1,
      anon_sym_RBRACE2,
  [309993] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15863), 1,
      anon_sym_RPAREN,
  [310000] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15865), 1,
      anon_sym_RBRACE3,
  [310007] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15867), 1,
      anon_sym_RBRACE3,
  [310014] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15869), 1,
      anon_sym_RPAREN,
  [310021] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15871), 1,
      anon_sym_RBRACE2,
  [310028] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15873), 1,
      aux_sym_brace_expression_token1,
  [310035] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15875), 1,
      anon_sym_BQUOTE,
  [310042] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15869), 1,
      anon_sym_BQUOTE,
  [310049] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15877), 1,
      anon_sym_RBRACE2,
  [310056] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15879), 1,
      anon_sym_RPAREN,
  [310063] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15881), 1,
      anon_sym_RPAREN,
  [310070] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15883), 1,
      anon_sym_RPAREN,
  [310077] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15885), 1,
      aux_sym_brace_expression_token1,
  [310084] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15887), 1,
      anon_sym_RBRACE2,
  [310091] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15889), 1,
      anon_sym_LT_LT_LT,
  [310098] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15891), 1,
      aux_sym_brace_expression_token1,
  [310105] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15893), 1,
      anon_sym_RPAREN_RPAREN,
  [310112] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15895), 1,
      anon_sym_in,
  [310119] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15897), 1,
      anon_sym_RBRACE3,
  [310126] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15899), 1,
      aux_sym_brace_expression_token1,
  [310133] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15901), 1,
      anon_sym_RBRACE3,
  [310140] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15903), 1,
      anon_sym_RPAREN,
  [310147] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15905), 1,
      anon_sym_RPAREN,
  [310154] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15907), 1,
      anon_sym_RBRACE3,
  [310161] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15909), 1,
      anon_sym_RPAREN,
  [310168] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15911), 1,
      anon_sym_in,
  [310175] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15913), 1,
      aux_sym_brace_expression_token1,
  [310182] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15915), 1,
      anon_sym_BQUOTE,
  [310189] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15917), 1,
      anon_sym_RBRACE3,
  [310196] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15919), 1,
      anon_sym_RPAREN,
  [310203] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15779), 1,
      anon_sym_BQUOTE,
  [310210] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15921), 1,
      anon_sym_BQUOTE,
  [310217] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15923), 1,
      anon_sym_BQUOTE,
  [310224] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15925), 1,
      aux_sym_brace_expression_token1,
  [310231] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15927), 1,
      ts_builtin_sym_end,
  [310238] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15929), 1,
      anon_sym_esac,
  [310245] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15931), 1,
      anon_sym_BQUOTE,
  [310252] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15919), 1,
      anon_sym_BQUOTE,
  [310259] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15933), 1,
      anon_sym_RPAREN,
  [310266] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15881), 1,
      anon_sym_BQUOTE,
  [310273] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15935), 1,
      aux_sym_brace_expression_token1,
  [310280] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15909), 1,
      anon_sym_BQUOTE,
  [310287] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15937), 1,
      anon_sym_RBRACE2,
  [310294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15939), 1,
      aux_sym_heredoc_redirect_token1,
  [310301] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15941), 1,
      anon_sym_RPAREN,
  [310308] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15943), 1,
      anon_sym_RPAREN,
  [310315] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15945), 1,
      sym_heredoc_end,
  [310322] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15947), 1,
      aux_sym_brace_expression_token1,
  [310329] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15903), 1,
      anon_sym_BQUOTE,
  [310336] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15949), 1,
      anon_sym_RBRACE2,
  [310343] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15951), 1,
      aux_sym_heredoc_redirect_token1,
  [310350] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15953), 1,
      anon_sym_RPAREN,
  [310357] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15955), 1,
      anon_sym_RBRACE3,
  [310364] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [310371] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15957), 1,
      aux_sym_brace_expression_token1,
  [310378] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15959), 1,
      anon_sym_RPAREN,
  [310385] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15961), 1,
      anon_sym_RBRACE3,
  [310392] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15963), 1,
      anon_sym_RPAREN,
  [310399] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15965), 1,
      anon_sym_RPAREN,
  [310406] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15967), 1,
      anon_sym_BQUOTE,
  [310413] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15963), 1,
      anon_sym_BQUOTE,
  [310420] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15969), 1,
      aux_sym_brace_expression_token1,
  [310427] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15971), 1,
      anon_sym_RPAREN,
  [310434] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15973), 1,
      anon_sym_RBRACE2,
  [310441] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15975), 1,
      anon_sym_RBRACE2,
  [310448] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15977), 1,
      anon_sym_BQUOTE,
  [310455] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15979), 1,
      anon_sym_RBRACE2,
  [310462] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15981), 1,
      anon_sym_RBRACE2,
  [310469] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15983), 1,
      aux_sym_brace_expression_token1,
  [310476] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15985), 1,
      anon_sym_BQUOTE,
  [310483] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15987), 1,
      anon_sym_RBRACE3,
  [310490] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15989), 1,
      anon_sym_RPAREN,
  [310497] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15991), 1,
      anon_sym_RBRACE3,
  [310504] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15993), 1,
      anon_sym_RPAREN,
  [310511] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15995), 1,
      anon_sym_RBRACK_RBRACK,
  [310518] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15997), 1,
      aux_sym_brace_expression_token1,
  [310525] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15999), 1,
      aux_sym_heredoc_redirect_token1,
  [310532] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16001), 1,
      anon_sym_RPAREN,
  [310539] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16003), 1,
      anon_sym_BQUOTE,
  [310546] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16005), 1,
      anon_sym_RBRACE3,
  [310553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16007), 1,
      aux_sym_heredoc_redirect_token1,
  [310560] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16009), 1,
      anon_sym_RPAREN,
  [310567] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16011), 1,
      aux_sym_brace_expression_token1,
  [310574] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16013), 1,
      sym_heredoc_start,
  [310581] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16015), 1,
      anon_sym_BQUOTE,
  [310588] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16009), 1,
      anon_sym_BQUOTE,
  [310595] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16017), 1,
      anon_sym_RPAREN,
  [310602] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16019), 1,
      sym_heredoc_end,
  [310609] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15993), 1,
      anon_sym_BQUOTE,
  [310616] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16021), 1,
      aux_sym_brace_expression_token1,
  [310623] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16023), 1,
      anon_sym_RBRACE2,
  [310630] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16025), 1,
      anon_sym_RPAREN,
  [310637] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16027), 1,
      anon_sym_RBRACK_RBRACK,
  [310644] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16029), 1,
      anon_sym_RBRACE3,
  [310651] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16031), 1,
      anon_sym_RBRACE3,
  [310658] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16033), 1,
      anon_sym_BQUOTE,
  [310665] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16035), 1,
      aux_sym_brace_expression_token1,
  [310672] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16037), 1,
      anon_sym_RBRACE2,
  [310679] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16039), 1,
      anon_sym_RPAREN,
  [310686] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16041), 1,
      anon_sym_RBRACE3,
  [310693] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16043), 1,
      anon_sym_RPAREN,
  [310700] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16045), 1,
      anon_sym_RBRACE3,
  [310707] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16047), 1,
      anon_sym_BQUOTE,
  [310714] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16049), 1,
      aux_sym_brace_expression_token1,
  [310721] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16043), 1,
      anon_sym_BQUOTE,
  [310728] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16051), 1,
      anon_sym_RPAREN,
  [310735] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16053), 1,
      anon_sym_LBRACK,
  [310742] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16055), 1,
      aux_sym_heredoc_redirect_token1,
  [310749] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16057), 1,
      aux_sym_heredoc_redirect_token1,
  [310756] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16059), 1,
      anon_sym_RBRACE3,
  [310763] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16061), 1,
      aux_sym_brace_expression_token1,
  [310770] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15989), 1,
      anon_sym_BQUOTE,
  [310777] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16063), 1,
      anon_sym_RBRACE3,
  [310784] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16065), 1,
      anon_sym_BQUOTE,
  [310791] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16039), 1,
      anon_sym_BQUOTE,
  [310798] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16067), 1,
      aux_sym_heredoc_redirect_token1,
  [310805] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16069), 1,
      anon_sym_RPAREN,
  [310812] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16071), 1,
      aux_sym_brace_expression_token1,
  [310819] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16073), 1,
      anon_sym_RPAREN,
  [310826] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15863), 1,
      anon_sym_BQUOTE,
  [310833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16075), 1,
      aux_sym_heredoc_redirect_token1,
  [310840] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16077), 1,
      anon_sym_BQUOTE,
  [310847] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16069), 1,
      anon_sym_BQUOTE,
  [310854] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16079), 1,
      anon_sym_RPAREN,
  [310861] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16081), 1,
      aux_sym_brace_expression_token1,
  [310868] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16083), 1,
      anon_sym_RBRACE3,
  [310875] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16085), 1,
      anon_sym_RPAREN,
  [310882] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16087), 1,
      anon_sym_RBRACE2,
  [310889] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16089), 1,
      anon_sym_RBRACE2,
  [310896] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15965), 1,
      anon_sym_BQUOTE,
  [310903] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15092), 1,
      anon_sym_RBRACE3,
  [310910] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16091), 1,
      aux_sym_brace_expression_token1,
  [310917] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16093), 1,
      anon_sym_RBRACE3,
  [310924] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16095), 1,
      anon_sym_RBRACE2,
  [310931] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16097), 1,
      anon_sym_RPAREN,
  [310938] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14994), 1,
      anon_sym_RBRACE3,
  [310945] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16099), 1,
      anon_sym_LT_LT_LT,
  [310952] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16101), 1,
      anon_sym_RPAREN,
  [310959] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16103), 1,
      aux_sym_brace_expression_token1,
  [310966] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16105), 1,
      anon_sym_RBRACE3,
  [310973] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16107), 1,
      anon_sym_RPAREN,
  [310980] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16109), 1,
      anon_sym_BQUOTE,
  [310987] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9954), 1,
      anon_sym_RBRACK,
  [310994] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9892), 1,
      anon_sym_RBRACK,
  [311001] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16111), 1,
      anon_sym_RBRACE2,
  [311008] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16113), 1,
      aux_sym_brace_expression_token1,
  [311015] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16115), 1,
      aux_sym_heredoc_redirect_token1,
  [311022] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16117), 1,
      anon_sym_RBRACE3,
  [311029] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16119), 1,
      anon_sym_RPAREN,
  [311036] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16121), 1,
      anon_sym_BQUOTE,
  [311043] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16123), 1,
      anon_sym_BQUOTE,
  [311050] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14958), 1,
      anon_sym_fi,
  [311057] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16125), 1,
      aux_sym_brace_expression_token1,
  [311064] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16119), 1,
      anon_sym_BQUOTE,
  [311071] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16127), 1,
      anon_sym_RPAREN,
  [311078] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16129), 1,
      anon_sym_esac,
  [311085] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15092), 1,
      anon_sym_RBRACE3,
  [311092] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16131), 1,
      aux_sym_brace_expression_token1,
  [311099] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16133), 1,
      anon_sym_esac,
  [311106] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16135), 1,
      aux_sym_brace_expression_token1,
  [311113] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16107), 1,
      anon_sym_BQUOTE,
  [311120] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16137), 1,
      anon_sym_RBRACE2,
  [311127] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16139), 1,
      anon_sym_RPAREN,
  [311134] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16141), 1,
      anon_sym_RPAREN,
  [311141] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16143), 1,
      anon_sym_RPAREN_RPAREN,
  [311148] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15092), 1,
      anon_sym_RBRACE3,
  [311155] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16145), 1,
      aux_sym_brace_expression_token1,
  [311162] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16147), 1,
      anon_sym_RBRACE2,
  [311169] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16149), 1,
      anon_sym_RBRACE3,
  [311176] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15012), 1,
      anon_sym_fi,
  [311183] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16151), 1,
      anon_sym_RBRACE2,
  [311190] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16153), 1,
      anon_sym_esac,
  [311197] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15905), 1,
      anon_sym_BQUOTE,
  [311204] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16155), 1,
      aux_sym_brace_expression_token1,
  [311211] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16157), 1,
      anon_sym_esac,
  [311218] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16159), 1,
      anon_sym_RPAREN,
  [311225] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16161), 1,
      anon_sym_RBRACE2,
  [311232] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16163), 1,
      anon_sym_RPAREN,
  [311239] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16165), 1,
      sym_heredoc_end,
  [311246] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16167), 1,
      sym_heredoc_end,
  [311253] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16169), 1,
      aux_sym_brace_expression_token1,
  [311260] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16171), 1,
      anon_sym_RBRACE3,
  [311267] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16173), 1,
      anon_sym_RPAREN,
  [311274] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14892), 1,
      anon_sym_RBRACE3,
  [311281] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16175), 1,
      anon_sym_BQUOTE,
  [311288] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16177), 1,
      anon_sym_fi,
  [311295] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16179), 1,
      anon_sym_esac,
  [311302] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16181), 1,
      aux_sym_brace_expression_token1,
  [311309] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16183), 1,
      anon_sym_esac,
  [311316] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16173), 1,
      anon_sym_BQUOTE,
  [311323] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16185), 1,
      anon_sym_RPAREN,
  [311330] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16187), 1,
      anon_sym_RBRACE3,
  [311337] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [311344] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16189), 1,
      anon_sym_RBRACE2,
  [311351] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16191), 1,
      aux_sym_brace_expression_token1,
  [311358] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16193), 1,
      anon_sym_esac,
  [311365] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16195), 1,
      anon_sym_esac,
  [311372] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16197), 1,
      anon_sym_RPAREN,
  [311379] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16199), 1,
      anon_sym_RBRACE3,
  [311386] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16201), 1,
      anon_sym_BQUOTE,
  [311393] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16203), 1,
      anon_sym_RBRACE3,
  [311400] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16205), 1,
      aux_sym_brace_expression_token1,
  [311407] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16207), 1,
      anon_sym_RBRACE3,
  [311414] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16197), 1,
      anon_sym_BQUOTE,
  [311421] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16209), 1,
      anon_sym_RPAREN,
  [311428] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16211), 1,
      anon_sym_in,
  [311435] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16213), 1,
      anon_sym_BQUOTE,
  [311442] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16209), 1,
      anon_sym_BQUOTE,
  [311449] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16215), 1,
      aux_sym_brace_expression_token1,
  [311456] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16217), 1,
      anon_sym_RBRACE3,
  [311463] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16219), 1,
      anon_sym_RPAREN,
  [311470] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16221), 1,
      anon_sym_RPAREN,
  [311477] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16223), 1,
      anon_sym_RPAREN,
  [311484] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16225), 1,
      anon_sym_BQUOTE,
  [311491] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16227), 1,
      anon_sym_in,
  [311498] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16229), 1,
      aux_sym_brace_expression_token1,
  [311505] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16219), 1,
      anon_sym_BQUOTE,
  [311512] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16231), 1,
      anon_sym_RPAREN,
  [311519] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16233), 1,
      anon_sym_RPAREN,
  [311526] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16235), 1,
      anon_sym_BQUOTE,
  [311533] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16237), 1,
      anon_sym_RBRACE2,
  [311540] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16239), 1,
      anon_sym_esac,
  [311547] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16241), 1,
      aux_sym_brace_expression_token1,
  [311554] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16243), 1,
      anon_sym_RBRACE2,
  [311561] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16245), 1,
      anon_sym_RBRACE2,
  [311568] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16247), 1,
      anon_sym_RBRACE2,
  [311575] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16249), 1,
      anon_sym_RBRACE3,
  [311582] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16251), 1,
      anon_sym_RPAREN,
  [311589] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16253), 1,
      anon_sym_RBRACE3,
  [311596] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16255), 1,
      aux_sym_brace_expression_token1,
  [311603] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16257), 1,
      anon_sym_BQUOTE,
  [311610] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16259), 1,
      anon_sym_RBRACE3,
  [311617] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16261), 1,
      anon_sym_RPAREN,
  [311624] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16251), 1,
      anon_sym_BQUOTE,
  [311631] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16263), 1,
      anon_sym_BQUOTE,
  [311638] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16261), 1,
      anon_sym_BQUOTE,
  [311645] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16265), 1,
      aux_sym_brace_expression_token1,
  [311652] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16267), 1,
      anon_sym_RPAREN,
  [311659] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16269), 1,
      anon_sym_RPAREN,
  [311666] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16271), 1,
      anon_sym_BQUOTE,
  [311673] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16273), 1,
      anon_sym_RPAREN,
  [311680] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16275), 1,
      anon_sym_RBRACE3,
  [311687] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16277), 1,
      anon_sym_RPAREN,
  [311694] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16279), 1,
      aux_sym_brace_expression_token1,
  [311701] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16281), 1,
      anon_sym_RBRACE2,
  [311708] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16283), 1,
      anon_sym_RBRACE3,
  [311715] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16285), 1,
      anon_sym_RPAREN,
  [311722] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14820), 1,
      anon_sym_RBRACE3,
  [311729] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16287), 1,
      anon_sym_LT_LT_LT,
  [311736] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16289), 1,
      anon_sym_BQUOTE,
  [311743] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16285), 1,
      anon_sym_BQUOTE,
  [311750] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16291), 1,
      anon_sym_BQUOTE,
  [311757] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16293), 1,
      aux_sym_brace_expression_token1,
  [311764] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16277), 1,
      anon_sym_BQUOTE,
  [311771] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16233), 1,
      anon_sym_BQUOTE,
  [311778] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16295), 1,
      anon_sym_RPAREN,
  [311785] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16297), 1,
      anon_sym_RPAREN,
  [311792] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [311799] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16299), 1,
      anon_sym_RPAREN,
  [311806] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [311813] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [311820] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16301), 1,
      anon_sym_RBRACE2,
  [311827] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16303), 1,
      anon_sym_RBRACE3,
  [311834] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16305), 1,
      anon_sym_RPAREN,
  [311841] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16307), 1,
      anon_sym_BQUOTE,
  [311848] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16309), 1,
      anon_sym_BQUOTE,
  [311855] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16305), 1,
      anon_sym_BQUOTE,
  [311862] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16311), 1,
      anon_sym_RBRACK_RBRACK,
  [311869] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16273), 1,
      anon_sym_BQUOTE,
  [311876] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16313), 1,
      anon_sym_RPAREN,
  [311883] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16315), 1,
      aux_sym_heredoc_redirect_token1,
  [311890] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16317), 1,
      aux_sym_heredoc_redirect_token1,
  [311897] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15115), 1,
      anon_sym_RBRACE3,
  [311904] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16319), 1,
      anon_sym_RBRACE3,
  [311911] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16321), 1,
      anon_sym_RPAREN,
  [311918] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16323), 1,
      anon_sym_RBRACE3,
  [311925] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16325), 1,
      anon_sym_BQUOTE,
  [311932] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16321), 1,
      anon_sym_BQUOTE,
  [311939] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16327), 1,
      anon_sym_RPAREN,
  [311946] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16329), 1,
      anon_sym_RBRACE3,
  [311953] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16331), 1,
      anon_sym_RPAREN,
  [311960] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16333), 1,
      anon_sym_RBRACE2,
  [311967] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16335), 1,
      anon_sym_BQUOTE,
  [311974] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16331), 1,
      anon_sym_BQUOTE,
  [311981] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14852), 1,
      anon_sym_RBRACE3,
  [311988] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [311995] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16337), 1,
      anon_sym_RBRACE2,
  [312002] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14852), 1,
      anon_sym_RBRACE3,
  [312009] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16339), 1,
      aux_sym_heredoc_redirect_token1,
  [312016] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14852), 1,
      anon_sym_RBRACE3,
  [312023] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16341), 1,
      anon_sym_RBRACE3,
  [312030] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16343), 1,
      aux_sym_heredoc_redirect_token1,
  [312037] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15629), 1,
      aux_sym__simple_variable_name_token1,
  [312044] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16345), 1,
      anon_sym_RPAREN,
  [312051] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16347), 1,
      anon_sym_RBRACE2,
  [312058] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16349), 1,
      sym_word,
  [312065] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16351), 1,
      anon_sym_DOT_DOT,
  [312072] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16353), 1,
      anon_sym_BQUOTE,
  [312079] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16355), 1,
      anon_sym_RBRACE3,
  [312086] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16357), 1,
      anon_sym_RPAREN,
  [312093] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16359), 1,
      sym_heredoc_start,
  [312100] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16361), 1,
      aux_sym_heredoc_redirect_token1,
  [312107] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16345), 1,
      anon_sym_BQUOTE,
  [312114] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16363), 1,
      anon_sym_RBRACE3,
  [312121] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16365), 1,
      anon_sym_RPAREN,
  [312128] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16367), 1,
      sym_heredoc_start,
  [312135] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16369), 1,
      anon_sym_RBRACE3,
  [312142] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16371), 1,
      anon_sym_BQUOTE,
  [312149] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9704), 1,
      anon_sym_RBRACK,
  [312156] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9678), 1,
      anon_sym_RBRACK,
  [312163] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16373), 1,
      anon_sym_RBRACE2,
  [312170] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16365), 1,
      anon_sym_BQUOTE,
  [312177] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16375), 1,
      anon_sym_RPAREN,
  [312184] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14852), 1,
      anon_sym_RBRACE3,
  [312191] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14862), 1,
      anon_sym_fi,
  [312198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16377), 1,
      aux_sym_heredoc_redirect_token1,
  [312205] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16379), 1,
      anon_sym_RBRACE3,
  [312212] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16381), 1,
      anon_sym_esac,
  [312219] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14824), 1,
      anon_sym_RBRACE3,
  [312226] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16383), 1,
      anon_sym_RBRACE2,
  [312233] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16385), 1,
      anon_sym_esac,
  [312240] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15115), 1,
      anon_sym_RBRACE3,
  [312247] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16387), 1,
      anon_sym_RPAREN,
  [312254] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16389), 1,
      anon_sym_RBRACE3,
  [312261] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16391), 1,
      anon_sym_RPAREN,
  [312268] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16393), 1,
      anon_sym_RPAREN,
  [312275] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16395), 1,
      anon_sym_BQUOTE,
  [312282] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [312289] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14874), 1,
      anon_sym_fi,
  [312296] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16391), 1,
      anon_sym_BQUOTE,
  [312303] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16397), 1,
      anon_sym_esac,
  [312310] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16399), 1,
      anon_sym_RBRACE3,
  [312317] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16401), 1,
      anon_sym_esac,
  [312324] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16403), 1,
      anon_sym_RPAREN,
  [312331] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16405), 1,
      anon_sym_RBRACE3,
  [312338] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16407), 1,
      sym_heredoc_end,
  [312345] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16409), 1,
      sym_heredoc_end,
  [312352] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16411), 1,
      anon_sym_RBRACE3,
  [312359] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16413), 1,
      anon_sym_BQUOTE,
  [312366] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16415), 1,
      anon_sym_RBRACE3,
  [312373] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16417), 1,
      anon_sym_RPAREN,
  [312380] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16403), 1,
      anon_sym_BQUOTE,
  [312387] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16419), 1,
      anon_sym_fi,
  [312394] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16421), 1,
      anon_sym_esac,
  [312401] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16423), 1,
      anon_sym_esac,
  [312408] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16425), 1,
      anon_sym_BQUOTE,
  [312415] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16417), 1,
      anon_sym_BQUOTE,
  [312422] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16427), 1,
      anon_sym_BQUOTE,
  [312429] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16429), 1,
      anon_sym_RPAREN,
  [312436] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16431), 1,
      anon_sym_BQUOTE,
  [312443] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16433), 1,
      anon_sym_esac,
  [312450] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16435), 1,
      anon_sym_esac,
  [312457] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16437), 1,
      anon_sym_BQUOTE,
  [312464] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16429), 1,
      anon_sym_BQUOTE,
  [312471] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16439), 1,
      anon_sym_RBRACE3,
  [312478] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16441), 1,
      anon_sym_RPAREN,
  [312485] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16443), 1,
      anon_sym_RPAREN,
  [312492] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16445), 1,
      anon_sym_BQUOTE,
  [312499] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16441), 1,
      anon_sym_BQUOTE,
  [312506] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16393), 1,
      anon_sym_BQUOTE,
  [312513] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16447), 1,
      aux_sym_heredoc_redirect_token1,
  [312520] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16449), 1,
      anon_sym_RPAREN,
  [312527] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16451), 1,
      anon_sym_RPAREN,
  [312534] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16453), 1,
      anon_sym_RBRACE2,
  [312541] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16455), 1,
      anon_sym_RPAREN,
  [312548] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16457), 1,
      anon_sym_RBRACE2,
  [312555] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16459), 1,
      anon_sym_RBRACE2,
  [312562] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16461), 1,
      ts_builtin_sym_end,
  [312569] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16463), 1,
      anon_sym_RBRACE3,
  [312576] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [312583] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16465), 1,
      anon_sym_RPAREN,
  [312590] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15115), 1,
      anon_sym_RBRACE3,
  [312597] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16467), 1,
      anon_sym_BQUOTE,
  [312604] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16465), 1,
      anon_sym_BQUOTE,
  [312611] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [312618] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16469), 1,
      anon_sym_RBRACE2,
  [312625] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15231), 1,
      anon_sym_RBRACE3,
  [312632] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9956), 1,
      anon_sym_RBRACK,
  [312639] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16471), 1,
      anon_sym_BQUOTE,
  [312646] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14364), 1,
      anon_sym_RBRACE3,
  [312653] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16473), 1,
      anon_sym_RPAREN,
  [312660] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16163), 1,
      anon_sym_BQUOTE,
  [312667] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16475), 1,
      anon_sym_BQUOTE,
  [312674] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16477), 1,
      anon_sym_RBRACE3,
  [312681] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16479), 1,
      anon_sym_RBRACE3,
  [312688] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16481), 1,
      anon_sym_RPAREN,
  [312695] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14916), 1,
      anon_sym_fi,
  [312702] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16483), 1,
      anon_sym_RBRACK_RBRACK,
  [312709] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16485), 1,
      anon_sym_RPAREN,
  [312716] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16267), 1,
      anon_sym_BQUOTE,
  [312723] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16487), 1,
      anon_sym_BQUOTE,
  [312730] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16481), 1,
      anon_sym_BQUOTE,
  [312737] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16489), 1,
      anon_sym_RBRACE3,
  [312744] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16491), 1,
      anon_sym_RBRACE3,
  [312751] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16493), 1,
      anon_sym_RPAREN,
  [312758] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16495), 1,
      anon_sym_RPAREN,
  [312765] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16497), 1,
      anon_sym_BQUOTE,
  [312772] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16493), 1,
      anon_sym_BQUOTE,
  [312779] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16499), 1,
      anon_sym_RPAREN,
  [312786] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16501), 1,
      anon_sym_RPAREN,
  [312793] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [312800] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16503), 1,
      anon_sym_RBRACE3,
  [312807] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16505), 1,
      anon_sym_BQUOTE,
  [312814] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16507), 1,
      aux_sym_heredoc_redirect_token1,
  [312821] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15115), 1,
      anon_sym_RBRACE3,
  [312828] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16501), 1,
      anon_sym_BQUOTE,
  [312835] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16509), 1,
      anon_sym_RBRACE3,
  [312842] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16511), 1,
      anon_sym_RPAREN,
  [312849] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16513), 1,
      aux_sym_heredoc_redirect_token1,
  [312856] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16515), 1,
      anon_sym_RPAREN,
  [312863] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15092), 1,
      anon_sym_RBRACE3,
  [312870] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16517), 1,
      anon_sym_BQUOTE,
  [312877] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16519), 1,
      anon_sym_RBRACE2,
  [312884] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16521), 1,
      anon_sym_RBRACE2,
  [312891] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16523), 1,
      aux_sym_brace_expression_token1,
  [312898] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9832), 1,
      anon_sym_RBRACK,
  [312905] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9830), 1,
      anon_sym_RBRACK,
  [312912] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16525), 1,
      anon_sym_RBRACE2,
  [312919] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16511), 1,
      anon_sym_BQUOTE,
  [312926] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16527), 1,
      anon_sym_RPAREN,
  [312933] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16529), 1,
      anon_sym_RBRACE2,
  [312940] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16531), 1,
      sym_heredoc_end,
  [312947] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16533), 1,
      sym_heredoc_end,
  [312954] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16535), 1,
      anon_sym_RBRACE3,
  [312961] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16537), 1,
      anon_sym_RBRACE2,
  [312968] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16539), 1,
      anon_sym_RPAREN,
  [312975] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [312982] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16541), 1,
      anon_sym_BQUOTE,
  [312989] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16543), 1,
      anon_sym_LT_LT_LT,
  [312996] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16545), 1,
      anon_sym_RBRACE3,
  [313003] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16539), 1,
      anon_sym_BQUOTE,
  [313010] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16547), 1,
      anon_sym_RPAREN,
  [313017] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16549), 1,
      aux_sym_heredoc_redirect_token1,
  [313024] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15613), 1,
      aux_sym__simple_variable_name_token1,
  [313031] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16551), 1,
      anon_sym_RPAREN,
  [313038] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16553), 1,
      anon_sym_BQUOTE,
  [313045] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16555), 1,
      sym_word,
  [313052] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16557), 1,
      anon_sym_DOT_DOT,
  [313059] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16559), 1,
      anon_sym_BQUOTE,
  [313066] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16551), 1,
      anon_sym_BQUOTE,
  [313073] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16561), 1,
      anon_sym_RPAREN,
  [313080] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16563), 1,
      sym_heredoc_start,
  [313087] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16565), 1,
      anon_sym_BQUOTE,
  [313094] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16485), 1,
      anon_sym_BQUOTE,
  [313101] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16567), 1,
      anon_sym_RPAREN,
  [313108] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16569), 1,
      sym_heredoc_start,
  [313115] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16387), 1,
      anon_sym_BQUOTE,
  [313122] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16571), 1,
      anon_sym_RBRACE2,
  [313129] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16573), 1,
      anon_sym_RBRACE3,
  [313136] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16575), 1,
      anon_sym_RPAREN,
  [313143] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16577), 1,
      anon_sym_RBRACE3,
  [313150] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16579), 1,
      anon_sym_BQUOTE,
  [313157] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16575), 1,
      anon_sym_BQUOTE,
  [313164] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16581), 1,
      aux_sym_heredoc_redirect_token1,
  [313171] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16583), 1,
      anon_sym_RPAREN,
  [313178] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16585), 1,
      anon_sym_RBRACE3,
  [313185] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16587), 1,
      anon_sym_BQUOTE,
  [313192] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16583), 1,
      anon_sym_BQUOTE,
  [313199] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16589), 1,
      anon_sym_RPAREN,
  [313206] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16591), 1,
      anon_sym_RPAREN,
  [313213] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16593), 1,
      anon_sym_BQUOTE,
  [313220] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16595), 1,
      anon_sym_RPAREN,
  [313227] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16597), 1,
      anon_sym_BQUOTE,
  [313234] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16599), 1,
      aux_sym_brace_expression_token1,
  [313241] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16601), 1,
      aux_sym_heredoc_redirect_token1,
  [313248] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16589), 1,
      anon_sym_BQUOTE,
  [313255] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16603), 1,
      anon_sym_RBRACE2,
  [313262] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16605), 1,
      sym_word,
  [313269] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16607), 1,
      anon_sym_RBRACE3,
  [313276] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16609), 1,
      anon_sym_RPAREN,
  [313283] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [313290] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16611), 1,
      anon_sym_BQUOTE,
  [313297] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16613), 1,
      anon_sym_in,
  [313304] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16615), 1,
      sym_word,
  [313311] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16617), 1,
      anon_sym_RBRACK_RBRACK,
  [313318] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16591), 1,
      anon_sym_BQUOTE,
  [313325] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16619), 1,
      anon_sym_in,
  [313332] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16621), 1,
      anon_sym_RPAREN,
  [313339] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16623), 1,
      anon_sym_RPAREN,
  [313346] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16625), 1,
      anon_sym_RPAREN,
  [313353] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16627), 1,
      anon_sym_BQUOTE,
  [313360] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16629), 1,
      anon_sym_RBRACE3,
  [313367] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16631), 1,
      anon_sym_RPAREN,
  [313374] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16623), 1,
      anon_sym_BQUOTE,
  [313381] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16633), 1,
      anon_sym_BQUOTE,
  [313388] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16631), 1,
      anon_sym_BQUOTE,
  [313395] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16635), 1,
      anon_sym_RPAREN,
  [313402] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16515), 1,
      anon_sym_BQUOTE,
  [313409] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16637), 1,
      anon_sym_RPAREN,
  [313416] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16639), 1,
      anon_sym_RPAREN,
  [313423] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16641), 1,
      anon_sym_RPAREN,
  [313430] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16643), 1,
      anon_sym_BQUOTE,
  [313437] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [313444] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16645), 1,
      anon_sym_RPAREN,
  [313451] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16621), 1,
      anon_sym_BQUOTE,
  [313458] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16647), 1,
      anon_sym_esac,
  [313465] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16649), 1,
      anon_sym_RPAREN,
  [313472] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16651), 1,
      aux_sym_heredoc_redirect_token1,
  [313479] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16653), 1,
      anon_sym_RPAREN,
  [313486] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [313493] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16655), 1,
      anon_sym_RBRACE2,
  [313500] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16657), 1,
      anon_sym_RBRACE3,
  [313507] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9952), 1,
      anon_sym_RBRACK,
  [313514] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9926), 1,
      anon_sym_RBRACK,
  [313521] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16659), 1,
      anon_sym_RBRACE2,
  [313528] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16661), 1,
      anon_sym_RPAREN,
  [313535] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16663), 1,
      anon_sym_BQUOTE,
  [313542] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16665), 1,
      anon_sym_BQUOTE,
  [313549] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16661), 1,
      anon_sym_BQUOTE,
  [313556] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16667), 1,
      anon_sym_RPAREN,
  [313563] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16669), 1,
      aux_sym_brace_expression_token1,
  [313570] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16671), 1,
      anon_sym_RPAREN,
  [313577] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16673), 1,
      anon_sym_LT_LT_LT,
  [313584] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16675), 1,
      aux_sym_brace_expression_token1,
  [313591] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16677), 1,
      anon_sym_RBRACE3,
  [313598] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16679), 1,
      anon_sym_RPAREN_RPAREN,
  [313605] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16625), 1,
      anon_sym_BQUOTE,
  [313612] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16681), 1,
      anon_sym_in,
  [313619] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16683), 1,
      anon_sym_in,
  [313626] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16685), 1,
      anon_sym_RBRACE2,
  [313633] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16687), 1,
      anon_sym_RBRACE3,
  [313640] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16689), 1,
      anon_sym_esac,
  [313647] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16691), 1,
      anon_sym_RPAREN,
  [313654] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16693), 1,
      anon_sym_RPAREN,
  [313661] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15625), 1,
      aux_sym__simple_variable_name_token1,
  [313668] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16695), 1,
      anon_sym_RPAREN,
  [313675] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14932), 1,
      anon_sym_RBRACE3,
  [313682] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16697), 1,
      anon_sym_RBRACK_RBRACK,
  [313689] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [313696] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16699), 1,
      anon_sym_RBRACE3,
  [313703] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16701), 1,
      anon_sym_LT_LT_LT,
  [313710] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16703), 1,
      anon_sym_LT_LT_LT,
  [313717] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16705), 1,
      anon_sym_BQUOTE,
  [313724] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16707), 1,
      anon_sym_RPAREN,
  [313731] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16709), 1,
      aux_sym_brace_expression_token1,
  [313738] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15621), 1,
      aux_sym__simple_variable_name_token1,
  [313745] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16711), 1,
      aux_sym_brace_expression_token1,
  [313752] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16695), 1,
      anon_sym_BQUOTE,
  [313759] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16713), 1,
      sym_word,
  [313766] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16715), 1,
      anon_sym_DOT_DOT,
  [313773] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16717), 1,
      anon_sym_BQUOTE,
  [313780] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16719), 1,
      anon_sym_RBRACE2,
  [313787] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16721), 1,
      anon_sym_RPAREN,
  [313794] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16723), 1,
      sym_heredoc_start,
  [313801] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16725), 1,
      anon_sym_RBRACE3,
  [313808] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16727), 1,
      anon_sym_RPAREN,
  [313815] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16729), 1,
      aux_sym_brace_expression_token1,
  [313822] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16731), 1,
      sym_heredoc_start,
  [313829] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16733), 1,
      anon_sym_BQUOTE,
  [313836] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16727), 1,
      anon_sym_BQUOTE,
  [313843] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16735), 1,
      anon_sym_RPAREN,
  [313850] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16737), 1,
      aux_sym_heredoc_redirect_token1,
  [313857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16739), 1,
      aux_sym_heredoc_redirect_token1,
  [313864] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16741), 1,
      anon_sym_BQUOTE,
  [313871] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16693), 1,
      anon_sym_BQUOTE,
  [313878] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16707), 1,
      anon_sym_BQUOTE,
  [313885] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16743), 1,
      anon_sym_DOT_DOT,
  [313892] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16745), 1,
      anon_sym_RPAREN,
  [313899] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16747), 1,
      anon_sym_RBRACK_RBRACK,
  [313906] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16749), 1,
      anon_sym_RBRACE2,
  [313913] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [313920] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16751), 1,
      anon_sym_RPAREN,
  [313927] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16753), 1,
      aux_sym_heredoc_redirect_token1,
  [313934] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16755), 1,
      anon_sym_RPAREN,
  [313941] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16757), 1,
      aux_sym_heredoc_redirect_token1,
  [313948] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16759), 1,
      sym_word,
  [313955] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16761), 1,
      anon_sym_DOT_DOT,
  [313962] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16763), 1,
      anon_sym_RPAREN,
  [313969] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16765), 1,
      sym_heredoc_start,
  [313976] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [313983] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16767), 1,
      anon_sym_RBRACE2,
  [313990] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16769), 1,
      sym_heredoc_start,
  [313997] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16771), 1,
      aux_sym_heredoc_redirect_token1,
  [314004] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16773), 1,
      anon_sym_RPAREN,
  [314011] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15115), 1,
      anon_sym_RBRACE3,
  [314018] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(16775), 1,
      aux_sym_heredoc_redirect_token1,
  [314025] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16777), 1,
      aux_sym_brace_expression_token1,
  [314032] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16779), 1,
      sym_heredoc_start,
  [314039] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15115), 1,
      anon_sym_RBRACE3,
  [314046] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15759), 1,
      anon_sym_BQUOTE,
  [314053] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [314060] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [314067] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15076), 1,
      anon_sym_RBRACE3,
  [314074] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16781), 1,
      anon_sym_RBRACE2,
  [314081] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16783), 1,
      anon_sym_RBRACE2,
  [314088] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(14974), 1,
      anon_sym_fi,
  [314095] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16785), 1,
      anon_sym_RBRACE2,
  [314102] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16787), 1,
      anon_sym_RBRACE3,
  [314109] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16789), 1,
      anon_sym_RBRACE3,
  [314116] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16791), 1,
      anon_sym_DOT_DOT,
  [314123] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16793), 1,
      anon_sym_DOT_DOT,
  [314130] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16795), 1,
      anon_sym_DOT_DOT,
  [314137] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16797), 1,
      anon_sym_DOT_DOT,
  [314144] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16799), 1,
      anon_sym_DOT_DOT,
  [314151] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16801), 1,
      anon_sym_DOT_DOT,
  [314158] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16803), 1,
      anon_sym_DOT_DOT,
  [314165] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16805), 1,
      anon_sym_DOT_DOT,
  [314172] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16807), 1,
      anon_sym_DOT_DOT,
  [314179] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16809), 1,
      anon_sym_DOT_DOT,
  [314186] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16811), 1,
      anon_sym_DOT_DOT,
  [314193] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16813), 1,
      anon_sym_DOT_DOT,
  [314200] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16815), 1,
      anon_sym_DOT_DOT,
  [314207] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16817), 1,
      anon_sym_DOT_DOT,
  [314214] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16819), 1,
      anon_sym_DOT_DOT,
  [314221] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16821), 1,
      anon_sym_DOT_DOT,
  [314228] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16823), 1,
      anon_sym_DOT_DOT,
  [314235] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16825), 1,
      anon_sym_DOT_DOT,
  [314242] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16827), 1,
      anon_sym_DOT_DOT,
  [314249] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16829), 1,
      anon_sym_DOT_DOT,
  [314256] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16831), 1,
      anon_sym_DOT_DOT,
  [314263] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16833), 1,
      anon_sym_DOT_DOT,
  [314270] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16835), 1,
      anon_sym_DOT_DOT,
  [314277] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16837), 1,
      anon_sym_DOT_DOT,
  [314284] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16839), 1,
      anon_sym_DOT_DOT,
  [314291] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16841), 1,
      anon_sym_DOT_DOT,
  [314298] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16843), 1,
      anon_sym_DOT_DOT,
  [314305] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16845), 1,
      anon_sym_DOT_DOT,
  [314312] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16847), 1,
      anon_sym_DOT_DOT,
  [314319] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16849), 1,
      anon_sym_DOT_DOT,
  [314326] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16851), 1,
      anon_sym_DOT_DOT,
  [314333] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16853), 1,
      anon_sym_DOT_DOT,
  [314340] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16855), 1,
      anon_sym_DOT_DOT,
  [314347] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16857), 1,
      anon_sym_DOT_DOT,
  [314354] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16859), 1,
      anon_sym_DOT_DOT,
  [314361] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16861), 1,
      anon_sym_DOT_DOT,
  [314368] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16863), 1,
      anon_sym_DOT_DOT,
  [314375] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16865), 1,
      anon_sym_DOT_DOT,
  [314382] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16867), 1,
      anon_sym_DOT_DOT,
  [314389] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16869), 1,
      anon_sym_DOT_DOT,
  [314396] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16871), 1,
      anon_sym_DOT_DOT,
  [314403] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16873), 1,
      anon_sym_DOT_DOT,
  [314410] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16875), 1,
      anon_sym_DOT_DOT,
  [314417] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16877), 1,
      anon_sym_DOT_DOT,
  [314424] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16879), 1,
      anon_sym_DOT_DOT,
  [314431] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16881), 1,
      anon_sym_DOT_DOT,
  [314438] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16883), 1,
      anon_sym_DOT_DOT,
  [314445] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16885), 1,
      anon_sym_DOT_DOT,
  [314452] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16887), 1,
      anon_sym_DOT_DOT,
  [314459] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16889), 1,
      anon_sym_DOT_DOT,
  [314466] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16891), 1,
      anon_sym_DOT_DOT,
  [314473] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16893), 1,
      anon_sym_DOT_DOT,
  [314480] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16895), 1,
      anon_sym_DOT_DOT,
  [314487] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16897), 1,
      anon_sym_DOT_DOT,
  [314494] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16899), 1,
      anon_sym_DOT_DOT,
  [314501] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16901), 1,
      anon_sym_DOT_DOT,
  [314508] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16903), 1,
      anon_sym_DOT_DOT,
  [314515] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16905), 1,
      anon_sym_DOT_DOT,
  [314522] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16907), 1,
      anon_sym_DOT_DOT,
  [314529] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16909), 1,
      aux_sym_brace_expression_token1,
  [314536] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15639), 1,
      anon_sym_RPAREN,
  [314543] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16911), 1,
      anon_sym_RPAREN,
  [314550] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16913), 1,
      anon_sym_esac,
  [314557] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16915), 1,
      anon_sym_BQUOTE,
  [314564] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16911), 1,
      anon_sym_BQUOTE,
  [314571] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16917), 1,
      sym_word,
  [314578] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(9958), 1,
      anon_sym_RBRACK,
  [314585] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16919), 1,
      anon_sym_RPAREN,
  [314592] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16921), 1,
      aux_sym_brace_expression_token1,
  [314599] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16923), 1,
      aux_sym_brace_expression_token1,
  [314606] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16925), 1,
      anon_sym_RBRACE3,
  [314613] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16927), 1,
      anon_sym_esac,
  [314620] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16929), 1,
      anon_sym_RPAREN,
  [314627] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15113), 1,
      anon_sym_RBRACE3,
  [314634] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(15653), 1,
      anon_sym_RPAREN,
  [314641] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16931), 1,
      aux_sym_brace_expression_token1,
  [314648] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16933), 1,
      aux_sym_brace_expression_token1,
  [314655] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16935), 1,
      aux_sym_brace_expression_token1,
  [314662] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16937), 1,
      aux_sym_brace_expression_token1,
  [314669] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16939), 1,
      aux_sym_brace_expression_token1,
  [314676] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16941), 1,
      aux_sym_brace_expression_token1,
  [314683] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16943), 1,
      aux_sym_brace_expression_token1,
  [314690] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16945), 1,
      aux_sym_brace_expression_token1,
  [314697] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16947), 1,
      aux_sym_brace_expression_token1,
  [314704] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16949), 1,
      aux_sym_brace_expression_token1,
  [314711] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16951), 1,
      aux_sym_brace_expression_token1,
  [314718] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16953), 1,
      aux_sym_brace_expression_token1,
  [314725] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16955), 1,
      aux_sym_brace_expression_token1,
  [314732] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16957), 1,
      aux_sym_brace_expression_token1,
  [314739] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16959), 1,
      aux_sym_brace_expression_token1,
  [314746] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16961), 1,
      aux_sym_brace_expression_token1,
  [314753] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16963), 1,
      aux_sym_brace_expression_token1,
  [314760] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16965), 1,
      aux_sym_brace_expression_token1,
  [314767] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16967), 1,
      aux_sym_brace_expression_token1,
  [314774] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16969), 1,
      aux_sym_brace_expression_token1,
  [314781] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16971), 1,
      aux_sym_brace_expression_token1,
  [314788] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16973), 1,
      aux_sym_brace_expression_token1,
  [314795] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16975), 1,
      aux_sym_brace_expression_token1,
  [314802] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16977), 1,
      aux_sym_brace_expression_token1,
  [314809] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16979), 1,
      aux_sym_brace_expression_token1,
  [314816] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16981), 1,
      aux_sym_brace_expression_token1,
  [314823] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16983), 1,
      aux_sym_brace_expression_token1,
  [314830] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16985), 1,
      aux_sym_brace_expression_token1,
  [314837] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16987), 1,
      aux_sym_brace_expression_token1,
  [314844] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16989), 1,
      aux_sym_brace_expression_token1,
  [314851] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16991), 1,
      aux_sym_brace_expression_token1,
  [314858] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16993), 1,
      aux_sym_brace_expression_token1,
  [314865] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16995), 1,
      aux_sym_brace_expression_token1,
  [314872] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16997), 1,
      aux_sym_brace_expression_token1,
  [314879] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(16999), 1,
      aux_sym_brace_expression_token1,
  [314886] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17001), 1,
      aux_sym_brace_expression_token1,
  [314893] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17003), 1,
      aux_sym_brace_expression_token1,
  [314900] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17005), 1,
      aux_sym_brace_expression_token1,
  [314907] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17007), 1,
      aux_sym_brace_expression_token1,
  [314914] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17009), 1,
      aux_sym_brace_expression_token1,
  [314921] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17011), 1,
      aux_sym_brace_expression_token1,
  [314928] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17013), 1,
      aux_sym_brace_expression_token1,
  [314935] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17015), 1,
      aux_sym_brace_expression_token1,
  [314942] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17017), 1,
      aux_sym_brace_expression_token1,
  [314949] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17019), 1,
      aux_sym_brace_expression_token1,
  [314956] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17021), 1,
      aux_sym_brace_expression_token1,
  [314963] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17023), 1,
      aux_sym_brace_expression_token1,
  [314970] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17025), 1,
      aux_sym_brace_expression_token1,
  [314977] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17027), 1,
      aux_sym_brace_expression_token1,
  [314984] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17029), 1,
      aux_sym_brace_expression_token1,
  [314991] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17031), 1,
      aux_sym_brace_expression_token1,
  [314998] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17033), 1,
      aux_sym_brace_expression_token1,
  [315005] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17035), 1,
      aux_sym_brace_expression_token1,
  [315012] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17037), 1,
      aux_sym_brace_expression_token1,
  [315019] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17039), 1,
      aux_sym_brace_expression_token1,
  [315026] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17041), 1,
      aux_sym_brace_expression_token1,
  [315033] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17043), 1,
      aux_sym_brace_expression_token1,
  [315040] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17045), 1,
      aux_sym_brace_expression_token1,
  [315047] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17047), 1,
      aux_sym_brace_expression_token1,
  [315054] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17049), 1,
      aux_sym_brace_expression_token1,
  [315061] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17051), 1,
      aux_sym_brace_expression_token1,
  [315068] = 2,
    ACTIONS(71), 1,
      sym_comment,
    ACTIONS(17053), 1,
      anon_sym_RBRACE3,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(523)] = 0,
  [SMALL_STATE(524)] = 119,
  [SMALL_STATE(525)] = 238,
  [SMALL_STATE(526)] = 356,
  [SMALL_STATE(527)] = 474,
  [SMALL_STATE(528)] = 587,
  [SMALL_STATE(529)] = 704,
  [SMALL_STATE(530)] = 819,
  [SMALL_STATE(531)] = 936,
  [SMALL_STATE(532)] = 1049,
  [SMALL_STATE(533)] = 1166,
  [SMALL_STATE(534)] = 1283,
  [SMALL_STATE(535)] = 1391,
  [SMALL_STATE(536)] = 1505,
  [SMALL_STATE(537)] = 1581,
  [SMALL_STATE(538)] = 1657,
  [SMALL_STATE(539)] = 1771,
  [SMALL_STATE(540)] = 1879,
  [SMALL_STATE(541)] = 1993,
  [SMALL_STATE(542)] = 2101,
  [SMALL_STATE(543)] = 2217,
  [SMALL_STATE(544)] = 2329,
  [SMALL_STATE(545)] = 2445,
  [SMALL_STATE(546)] = 2557,
  [SMALL_STATE(547)] = 2632,
  [SMALL_STATE(548)] = 2707,
  [SMALL_STATE(549)] = 2818,
  [SMALL_STATE(550)] = 2893,
  [SMALL_STATE(551)] = 3000,
  [SMALL_STATE(552)] = 3113,
  [SMALL_STATE(553)] = 3224,
  [SMALL_STATE(554)] = 3335,
  [SMALL_STATE(555)] = 3442,
  [SMALL_STATE(556)] = 3553,
  [SMALL_STATE(557)] = 3666,
  [SMALL_STATE(558)] = 3773,
  [SMALL_STATE(559)] = 3848,
  [SMALL_STATE(560)] = 3954,
  [SMALL_STATE(561)] = 4028,
  [SMALL_STATE(562)] = 4136,
  [SMALL_STATE(563)] = 4244,
  [SMALL_STATE(564)] = 4350,
  [SMALL_STATE(565)] = 4424,
  [SMALL_STATE(566)] = 4530,
  [SMALL_STATE(567)] = 4636,
  [SMALL_STATE(568)] = 4710,
  [SMALL_STATE(569)] = 4816,
  [SMALL_STATE(570)] = 4886,
  [SMALL_STATE(571)] = 4950,
  [SMALL_STATE(572)] = 5020,
  [SMALL_STATE(573)] = 5120,
  [SMALL_STATE(574)] = 5226,
  [SMALL_STATE(575)] = 5300,
  [SMALL_STATE(576)] = 5374,
  [SMALL_STATE(577)] = 5448,
  [SMALL_STATE(578)] = 5558,
  [SMALL_STATE(579)] = 5670,
  [SMALL_STATE(580)] = 5780,
  [SMALL_STATE(581)] = 5847,
  [SMALL_STATE(582)] = 5960,
  [SMALL_STATE(583)] = 6033,
  [SMALL_STATE(584)] = 6106,
  [SMALL_STATE(585)] = 6179,
  [SMALL_STATE(586)] = 6252,
  [SMALL_STATE(587)] = 6321,
  [SMALL_STATE(588)] = 6390,
  [SMALL_STATE(589)] = 6491,
  [SMALL_STATE(590)] = 6594,
  [SMALL_STATE(591)] = 6661,
  [SMALL_STATE(592)] = 6762,
  [SMALL_STATE(593)] = 6861,
  [SMALL_STATE(594)] = 6960,
  [SMALL_STATE(595)] = 7059,
  [SMALL_STATE(596)] = 7128,
  [SMALL_STATE(597)] = 7197,
  [SMALL_STATE(598)] = 7296,
  [SMALL_STATE(599)] = 7397,
  [SMALL_STATE(600)] = 7464,
  [SMALL_STATE(601)] = 7567,
  [SMALL_STATE(602)] = 7672,
  [SMALL_STATE(603)] = 7745,
  [SMALL_STATE(604)] = 7850,
  [SMALL_STATE(605)] = 7923,
  [SMALL_STATE(606)] = 8036,
  [SMALL_STATE(607)] = 8103,
  [SMALL_STATE(608)] = 8208,
  [SMALL_STATE(609)] = 8336,
  [SMALL_STATE(610)] = 8404,
  [SMALL_STATE(611)] = 8532,
  [SMALL_STATE(612)] = 8632,
  [SMALL_STATE(613)] = 8700,
  [SMALL_STATE(614)] = 8768,
  [SMALL_STATE(615)] = 8868,
  [SMALL_STATE(616)] = 8936,
  [SMALL_STATE(617)] = 9034,
  [SMALL_STATE(618)] = 9132,
  [SMALL_STATE(619)] = 9260,
  [SMALL_STATE(620)] = 9374,
  [SMALL_STATE(621)] = 9472,
  [SMALL_STATE(622)] = 9570,
  [SMALL_STATE(623)] = 9668,
  [SMALL_STATE(624)] = 9736,
  [SMALL_STATE(625)] = 9864,
  [SMALL_STATE(626)] = 9936,
  [SMALL_STATE(627)] = 10064,
  [SMALL_STATE(628)] = 10136,
  [SMALL_STATE(629)] = 10208,
  [SMALL_STATE(630)] = 10276,
  [SMALL_STATE(631)] = 10348,
  [SMALL_STATE(632)] = 10476,
  [SMALL_STATE(633)] = 10548,
  [SMALL_STATE(634)] = 10646,
  [SMALL_STATE(635)] = 10774,
  [SMALL_STATE(636)] = 10872,
  [SMALL_STATE(637)] = 10972,
  [SMALL_STATE(638)] = 11100,
  [SMALL_STATE(639)] = 11198,
  [SMALL_STATE(640)] = 11312,
  [SMALL_STATE(641)] = 11410,
  [SMALL_STATE(642)] = 11508,
  [SMALL_STATE(643)] = 11580,
  [SMALL_STATE(644)] = 11687,
  [SMALL_STATE(645)] = 11786,
  [SMALL_STATE(646)] = 11883,
  [SMALL_STATE(647)] = 11980,
  [SMALL_STATE(648)] = 12077,
  [SMALL_STATE(649)] = 12176,
  [SMALL_STATE(650)] = 12243,
  [SMALL_STATE(651)] = 12314,
  [SMALL_STATE(652)] = 12381,
  [SMALL_STATE(653)] = 12478,
  [SMALL_STATE(654)] = 12575,
  [SMALL_STATE(655)] = 12642,
  [SMALL_STATE(656)] = 12709,
  [SMALL_STATE(657)] = 12808,
  [SMALL_STATE(658)] = 12907,
  [SMALL_STATE(659)] = 12978,
  [SMALL_STATE(660)] = 13075,
  [SMALL_STATE(661)] = 13172,
  [SMALL_STATE(662)] = 13269,
  [SMALL_STATE(663)] = 13366,
  [SMALL_STATE(664)] = 13465,
  [SMALL_STATE(665)] = 13562,
  [SMALL_STATE(666)] = 13659,
  [SMALL_STATE(667)] = 13756,
  [SMALL_STATE(668)] = 13827,
  [SMALL_STATE(669)] = 13898,
  [SMALL_STATE(670)] = 13969,
  [SMALL_STATE(671)] = 14040,
  [SMALL_STATE(672)] = 14111,
  [SMALL_STATE(673)] = 14182,
  [SMALL_STATE(674)] = 14279,
  [SMALL_STATE(675)] = 14350,
  [SMALL_STATE(676)] = 14421,
  [SMALL_STATE(677)] = 14488,
  [SMALL_STATE(678)] = 14555,
  [SMALL_STATE(679)] = 14652,
  [SMALL_STATE(680)] = 14759,
  [SMALL_STATE(681)] = 14868,
  [SMALL_STATE(682)] = 14967,
  [SMALL_STATE(683)] = 15027,
  [SMALL_STATE(684)] = 15123,
  [SMALL_STATE(685)] = 15219,
  [SMALL_STATE(686)] = 15315,
  [SMALL_STATE(687)] = 15411,
  [SMALL_STATE(688)] = 15525,
  [SMALL_STATE(689)] = 15639,
  [SMALL_STATE(690)] = 15753,
  [SMALL_STATE(691)] = 15849,
  [SMALL_STATE(692)] = 15911,
  [SMALL_STATE(693)] = 15981,
  [SMALL_STATE(694)] = 16051,
  [SMALL_STATE(695)] = 16165,
  [SMALL_STATE(696)] = 16273,
  [SMALL_STATE(697)] = 16387,
  [SMALL_STATE(698)] = 16501,
  [SMALL_STATE(699)] = 16597,
  [SMALL_STATE(700)] = 16707,
  [SMALL_STATE(701)] = 16777,
  [SMALL_STATE(702)] = 16847,
  [SMALL_STATE(703)] = 16955,
  [SMALL_STATE(704)] = 17051,
  [SMALL_STATE(705)] = 17165,
  [SMALL_STATE(706)] = 17261,
  [SMALL_STATE(707)] = 17375,
  [SMALL_STATE(708)] = 17471,
  [SMALL_STATE(709)] = 17585,
  [SMALL_STATE(710)] = 17681,
  [SMALL_STATE(711)] = 17795,
  [SMALL_STATE(712)] = 17891,
  [SMALL_STATE(713)] = 17985,
  [SMALL_STATE(714)] = 18055,
  [SMALL_STATE(715)] = 18151,
  [SMALL_STATE(716)] = 18221,
  [SMALL_STATE(717)] = 18317,
  [SMALL_STATE(718)] = 18387,
  [SMALL_STATE(719)] = 18483,
  [SMALL_STATE(720)] = 18553,
  [SMALL_STATE(721)] = 18649,
  [SMALL_STATE(722)] = 18747,
  [SMALL_STATE(723)] = 18841,
  [SMALL_STATE(724)] = 18937,
  [SMALL_STATE(725)] = 19033,
  [SMALL_STATE(726)] = 19131,
  [SMALL_STATE(727)] = 19193,
  [SMALL_STATE(728)] = 19263,
  [SMALL_STATE(729)] = 19365,
  [SMALL_STATE(730)] = 19435,
  [SMALL_STATE(731)] = 19505,
  [SMALL_STATE(732)] = 19607,
  [SMALL_STATE(733)] = 19677,
  [SMALL_STATE(734)] = 19747,
  [SMALL_STATE(735)] = 19817,
  [SMALL_STATE(736)] = 19887,
  [SMALL_STATE(737)] = 19985,
  [SMALL_STATE(738)] = 20051,
  [SMALL_STATE(739)] = 20121,
  [SMALL_STATE(740)] = 20187,
  [SMALL_STATE(741)] = 20289,
  [SMALL_STATE(742)] = 20349,
  [SMALL_STATE(743)] = 20418,
  [SMALL_STATE(744)] = 20513,
  [SMALL_STATE(745)] = 20582,
  [SMALL_STATE(746)] = 20651,
  [SMALL_STATE(747)] = 20720,
  [SMALL_STATE(748)] = 20823,
  [SMALL_STATE(749)] = 20892,
  [SMALL_STATE(750)] = 20961,
  [SMALL_STATE(751)] = 21030,
  [SMALL_STATE(752)] = 21099,
  [SMALL_STATE(753)] = 21168,
  [SMALL_STATE(754)] = 21229,
  [SMALL_STATE(755)] = 21298,
  [SMALL_STATE(756)] = 21367,
  [SMALL_STATE(757)] = 21462,
  [SMALL_STATE(758)] = 21555,
  [SMALL_STATE(759)] = 21648,
  [SMALL_STATE(760)] = 21743,
  [SMALL_STATE(761)] = 21812,
  [SMALL_STATE(762)] = 21915,
  [SMALL_STATE(763)] = 22008,
  [SMALL_STATE(764)] = 22069,
  [SMALL_STATE(765)] = 22162,
  [SMALL_STATE(766)] = 22257,
  [SMALL_STATE(767)] = 22352,
  [SMALL_STATE(768)] = 22421,
  [SMALL_STATE(769)] = 22516,
  [SMALL_STATE(770)] = 22611,
  [SMALL_STATE(771)] = 22706,
  [SMALL_STATE(772)] = 22801,
  [SMALL_STATE(773)] = 22870,
  [SMALL_STATE(774)] = 22939,
  [SMALL_STATE(775)] = 23008,
  [SMALL_STATE(776)] = 23077,
  [SMALL_STATE(777)] = 23146,
  [SMALL_STATE(778)] = 23215,
  [SMALL_STATE(779)] = 23274,
  [SMALL_STATE(780)] = 23377,
  [SMALL_STATE(781)] = 23446,
  [SMALL_STATE(782)] = 23510,
  [SMALL_STATE(783)] = 23582,
  [SMALL_STATE(784)] = 23648,
  [SMALL_STATE(785)] = 23716,
  [SMALL_STATE(786)] = 23794,
  [SMALL_STATE(787)] = 23890,
  [SMALL_STATE(788)] = 23958,
  [SMALL_STATE(789)] = 24050,
  [SMALL_STATE(790)] = 24144,
  [SMALL_STATE(791)] = 24238,
  [SMALL_STATE(792)] = 24330,
  [SMALL_STATE(793)] = 24398,
  [SMALL_STATE(794)] = 24476,
  [SMALL_STATE(795)] = 24540,
  [SMALL_STATE(796)] = 24604,
  [SMALL_STATE(797)] = 24668,
  [SMALL_STATE(798)] = 24732,
  [SMALL_STATE(799)] = 24826,
  [SMALL_STATE(800)] = 24894,
  [SMALL_STATE(801)] = 24964,
  [SMALL_STATE(802)] = 25028,
  [SMALL_STATE(803)] = 25092,
  [SMALL_STATE(804)] = 25156,
  [SMALL_STATE(805)] = 25220,
  [SMALL_STATE(806)] = 25284,
  [SMALL_STATE(807)] = 25352,
  [SMALL_STATE(808)] = 25420,
  [SMALL_STATE(809)] = 25488,
  [SMALL_STATE(810)] = 25556,
  [SMALL_STATE(811)] = 25619,
  [SMALL_STATE(812)] = 25676,
  [SMALL_STATE(813)] = 25733,
  [SMALL_STATE(814)] = 25796,
  [SMALL_STATE(815)] = 25873,
  [SMALL_STATE(816)] = 25936,
  [SMALL_STATE(817)] = 25999,
  [SMALL_STATE(818)] = 26062,
  [SMALL_STATE(819)] = 26125,
  [SMALL_STATE(820)] = 26188,
  [SMALL_STATE(821)] = 26283,
  [SMALL_STATE(822)] = 26378,
  [SMALL_STATE(823)] = 26471,
  [SMALL_STATE(824)] = 26534,
  [SMALL_STATE(825)] = 26591,
  [SMALL_STATE(826)] = 26648,
  [SMALL_STATE(827)] = 26711,
  [SMALL_STATE(828)] = 26804,
  [SMALL_STATE(829)] = 26867,
  [SMALL_STATE(830)] = 26962,
  [SMALL_STATE(831)] = 27027,
  [SMALL_STATE(832)] = 27090,
  [SMALL_STATE(833)] = 27147,
  [SMALL_STATE(834)] = 27210,
  [SMALL_STATE(835)] = 27267,
  [SMALL_STATE(836)] = 27330,
  [SMALL_STATE(837)] = 27387,
  [SMALL_STATE(838)] = 27444,
  [SMALL_STATE(839)] = 27507,
  [SMALL_STATE(840)] = 27570,
  [SMALL_STATE(841)] = 27633,
  [SMALL_STATE(842)] = 27690,
  [SMALL_STATE(843)] = 27753,
  [SMALL_STATE(844)] = 27848,
  [SMALL_STATE(845)] = 27911,
  [SMALL_STATE(846)] = 27974,
  [SMALL_STATE(847)] = 28045,
  [SMALL_STATE(848)] = 28102,
  [SMALL_STATE(849)] = 28159,
  [SMALL_STATE(850)] = 28222,
  [SMALL_STATE(851)] = 28317,
  [SMALL_STATE(852)] = 28412,
  [SMALL_STATE(853)] = 28469,
  [SMALL_STATE(854)] = 28526,
  [SMALL_STATE(855)] = 28619,
  [SMALL_STATE(856)] = 28696,
  [SMALL_STATE(857)] = 28759,
  [SMALL_STATE(858)] = 28816,
  [SMALL_STATE(859)] = 28873,
  [SMALL_STATE(860)] = 28930,
  [SMALL_STATE(861)] = 28999,
  [SMALL_STATE(862)] = 29056,
  [SMALL_STATE(863)] = 29113,
  [SMALL_STATE(864)] = 29208,
  [SMALL_STATE(865)] = 29271,
  [SMALL_STATE(866)] = 29334,
  [SMALL_STATE(867)] = 29397,
  [SMALL_STATE(868)] = 29454,
  [SMALL_STATE(869)] = 29530,
  [SMALL_STATE(870)] = 29592,
  [SMALL_STATE(871)] = 29686,
  [SMALL_STATE(872)] = 29780,
  [SMALL_STATE(873)] = 29874,
  [SMALL_STATE(874)] = 29944,
  [SMALL_STATE(875)] = 30010,
  [SMALL_STATE(876)] = 30076,
  [SMALL_STATE(877)] = 30172,
  [SMALL_STATE(878)] = 30234,
  [SMALL_STATE(879)] = 30296,
  [SMALL_STATE(880)] = 30358,
  [SMALL_STATE(881)] = 30468,
  [SMALL_STATE(882)] = 30530,
  [SMALL_STATE(883)] = 30592,
  [SMALL_STATE(884)] = 30654,
  [SMALL_STATE(885)] = 30722,
  [SMALL_STATE(886)] = 30818,
  [SMALL_STATE(887)] = 30880,
  [SMALL_STATE(888)] = 30940,
  [SMALL_STATE(889)] = 30996,
  [SMALL_STATE(890)] = 31052,
  [SMALL_STATE(891)] = 31108,
  [SMALL_STATE(892)] = 31164,
  [SMALL_STATE(893)] = 31220,
  [SMALL_STATE(894)] = 31276,
  [SMALL_STATE(895)] = 31332,
  [SMALL_STATE(896)] = 31394,
  [SMALL_STATE(897)] = 31450,
  [SMALL_STATE(898)] = 31506,
  [SMALL_STATE(899)] = 31562,
  [SMALL_STATE(900)] = 31618,
  [SMALL_STATE(901)] = 31684,
  [SMALL_STATE(902)] = 31750,
  [SMALL_STATE(903)] = 31806,
  [SMALL_STATE(904)] = 31862,
  [SMALL_STATE(905)] = 31918,
  [SMALL_STATE(906)] = 31974,
  [SMALL_STATE(907)] = 32030,
  [SMALL_STATE(908)] = 32092,
  [SMALL_STATE(909)] = 32148,
  [SMALL_STATE(910)] = 32204,
  [SMALL_STATE(911)] = 32266,
  [SMALL_STATE(912)] = 32328,
  [SMALL_STATE(913)] = 32390,
  [SMALL_STATE(914)] = 32446,
  [SMALL_STATE(915)] = 32502,
  [SMALL_STATE(916)] = 32558,
  [SMALL_STATE(917)] = 32614,
  [SMALL_STATE(918)] = 32670,
  [SMALL_STATE(919)] = 32726,
  [SMALL_STATE(920)] = 32782,
  [SMALL_STATE(921)] = 32838,
  [SMALL_STATE(922)] = 32894,
  [SMALL_STATE(923)] = 32950,
  [SMALL_STATE(924)] = 33006,
  [SMALL_STATE(925)] = 33068,
  [SMALL_STATE(926)] = 33134,
  [SMALL_STATE(927)] = 33200,
  [SMALL_STATE(928)] = 33256,
  [SMALL_STATE(929)] = 33312,
  [SMALL_STATE(930)] = 33368,
  [SMALL_STATE(931)] = 33424,
  [SMALL_STATE(932)] = 33486,
  [SMALL_STATE(933)] = 33542,
  [SMALL_STATE(934)] = 33638,
  [SMALL_STATE(935)] = 33694,
  [SMALL_STATE(936)] = 33750,
  [SMALL_STATE(937)] = 33806,
  [SMALL_STATE(938)] = 33916,
  [SMALL_STATE(939)] = 34026,
  [SMALL_STATE(940)] = 34096,
  [SMALL_STATE(941)] = 34162,
  [SMALL_STATE(942)] = 34228,
  [SMALL_STATE(943)] = 34338,
  [SMALL_STATE(944)] = 34398,
  [SMALL_STATE(945)] = 34460,
  [SMALL_STATE(946)] = 34522,
  [SMALL_STATE(947)] = 34614,
  [SMALL_STATE(948)] = 34706,
  [SMALL_STATE(949)] = 34798,
  [SMALL_STATE(950)] = 34908,
  [SMALL_STATE(951)] = 34970,
  [SMALL_STATE(952)] = 35032,
  [SMALL_STATE(953)] = 35094,
  [SMALL_STATE(954)] = 35170,
  [SMALL_STATE(955)] = 35234,
  [SMALL_STATE(956)] = 35296,
  [SMALL_STATE(957)] = 35358,
  [SMALL_STATE(958)] = 35422,
  [SMALL_STATE(959)] = 35498,
  [SMALL_STATE(960)] = 35560,
  [SMALL_STATE(961)] = 35622,
  [SMALL_STATE(962)] = 35732,
  [SMALL_STATE(963)] = 35800,
  [SMALL_STATE(964)] = 35862,
  [SMALL_STATE(965)] = 35956,
  [SMALL_STATE(966)] = 36050,
  [SMALL_STATE(967)] = 36144,
  [SMALL_STATE(968)] = 36238,
  [SMALL_STATE(969)] = 36300,
  [SMALL_STATE(970)] = 36376,
  [SMALL_STATE(971)] = 36486,
  [SMALL_STATE(972)] = 36580,
  [SMALL_STATE(973)] = 36646,
  [SMALL_STATE(974)] = 36712,
  [SMALL_STATE(975)] = 36822,
  [SMALL_STATE(976)] = 36914,
  [SMALL_STATE(977)] = 37006,
  [SMALL_STATE(978)] = 37062,
  [SMALL_STATE(979)] = 37117,
  [SMALL_STATE(980)] = 37182,
  [SMALL_STATE(981)] = 37247,
  [SMALL_STATE(982)] = 37312,
  [SMALL_STATE(983)] = 37373,
  [SMALL_STATE(984)] = 37428,
  [SMALL_STATE(985)] = 37483,
  [SMALL_STATE(986)] = 37544,
  [SMALL_STATE(987)] = 37605,
  [SMALL_STATE(988)] = 37666,
  [SMALL_STATE(989)] = 37727,
  [SMALL_STATE(990)] = 37788,
  [SMALL_STATE(991)] = 37849,
  [SMALL_STATE(992)] = 37910,
  [SMALL_STATE(993)] = 37971,
  [SMALL_STATE(994)] = 38046,
  [SMALL_STATE(995)] = 38107,
  [SMALL_STATE(996)] = 38166,
  [SMALL_STATE(997)] = 38221,
  [SMALL_STATE(998)] = 38276,
  [SMALL_STATE(999)] = 38369,
  [SMALL_STATE(1000)] = 38462,
  [SMALL_STATE(1001)] = 38555,
  [SMALL_STATE(1002)] = 38648,
  [SMALL_STATE(1003)] = 38713,
  [SMALL_STATE(1004)] = 38806,
  [SMALL_STATE(1005)] = 38871,
  [SMALL_STATE(1006)] = 38930,
  [SMALL_STATE(1007)] = 38995,
  [SMALL_STATE(1008)] = 39060,
  [SMALL_STATE(1009)] = 39121,
  [SMALL_STATE(1010)] = 39182,
  [SMALL_STATE(1011)] = 39237,
  [SMALL_STATE(1012)] = 39292,
  [SMALL_STATE(1013)] = 39347,
  [SMALL_STATE(1014)] = 39402,
  [SMALL_STATE(1015)] = 39457,
  [SMALL_STATE(1016)] = 39518,
  [SMALL_STATE(1017)] = 39579,
  [SMALL_STATE(1018)] = 39634,
  [SMALL_STATE(1019)] = 39689,
  [SMALL_STATE(1020)] = 39750,
  [SMALL_STATE(1021)] = 39811,
  [SMALL_STATE(1022)] = 39872,
  [SMALL_STATE(1023)] = 39937,
  [SMALL_STATE(1024)] = 40002,
  [SMALL_STATE(1025)] = 40057,
  [SMALL_STATE(1026)] = 40112,
  [SMALL_STATE(1027)] = 40173,
  [SMALL_STATE(1028)] = 40232,
  [SMALL_STATE(1029)] = 40293,
  [SMALL_STATE(1030)] = 40352,
  [SMALL_STATE(1031)] = 40407,
  [SMALL_STATE(1032)] = 40462,
  [SMALL_STATE(1033)] = 40525,
  [SMALL_STATE(1034)] = 40580,
  [SMALL_STATE(1035)] = 40635,
  [SMALL_STATE(1036)] = 40690,
  [SMALL_STATE(1037)] = 40745,
  [SMALL_STATE(1038)] = 40800,
  [SMALL_STATE(1039)] = 40855,
  [SMALL_STATE(1040)] = 40910,
  [SMALL_STATE(1041)] = 40965,
  [SMALL_STATE(1042)] = 41020,
  [SMALL_STATE(1043)] = 41075,
  [SMALL_STATE(1044)] = 41130,
  [SMALL_STATE(1045)] = 41185,
  [SMALL_STATE(1046)] = 41252,
  [SMALL_STATE(1047)] = 41307,
  [SMALL_STATE(1048)] = 41380,
  [SMALL_STATE(1049)] = 41435,
  [SMALL_STATE(1050)] = 41490,
  [SMALL_STATE(1051)] = 41545,
  [SMALL_STATE(1052)] = 41600,
  [SMALL_STATE(1053)] = 41655,
  [SMALL_STATE(1054)] = 41716,
  [SMALL_STATE(1055)] = 41771,
  [SMALL_STATE(1056)] = 41832,
  [SMALL_STATE(1057)] = 41887,
  [SMALL_STATE(1058)] = 41952,
  [SMALL_STATE(1059)] = 42017,
  [SMALL_STATE(1060)] = 42082,
  [SMALL_STATE(1061)] = 42155,
  [SMALL_STATE(1062)] = 42220,
  [SMALL_STATE(1063)] = 42285,
  [SMALL_STATE(1064)] = 42346,
  [SMALL_STATE(1065)] = 42407,
  [SMALL_STATE(1066)] = 42472,
  [SMALL_STATE(1067)] = 42527,
  [SMALL_STATE(1068)] = 42582,
  [SMALL_STATE(1069)] = 42637,
  [SMALL_STATE(1070)] = 42692,
  [SMALL_STATE(1071)] = 42747,
  [SMALL_STATE(1072)] = 42806,
  [SMALL_STATE(1073)] = 42861,
  [SMALL_STATE(1074)] = 42916,
  [SMALL_STATE(1075)] = 42985,
  [SMALL_STATE(1076)] = 43046,
  [SMALL_STATE(1077)] = 43107,
  [SMALL_STATE(1078)] = 43162,
  [SMALL_STATE(1079)] = 43217,
  [SMALL_STATE(1080)] = 43272,
  [SMALL_STATE(1081)] = 43327,
  [SMALL_STATE(1082)] = 43382,
  [SMALL_STATE(1083)] = 43437,
  [SMALL_STATE(1084)] = 43496,
  [SMALL_STATE(1085)] = 43551,
  [SMALL_STATE(1086)] = 43606,
  [SMALL_STATE(1087)] = 43661,
  [SMALL_STATE(1088)] = 43716,
  [SMALL_STATE(1089)] = 43771,
  [SMALL_STATE(1090)] = 43830,
  [SMALL_STATE(1091)] = 43885,
  [SMALL_STATE(1092)] = 43940,
  [SMALL_STATE(1093)] = 44007,
  [SMALL_STATE(1094)] = 44062,
  [SMALL_STATE(1095)] = 44123,
  [SMALL_STATE(1096)] = 44184,
  [SMALL_STATE(1097)] = 44245,
  [SMALL_STATE(1098)] = 44318,
  [SMALL_STATE(1099)] = 44393,
  [SMALL_STATE(1100)] = 44454,
  [SMALL_STATE(1101)] = 44515,
  [SMALL_STATE(1102)] = 44576,
  [SMALL_STATE(1103)] = 44637,
  [SMALL_STATE(1104)] = 44702,
  [SMALL_STATE(1105)] = 44767,
  [SMALL_STATE(1106)] = 44828,
  [SMALL_STATE(1107)] = 44889,
  [SMALL_STATE(1108)] = 44950,
  [SMALL_STATE(1109)] = 45011,
  [SMALL_STATE(1110)] = 45066,
  [SMALL_STATE(1111)] = 45121,
  [SMALL_STATE(1112)] = 45214,
  [SMALL_STATE(1113)] = 45275,
  [SMALL_STATE(1114)] = 45368,
  [SMALL_STATE(1115)] = 45429,
  [SMALL_STATE(1116)] = 45490,
  [SMALL_STATE(1117)] = 45551,
  [SMALL_STATE(1118)] = 45612,
  [SMALL_STATE(1119)] = 45673,
  [SMALL_STATE(1120)] = 45734,
  [SMALL_STATE(1121)] = 45795,
  [SMALL_STATE(1122)] = 45856,
  [SMALL_STATE(1123)] = 45917,
  [SMALL_STATE(1124)] = 45978,
  [SMALL_STATE(1125)] = 46039,
  [SMALL_STATE(1126)] = 46100,
  [SMALL_STATE(1127)] = 46161,
  [SMALL_STATE(1128)] = 46224,
  [SMALL_STATE(1129)] = 46293,
  [SMALL_STATE(1130)] = 46354,
  [SMALL_STATE(1131)] = 46421,
  [SMALL_STATE(1132)] = 46486,
  [SMALL_STATE(1133)] = 46577,
  [SMALL_STATE(1134)] = 46668,
  [SMALL_STATE(1135)] = 46733,
  [SMALL_STATE(1136)] = 46798,
  [SMALL_STATE(1137)] = 46871,
  [SMALL_STATE(1138)] = 46931,
  [SMALL_STATE(1139)] = 46985,
  [SMALL_STATE(1140)] = 47043,
  [SMALL_STATE(1141)] = 47097,
  [SMALL_STATE(1142)] = 47151,
  [SMALL_STATE(1143)] = 47205,
  [SMALL_STATE(1144)] = 47259,
  [SMALL_STATE(1145)] = 47313,
  [SMALL_STATE(1146)] = 47367,
  [SMALL_STATE(1147)] = 47421,
  [SMALL_STATE(1148)] = 47481,
  [SMALL_STATE(1149)] = 47535,
  [SMALL_STATE(1150)] = 47589,
  [SMALL_STATE(1151)] = 47643,
  [SMALL_STATE(1152)] = 47697,
  [SMALL_STATE(1153)] = 47751,
  [SMALL_STATE(1154)] = 47805,
  [SMALL_STATE(1155)] = 47859,
  [SMALL_STATE(1156)] = 47913,
  [SMALL_STATE(1157)] = 47967,
  [SMALL_STATE(1158)] = 48021,
  [SMALL_STATE(1159)] = 48081,
  [SMALL_STATE(1160)] = 48139,
  [SMALL_STATE(1161)] = 48193,
  [SMALL_STATE(1162)] = 48253,
  [SMALL_STATE(1163)] = 48313,
  [SMALL_STATE(1164)] = 48367,
  [SMALL_STATE(1165)] = 48421,
  [SMALL_STATE(1166)] = 48481,
  [SMALL_STATE(1167)] = 48541,
  [SMALL_STATE(1168)] = 48595,
  [SMALL_STATE(1169)] = 48649,
  [SMALL_STATE(1170)] = 48709,
  [SMALL_STATE(1171)] = 48763,
  [SMALL_STATE(1172)] = 48817,
  [SMALL_STATE(1173)] = 48871,
  [SMALL_STATE(1174)] = 48925,
  [SMALL_STATE(1175)] = 48979,
  [SMALL_STATE(1176)] = 49033,
  [SMALL_STATE(1177)] = 49125,
  [SMALL_STATE(1178)] = 49179,
  [SMALL_STATE(1179)] = 49233,
  [SMALL_STATE(1180)] = 49297,
  [SMALL_STATE(1181)] = 49361,
  [SMALL_STATE(1182)] = 49419,
  [SMALL_STATE(1183)] = 49473,
  [SMALL_STATE(1184)] = 49565,
  [SMALL_STATE(1185)] = 49619,
  [SMALL_STATE(1186)] = 49673,
  [SMALL_STATE(1187)] = 49781,
  [SMALL_STATE(1188)] = 49845,
  [SMALL_STATE(1189)] = 49909,
  [SMALL_STATE(1190)] = 49963,
  [SMALL_STATE(1191)] = 50023,
  [SMALL_STATE(1192)] = 50083,
  [SMALL_STATE(1193)] = 50137,
  [SMALL_STATE(1194)] = 50191,
  [SMALL_STATE(1195)] = 50251,
  [SMALL_STATE(1196)] = 50305,
  [SMALL_STATE(1197)] = 50359,
  [SMALL_STATE(1198)] = 50413,
  [SMALL_STATE(1199)] = 50473,
  [SMALL_STATE(1200)] = 50581,
  [SMALL_STATE(1201)] = 50641,
  [SMALL_STATE(1202)] = 50701,
  [SMALL_STATE(1203)] = 50755,
  [SMALL_STATE(1204)] = 50815,
  [SMALL_STATE(1205)] = 50875,
  [SMALL_STATE(1206)] = 50935,
  [SMALL_STATE(1207)] = 51043,
  [SMALL_STATE(1208)] = 51103,
  [SMALL_STATE(1209)] = 51157,
  [SMALL_STATE(1210)] = 51211,
  [SMALL_STATE(1211)] = 51271,
  [SMALL_STATE(1212)] = 51331,
  [SMALL_STATE(1213)] = 51385,
  [SMALL_STATE(1214)] = 51445,
  [SMALL_STATE(1215)] = 51499,
  [SMALL_STATE(1216)] = 51607,
  [SMALL_STATE(1217)] = 51673,
  [SMALL_STATE(1218)] = 51781,
  [SMALL_STATE(1219)] = 51889,
  [SMALL_STATE(1220)] = 51949,
  [SMALL_STATE(1221)] = 52003,
  [SMALL_STATE(1222)] = 52063,
  [SMALL_STATE(1223)] = 52123,
  [SMALL_STATE(1224)] = 52183,
  [SMALL_STATE(1225)] = 52237,
  [SMALL_STATE(1226)] = 52297,
  [SMALL_STATE(1227)] = 52357,
  [SMALL_STATE(1228)] = 52417,
  [SMALL_STATE(1229)] = 52471,
  [SMALL_STATE(1230)] = 52525,
  [SMALL_STATE(1231)] = 52583,
  [SMALL_STATE(1232)] = 52637,
  [SMALL_STATE(1233)] = 52695,
  [SMALL_STATE(1234)] = 52755,
  [SMALL_STATE(1235)] = 52815,
  [SMALL_STATE(1236)] = 52873,
  [SMALL_STATE(1237)] = 52927,
  [SMALL_STATE(1238)] = 52985,
  [SMALL_STATE(1239)] = 53039,
  [SMALL_STATE(1240)] = 53099,
  [SMALL_STATE(1241)] = 53159,
  [SMALL_STATE(1242)] = 53213,
  [SMALL_STATE(1243)] = 53267,
  [SMALL_STATE(1244)] = 53321,
  [SMALL_STATE(1245)] = 53385,
  [SMALL_STATE(1246)] = 53443,
  [SMALL_STATE(1247)] = 53497,
  [SMALL_STATE(1248)] = 53551,
  [SMALL_STATE(1249)] = 53605,
  [SMALL_STATE(1250)] = 53659,
  [SMALL_STATE(1251)] = 53723,
  [SMALL_STATE(1252)] = 53777,
  [SMALL_STATE(1253)] = 53831,
  [SMALL_STATE(1254)] = 53885,
  [SMALL_STATE(1255)] = 53939,
  [SMALL_STATE(1256)] = 53993,
  [SMALL_STATE(1257)] = 54047,
  [SMALL_STATE(1258)] = 54101,
  [SMALL_STATE(1259)] = 54159,
  [SMALL_STATE(1260)] = 54213,
  [SMALL_STATE(1261)] = 54267,
  [SMALL_STATE(1262)] = 54321,
  [SMALL_STATE(1263)] = 54375,
  [SMALL_STATE(1264)] = 54429,
  [SMALL_STATE(1265)] = 54489,
  [SMALL_STATE(1266)] = 54549,
  [SMALL_STATE(1267)] = 54609,
  [SMALL_STATE(1268)] = 54673,
  [SMALL_STATE(1269)] = 54727,
  [SMALL_STATE(1270)] = 54787,
  [SMALL_STATE(1271)] = 54847,
  [SMALL_STATE(1272)] = 54911,
  [SMALL_STATE(1273)] = 54965,
  [SMALL_STATE(1274)] = 55019,
  [SMALL_STATE(1275)] = 55073,
  [SMALL_STATE(1276)] = 55133,
  [SMALL_STATE(1277)] = 55193,
  [SMALL_STATE(1278)] = 55247,
  [SMALL_STATE(1279)] = 55301,
  [SMALL_STATE(1280)] = 55361,
  [SMALL_STATE(1281)] = 55421,
  [SMALL_STATE(1282)] = 55481,
  [SMALL_STATE(1283)] = 55541,
  [SMALL_STATE(1284)] = 55601,
  [SMALL_STATE(1285)] = 55655,
  [SMALL_STATE(1286)] = 55709,
  [SMALL_STATE(1287)] = 55763,
  [SMALL_STATE(1288)] = 55817,
  [SMALL_STATE(1289)] = 55871,
  [SMALL_STATE(1290)] = 55925,
  [SMALL_STATE(1291)] = 55979,
  [SMALL_STATE(1292)] = 56039,
  [SMALL_STATE(1293)] = 56098,
  [SMALL_STATE(1294)] = 56151,
  [SMALL_STATE(1295)] = 56204,
  [SMALL_STATE(1296)] = 56257,
  [SMALL_STATE(1297)] = 56310,
  [SMALL_STATE(1298)] = 56369,
  [SMALL_STATE(1299)] = 56422,
  [SMALL_STATE(1300)] = 56475,
  [SMALL_STATE(1301)] = 56528,
  [SMALL_STATE(1302)] = 56587,
  [SMALL_STATE(1303)] = 56640,
  [SMALL_STATE(1304)] = 56693,
  [SMALL_STATE(1305)] = 56746,
  [SMALL_STATE(1306)] = 56835,
  [SMALL_STATE(1307)] = 56894,
  [SMALL_STATE(1308)] = 56953,
  [SMALL_STATE(1309)] = 57006,
  [SMALL_STATE(1310)] = 57059,
  [SMALL_STATE(1311)] = 57112,
  [SMALL_STATE(1312)] = 57171,
  [SMALL_STATE(1313)] = 57224,
  [SMALL_STATE(1314)] = 57277,
  [SMALL_STATE(1315)] = 57330,
  [SMALL_STATE(1316)] = 57383,
  [SMALL_STATE(1317)] = 57436,
  [SMALL_STATE(1318)] = 57495,
  [SMALL_STATE(1319)] = 57548,
  [SMALL_STATE(1320)] = 57601,
  [SMALL_STATE(1321)] = 57658,
  [SMALL_STATE(1322)] = 57711,
  [SMALL_STATE(1323)] = 57770,
  [SMALL_STATE(1324)] = 57829,
  [SMALL_STATE(1325)] = 57888,
  [SMALL_STATE(1326)] = 57947,
  [SMALL_STATE(1327)] = 58006,
  [SMALL_STATE(1328)] = 58059,
  [SMALL_STATE(1329)] = 58112,
  [SMALL_STATE(1330)] = 58165,
  [SMALL_STATE(1331)] = 58218,
  [SMALL_STATE(1332)] = 58271,
  [SMALL_STATE(1333)] = 58324,
  [SMALL_STATE(1334)] = 58377,
  [SMALL_STATE(1335)] = 58434,
  [SMALL_STATE(1336)] = 58487,
  [SMALL_STATE(1337)] = 58540,
  [SMALL_STATE(1338)] = 58597,
  [SMALL_STATE(1339)] = 58656,
  [SMALL_STATE(1340)] = 58709,
  [SMALL_STATE(1341)] = 58762,
  [SMALL_STATE(1342)] = 58821,
  [SMALL_STATE(1343)] = 58874,
  [SMALL_STATE(1344)] = 58927,
  [SMALL_STATE(1345)] = 58986,
  [SMALL_STATE(1346)] = 59045,
  [SMALL_STATE(1347)] = 59104,
  [SMALL_STATE(1348)] = 59157,
  [SMALL_STATE(1349)] = 59216,
  [SMALL_STATE(1350)] = 59269,
  [SMALL_STATE(1351)] = 59322,
  [SMALL_STATE(1352)] = 59375,
  [SMALL_STATE(1353)] = 59434,
  [SMALL_STATE(1354)] = 59493,
  [SMALL_STATE(1355)] = 59552,
  [SMALL_STATE(1356)] = 59611,
  [SMALL_STATE(1357)] = 59670,
  [SMALL_STATE(1358)] = 59729,
  [SMALL_STATE(1359)] = 59782,
  [SMALL_STATE(1360)] = 59835,
  [SMALL_STATE(1361)] = 59892,
  [SMALL_STATE(1362)] = 59945,
  [SMALL_STATE(1363)] = 60004,
  [SMALL_STATE(1364)] = 60063,
  [SMALL_STATE(1365)] = 60116,
  [SMALL_STATE(1366)] = 60169,
  [SMALL_STATE(1367)] = 60226,
  [SMALL_STATE(1368)] = 60285,
  [SMALL_STATE(1369)] = 60344,
  [SMALL_STATE(1370)] = 60397,
  [SMALL_STATE(1371)] = 60456,
  [SMALL_STATE(1372)] = 60515,
  [SMALL_STATE(1373)] = 60574,
  [SMALL_STATE(1374)] = 60633,
  [SMALL_STATE(1375)] = 60692,
  [SMALL_STATE(1376)] = 60751,
  [SMALL_STATE(1377)] = 60810,
  [SMALL_STATE(1378)] = 60869,
  [SMALL_STATE(1379)] = 60928,
  [SMALL_STATE(1380)] = 60987,
  [SMALL_STATE(1381)] = 61040,
  [SMALL_STATE(1382)] = 61099,
  [SMALL_STATE(1383)] = 61158,
  [SMALL_STATE(1384)] = 61211,
  [SMALL_STATE(1385)] = 61264,
  [SMALL_STATE(1386)] = 61329,
  [SMALL_STATE(1387)] = 61388,
  [SMALL_STATE(1388)] = 61445,
  [SMALL_STATE(1389)] = 61498,
  [SMALL_STATE(1390)] = 61557,
  [SMALL_STATE(1391)] = 61646,
  [SMALL_STATE(1392)] = 61703,
  [SMALL_STATE(1393)] = 61756,
  [SMALL_STATE(1394)] = 61815,
  [SMALL_STATE(1395)] = 61868,
  [SMALL_STATE(1396)] = 61925,
  [SMALL_STATE(1397)] = 61978,
  [SMALL_STATE(1398)] = 62035,
  [SMALL_STATE(1399)] = 62088,
  [SMALL_STATE(1400)] = 62141,
  [SMALL_STATE(1401)] = 62194,
  [SMALL_STATE(1402)] = 62253,
  [SMALL_STATE(1403)] = 62312,
  [SMALL_STATE(1404)] = 62365,
  [SMALL_STATE(1405)] = 62418,
  [SMALL_STATE(1406)] = 62471,
  [SMALL_STATE(1407)] = 62524,
  [SMALL_STATE(1408)] = 62577,
  [SMALL_STATE(1409)] = 62630,
  [SMALL_STATE(1410)] = 62683,
  [SMALL_STATE(1411)] = 62740,
  [SMALL_STATE(1412)] = 62797,
  [SMALL_STATE(1413)] = 62854,
  [SMALL_STATE(1414)] = 62907,
  [SMALL_STATE(1415)] = 62960,
  [SMALL_STATE(1416)] = 63013,
  [SMALL_STATE(1417)] = 63072,
  [SMALL_STATE(1418)] = 63125,
  [SMALL_STATE(1419)] = 63184,
  [SMALL_STATE(1420)] = 63237,
  [SMALL_STATE(1421)] = 63296,
  [SMALL_STATE(1422)] = 63355,
  [SMALL_STATE(1423)] = 63414,
  [SMALL_STATE(1424)] = 63471,
  [SMALL_STATE(1425)] = 63528,
  [SMALL_STATE(1426)] = 63585,
  [SMALL_STATE(1427)] = 63638,
  [SMALL_STATE(1428)] = 63695,
  [SMALL_STATE(1429)] = 63748,
  [SMALL_STATE(1430)] = 63837,
  [SMALL_STATE(1431)] = 63896,
  [SMALL_STATE(1432)] = 63949,
  [SMALL_STATE(1433)] = 64002,
  [SMALL_STATE(1434)] = 64055,
  [SMALL_STATE(1435)] = 64108,
  [SMALL_STATE(1436)] = 64161,
  [SMALL_STATE(1437)] = 64218,
  [SMALL_STATE(1438)] = 64277,
  [SMALL_STATE(1439)] = 64330,
  [SMALL_STATE(1440)] = 64383,
  [SMALL_STATE(1441)] = 64436,
  [SMALL_STATE(1442)] = 64489,
  [SMALL_STATE(1443)] = 64542,
  [SMALL_STATE(1444)] = 64601,
  [SMALL_STATE(1445)] = 64660,
  [SMALL_STATE(1446)] = 64719,
  [SMALL_STATE(1447)] = 64778,
  [SMALL_STATE(1448)] = 64837,
  [SMALL_STATE(1449)] = 64894,
  [SMALL_STATE(1450)] = 64947,
  [SMALL_STATE(1451)] = 65006,
  [SMALL_STATE(1452)] = 65059,
  [SMALL_STATE(1453)] = 65112,
  [SMALL_STATE(1454)] = 65165,
  [SMALL_STATE(1455)] = 65224,
  [SMALL_STATE(1456)] = 65277,
  [SMALL_STATE(1457)] = 65336,
  [SMALL_STATE(1458)] = 65393,
  [SMALL_STATE(1459)] = 65446,
  [SMALL_STATE(1460)] = 65499,
  [SMALL_STATE(1461)] = 65552,
  [SMALL_STATE(1462)] = 65611,
  [SMALL_STATE(1463)] = 65670,
  [SMALL_STATE(1464)] = 65727,
  [SMALL_STATE(1465)] = 65783,
  [SMALL_STATE(1466)] = 65835,
  [SMALL_STATE(1467)] = 65887,
  [SMALL_STATE(1468)] = 65939,
  [SMALL_STATE(1469)] = 65991,
  [SMALL_STATE(1470)] = 66053,
  [SMALL_STATE(1471)] = 66115,
  [SMALL_STATE(1472)] = 66171,
  [SMALL_STATE(1473)] = 66223,
  [SMALL_STATE(1474)] = 66275,
  [SMALL_STATE(1475)] = 66331,
  [SMALL_STATE(1476)] = 66383,
  [SMALL_STATE(1477)] = 66435,
  [SMALL_STATE(1478)] = 66487,
  [SMALL_STATE(1479)] = 66539,
  [SMALL_STATE(1480)] = 66591,
  [SMALL_STATE(1481)] = 66647,
  [SMALL_STATE(1482)] = 66699,
  [SMALL_STATE(1483)] = 66751,
  [SMALL_STATE(1484)] = 66803,
  [SMALL_STATE(1485)] = 66859,
  [SMALL_STATE(1486)] = 66911,
  [SMALL_STATE(1487)] = 66963,
  [SMALL_STATE(1488)] = 67015,
  [SMALL_STATE(1489)] = 67073,
  [SMALL_STATE(1490)] = 67125,
  [SMALL_STATE(1491)] = 67177,
  [SMALL_STATE(1492)] = 67233,
  [SMALL_STATE(1493)] = 67285,
  [SMALL_STATE(1494)] = 67337,
  [SMALL_STATE(1495)] = 67389,
  [SMALL_STATE(1496)] = 67441,
  [SMALL_STATE(1497)] = 67499,
  [SMALL_STATE(1498)] = 67551,
  [SMALL_STATE(1499)] = 67603,
  [SMALL_STATE(1500)] = 67655,
  [SMALL_STATE(1501)] = 67707,
  [SMALL_STATE(1502)] = 67763,
  [SMALL_STATE(1503)] = 67819,
  [SMALL_STATE(1504)] = 67871,
  [SMALL_STATE(1505)] = 67927,
  [SMALL_STATE(1506)] = 67979,
  [SMALL_STATE(1507)] = 68031,
  [SMALL_STATE(1508)] = 68083,
  [SMALL_STATE(1509)] = 68139,
  [SMALL_STATE(1510)] = 68191,
  [SMALL_STATE(1511)] = 68249,
  [SMALL_STATE(1512)] = 68301,
  [SMALL_STATE(1513)] = 68353,
  [SMALL_STATE(1514)] = 68411,
  [SMALL_STATE(1515)] = 68467,
  [SMALL_STATE(1516)] = 68525,
  [SMALL_STATE(1517)] = 68577,
  [SMALL_STATE(1518)] = 68629,
  [SMALL_STATE(1519)] = 68681,
  [SMALL_STATE(1520)] = 68783,
  [SMALL_STATE(1521)] = 68835,
  [SMALL_STATE(1522)] = 68887,
  [SMALL_STATE(1523)] = 68945,
  [SMALL_STATE(1524)] = 69003,
  [SMALL_STATE(1525)] = 69061,
  [SMALL_STATE(1526)] = 69113,
  [SMALL_STATE(1527)] = 69165,
  [SMALL_STATE(1528)] = 69217,
  [SMALL_STATE(1529)] = 69269,
  [SMALL_STATE(1530)] = 69321,
  [SMALL_STATE(1531)] = 69373,
  [SMALL_STATE(1532)] = 69425,
  [SMALL_STATE(1533)] = 69477,
  [SMALL_STATE(1534)] = 69529,
  [SMALL_STATE(1535)] = 69581,
  [SMALL_STATE(1536)] = 69633,
  [SMALL_STATE(1537)] = 69685,
  [SMALL_STATE(1538)] = 69737,
  [SMALL_STATE(1539)] = 69789,
  [SMALL_STATE(1540)] = 69841,
  [SMALL_STATE(1541)] = 69893,
  [SMALL_STATE(1542)] = 69981,
  [SMALL_STATE(1543)] = 70037,
  [SMALL_STATE(1544)] = 70125,
  [SMALL_STATE(1545)] = 70177,
  [SMALL_STATE(1546)] = 70229,
  [SMALL_STATE(1547)] = 70281,
  [SMALL_STATE(1548)] = 70333,
  [SMALL_STATE(1549)] = 70391,
  [SMALL_STATE(1550)] = 70443,
  [SMALL_STATE(1551)] = 70495,
  [SMALL_STATE(1552)] = 70547,
  [SMALL_STATE(1553)] = 70599,
  [SMALL_STATE(1554)] = 70651,
  [SMALL_STATE(1555)] = 70703,
  [SMALL_STATE(1556)] = 70755,
  [SMALL_STATE(1557)] = 70807,
  [SMALL_STATE(1558)] = 70859,
  [SMALL_STATE(1559)] = 70911,
  [SMALL_STATE(1560)] = 70963,
  [SMALL_STATE(1561)] = 71015,
  [SMALL_STATE(1562)] = 71067,
  [SMALL_STATE(1563)] = 71119,
  [SMALL_STATE(1564)] = 71171,
  [SMALL_STATE(1565)] = 71273,
  [SMALL_STATE(1566)] = 71325,
  [SMALL_STATE(1567)] = 71377,
  [SMALL_STATE(1568)] = 71429,
  [SMALL_STATE(1569)] = 71487,
  [SMALL_STATE(1570)] = 71539,
  [SMALL_STATE(1571)] = 71591,
  [SMALL_STATE(1572)] = 71643,
  [SMALL_STATE(1573)] = 71701,
  [SMALL_STATE(1574)] = 71753,
  [SMALL_STATE(1575)] = 71805,
  [SMALL_STATE(1576)] = 71857,
  [SMALL_STATE(1577)] = 71909,
  [SMALL_STATE(1578)] = 71961,
  [SMALL_STATE(1579)] = 72013,
  [SMALL_STATE(1580)] = 72065,
  [SMALL_STATE(1581)] = 72117,
  [SMALL_STATE(1582)] = 72169,
  [SMALL_STATE(1583)] = 72221,
  [SMALL_STATE(1584)] = 72279,
  [SMALL_STATE(1585)] = 72331,
  [SMALL_STATE(1586)] = 72433,
  [SMALL_STATE(1587)] = 72485,
  [SMALL_STATE(1588)] = 72537,
  [SMALL_STATE(1589)] = 72595,
  [SMALL_STATE(1590)] = 72697,
  [SMALL_STATE(1591)] = 72755,
  [SMALL_STATE(1592)] = 72813,
  [SMALL_STATE(1593)] = 72871,
  [SMALL_STATE(1594)] = 72929,
  [SMALL_STATE(1595)] = 72987,
  [SMALL_STATE(1596)] = 73045,
  [SMALL_STATE(1597)] = 73097,
  [SMALL_STATE(1598)] = 73155,
  [SMALL_STATE(1599)] = 73213,
  [SMALL_STATE(1600)] = 73271,
  [SMALL_STATE(1601)] = 73329,
  [SMALL_STATE(1602)] = 73397,
  [SMALL_STATE(1603)] = 73465,
  [SMALL_STATE(1604)] = 73523,
  [SMALL_STATE(1605)] = 73579,
  [SMALL_STATE(1606)] = 73635,
  [SMALL_STATE(1607)] = 73687,
  [SMALL_STATE(1608)] = 73739,
  [SMALL_STATE(1609)] = 73799,
  [SMALL_STATE(1610)] = 73859,
  [SMALL_STATE(1611)] = 73917,
  [SMALL_STATE(1612)] = 73975,
  [SMALL_STATE(1613)] = 74027,
  [SMALL_STATE(1614)] = 74079,
  [SMALL_STATE(1615)] = 74137,
  [SMALL_STATE(1616)] = 74195,
  [SMALL_STATE(1617)] = 74247,
  [SMALL_STATE(1618)] = 74299,
  [SMALL_STATE(1619)] = 74351,
  [SMALL_STATE(1620)] = 74403,
  [SMALL_STATE(1621)] = 74455,
  [SMALL_STATE(1622)] = 74507,
  [SMALL_STATE(1623)] = 74559,
  [SMALL_STATE(1624)] = 74617,
  [SMALL_STATE(1625)] = 74669,
  [SMALL_STATE(1626)] = 74721,
  [SMALL_STATE(1627)] = 74779,
  [SMALL_STATE(1628)] = 74835,
  [SMALL_STATE(1629)] = 74887,
  [SMALL_STATE(1630)] = 74939,
  [SMALL_STATE(1631)] = 74991,
  [SMALL_STATE(1632)] = 75043,
  [SMALL_STATE(1633)] = 75101,
  [SMALL_STATE(1634)] = 75153,
  [SMALL_STATE(1635)] = 75205,
  [SMALL_STATE(1636)] = 75257,
  [SMALL_STATE(1637)] = 75315,
  [SMALL_STATE(1638)] = 75367,
  [SMALL_STATE(1639)] = 75419,
  [SMALL_STATE(1640)] = 75471,
  [SMALL_STATE(1641)] = 75523,
  [SMALL_STATE(1642)] = 75575,
  [SMALL_STATE(1643)] = 75627,
  [SMALL_STATE(1644)] = 75679,
  [SMALL_STATE(1645)] = 75731,
  [SMALL_STATE(1646)] = 75783,
  [SMALL_STATE(1647)] = 75835,
  [SMALL_STATE(1648)] = 75887,
  [SMALL_STATE(1649)] = 75939,
  [SMALL_STATE(1650)] = 75991,
  [SMALL_STATE(1651)] = 76043,
  [SMALL_STATE(1652)] = 76095,
  [SMALL_STATE(1653)] = 76153,
  [SMALL_STATE(1654)] = 76211,
  [SMALL_STATE(1655)] = 76263,
  [SMALL_STATE(1656)] = 76315,
  [SMALL_STATE(1657)] = 76367,
  [SMALL_STATE(1658)] = 76419,
  [SMALL_STATE(1659)] = 76471,
  [SMALL_STATE(1660)] = 76523,
  [SMALL_STATE(1661)] = 76575,
  [SMALL_STATE(1662)] = 76627,
  [SMALL_STATE(1663)] = 76685,
  [SMALL_STATE(1664)] = 76743,
  [SMALL_STATE(1665)] = 76795,
  [SMALL_STATE(1666)] = 76853,
  [SMALL_STATE(1667)] = 76911,
  [SMALL_STATE(1668)] = 76969,
  [SMALL_STATE(1669)] = 77027,
  [SMALL_STATE(1670)] = 77085,
  [SMALL_STATE(1671)] = 77137,
  [SMALL_STATE(1672)] = 77195,
  [SMALL_STATE(1673)] = 77247,
  [SMALL_STATE(1674)] = 77299,
  [SMALL_STATE(1675)] = 77357,
  [SMALL_STATE(1676)] = 77415,
  [SMALL_STATE(1677)] = 77473,
  [SMALL_STATE(1678)] = 77531,
  [SMALL_STATE(1679)] = 77589,
  [SMALL_STATE(1680)] = 77641,
  [SMALL_STATE(1681)] = 77693,
  [SMALL_STATE(1682)] = 77745,
  [SMALL_STATE(1683)] = 77797,
  [SMALL_STATE(1684)] = 77849,
  [SMALL_STATE(1685)] = 77951,
  [SMALL_STATE(1686)] = 78009,
  [SMALL_STATE(1687)] = 78067,
  [SMALL_STATE(1688)] = 78119,
  [SMALL_STATE(1689)] = 78177,
  [SMALL_STATE(1690)] = 78235,
  [SMALL_STATE(1691)] = 78337,
  [SMALL_STATE(1692)] = 78395,
  [SMALL_STATE(1693)] = 78453,
  [SMALL_STATE(1694)] = 78513,
  [SMALL_STATE(1695)] = 78565,
  [SMALL_STATE(1696)] = 78631,
  [SMALL_STATE(1697)] = 78683,
  [SMALL_STATE(1698)] = 78741,
  [SMALL_STATE(1699)] = 78805,
  [SMALL_STATE(1700)] = 78857,
  [SMALL_STATE(1701)] = 78909,
  [SMALL_STATE(1702)] = 78961,
  [SMALL_STATE(1703)] = 79013,
  [SMALL_STATE(1704)] = 79065,
  [SMALL_STATE(1705)] = 79117,
  [SMALL_STATE(1706)] = 79169,
  [SMALL_STATE(1707)] = 79221,
  [SMALL_STATE(1708)] = 79279,
  [SMALL_STATE(1709)] = 79378,
  [SMALL_STATE(1710)] = 79429,
  [SMALL_STATE(1711)] = 79480,
  [SMALL_STATE(1712)] = 79537,
  [SMALL_STATE(1713)] = 79588,
  [SMALL_STATE(1714)] = 79639,
  [SMALL_STATE(1715)] = 79690,
  [SMALL_STATE(1716)] = 79747,
  [SMALL_STATE(1717)] = 79804,
  [SMALL_STATE(1718)] = 79855,
  [SMALL_STATE(1719)] = 79906,
  [SMALL_STATE(1720)] = 79957,
  [SMALL_STATE(1721)] = 80012,
  [SMALL_STATE(1722)] = 80067,
  [SMALL_STATE(1723)] = 80122,
  [SMALL_STATE(1724)] = 80179,
  [SMALL_STATE(1725)] = 80230,
  [SMALL_STATE(1726)] = 80281,
  [SMALL_STATE(1727)] = 80332,
  [SMALL_STATE(1728)] = 80383,
  [SMALL_STATE(1729)] = 80434,
  [SMALL_STATE(1730)] = 80485,
  [SMALL_STATE(1731)] = 80536,
  [SMALL_STATE(1732)] = 80587,
  [SMALL_STATE(1733)] = 80638,
  [SMALL_STATE(1734)] = 80689,
  [SMALL_STATE(1735)] = 80740,
  [SMALL_STATE(1736)] = 80791,
  [SMALL_STATE(1737)] = 80842,
  [SMALL_STATE(1738)] = 80909,
  [SMALL_STATE(1739)] = 80960,
  [SMALL_STATE(1740)] = 81011,
  [SMALL_STATE(1741)] = 81062,
  [SMALL_STATE(1742)] = 81113,
  [SMALL_STATE(1743)] = 81212,
  [SMALL_STATE(1744)] = 81263,
  [SMALL_STATE(1745)] = 81332,
  [SMALL_STATE(1746)] = 81383,
  [SMALL_STATE(1747)] = 81440,
  [SMALL_STATE(1748)] = 81491,
  [SMALL_STATE(1749)] = 81548,
  [SMALL_STATE(1750)] = 81605,
  [SMALL_STATE(1751)] = 81662,
  [SMALL_STATE(1752)] = 81725,
  [SMALL_STATE(1753)] = 81776,
  [SMALL_STATE(1754)] = 81833,
  [SMALL_STATE(1755)] = 81932,
  [SMALL_STATE(1756)] = 81983,
  [SMALL_STATE(1757)] = 82038,
  [SMALL_STATE(1758)] = 82095,
  [SMALL_STATE(1759)] = 82146,
  [SMALL_STATE(1760)] = 82203,
  [SMALL_STATE(1761)] = 82260,
  [SMALL_STATE(1762)] = 82317,
  [SMALL_STATE(1763)] = 82368,
  [SMALL_STATE(1764)] = 82419,
  [SMALL_STATE(1765)] = 82470,
  [SMALL_STATE(1766)] = 82521,
  [SMALL_STATE(1767)] = 82578,
  [SMALL_STATE(1768)] = 82635,
  [SMALL_STATE(1769)] = 82686,
  [SMALL_STATE(1770)] = 82785,
  [SMALL_STATE(1771)] = 82884,
  [SMALL_STATE(1772)] = 82939,
  [SMALL_STATE(1773)] = 82990,
  [SMALL_STATE(1774)] = 83041,
  [SMALL_STATE(1775)] = 83092,
  [SMALL_STATE(1776)] = 83143,
  [SMALL_STATE(1777)] = 83194,
  [SMALL_STATE(1778)] = 83245,
  [SMALL_STATE(1779)] = 83302,
  [SMALL_STATE(1780)] = 83359,
  [SMALL_STATE(1781)] = 83410,
  [SMALL_STATE(1782)] = 83509,
  [SMALL_STATE(1783)] = 83560,
  [SMALL_STATE(1784)] = 83611,
  [SMALL_STATE(1785)] = 83662,
  [SMALL_STATE(1786)] = 83761,
  [SMALL_STATE(1787)] = 83812,
  [SMALL_STATE(1788)] = 83867,
  [SMALL_STATE(1789)] = 83918,
  [SMALL_STATE(1790)] = 84017,
  [SMALL_STATE(1791)] = 84072,
  [SMALL_STATE(1792)] = 84129,
  [SMALL_STATE(1793)] = 84180,
  [SMALL_STATE(1794)] = 84279,
  [SMALL_STATE(1795)] = 84330,
  [SMALL_STATE(1796)] = 84381,
  [SMALL_STATE(1797)] = 84432,
  [SMALL_STATE(1798)] = 84483,
  [SMALL_STATE(1799)] = 84582,
  [SMALL_STATE(1800)] = 84639,
  [SMALL_STATE(1801)] = 84696,
  [SMALL_STATE(1802)] = 84751,
  [SMALL_STATE(1803)] = 84802,
  [SMALL_STATE(1804)] = 84857,
  [SMALL_STATE(1805)] = 84908,
  [SMALL_STATE(1806)] = 85007,
  [SMALL_STATE(1807)] = 85058,
  [SMALL_STATE(1808)] = 85109,
  [SMALL_STATE(1809)] = 85160,
  [SMALL_STATE(1810)] = 85215,
  [SMALL_STATE(1811)] = 85266,
  [SMALL_STATE(1812)] = 85321,
  [SMALL_STATE(1813)] = 85372,
  [SMALL_STATE(1814)] = 85427,
  [SMALL_STATE(1815)] = 85482,
  [SMALL_STATE(1816)] = 85533,
  [SMALL_STATE(1817)] = 85584,
  [SMALL_STATE(1818)] = 85635,
  [SMALL_STATE(1819)] = 85690,
  [SMALL_STATE(1820)] = 85745,
  [SMALL_STATE(1821)] = 85800,
  [SMALL_STATE(1822)] = 85851,
  [SMALL_STATE(1823)] = 85902,
  [SMALL_STATE(1824)] = 85961,
  [SMALL_STATE(1825)] = 86020,
  [SMALL_STATE(1826)] = 86075,
  [SMALL_STATE(1827)] = 86126,
  [SMALL_STATE(1828)] = 86181,
  [SMALL_STATE(1829)] = 86236,
  [SMALL_STATE(1830)] = 86287,
  [SMALL_STATE(1831)] = 86338,
  [SMALL_STATE(1832)] = 86389,
  [SMALL_STATE(1833)] = 86440,
  [SMALL_STATE(1834)] = 86491,
  [SMALL_STATE(1835)] = 86546,
  [SMALL_STATE(1836)] = 86597,
  [SMALL_STATE(1837)] = 86648,
  [SMALL_STATE(1838)] = 86699,
  [SMALL_STATE(1839)] = 86750,
  [SMALL_STATE(1840)] = 86801,
  [SMALL_STATE(1841)] = 86852,
  [SMALL_STATE(1842)] = 86903,
  [SMALL_STATE(1843)] = 86954,
  [SMALL_STATE(1844)] = 87009,
  [SMALL_STATE(1845)] = 87060,
  [SMALL_STATE(1846)] = 87111,
  [SMALL_STATE(1847)] = 87162,
  [SMALL_STATE(1848)] = 87213,
  [SMALL_STATE(1849)] = 87264,
  [SMALL_STATE(1850)] = 87321,
  [SMALL_STATE(1851)] = 87378,
  [SMALL_STATE(1852)] = 87435,
  [SMALL_STATE(1853)] = 87486,
  [SMALL_STATE(1854)] = 87537,
  [SMALL_STATE(1855)] = 87588,
  [SMALL_STATE(1856)] = 87639,
  [SMALL_STATE(1857)] = 87690,
  [SMALL_STATE(1858)] = 87741,
  [SMALL_STATE(1859)] = 87792,
  [SMALL_STATE(1860)] = 87843,
  [SMALL_STATE(1861)] = 87894,
  [SMALL_STATE(1862)] = 87945,
  [SMALL_STATE(1863)] = 87996,
  [SMALL_STATE(1864)] = 88047,
  [SMALL_STATE(1865)] = 88098,
  [SMALL_STATE(1866)] = 88187,
  [SMALL_STATE(1867)] = 88238,
  [SMALL_STATE(1868)] = 88293,
  [SMALL_STATE(1869)] = 88348,
  [SMALL_STATE(1870)] = 88405,
  [SMALL_STATE(1871)] = 88460,
  [SMALL_STATE(1872)] = 88511,
  [SMALL_STATE(1873)] = 88562,
  [SMALL_STATE(1874)] = 88661,
  [SMALL_STATE(1875)] = 88712,
  [SMALL_STATE(1876)] = 88769,
  [SMALL_STATE(1877)] = 88826,
  [SMALL_STATE(1878)] = 88877,
  [SMALL_STATE(1879)] = 88932,
  [SMALL_STATE(1880)] = 88987,
  [SMALL_STATE(1881)] = 89038,
  [SMALL_STATE(1882)] = 89089,
  [SMALL_STATE(1883)] = 89146,
  [SMALL_STATE(1884)] = 89245,
  [SMALL_STATE(1885)] = 89344,
  [SMALL_STATE(1886)] = 89399,
  [SMALL_STATE(1887)] = 89454,
  [SMALL_STATE(1888)] = 89511,
  [SMALL_STATE(1889)] = 89562,
  [SMALL_STATE(1890)] = 89619,
  [SMALL_STATE(1891)] = 89676,
  [SMALL_STATE(1892)] = 89727,
  [SMALL_STATE(1893)] = 89782,
  [SMALL_STATE(1894)] = 89839,
  [SMALL_STATE(1895)] = 89896,
  [SMALL_STATE(1896)] = 89953,
  [SMALL_STATE(1897)] = 90004,
  [SMALL_STATE(1898)] = 90103,
  [SMALL_STATE(1899)] = 90160,
  [SMALL_STATE(1900)] = 90217,
  [SMALL_STATE(1901)] = 90274,
  [SMALL_STATE(1902)] = 90331,
  [SMALL_STATE(1903)] = 90388,
  [SMALL_STATE(1904)] = 90443,
  [SMALL_STATE(1905)] = 90494,
  [SMALL_STATE(1906)] = 90549,
  [SMALL_STATE(1907)] = 90600,
  [SMALL_STATE(1908)] = 90660,
  [SMALL_STATE(1909)] = 90720,
  [SMALL_STATE(1910)] = 90780,
  [SMALL_STATE(1911)] = 90830,
  [SMALL_STATE(1912)] = 90880,
  [SMALL_STATE(1913)] = 90930,
  [SMALL_STATE(1914)] = 91026,
  [SMALL_STATE(1915)] = 91080,
  [SMALL_STATE(1916)] = 91176,
  [SMALL_STATE(1917)] = 91230,
  [SMALL_STATE(1918)] = 91326,
  [SMALL_STATE(1919)] = 91422,
  [SMALL_STATE(1920)] = 91518,
  [SMALL_STATE(1921)] = 91614,
  [SMALL_STATE(1922)] = 91710,
  [SMALL_STATE(1923)] = 91806,
  [SMALL_STATE(1924)] = 91856,
  [SMALL_STATE(1925)] = 91906,
  [SMALL_STATE(1926)] = 91962,
  [SMALL_STATE(1927)] = 92058,
  [SMALL_STATE(1928)] = 92154,
  [SMALL_STATE(1929)] = 92250,
  [SMALL_STATE(1930)] = 92346,
  [SMALL_STATE(1931)] = 92402,
  [SMALL_STATE(1932)] = 92458,
  [SMALL_STATE(1933)] = 92554,
  [SMALL_STATE(1934)] = 92604,
  [SMALL_STATE(1935)] = 92660,
  [SMALL_STATE(1936)] = 92756,
  [SMALL_STATE(1937)] = 92806,
  [SMALL_STATE(1938)] = 92902,
  [SMALL_STATE(1939)] = 92998,
  [SMALL_STATE(1940)] = 93058,
  [SMALL_STATE(1941)] = 93154,
  [SMALL_STATE(1942)] = 93250,
  [SMALL_STATE(1943)] = 93346,
  [SMALL_STATE(1944)] = 93396,
  [SMALL_STATE(1945)] = 93492,
  [SMALL_STATE(1946)] = 93588,
  [SMALL_STATE(1947)] = 93684,
  [SMALL_STATE(1948)] = 93780,
  [SMALL_STATE(1949)] = 93876,
  [SMALL_STATE(1950)] = 93972,
  [SMALL_STATE(1951)] = 94022,
  [SMALL_STATE(1952)] = 94072,
  [SMALL_STATE(1953)] = 94168,
  [SMALL_STATE(1954)] = 94218,
  [SMALL_STATE(1955)] = 94314,
  [SMALL_STATE(1956)] = 94410,
  [SMALL_STATE(1957)] = 94460,
  [SMALL_STATE(1958)] = 94556,
  [SMALL_STATE(1959)] = 94652,
  [SMALL_STATE(1960)] = 94748,
  [SMALL_STATE(1961)] = 94844,
  [SMALL_STATE(1962)] = 94940,
  [SMALL_STATE(1963)] = 94990,
  [SMALL_STATE(1964)] = 95086,
  [SMALL_STATE(1965)] = 95182,
  [SMALL_STATE(1966)] = 95278,
  [SMALL_STATE(1967)] = 95374,
  [SMALL_STATE(1968)] = 95470,
  [SMALL_STATE(1969)] = 95524,
  [SMALL_STATE(1970)] = 95574,
  [SMALL_STATE(1971)] = 95630,
  [SMALL_STATE(1972)] = 95680,
  [SMALL_STATE(1973)] = 95776,
  [SMALL_STATE(1974)] = 95826,
  [SMALL_STATE(1975)] = 95922,
  [SMALL_STATE(1976)] = 95972,
  [SMALL_STATE(1977)] = 96068,
  [SMALL_STATE(1978)] = 96164,
  [SMALL_STATE(1979)] = 96260,
  [SMALL_STATE(1980)] = 96310,
  [SMALL_STATE(1981)] = 96406,
  [SMALL_STATE(1982)] = 96456,
  [SMALL_STATE(1983)] = 96506,
  [SMALL_STATE(1984)] = 96602,
  [SMALL_STATE(1985)] = 96652,
  [SMALL_STATE(1986)] = 96702,
  [SMALL_STATE(1987)] = 96752,
  [SMALL_STATE(1988)] = 96802,
  [SMALL_STATE(1989)] = 96852,
  [SMALL_STATE(1990)] = 96948,
  [SMALL_STATE(1991)] = 96998,
  [SMALL_STATE(1992)] = 97054,
  [SMALL_STATE(1993)] = 97110,
  [SMALL_STATE(1994)] = 97206,
  [SMALL_STATE(1995)] = 97256,
  [SMALL_STATE(1996)] = 97312,
  [SMALL_STATE(1997)] = 97362,
  [SMALL_STATE(1998)] = 97412,
  [SMALL_STATE(1999)] = 97508,
  [SMALL_STATE(2000)] = 97568,
  [SMALL_STATE(2001)] = 97664,
  [SMALL_STATE(2002)] = 97718,
  [SMALL_STATE(2003)] = 97768,
  [SMALL_STATE(2004)] = 97818,
  [SMALL_STATE(2005)] = 97868,
  [SMALL_STATE(2006)] = 97918,
  [SMALL_STATE(2007)] = 97968,
  [SMALL_STATE(2008)] = 98018,
  [SMALL_STATE(2009)] = 98068,
  [SMALL_STATE(2010)] = 98118,
  [SMALL_STATE(2011)] = 98168,
  [SMALL_STATE(2012)] = 98218,
  [SMALL_STATE(2013)] = 98314,
  [SMALL_STATE(2014)] = 98364,
  [SMALL_STATE(2015)] = 98414,
  [SMALL_STATE(2016)] = 98510,
  [SMALL_STATE(2017)] = 98570,
  [SMALL_STATE(2018)] = 98620,
  [SMALL_STATE(2019)] = 98678,
  [SMALL_STATE(2020)] = 98736,
  [SMALL_STATE(2021)] = 98786,
  [SMALL_STATE(2022)] = 98836,
  [SMALL_STATE(2023)] = 98886,
  [SMALL_STATE(2024)] = 98936,
  [SMALL_STATE(2025)] = 98986,
  [SMALL_STATE(2026)] = 99082,
  [SMALL_STATE(2027)] = 99136,
  [SMALL_STATE(2028)] = 99190,
  [SMALL_STATE(2029)] = 99240,
  [SMALL_STATE(2030)] = 99290,
  [SMALL_STATE(2031)] = 99344,
  [SMALL_STATE(2032)] = 99394,
  [SMALL_STATE(2033)] = 99490,
  [SMALL_STATE(2034)] = 99586,
  [SMALL_STATE(2035)] = 99636,
  [SMALL_STATE(2036)] = 99696,
  [SMALL_STATE(2037)] = 99746,
  [SMALL_STATE(2038)] = 99796,
  [SMALL_STATE(2039)] = 99846,
  [SMALL_STATE(2040)] = 99896,
  [SMALL_STATE(2041)] = 99992,
  [SMALL_STATE(2042)] = 100088,
  [SMALL_STATE(2043)] = 100142,
  [SMALL_STATE(2044)] = 100192,
  [SMALL_STATE(2045)] = 100246,
  [SMALL_STATE(2046)] = 100300,
  [SMALL_STATE(2047)] = 100396,
  [SMALL_STATE(2048)] = 100446,
  [SMALL_STATE(2049)] = 100542,
  [SMALL_STATE(2050)] = 100602,
  [SMALL_STATE(2051)] = 100698,
  [SMALL_STATE(2052)] = 100748,
  [SMALL_STATE(2053)] = 100798,
  [SMALL_STATE(2054)] = 100848,
  [SMALL_STATE(2055)] = 100898,
  [SMALL_STATE(2056)] = 100948,
  [SMALL_STATE(2057)] = 100998,
  [SMALL_STATE(2058)] = 101058,
  [SMALL_STATE(2059)] = 101154,
  [SMALL_STATE(2060)] = 101204,
  [SMALL_STATE(2061)] = 101254,
  [SMALL_STATE(2062)] = 101314,
  [SMALL_STATE(2063)] = 101364,
  [SMALL_STATE(2064)] = 101414,
  [SMALL_STATE(2065)] = 101510,
  [SMALL_STATE(2066)] = 101560,
  [SMALL_STATE(2067)] = 101656,
  [SMALL_STATE(2068)] = 101752,
  [SMALL_STATE(2069)] = 101812,
  [SMALL_STATE(2070)] = 101862,
  [SMALL_STATE(2071)] = 101922,
  [SMALL_STATE(2072)] = 102018,
  [SMALL_STATE(2073)] = 102072,
  [SMALL_STATE(2074)] = 102132,
  [SMALL_STATE(2075)] = 102192,
  [SMALL_STATE(2076)] = 102252,
  [SMALL_STATE(2077)] = 102302,
  [SMALL_STATE(2078)] = 102362,
  [SMALL_STATE(2079)] = 102416,
  [SMALL_STATE(2080)] = 102512,
  [SMALL_STATE(2081)] = 102608,
  [SMALL_STATE(2082)] = 102668,
  [SMALL_STATE(2083)] = 102718,
  [SMALL_STATE(2084)] = 102778,
  [SMALL_STATE(2085)] = 102838,
  [SMALL_STATE(2086)] = 102888,
  [SMALL_STATE(2087)] = 102948,
  [SMALL_STATE(2088)] = 103002,
  [SMALL_STATE(2089)] = 103062,
  [SMALL_STATE(2090)] = 103158,
  [SMALL_STATE(2091)] = 103218,
  [SMALL_STATE(2092)] = 103278,
  [SMALL_STATE(2093)] = 103338,
  [SMALL_STATE(2094)] = 103398,
  [SMALL_STATE(2095)] = 103458,
  [SMALL_STATE(2096)] = 103518,
  [SMALL_STATE(2097)] = 103578,
  [SMALL_STATE(2098)] = 103638,
  [SMALL_STATE(2099)] = 103698,
  [SMALL_STATE(2100)] = 103794,
  [SMALL_STATE(2101)] = 103854,
  [SMALL_STATE(2102)] = 103914,
  [SMALL_STATE(2103)] = 103974,
  [SMALL_STATE(2104)] = 104034,
  [SMALL_STATE(2105)] = 104094,
  [SMALL_STATE(2106)] = 104154,
  [SMALL_STATE(2107)] = 104214,
  [SMALL_STATE(2108)] = 104274,
  [SMALL_STATE(2109)] = 104334,
  [SMALL_STATE(2110)] = 104394,
  [SMALL_STATE(2111)] = 104448,
  [SMALL_STATE(2112)] = 104498,
  [SMALL_STATE(2113)] = 104552,
  [SMALL_STATE(2114)] = 104606,
  [SMALL_STATE(2115)] = 104660,
  [SMALL_STATE(2116)] = 104756,
  [SMALL_STATE(2117)] = 104810,
  [SMALL_STATE(2118)] = 104864,
  [SMALL_STATE(2119)] = 104960,
  [SMALL_STATE(2120)] = 105056,
  [SMALL_STATE(2121)] = 105152,
  [SMALL_STATE(2122)] = 105206,
  [SMALL_STATE(2123)] = 105256,
  [SMALL_STATE(2124)] = 105316,
  [SMALL_STATE(2125)] = 105376,
  [SMALL_STATE(2126)] = 105434,
  [SMALL_STATE(2127)] = 105530,
  [SMALL_STATE(2128)] = 105580,
  [SMALL_STATE(2129)] = 105640,
  [SMALL_STATE(2130)] = 105736,
  [SMALL_STATE(2131)] = 105796,
  [SMALL_STATE(2132)] = 105892,
  [SMALL_STATE(2133)] = 105988,
  [SMALL_STATE(2134)] = 106084,
  [SMALL_STATE(2135)] = 106144,
  [SMALL_STATE(2136)] = 106240,
  [SMALL_STATE(2137)] = 106300,
  [SMALL_STATE(2138)] = 106350,
  [SMALL_STATE(2139)] = 106446,
  [SMALL_STATE(2140)] = 106506,
  [SMALL_STATE(2141)] = 106566,
  [SMALL_STATE(2142)] = 106626,
  [SMALL_STATE(2143)] = 106680,
  [SMALL_STATE(2144)] = 106740,
  [SMALL_STATE(2145)] = 106790,
  [SMALL_STATE(2146)] = 106886,
  [SMALL_STATE(2147)] = 106946,
  [SMALL_STATE(2148)] = 107042,
  [SMALL_STATE(2149)] = 107098,
  [SMALL_STATE(2150)] = 107152,
  [SMALL_STATE(2151)] = 107202,
  [SMALL_STATE(2152)] = 107262,
  [SMALL_STATE(2153)] = 107358,
  [SMALL_STATE(2154)] = 107418,
  [SMALL_STATE(2155)] = 107514,
  [SMALL_STATE(2156)] = 107610,
  [SMALL_STATE(2157)] = 107670,
  [SMALL_STATE(2158)] = 107766,
  [SMALL_STATE(2159)] = 107816,
  [SMALL_STATE(2160)] = 107912,
  [SMALL_STATE(2161)] = 108008,
  [SMALL_STATE(2162)] = 108104,
  [SMALL_STATE(2163)] = 108200,
  [SMALL_STATE(2164)] = 108296,
  [SMALL_STATE(2165)] = 108392,
  [SMALL_STATE(2166)] = 108452,
  [SMALL_STATE(2167)] = 108548,
  [SMALL_STATE(2168)] = 108644,
  [SMALL_STATE(2169)] = 108740,
  [SMALL_STATE(2170)] = 108836,
  [SMALL_STATE(2171)] = 108932,
  [SMALL_STATE(2172)] = 108992,
  [SMALL_STATE(2173)] = 109088,
  [SMALL_STATE(2174)] = 109184,
  [SMALL_STATE(2175)] = 109244,
  [SMALL_STATE(2176)] = 109340,
  [SMALL_STATE(2177)] = 109400,
  [SMALL_STATE(2178)] = 109454,
  [SMALL_STATE(2179)] = 109550,
  [SMALL_STATE(2180)] = 109600,
  [SMALL_STATE(2181)] = 109696,
  [SMALL_STATE(2182)] = 109792,
  [SMALL_STATE(2183)] = 109852,
  [SMALL_STATE(2184)] = 109912,
  [SMALL_STATE(2185)] = 110008,
  [SMALL_STATE(2186)] = 110104,
  [SMALL_STATE(2187)] = 110200,
  [SMALL_STATE(2188)] = 110250,
  [SMALL_STATE(2189)] = 110346,
  [SMALL_STATE(2190)] = 110406,
  [SMALL_STATE(2191)] = 110502,
  [SMALL_STATE(2192)] = 110598,
  [SMALL_STATE(2193)] = 110658,
  [SMALL_STATE(2194)] = 110718,
  [SMALL_STATE(2195)] = 110778,
  [SMALL_STATE(2196)] = 110828,
  [SMALL_STATE(2197)] = 110888,
  [SMALL_STATE(2198)] = 110948,
  [SMALL_STATE(2199)] = 111008,
  [SMALL_STATE(2200)] = 111068,
  [SMALL_STATE(2201)] = 111128,
  [SMALL_STATE(2202)] = 111188,
  [SMALL_STATE(2203)] = 111248,
  [SMALL_STATE(2204)] = 111308,
  [SMALL_STATE(2205)] = 111368,
  [SMALL_STATE(2206)] = 111428,
  [SMALL_STATE(2207)] = 111488,
  [SMALL_STATE(2208)] = 111546,
  [SMALL_STATE(2209)] = 111606,
  [SMALL_STATE(2210)] = 111702,
  [SMALL_STATE(2211)] = 111752,
  [SMALL_STATE(2212)] = 111812,
  [SMALL_STATE(2213)] = 111908,
  [SMALL_STATE(2214)] = 112004,
  [SMALL_STATE(2215)] = 112054,
  [SMALL_STATE(2216)] = 112114,
  [SMALL_STATE(2217)] = 112174,
  [SMALL_STATE(2218)] = 112227,
  [SMALL_STATE(2219)] = 112276,
  [SMALL_STATE(2220)] = 112325,
  [SMALL_STATE(2221)] = 112374,
  [SMALL_STATE(2222)] = 112423,
  [SMALL_STATE(2223)] = 112472,
  [SMALL_STATE(2224)] = 112521,
  [SMALL_STATE(2225)] = 112570,
  [SMALL_STATE(2226)] = 112619,
  [SMALL_STATE(2227)] = 112668,
  [SMALL_STATE(2228)] = 112717,
  [SMALL_STATE(2229)] = 112770,
  [SMALL_STATE(2230)] = 112819,
  [SMALL_STATE(2231)] = 112868,
  [SMALL_STATE(2232)] = 112921,
  [SMALL_STATE(2233)] = 112970,
  [SMALL_STATE(2234)] = 113019,
  [SMALL_STATE(2235)] = 113068,
  [SMALL_STATE(2236)] = 113117,
  [SMALL_STATE(2237)] = 113166,
  [SMALL_STATE(2238)] = 113215,
  [SMALL_STATE(2239)] = 113268,
  [SMALL_STATE(2240)] = 113317,
  [SMALL_STATE(2241)] = 113366,
  [SMALL_STATE(2242)] = 113415,
  [SMALL_STATE(2243)] = 113464,
  [SMALL_STATE(2244)] = 113513,
  [SMALL_STATE(2245)] = 113562,
  [SMALL_STATE(2246)] = 113611,
  [SMALL_STATE(2247)] = 113664,
  [SMALL_STATE(2248)] = 113713,
  [SMALL_STATE(2249)] = 113762,
  [SMALL_STATE(2250)] = 113815,
  [SMALL_STATE(2251)] = 113868,
  [SMALL_STATE(2252)] = 113917,
  [SMALL_STATE(2253)] = 113970,
  [SMALL_STATE(2254)] = 114023,
  [SMALL_STATE(2255)] = 114078,
  [SMALL_STATE(2256)] = 114133,
  [SMALL_STATE(2257)] = 114188,
  [SMALL_STATE(2258)] = 114243,
  [SMALL_STATE(2259)] = 114292,
  [SMALL_STATE(2260)] = 114345,
  [SMALL_STATE(2261)] = 114394,
  [SMALL_STATE(2262)] = 114443,
  [SMALL_STATE(2263)] = 114502,
  [SMALL_STATE(2264)] = 114551,
  [SMALL_STATE(2265)] = 114604,
  [SMALL_STATE(2266)] = 114653,
  [SMALL_STATE(2267)] = 114702,
  [SMALL_STATE(2268)] = 114751,
  [SMALL_STATE(2269)] = 114808,
  [SMALL_STATE(2270)] = 114865,
  [SMALL_STATE(2271)] = 114918,
  [SMALL_STATE(2272)] = 114967,
  [SMALL_STATE(2273)] = 115016,
  [SMALL_STATE(2274)] = 115071,
  [SMALL_STATE(2275)] = 115120,
  [SMALL_STATE(2276)] = 115175,
  [SMALL_STATE(2277)] = 115224,
  [SMALL_STATE(2278)] = 115277,
  [SMALL_STATE(2279)] = 115326,
  [SMALL_STATE(2280)] = 115379,
  [SMALL_STATE(2281)] = 115432,
  [SMALL_STATE(2282)] = 115481,
  [SMALL_STATE(2283)] = 115534,
  [SMALL_STATE(2284)] = 115587,
  [SMALL_STATE(2285)] = 115640,
  [SMALL_STATE(2286)] = 115693,
  [SMALL_STATE(2287)] = 115748,
  [SMALL_STATE(2288)] = 115803,
  [SMALL_STATE(2289)] = 115858,
  [SMALL_STATE(2290)] = 115913,
  [SMALL_STATE(2291)] = 115968,
  [SMALL_STATE(2292)] = 116023,
  [SMALL_STATE(2293)] = 116078,
  [SMALL_STATE(2294)] = 116133,
  [SMALL_STATE(2295)] = 116188,
  [SMALL_STATE(2296)] = 116243,
  [SMALL_STATE(2297)] = 116298,
  [SMALL_STATE(2298)] = 116353,
  [SMALL_STATE(2299)] = 116402,
  [SMALL_STATE(2300)] = 116455,
  [SMALL_STATE(2301)] = 116510,
  [SMALL_STATE(2302)] = 116565,
  [SMALL_STATE(2303)] = 116614,
  [SMALL_STATE(2304)] = 116669,
  [SMALL_STATE(2305)] = 116724,
  [SMALL_STATE(2306)] = 116783,
  [SMALL_STATE(2307)] = 116836,
  [SMALL_STATE(2308)] = 116889,
  [SMALL_STATE(2309)] = 116943,
  [SMALL_STATE(2310)] = 116995,
  [SMALL_STATE(2311)] = 117049,
  [SMALL_STATE(2312)] = 117103,
  [SMALL_STATE(2313)] = 117155,
  [SMALL_STATE(2314)] = 117203,
  [SMALL_STATE(2315)] = 117257,
  [SMALL_STATE(2316)] = 117311,
  [SMALL_STATE(2317)] = 117359,
  [SMALL_STATE(2318)] = 117413,
  [SMALL_STATE(2319)] = 117461,
  [SMALL_STATE(2320)] = 117509,
  [SMALL_STATE(2321)] = 117603,
  [SMALL_STATE(2322)] = 117655,
  [SMALL_STATE(2323)] = 117749,
  [SMALL_STATE(2324)] = 117801,
  [SMALL_STATE(2325)] = 117855,
  [SMALL_STATE(2326)] = 117907,
  [SMALL_STATE(2327)] = 118001,
  [SMALL_STATE(2328)] = 118057,
  [SMALL_STATE(2329)] = 118105,
  [SMALL_STATE(2330)] = 118157,
  [SMALL_STATE(2331)] = 118211,
  [SMALL_STATE(2332)] = 118305,
  [SMALL_STATE(2333)] = 118357,
  [SMALL_STATE(2334)] = 118405,
  [SMALL_STATE(2335)] = 118499,
  [SMALL_STATE(2336)] = 118551,
  [SMALL_STATE(2337)] = 118645,
  [SMALL_STATE(2338)] = 118695,
  [SMALL_STATE(2339)] = 118743,
  [SMALL_STATE(2340)] = 118791,
  [SMALL_STATE(2341)] = 118839,
  [SMALL_STATE(2342)] = 118887,
  [SMALL_STATE(2343)] = 118943,
  [SMALL_STATE(2344)] = 118991,
  [SMALL_STATE(2345)] = 119043,
  [SMALL_STATE(2346)] = 119099,
  [SMALL_STATE(2347)] = 119151,
  [SMALL_STATE(2348)] = 119199,
  [SMALL_STATE(2349)] = 119247,
  [SMALL_STATE(2350)] = 119299,
  [SMALL_STATE(2351)] = 119351,
  [SMALL_STATE(2352)] = 119399,
  [SMALL_STATE(2353)] = 119447,
  [SMALL_STATE(2354)] = 119495,
  [SMALL_STATE(2355)] = 119547,
  [SMALL_STATE(2356)] = 119603,
  [SMALL_STATE(2357)] = 119657,
  [SMALL_STATE(2358)] = 119713,
  [SMALL_STATE(2359)] = 119761,
  [SMALL_STATE(2360)] = 119817,
  [SMALL_STATE(2361)] = 119865,
  [SMALL_STATE(2362)] = 119917,
  [SMALL_STATE(2363)] = 119973,
  [SMALL_STATE(2364)] = 120029,
  [SMALL_STATE(2365)] = 120083,
  [SMALL_STATE(2366)] = 120135,
  [SMALL_STATE(2367)] = 120191,
  [SMALL_STATE(2368)] = 120243,
  [SMALL_STATE(2369)] = 120295,
  [SMALL_STATE(2370)] = 120347,
  [SMALL_STATE(2371)] = 120395,
  [SMALL_STATE(2372)] = 120447,
  [SMALL_STATE(2373)] = 120495,
  [SMALL_STATE(2374)] = 120551,
  [SMALL_STATE(2375)] = 120645,
  [SMALL_STATE(2376)] = 120739,
  [SMALL_STATE(2377)] = 120793,
  [SMALL_STATE(2378)] = 120887,
  [SMALL_STATE(2379)] = 120981,
  [SMALL_STATE(2380)] = 121075,
  [SMALL_STATE(2381)] = 121127,
  [SMALL_STATE(2382)] = 121179,
  [SMALL_STATE(2383)] = 121231,
  [SMALL_STATE(2384)] = 121325,
  [SMALL_STATE(2385)] = 121379,
  [SMALL_STATE(2386)] = 121473,
  [SMALL_STATE(2387)] = 121527,
  [SMALL_STATE(2388)] = 121579,
  [SMALL_STATE(2389)] = 121631,
  [SMALL_STATE(2390)] = 121725,
  [SMALL_STATE(2391)] = 121773,
  [SMALL_STATE(2392)] = 121825,
  [SMALL_STATE(2393)] = 121879,
  [SMALL_STATE(2394)] = 121933,
  [SMALL_STATE(2395)] = 122027,
  [SMALL_STATE(2396)] = 122079,
  [SMALL_STATE(2397)] = 122133,
  [SMALL_STATE(2398)] = 122181,
  [SMALL_STATE(2399)] = 122235,
  [SMALL_STATE(2400)] = 122287,
  [SMALL_STATE(2401)] = 122341,
  [SMALL_STATE(2402)] = 122389,
  [SMALL_STATE(2403)] = 122437,
  [SMALL_STATE(2404)] = 122489,
  [SMALL_STATE(2405)] = 122537,
  [SMALL_STATE(2406)] = 122589,
  [SMALL_STATE(2407)] = 122641,
  [SMALL_STATE(2408)] = 122693,
  [SMALL_STATE(2409)] = 122745,
  [SMALL_STATE(2410)] = 122797,
  [SMALL_STATE(2411)] = 122849,
  [SMALL_STATE(2412)] = 122903,
  [SMALL_STATE(2413)] = 122951,
  [SMALL_STATE(2414)] = 123005,
  [SMALL_STATE(2415)] = 123053,
  [SMALL_STATE(2416)] = 123101,
  [SMALL_STATE(2417)] = 123155,
  [SMALL_STATE(2418)] = 123209,
  [SMALL_STATE(2419)] = 123265,
  [SMALL_STATE(2420)] = 123317,
  [SMALL_STATE(2421)] = 123371,
  [SMALL_STATE(2422)] = 123425,
  [SMALL_STATE(2423)] = 123477,
  [SMALL_STATE(2424)] = 123529,
  [SMALL_STATE(2425)] = 123583,
  [SMALL_STATE(2426)] = 123637,
  [SMALL_STATE(2427)] = 123689,
  [SMALL_STATE(2428)] = 123737,
  [SMALL_STATE(2429)] = 123785,
  [SMALL_STATE(2430)] = 123833,
  [SMALL_STATE(2431)] = 123927,
  [SMALL_STATE(2432)] = 123983,
  [SMALL_STATE(2433)] = 124030,
  [SMALL_STATE(2434)] = 124077,
  [SMALL_STATE(2435)] = 124124,
  [SMALL_STATE(2436)] = 124171,
  [SMALL_STATE(2437)] = 124222,
  [SMALL_STATE(2438)] = 124269,
  [SMALL_STATE(2439)] = 124316,
  [SMALL_STATE(2440)] = 124363,
  [SMALL_STATE(2441)] = 124410,
  [SMALL_STATE(2442)] = 124457,
  [SMALL_STATE(2443)] = 124504,
  [SMALL_STATE(2444)] = 124551,
  [SMALL_STATE(2445)] = 124598,
  [SMALL_STATE(2446)] = 124645,
  [SMALL_STATE(2447)] = 124692,
  [SMALL_STATE(2448)] = 124739,
  [SMALL_STATE(2449)] = 124786,
  [SMALL_STATE(2450)] = 124833,
  [SMALL_STATE(2451)] = 124880,
  [SMALL_STATE(2452)] = 124931,
  [SMALL_STATE(2453)] = 124982,
  [SMALL_STATE(2454)] = 125029,
  [SMALL_STATE(2455)] = 125076,
  [SMALL_STATE(2456)] = 125123,
  [SMALL_STATE(2457)] = 125170,
  [SMALL_STATE(2458)] = 125217,
  [SMALL_STATE(2459)] = 125268,
  [SMALL_STATE(2460)] = 125315,
  [SMALL_STATE(2461)] = 125362,
  [SMALL_STATE(2462)] = 125409,
  [SMALL_STATE(2463)] = 125456,
  [SMALL_STATE(2464)] = 125503,
  [SMALL_STATE(2465)] = 125550,
  [SMALL_STATE(2466)] = 125601,
  [SMALL_STATE(2467)] = 125648,
  [SMALL_STATE(2468)] = 125695,
  [SMALL_STATE(2469)] = 125742,
  [SMALL_STATE(2470)] = 125789,
  [SMALL_STATE(2471)] = 125836,
  [SMALL_STATE(2472)] = 125883,
  [SMALL_STATE(2473)] = 125930,
  [SMALL_STATE(2474)] = 125983,
  [SMALL_STATE(2475)] = 126036,
  [SMALL_STATE(2476)] = 126089,
  [SMALL_STATE(2477)] = 126140,
  [SMALL_STATE(2478)] = 126187,
  [SMALL_STATE(2479)] = 126234,
  [SMALL_STATE(2480)] = 126285,
  [SMALL_STATE(2481)] = 126332,
  [SMALL_STATE(2482)] = 126383,
  [SMALL_STATE(2483)] = 126430,
  [SMALL_STATE(2484)] = 126477,
  [SMALL_STATE(2485)] = 126524,
  [SMALL_STATE(2486)] = 126571,
  [SMALL_STATE(2487)] = 126618,
  [SMALL_STATE(2488)] = 126667,
  [SMALL_STATE(2489)] = 126714,
  [SMALL_STATE(2490)] = 126761,
  [SMALL_STATE(2491)] = 126812,
  [SMALL_STATE(2492)] = 126861,
  [SMALL_STATE(2493)] = 126908,
  [SMALL_STATE(2494)] = 126955,
  [SMALL_STATE(2495)] = 127002,
  [SMALL_STATE(2496)] = 127051,
  [SMALL_STATE(2497)] = 127102,
  [SMALL_STATE(2498)] = 127149,
  [SMALL_STATE(2499)] = 127196,
  [SMALL_STATE(2500)] = 127243,
  [SMALL_STATE(2501)] = 127290,
  [SMALL_STATE(2502)] = 127337,
  [SMALL_STATE(2503)] = 127384,
  [SMALL_STATE(2504)] = 127437,
  [SMALL_STATE(2505)] = 127488,
  [SMALL_STATE(2506)] = 127535,
  [SMALL_STATE(2507)] = 127582,
  [SMALL_STATE(2508)] = 127629,
  [SMALL_STATE(2509)] = 127676,
  [SMALL_STATE(2510)] = 127723,
  [SMALL_STATE(2511)] = 127770,
  [SMALL_STATE(2512)] = 127817,
  [SMALL_STATE(2513)] = 127864,
  [SMALL_STATE(2514)] = 127915,
  [SMALL_STATE(2515)] = 127968,
  [SMALL_STATE(2516)] = 128015,
  [SMALL_STATE(2517)] = 128062,
  [SMALL_STATE(2518)] = 128109,
  [SMALL_STATE(2519)] = 128156,
  [SMALL_STATE(2520)] = 128209,
  [SMALL_STATE(2521)] = 128258,
  [SMALL_STATE(2522)] = 128305,
  [SMALL_STATE(2523)] = 128352,
  [SMALL_STATE(2524)] = 128399,
  [SMALL_STATE(2525)] = 128446,
  [SMALL_STATE(2526)] = 128493,
  [SMALL_STATE(2527)] = 128544,
  [SMALL_STATE(2528)] = 128595,
  [SMALL_STATE(2529)] = 128648,
  [SMALL_STATE(2530)] = 128695,
  [SMALL_STATE(2531)] = 128748,
  [SMALL_STATE(2532)] = 128799,
  [SMALL_STATE(2533)] = 128846,
  [SMALL_STATE(2534)] = 128897,
  [SMALL_STATE(2535)] = 128944,
  [SMALL_STATE(2536)] = 128991,
  [SMALL_STATE(2537)] = 129042,
  [SMALL_STATE(2538)] = 129089,
  [SMALL_STATE(2539)] = 129140,
  [SMALL_STATE(2540)] = 129193,
  [SMALL_STATE(2541)] = 129244,
  [SMALL_STATE(2542)] = 129291,
  [SMALL_STATE(2543)] = 129338,
  [SMALL_STATE(2544)] = 129387,
  [SMALL_STATE(2545)] = 129438,
  [SMALL_STATE(2546)] = 129487,
  [SMALL_STATE(2547)] = 129534,
  [SMALL_STATE(2548)] = 129587,
  [SMALL_STATE(2549)] = 129634,
  [SMALL_STATE(2550)] = 129685,
  [SMALL_STATE(2551)] = 129732,
  [SMALL_STATE(2552)] = 129779,
  [SMALL_STATE(2553)] = 129826,
  [SMALL_STATE(2554)] = 129873,
  [SMALL_STATE(2555)] = 129920,
  [SMALL_STATE(2556)] = 129973,
  [SMALL_STATE(2557)] = 130026,
  [SMALL_STATE(2558)] = 130077,
  [SMALL_STATE(2559)] = 130124,
  [SMALL_STATE(2560)] = 130171,
  [SMALL_STATE(2561)] = 130218,
  [SMALL_STATE(2562)] = 130271,
  [SMALL_STATE(2563)] = 130318,
  [SMALL_STATE(2564)] = 130365,
  [SMALL_STATE(2565)] = 130412,
  [SMALL_STATE(2566)] = 130461,
  [SMALL_STATE(2567)] = 130508,
  [SMALL_STATE(2568)] = 130555,
  [SMALL_STATE(2569)] = 130602,
  [SMALL_STATE(2570)] = 130653,
  [SMALL_STATE(2571)] = 130700,
  [SMALL_STATE(2572)] = 130747,
  [SMALL_STATE(2573)] = 130794,
  [SMALL_STATE(2574)] = 130840,
  [SMALL_STATE(2575)] = 130886,
  [SMALL_STATE(2576)] = 130938,
  [SMALL_STATE(2577)] = 130990,
  [SMALL_STATE(2578)] = 131040,
  [SMALL_STATE(2579)] = 131090,
  [SMALL_STATE(2580)] = 131136,
  [SMALL_STATE(2581)] = 131182,
  [SMALL_STATE(2582)] = 131228,
  [SMALL_STATE(2583)] = 131274,
  [SMALL_STATE(2584)] = 131320,
  [SMALL_STATE(2585)] = 131366,
  [SMALL_STATE(2586)] = 131412,
  [SMALL_STATE(2587)] = 131458,
  [SMALL_STATE(2588)] = 131504,
  [SMALL_STATE(2589)] = 131550,
  [SMALL_STATE(2590)] = 131596,
  [SMALL_STATE(2591)] = 131642,
  [SMALL_STATE(2592)] = 131688,
  [SMALL_STATE(2593)] = 131734,
  [SMALL_STATE(2594)] = 131780,
  [SMALL_STATE(2595)] = 131828,
  [SMALL_STATE(2596)] = 131874,
  [SMALL_STATE(2597)] = 131920,
  [SMALL_STATE(2598)] = 131966,
  [SMALL_STATE(2599)] = 132012,
  [SMALL_STATE(2600)] = 132058,
  [SMALL_STATE(2601)] = 132104,
  [SMALL_STATE(2602)] = 132150,
  [SMALL_STATE(2603)] = 132198,
  [SMALL_STATE(2604)] = 132252,
  [SMALL_STATE(2605)] = 132306,
  [SMALL_STATE(2606)] = 132356,
  [SMALL_STATE(2607)] = 132402,
  [SMALL_STATE(2608)] = 132448,
  [SMALL_STATE(2609)] = 132494,
  [SMALL_STATE(2610)] = 132544,
  [SMALL_STATE(2611)] = 132594,
  [SMALL_STATE(2612)] = 132644,
  [SMALL_STATE(2613)] = 132690,
  [SMALL_STATE(2614)] = 132736,
  [SMALL_STATE(2615)] = 132782,
  [SMALL_STATE(2616)] = 132828,
  [SMALL_STATE(2617)] = 132874,
  [SMALL_STATE(2618)] = 132930,
  [SMALL_STATE(2619)] = 132980,
  [SMALL_STATE(2620)] = 133028,
  [SMALL_STATE(2621)] = 133074,
  [SMALL_STATE(2622)] = 133120,
  [SMALL_STATE(2623)] = 133166,
  [SMALL_STATE(2624)] = 133222,
  [SMALL_STATE(2625)] = 133280,
  [SMALL_STATE(2626)] = 133336,
  [SMALL_STATE(2627)] = 133384,
  [SMALL_STATE(2628)] = 133440,
  [SMALL_STATE(2629)] = 133486,
  [SMALL_STATE(2630)] = 133558,
  [SMALL_STATE(2631)] = 133608,
  [SMALL_STATE(2632)] = 133654,
  [SMALL_STATE(2633)] = 133704,
  [SMALL_STATE(2634)] = 133754,
  [SMALL_STATE(2635)] = 133804,
  [SMALL_STATE(2636)] = 133850,
  [SMALL_STATE(2637)] = 133906,
  [SMALL_STATE(2638)] = 133982,
  [SMALL_STATE(2639)] = 134060,
  [SMALL_STATE(2640)] = 134132,
  [SMALL_STATE(2641)] = 134202,
  [SMALL_STATE(2642)] = 134270,
  [SMALL_STATE(2643)] = 134336,
  [SMALL_STATE(2644)] = 134400,
  [SMALL_STATE(2645)] = 134462,
  [SMALL_STATE(2646)] = 134508,
  [SMALL_STATE(2647)] = 134566,
  [SMALL_STATE(2648)] = 134620,
  [SMALL_STATE(2649)] = 134672,
  [SMALL_STATE(2650)] = 134722,
  [SMALL_STATE(2651)] = 134772,
  [SMALL_STATE(2652)] = 134818,
  [SMALL_STATE(2653)] = 134874,
  [SMALL_STATE(2654)] = 134930,
  [SMALL_STATE(2655)] = 134980,
  [SMALL_STATE(2656)] = 135030,
  [SMALL_STATE(2657)] = 135112,
  [SMALL_STATE(2658)] = 135162,
  [SMALL_STATE(2659)] = 135208,
  [SMALL_STATE(2660)] = 135290,
  [SMALL_STATE(2661)] = 135340,
  [SMALL_STATE(2662)] = 135386,
  [SMALL_STATE(2663)] = 135432,
  [SMALL_STATE(2664)] = 135482,
  [SMALL_STATE(2665)] = 135528,
  [SMALL_STATE(2666)] = 135574,
  [SMALL_STATE(2667)] = 135620,
  [SMALL_STATE(2668)] = 135702,
  [SMALL_STATE(2669)] = 135752,
  [SMALL_STATE(2670)] = 135834,
  [SMALL_STATE(2671)] = 135884,
  [SMALL_STATE(2672)] = 135966,
  [SMALL_STATE(2673)] = 136048,
  [SMALL_STATE(2674)] = 136130,
  [SMALL_STATE(2675)] = 136212,
  [SMALL_STATE(2676)] = 136294,
  [SMALL_STATE(2677)] = 136376,
  [SMALL_STATE(2678)] = 136422,
  [SMALL_STATE(2679)] = 136504,
  [SMALL_STATE(2680)] = 136586,
  [SMALL_STATE(2681)] = 136668,
  [SMALL_STATE(2682)] = 136750,
  [SMALL_STATE(2683)] = 136832,
  [SMALL_STATE(2684)] = 136914,
  [SMALL_STATE(2685)] = 136996,
  [SMALL_STATE(2686)] = 137078,
  [SMALL_STATE(2687)] = 137124,
  [SMALL_STATE(2688)] = 137206,
  [SMALL_STATE(2689)] = 137288,
  [SMALL_STATE(2690)] = 137370,
  [SMALL_STATE(2691)] = 137452,
  [SMALL_STATE(2692)] = 137534,
  [SMALL_STATE(2693)] = 137616,
  [SMALL_STATE(2694)] = 137698,
  [SMALL_STATE(2695)] = 137780,
  [SMALL_STATE(2696)] = 137862,
  [SMALL_STATE(2697)] = 137944,
  [SMALL_STATE(2698)] = 138026,
  [SMALL_STATE(2699)] = 138108,
  [SMALL_STATE(2700)] = 138190,
  [SMALL_STATE(2701)] = 138272,
  [SMALL_STATE(2702)] = 138354,
  [SMALL_STATE(2703)] = 138436,
  [SMALL_STATE(2704)] = 138518,
  [SMALL_STATE(2705)] = 138600,
  [SMALL_STATE(2706)] = 138682,
  [SMALL_STATE(2707)] = 138764,
  [SMALL_STATE(2708)] = 138846,
  [SMALL_STATE(2709)] = 138928,
  [SMALL_STATE(2710)] = 139010,
  [SMALL_STATE(2711)] = 139092,
  [SMALL_STATE(2712)] = 139174,
  [SMALL_STATE(2713)] = 139220,
  [SMALL_STATE(2714)] = 139302,
  [SMALL_STATE(2715)] = 139384,
  [SMALL_STATE(2716)] = 139430,
  [SMALL_STATE(2717)] = 139512,
  [SMALL_STATE(2718)] = 139594,
  [SMALL_STATE(2719)] = 139676,
  [SMALL_STATE(2720)] = 139758,
  [SMALL_STATE(2721)] = 139840,
  [SMALL_STATE(2722)] = 139922,
  [SMALL_STATE(2723)] = 140004,
  [SMALL_STATE(2724)] = 140086,
  [SMALL_STATE(2725)] = 140168,
  [SMALL_STATE(2726)] = 140250,
  [SMALL_STATE(2727)] = 140332,
  [SMALL_STATE(2728)] = 140378,
  [SMALL_STATE(2729)] = 140460,
  [SMALL_STATE(2730)] = 140506,
  [SMALL_STATE(2731)] = 140588,
  [SMALL_STATE(2732)] = 140670,
  [SMALL_STATE(2733)] = 140752,
  [SMALL_STATE(2734)] = 140834,
  [SMALL_STATE(2735)] = 140916,
  [SMALL_STATE(2736)] = 140998,
  [SMALL_STATE(2737)] = 141044,
  [SMALL_STATE(2738)] = 141094,
  [SMALL_STATE(2739)] = 141140,
  [SMALL_STATE(2740)] = 141186,
  [SMALL_STATE(2741)] = 141232,
  [SMALL_STATE(2742)] = 141278,
  [SMALL_STATE(2743)] = 141324,
  [SMALL_STATE(2744)] = 141370,
  [SMALL_STATE(2745)] = 141416,
  [SMALL_STATE(2746)] = 141462,
  [SMALL_STATE(2747)] = 141508,
  [SMALL_STATE(2748)] = 141554,
  [SMALL_STATE(2749)] = 141600,
  [SMALL_STATE(2750)] = 141646,
  [SMALL_STATE(2751)] = 141720,
  [SMALL_STATE(2752)] = 141766,
  [SMALL_STATE(2753)] = 141840,
  [SMALL_STATE(2754)] = 141886,
  [SMALL_STATE(2755)] = 141932,
  [SMALL_STATE(2756)] = 141978,
  [SMALL_STATE(2757)] = 142024,
  [SMALL_STATE(2758)] = 142070,
  [SMALL_STATE(2759)] = 142116,
  [SMALL_STATE(2760)] = 142162,
  [SMALL_STATE(2761)] = 142208,
  [SMALL_STATE(2762)] = 142254,
  [SMALL_STATE(2763)] = 142300,
  [SMALL_STATE(2764)] = 142346,
  [SMALL_STATE(2765)] = 142392,
  [SMALL_STATE(2766)] = 142468,
  [SMALL_STATE(2767)] = 142538,
  [SMALL_STATE(2768)] = 142606,
  [SMALL_STATE(2769)] = 142672,
  [SMALL_STATE(2770)] = 142736,
  [SMALL_STATE(2771)] = 142798,
  [SMALL_STATE(2772)] = 142858,
  [SMALL_STATE(2773)] = 142914,
  [SMALL_STATE(2774)] = 142968,
  [SMALL_STATE(2775)] = 143020,
  [SMALL_STATE(2776)] = 143070,
  [SMALL_STATE(2777)] = 143118,
  [SMALL_STATE(2778)] = 143164,
  [SMALL_STATE(2779)] = 143210,
  [SMALL_STATE(2780)] = 143256,
  [SMALL_STATE(2781)] = 143302,
  [SMALL_STATE(2782)] = 143348,
  [SMALL_STATE(2783)] = 143394,
  [SMALL_STATE(2784)] = 143440,
  [SMALL_STATE(2785)] = 143486,
  [SMALL_STATE(2786)] = 143532,
  [SMALL_STATE(2787)] = 143582,
  [SMALL_STATE(2788)] = 143628,
  [SMALL_STATE(2789)] = 143674,
  [SMALL_STATE(2790)] = 143720,
  [SMALL_STATE(2791)] = 143770,
  [SMALL_STATE(2792)] = 143852,
  [SMALL_STATE(2793)] = 143898,
  [SMALL_STATE(2794)] = 143948,
  [SMALL_STATE(2795)] = 143994,
  [SMALL_STATE(2796)] = 144040,
  [SMALL_STATE(2797)] = 144086,
  [SMALL_STATE(2798)] = 144132,
  [SMALL_STATE(2799)] = 144178,
  [SMALL_STATE(2800)] = 144224,
  [SMALL_STATE(2801)] = 144270,
  [SMALL_STATE(2802)] = 144316,
  [SMALL_STATE(2803)] = 144362,
  [SMALL_STATE(2804)] = 144444,
  [SMALL_STATE(2805)] = 144497,
  [SMALL_STATE(2806)] = 144576,
  [SMALL_STATE(2807)] = 144655,
  [SMALL_STATE(2808)] = 144714,
  [SMALL_STATE(2809)] = 144759,
  [SMALL_STATE(2810)] = 144838,
  [SMALL_STATE(2811)] = 144917,
  [SMALL_STATE(2812)] = 144996,
  [SMALL_STATE(2813)] = 145075,
  [SMALL_STATE(2814)] = 145120,
  [SMALL_STATE(2815)] = 145165,
  [SMALL_STATE(2816)] = 145210,
  [SMALL_STATE(2817)] = 145289,
  [SMALL_STATE(2818)] = 145368,
  [SMALL_STATE(2819)] = 145447,
  [SMALL_STATE(2820)] = 145526,
  [SMALL_STATE(2821)] = 145583,
  [SMALL_STATE(2822)] = 145662,
  [SMALL_STATE(2823)] = 145709,
  [SMALL_STATE(2824)] = 145788,
  [SMALL_STATE(2825)] = 145867,
  [SMALL_STATE(2826)] = 145946,
  [SMALL_STATE(2827)] = 146001,
  [SMALL_STATE(2828)] = 146080,
  [SMALL_STATE(2829)] = 146159,
  [SMALL_STATE(2830)] = 146212,
  [SMALL_STATE(2831)] = 146291,
  [SMALL_STATE(2832)] = 146340,
  [SMALL_STATE(2833)] = 146385,
  [SMALL_STATE(2834)] = 146430,
  [SMALL_STATE(2835)] = 146475,
  [SMALL_STATE(2836)] = 146526,
  [SMALL_STATE(2837)] = 146575,
  [SMALL_STATE(2838)] = 146624,
  [SMALL_STATE(2839)] = 146669,
  [SMALL_STATE(2840)] = 146714,
  [SMALL_STATE(2841)] = 146769,
  [SMALL_STATE(2842)] = 146814,
  [SMALL_STATE(2843)] = 146859,
  [SMALL_STATE(2844)] = 146916,
  [SMALL_STATE(2845)] = 146969,
  [SMALL_STATE(2846)] = 147048,
  [SMALL_STATE(2847)] = 147093,
  [SMALL_STATE(2848)] = 147138,
  [SMALL_STATE(2849)] = 147183,
  [SMALL_STATE(2850)] = 147228,
  [SMALL_STATE(2851)] = 147277,
  [SMALL_STATE(2852)] = 147344,
  [SMALL_STATE(2853)] = 147389,
  [SMALL_STATE(2854)] = 147440,
  [SMALL_STATE(2855)] = 147505,
  [SMALL_STATE(2856)] = 147554,
  [SMALL_STATE(2857)] = 147599,
  [SMALL_STATE(2858)] = 147662,
  [SMALL_STATE(2859)] = 147709,
  [SMALL_STATE(2860)] = 147758,
  [SMALL_STATE(2861)] = 147803,
  [SMALL_STATE(2862)] = 147864,
  [SMALL_STATE(2863)] = 147929,
  [SMALL_STATE(2864)] = 148008,
  [SMALL_STATE(2865)] = 148053,
  [SMALL_STATE(2866)] = 148098,
  [SMALL_STATE(2867)] = 148143,
  [SMALL_STATE(2868)] = 148200,
  [SMALL_STATE(2869)] = 148249,
  [SMALL_STATE(2870)] = 148294,
  [SMALL_STATE(2871)] = 148369,
  [SMALL_STATE(2872)] = 148414,
  [SMALL_STATE(2873)] = 148459,
  [SMALL_STATE(2874)] = 148532,
  [SMALL_STATE(2875)] = 148577,
  [SMALL_STATE(2876)] = 148650,
  [SMALL_STATE(2877)] = 148695,
  [SMALL_STATE(2878)] = 148742,
  [SMALL_STATE(2879)] = 148789,
  [SMALL_STATE(2880)] = 148834,
  [SMALL_STATE(2881)] = 148879,
  [SMALL_STATE(2882)] = 148924,
  [SMALL_STATE(2883)] = 148969,
  [SMALL_STATE(2884)] = 149046,
  [SMALL_STATE(2885)] = 149117,
  [SMALL_STATE(2886)] = 149196,
  [SMALL_STATE(2887)] = 149249,
  [SMALL_STATE(2888)] = 149328,
  [SMALL_STATE(2889)] = 149373,
  [SMALL_STATE(2890)] = 149450,
  [SMALL_STATE(2891)] = 149495,
  [SMALL_STATE(2892)] = 149540,
  [SMALL_STATE(2893)] = 149585,
  [SMALL_STATE(2894)] = 149630,
  [SMALL_STATE(2895)] = 149699,
  [SMALL_STATE(2896)] = 149768,
  [SMALL_STATE(2897)] = 149823,
  [SMALL_STATE(2898)] = 149878,
  [SMALL_STATE(2899)] = 149923,
  [SMALL_STATE(2900)] = 149968,
  [SMALL_STATE(2901)] = 150035,
  [SMALL_STATE(2902)] = 150080,
  [SMALL_STATE(2903)] = 150151,
  [SMALL_STATE(2904)] = 150202,
  [SMALL_STATE(2905)] = 150281,
  [SMALL_STATE(2906)] = 150326,
  [SMALL_STATE(2907)] = 150371,
  [SMALL_STATE(2908)] = 150416,
  [SMALL_STATE(2909)] = 150463,
  [SMALL_STATE(2910)] = 150518,
  [SMALL_STATE(2911)] = 150593,
  [SMALL_STATE(2912)] = 150670,
  [SMALL_STATE(2913)] = 150741,
  [SMALL_STATE(2914)] = 150810,
  [SMALL_STATE(2915)] = 150877,
  [SMALL_STATE(2916)] = 150942,
  [SMALL_STATE(2917)] = 151005,
  [SMALL_STATE(2918)] = 151066,
  [SMALL_STATE(2919)] = 151123,
  [SMALL_STATE(2920)] = 151184,
  [SMALL_STATE(2921)] = 151239,
  [SMALL_STATE(2922)] = 151288,
  [SMALL_STATE(2923)] = 151337,
  [SMALL_STATE(2924)] = 151386,
  [SMALL_STATE(2925)] = 151431,
  [SMALL_STATE(2926)] = 151476,
  [SMALL_STATE(2927)] = 151521,
  [SMALL_STATE(2928)] = 151566,
  [SMALL_STATE(2929)] = 151613,
  [SMALL_STATE(2930)] = 151666,
  [SMALL_STATE(2931)] = 151719,
  [SMALL_STATE(2932)] = 151766,
  [SMALL_STATE(2933)] = 151811,
  [SMALL_STATE(2934)] = 151858,
  [SMALL_STATE(2935)] = 151903,
  [SMALL_STATE(2936)] = 151950,
  [SMALL_STATE(2937)] = 152005,
  [SMALL_STATE(2938)] = 152060,
  [SMALL_STATE(2939)] = 152109,
  [SMALL_STATE(2940)] = 152158,
  [SMALL_STATE(2941)] = 152213,
  [SMALL_STATE(2942)] = 152268,
  [SMALL_STATE(2943)] = 152347,
  [SMALL_STATE(2944)] = 152426,
  [SMALL_STATE(2945)] = 152505,
  [SMALL_STATE(2946)] = 152554,
  [SMALL_STATE(2947)] = 152617,
  [SMALL_STATE(2948)] = 152696,
  [SMALL_STATE(2949)] = 152775,
  [SMALL_STATE(2950)] = 152820,
  [SMALL_STATE(2951)] = 152865,
  [SMALL_STATE(2952)] = 152922,
  [SMALL_STATE(2953)] = 152977,
  [SMALL_STATE(2954)] = 153022,
  [SMALL_STATE(2955)] = 153077,
  [SMALL_STATE(2956)] = 153156,
  [SMALL_STATE(2957)] = 153213,
  [SMALL_STATE(2958)] = 153268,
  [SMALL_STATE(2959)] = 153323,
  [SMALL_STATE(2960)] = 153370,
  [SMALL_STATE(2961)] = 153417,
  [SMALL_STATE(2962)] = 153472,
  [SMALL_STATE(2963)] = 153547,
  [SMALL_STATE(2964)] = 153624,
  [SMALL_STATE(2965)] = 153695,
  [SMALL_STATE(2966)] = 153764,
  [SMALL_STATE(2967)] = 153831,
  [SMALL_STATE(2968)] = 153896,
  [SMALL_STATE(2969)] = 153959,
  [SMALL_STATE(2970)] = 154020,
  [SMALL_STATE(2971)] = 154077,
  [SMALL_STATE(2972)] = 154130,
  [SMALL_STATE(2973)] = 154181,
  [SMALL_STATE(2974)] = 154230,
  [SMALL_STATE(2975)] = 154279,
  [SMALL_STATE(2976)] = 154328,
  [SMALL_STATE(2977)] = 154375,
  [SMALL_STATE(2978)] = 154422,
  [SMALL_STATE(2979)] = 154491,
  [SMALL_STATE(2980)] = 154564,
  [SMALL_STATE(2981)] = 154643,
  [SMALL_STATE(2982)] = 154722,
  [SMALL_STATE(2983)] = 154801,
  [SMALL_STATE(2984)] = 154880,
  [SMALL_STATE(2985)] = 154947,
  [SMALL_STATE(2986)] = 155012,
  [SMALL_STATE(2987)] = 155091,
  [SMALL_STATE(2988)] = 155170,
  [SMALL_STATE(2989)] = 155249,
  [SMALL_STATE(2990)] = 155306,
  [SMALL_STATE(2991)] = 155361,
  [SMALL_STATE(2992)] = 155406,
  [SMALL_STATE(2993)] = 155461,
  [SMALL_STATE(2994)] = 155540,
  [SMALL_STATE(2995)] = 155597,
  [SMALL_STATE(2996)] = 155676,
  [SMALL_STATE(2997)] = 155739,
  [SMALL_STATE(2998)] = 155812,
  [SMALL_STATE(2999)] = 155891,
  [SMALL_STATE(3000)] = 155940,
  [SMALL_STATE(3001)] = 155985,
  [SMALL_STATE(3002)] = 156040,
  [SMALL_STATE(3003)] = 156115,
  [SMALL_STATE(3004)] = 156192,
  [SMALL_STATE(3005)] = 156271,
  [SMALL_STATE(3006)] = 156342,
  [SMALL_STATE(3007)] = 156421,
  [SMALL_STATE(3008)] = 156466,
  [SMALL_STATE(3009)] = 156511,
  [SMALL_STATE(3010)] = 156556,
  [SMALL_STATE(3011)] = 156635,
  [SMALL_STATE(3012)] = 156696,
  [SMALL_STATE(3013)] = 156775,
  [SMALL_STATE(3014)] = 156830,
  [SMALL_STATE(3015)] = 156875,
  [SMALL_STATE(3016)] = 156954,
  [SMALL_STATE(3017)] = 157001,
  [SMALL_STATE(3018)] = 157080,
  [SMALL_STATE(3019)] = 157131,
  [SMALL_STATE(3020)] = 157187,
  [SMALL_STATE(3021)] = 157263,
  [SMALL_STATE(3022)] = 157331,
  [SMALL_STATE(3023)] = 157397,
  [SMALL_STATE(3024)] = 157473,
  [SMALL_STATE(3025)] = 157517,
  [SMALL_STATE(3026)] = 157581,
  [SMALL_STATE(3027)] = 157657,
  [SMALL_STATE(3028)] = 157701,
  [SMALL_STATE(3029)] = 157777,
  [SMALL_STATE(3030)] = 157839,
  [SMALL_STATE(3031)] = 157915,
  [SMALL_STATE(3032)] = 157959,
  [SMALL_STATE(3033)] = 158019,
  [SMALL_STATE(3034)] = 158095,
  [SMALL_STATE(3035)] = 158139,
  [SMALL_STATE(3036)] = 158197,
  [SMALL_STATE(3037)] = 158273,
  [SMALL_STATE(3038)] = 158327,
  [SMALL_STATE(3039)] = 158403,
  [SMALL_STATE(3040)] = 158455,
  [SMALL_STATE(3041)] = 158531,
  [SMALL_STATE(3042)] = 158581,
  [SMALL_STATE(3043)] = 158657,
  [SMALL_STATE(3044)] = 158705,
  [SMALL_STATE(3045)] = 158781,
  [SMALL_STATE(3046)] = 158827,
  [SMALL_STATE(3047)] = 158903,
  [SMALL_STATE(3048)] = 158971,
  [SMALL_STATE(3049)] = 159047,
  [SMALL_STATE(3050)] = 159113,
  [SMALL_STATE(3051)] = 159189,
  [SMALL_STATE(3052)] = 159253,
  [SMALL_STATE(3053)] = 159329,
  [SMALL_STATE(3054)] = 159393,
  [SMALL_STATE(3055)] = 159469,
  [SMALL_STATE(3056)] = 159545,
  [SMALL_STATE(3057)] = 159607,
  [SMALL_STATE(3058)] = 159683,
  [SMALL_STATE(3059)] = 159759,
  [SMALL_STATE(3060)] = 159819,
  [SMALL_STATE(3061)] = 159895,
  [SMALL_STATE(3062)] = 159971,
  [SMALL_STATE(3063)] = 160025,
  [SMALL_STATE(3064)] = 160101,
  [SMALL_STATE(3065)] = 160159,
  [SMALL_STATE(3066)] = 160235,
  [SMALL_STATE(3067)] = 160289,
  [SMALL_STATE(3068)] = 160365,
  [SMALL_STATE(3069)] = 160417,
  [SMALL_STATE(3070)] = 160493,
  [SMALL_STATE(3071)] = 160543,
  [SMALL_STATE(3072)] = 160619,
  [SMALL_STATE(3073)] = 160695,
  [SMALL_STATE(3074)] = 160745,
  [SMALL_STATE(3075)] = 160821,
  [SMALL_STATE(3076)] = 160865,
  [SMALL_STATE(3077)] = 160941,
  [SMALL_STATE(3078)] = 160989,
  [SMALL_STATE(3079)] = 161037,
  [SMALL_STATE(3080)] = 161113,
  [SMALL_STATE(3081)] = 161163,
  [SMALL_STATE(3082)] = 161239,
  [SMALL_STATE(3083)] = 161289,
  [SMALL_STATE(3084)] = 161365,
  [SMALL_STATE(3085)] = 161441,
  [SMALL_STATE(3086)] = 161517,
  [SMALL_STATE(3087)] = 161593,
  [SMALL_STATE(3088)] = 161637,
  [SMALL_STATE(3089)] = 161713,
  [SMALL_STATE(3090)] = 161759,
  [SMALL_STATE(3091)] = 161835,
  [SMALL_STATE(3092)] = 161879,
  [SMALL_STATE(3093)] = 161923,
  [SMALL_STATE(3094)] = 161999,
  [SMALL_STATE(3095)] = 162075,
  [SMALL_STATE(3096)] = 162119,
  [SMALL_STATE(3097)] = 162195,
  [SMALL_STATE(3098)] = 162239,
  [SMALL_STATE(3099)] = 162315,
  [SMALL_STATE(3100)] = 162359,
  [SMALL_STATE(3101)] = 162435,
  [SMALL_STATE(3102)] = 162479,
  [SMALL_STATE(3103)] = 162555,
  [SMALL_STATE(3104)] = 162599,
  [SMALL_STATE(3105)] = 162675,
  [SMALL_STATE(3106)] = 162743,
  [SMALL_STATE(3107)] = 162819,
  [SMALL_STATE(3108)] = 162885,
  [SMALL_STATE(3109)] = 162961,
  [SMALL_STATE(3110)] = 163005,
  [SMALL_STATE(3111)] = 163081,
  [SMALL_STATE(3112)] = 163125,
  [SMALL_STATE(3113)] = 163201,
  [SMALL_STATE(3114)] = 163271,
  [SMALL_STATE(3115)] = 163335,
  [SMALL_STATE(3116)] = 163411,
  [SMALL_STATE(3117)] = 163473,
  [SMALL_STATE(3118)] = 163517,
  [SMALL_STATE(3119)] = 163593,
  [SMALL_STATE(3120)] = 163657,
  [SMALL_STATE(3121)] = 163719,
  [SMALL_STATE(3122)] = 163795,
  [SMALL_STATE(3123)] = 163855,
  [SMALL_STATE(3124)] = 163913,
  [SMALL_STATE(3125)] = 163989,
  [SMALL_STATE(3126)] = 164043,
  [SMALL_STATE(3127)] = 164119,
  [SMALL_STATE(3128)] = 164171,
  [SMALL_STATE(3129)] = 164247,
  [SMALL_STATE(3130)] = 164291,
  [SMALL_STATE(3131)] = 164367,
  [SMALL_STATE(3132)] = 164417,
  [SMALL_STATE(3133)] = 164493,
  [SMALL_STATE(3134)] = 164541,
  [SMALL_STATE(3135)] = 164617,
  [SMALL_STATE(3136)] = 164665,
  [SMALL_STATE(3137)] = 164713,
  [SMALL_STATE(3138)] = 164757,
  [SMALL_STATE(3139)] = 164811,
  [SMALL_STATE(3140)] = 164865,
  [SMALL_STATE(3141)] = 164909,
  [SMALL_STATE(3142)] = 164953,
  [SMALL_STATE(3143)] = 165007,
  [SMALL_STATE(3144)] = 165061,
  [SMALL_STATE(3145)] = 165105,
  [SMALL_STATE(3146)] = 165149,
  [SMALL_STATE(3147)] = 165193,
  [SMALL_STATE(3148)] = 165269,
  [SMALL_STATE(3149)] = 165313,
  [SMALL_STATE(3150)] = 165389,
  [SMALL_STATE(3151)] = 165465,
  [SMALL_STATE(3152)] = 165509,
  [SMALL_STATE(3153)] = 165553,
  [SMALL_STATE(3154)] = 165597,
  [SMALL_STATE(3155)] = 165641,
  [SMALL_STATE(3156)] = 165717,
  [SMALL_STATE(3157)] = 165791,
  [SMALL_STATE(3158)] = 165835,
  [SMALL_STATE(3159)] = 165911,
  [SMALL_STATE(3160)] = 165981,
  [SMALL_STATE(3161)] = 166069,
  [SMALL_STATE(3162)] = 166157,
  [SMALL_STATE(3163)] = 166201,
  [SMALL_STATE(3164)] = 166289,
  [SMALL_STATE(3165)] = 166359,
  [SMALL_STATE(3166)] = 166403,
  [SMALL_STATE(3167)] = 166491,
  [SMALL_STATE(3168)] = 166535,
  [SMALL_STATE(3169)] = 166623,
  [SMALL_STATE(3170)] = 166667,
  [SMALL_STATE(3171)] = 166711,
  [SMALL_STATE(3172)] = 166755,
  [SMALL_STATE(3173)] = 166809,
  [SMALL_STATE(3174)] = 166855,
  [SMALL_STATE(3175)] = 166927,
  [SMALL_STATE(3176)] = 166981,
  [SMALL_STATE(3177)] = 167025,
  [SMALL_STATE(3178)] = 167069,
  [SMALL_STATE(3179)] = 167113,
  [SMALL_STATE(3180)] = 167189,
  [SMALL_STATE(3181)] = 167265,
  [SMALL_STATE(3182)] = 167341,
  [SMALL_STATE(3183)] = 167385,
  [SMALL_STATE(3184)] = 167473,
  [SMALL_STATE(3185)] = 167517,
  [SMALL_STATE(3186)] = 167605,
  [SMALL_STATE(3187)] = 167649,
  [SMALL_STATE(3188)] = 167737,
  [SMALL_STATE(3189)] = 167825,
  [SMALL_STATE(3190)] = 167869,
  [SMALL_STATE(3191)] = 167913,
  [SMALL_STATE(3192)] = 167957,
  [SMALL_STATE(3193)] = 168001,
  [SMALL_STATE(3194)] = 168045,
  [SMALL_STATE(3195)] = 168089,
  [SMALL_STATE(3196)] = 168159,
  [SMALL_STATE(3197)] = 168203,
  [SMALL_STATE(3198)] = 168279,
  [SMALL_STATE(3199)] = 168323,
  [SMALL_STATE(3200)] = 168367,
  [SMALL_STATE(3201)] = 168411,
  [SMALL_STATE(3202)] = 168455,
  [SMALL_STATE(3203)] = 168499,
  [SMALL_STATE(3204)] = 168553,
  [SMALL_STATE(3205)] = 168607,
  [SMALL_STATE(3206)] = 168661,
  [SMALL_STATE(3207)] = 168705,
  [SMALL_STATE(3208)] = 168749,
  [SMALL_STATE(3209)] = 168795,
  [SMALL_STATE(3210)] = 168883,
  [SMALL_STATE(3211)] = 168937,
  [SMALL_STATE(3212)] = 168981,
  [SMALL_STATE(3213)] = 169057,
  [SMALL_STATE(3214)] = 169101,
  [SMALL_STATE(3215)] = 169177,
  [SMALL_STATE(3216)] = 169221,
  [SMALL_STATE(3217)] = 169265,
  [SMALL_STATE(3218)] = 169341,
  [SMALL_STATE(3219)] = 169385,
  [SMALL_STATE(3220)] = 169473,
  [SMALL_STATE(3221)] = 169517,
  [SMALL_STATE(3222)] = 169561,
  [SMALL_STATE(3223)] = 169649,
  [SMALL_STATE(3224)] = 169693,
  [SMALL_STATE(3225)] = 169737,
  [SMALL_STATE(3226)] = 169825,
  [SMALL_STATE(3227)] = 169913,
  [SMALL_STATE(3228)] = 169957,
  [SMALL_STATE(3229)] = 170011,
  [SMALL_STATE(3230)] = 170065,
  [SMALL_STATE(3231)] = 170109,
  [SMALL_STATE(3232)] = 170153,
  [SMALL_STATE(3233)] = 170197,
  [SMALL_STATE(3234)] = 170241,
  [SMALL_STATE(3235)] = 170285,
  [SMALL_STATE(3236)] = 170361,
  [SMALL_STATE(3237)] = 170405,
  [SMALL_STATE(3238)] = 170449,
  [SMALL_STATE(3239)] = 170493,
  [SMALL_STATE(3240)] = 170541,
  [SMALL_STATE(3241)] = 170629,
  [SMALL_STATE(3242)] = 170683,
  [SMALL_STATE(3243)] = 170737,
  [SMALL_STATE(3244)] = 170811,
  [SMALL_STATE(3245)] = 170887,
  [SMALL_STATE(3246)] = 170957,
  [SMALL_STATE(3247)] = 171025,
  [SMALL_STATE(3248)] = 171091,
  [SMALL_STATE(3249)] = 171155,
  [SMALL_STATE(3250)] = 171217,
  [SMALL_STATE(3251)] = 171277,
  [SMALL_STATE(3252)] = 171325,
  [SMALL_STATE(3253)] = 171377,
  [SMALL_STATE(3254)] = 171427,
  [SMALL_STATE(3255)] = 171475,
  [SMALL_STATE(3256)] = 171523,
  [SMALL_STATE(3257)] = 171567,
  [SMALL_STATE(3258)] = 171643,
  [SMALL_STATE(3259)] = 171699,
  [SMALL_STATE(3260)] = 171753,
  [SMALL_STATE(3261)] = 171807,
  [SMALL_STATE(3262)] = 171851,
  [SMALL_STATE(3263)] = 171895,
  [SMALL_STATE(3264)] = 171941,
  [SMALL_STATE(3265)] = 171985,
  [SMALL_STATE(3266)] = 172029,
  [SMALL_STATE(3267)] = 172101,
  [SMALL_STATE(3268)] = 172145,
  [SMALL_STATE(3269)] = 172221,
  [SMALL_STATE(3270)] = 172295,
  [SMALL_STATE(3271)] = 172363,
  [SMALL_STATE(3272)] = 172429,
  [SMALL_STATE(3273)] = 172473,
  [SMALL_STATE(3274)] = 172537,
  [SMALL_STATE(3275)] = 172581,
  [SMALL_STATE(3276)] = 172627,
  [SMALL_STATE(3277)] = 172689,
  [SMALL_STATE(3278)] = 172733,
  [SMALL_STATE(3279)] = 172793,
  [SMALL_STATE(3280)] = 172843,
  [SMALL_STATE(3281)] = 172919,
  [SMALL_STATE(3282)] = 172969,
  [SMALL_STATE(3283)] = 173013,
  [SMALL_STATE(3284)] = 173063,
  [SMALL_STATE(3285)] = 173135,
  [SMALL_STATE(3286)] = 173193,
  [SMALL_STATE(3287)] = 173247,
  [SMALL_STATE(3288)] = 173299,
  [SMALL_STATE(3289)] = 173349,
  [SMALL_STATE(3290)] = 173437,
  [SMALL_STATE(3291)] = 173490,
  [SMALL_STATE(3292)] = 173543,
  [SMALL_STATE(3293)] = 173596,
  [SMALL_STATE(3294)] = 173639,
  [SMALL_STATE(3295)] = 173682,
  [SMALL_STATE(3296)] = 173725,
  [SMALL_STATE(3297)] = 173768,
  [SMALL_STATE(3298)] = 173811,
  [SMALL_STATE(3299)] = 173854,
  [SMALL_STATE(3300)] = 173939,
  [SMALL_STATE(3301)] = 174024,
  [SMALL_STATE(3302)] = 174067,
  [SMALL_STATE(3303)] = 174152,
  [SMALL_STATE(3304)] = 174237,
  [SMALL_STATE(3305)] = 174322,
  [SMALL_STATE(3306)] = 174365,
  [SMALL_STATE(3307)] = 174450,
  [SMALL_STATE(3308)] = 174535,
  [SMALL_STATE(3309)] = 174588,
  [SMALL_STATE(3310)] = 174641,
  [SMALL_STATE(3311)] = 174726,
  [SMALL_STATE(3312)] = 174779,
  [SMALL_STATE(3313)] = 174822,
  [SMALL_STATE(3314)] = 174865,
  [SMALL_STATE(3315)] = 174950,
  [SMALL_STATE(3316)] = 175003,
  [SMALL_STATE(3317)] = 175046,
  [SMALL_STATE(3318)] = 175099,
  [SMALL_STATE(3319)] = 175152,
  [SMALL_STATE(3320)] = 175237,
  [SMALL_STATE(3321)] = 175322,
  [SMALL_STATE(3322)] = 175375,
  [SMALL_STATE(3323)] = 175460,
  [SMALL_STATE(3324)] = 175545,
  [SMALL_STATE(3325)] = 175630,
  [SMALL_STATE(3326)] = 175715,
  [SMALL_STATE(3327)] = 175800,
  [SMALL_STATE(3328)] = 175885,
  [SMALL_STATE(3329)] = 175970,
  [SMALL_STATE(3330)] = 176013,
  [SMALL_STATE(3331)] = 176098,
  [SMALL_STATE(3332)] = 176183,
  [SMALL_STATE(3333)] = 176268,
  [SMALL_STATE(3334)] = 176311,
  [SMALL_STATE(3335)] = 176396,
  [SMALL_STATE(3336)] = 176439,
  [SMALL_STATE(3337)] = 176524,
  [SMALL_STATE(3338)] = 176567,
  [SMALL_STATE(3339)] = 176620,
  [SMALL_STATE(3340)] = 176673,
  [SMALL_STATE(3341)] = 176716,
  [SMALL_STATE(3342)] = 176759,
  [SMALL_STATE(3343)] = 176802,
  [SMALL_STATE(3344)] = 176855,
  [SMALL_STATE(3345)] = 176898,
  [SMALL_STATE(3346)] = 176951,
  [SMALL_STATE(3347)] = 176994,
  [SMALL_STATE(3348)] = 177079,
  [SMALL_STATE(3349)] = 177131,
  [SMALL_STATE(3350)] = 177177,
  [SMALL_STATE(3351)] = 177255,
  [SMALL_STATE(3352)] = 177301,
  [SMALL_STATE(3353)] = 177347,
  [SMALL_STATE(3354)] = 177399,
  [SMALL_STATE(3355)] = 177445,
  [SMALL_STATE(3356)] = 177523,
  [SMALL_STATE(3357)] = 177569,
  [SMALL_STATE(3358)] = 177651,
  [SMALL_STATE(3359)] = 177697,
  [SMALL_STATE(3360)] = 177743,
  [SMALL_STATE(3361)] = 177821,
  [SMALL_STATE(3362)] = 177867,
  [SMALL_STATE(3363)] = 177915,
  [SMALL_STATE(3364)] = 177961,
  [SMALL_STATE(3365)] = 178007,
  [SMALL_STATE(3366)] = 178085,
  [SMALL_STATE(3367)] = 178161,
  [SMALL_STATE(3368)] = 178239,
  [SMALL_STATE(3369)] = 178325,
  [SMALL_STATE(3370)] = 178371,
  [SMALL_STATE(3371)] = 178457,
  [SMALL_STATE(3372)] = 178543,
  [SMALL_STATE(3373)] = 178591,
  [SMALL_STATE(3374)] = 178637,
  [SMALL_STATE(3375)] = 178683,
  [SMALL_STATE(3376)] = 178735,
  [SMALL_STATE(3377)] = 178781,
  [SMALL_STATE(3378)] = 178833,
  [SMALL_STATE(3379)] = 178906,
  [SMALL_STATE(3380)] = 178947,
  [SMALL_STATE(3381)] = 178988,
  [SMALL_STATE(3382)] = 179069,
  [SMALL_STATE(3383)] = 179110,
  [SMALL_STATE(3384)] = 179151,
  [SMALL_STATE(3385)] = 179232,
  [SMALL_STATE(3386)] = 179305,
  [SMALL_STATE(3387)] = 179378,
  [SMALL_STATE(3388)] = 179459,
  [SMALL_STATE(3389)] = 179540,
  [SMALL_STATE(3390)] = 179621,
  [SMALL_STATE(3391)] = 179702,
  [SMALL_STATE(3392)] = 179783,
  [SMALL_STATE(3393)] = 179864,
  [SMALL_STATE(3394)] = 179945,
  [SMALL_STATE(3395)] = 180026,
  [SMALL_STATE(3396)] = 180107,
  [SMALL_STATE(3397)] = 180188,
  [SMALL_STATE(3398)] = 180269,
  [SMALL_STATE(3399)] = 180350,
  [SMALL_STATE(3400)] = 180431,
  [SMALL_STATE(3401)] = 180512,
  [SMALL_STATE(3402)] = 180593,
  [SMALL_STATE(3403)] = 180634,
  [SMALL_STATE(3404)] = 180707,
  [SMALL_STATE(3405)] = 180748,
  [SMALL_STATE(3406)] = 180789,
  [SMALL_STATE(3407)] = 180830,
  [SMALL_STATE(3408)] = 180871,
  [SMALL_STATE(3409)] = 180912,
  [SMALL_STATE(3410)] = 180953,
  [SMALL_STATE(3411)] = 180994,
  [SMALL_STATE(3412)] = 181035,
  [SMALL_STATE(3413)] = 181076,
  [SMALL_STATE(3414)] = 181117,
  [SMALL_STATE(3415)] = 181158,
  [SMALL_STATE(3416)] = 181199,
  [SMALL_STATE(3417)] = 181250,
  [SMALL_STATE(3418)] = 181301,
  [SMALL_STATE(3419)] = 181342,
  [SMALL_STATE(3420)] = 181383,
  [SMALL_STATE(3421)] = 181464,
  [SMALL_STATE(3422)] = 181545,
  [SMALL_STATE(3423)] = 181586,
  [SMALL_STATE(3424)] = 181667,
  [SMALL_STATE(3425)] = 181748,
  [SMALL_STATE(3426)] = 181829,
  [SMALL_STATE(3427)] = 181910,
  [SMALL_STATE(3428)] = 181954,
  [SMALL_STATE(3429)] = 182034,
  [SMALL_STATE(3430)] = 182114,
  [SMALL_STATE(3431)] = 182194,
  [SMALL_STATE(3432)] = 182274,
  [SMALL_STATE(3433)] = 182318,
  [SMALL_STATE(3434)] = 182368,
  [SMALL_STATE(3435)] = 182448,
  [SMALL_STATE(3436)] = 182528,
  [SMALL_STATE(3437)] = 182608,
  [SMALL_STATE(3438)] = 182688,
  [SMALL_STATE(3439)] = 182768,
  [SMALL_STATE(3440)] = 182848,
  [SMALL_STATE(3441)] = 182928,
  [SMALL_STATE(3442)] = 183008,
  [SMALL_STATE(3443)] = 183052,
  [SMALL_STATE(3444)] = 183102,
  [SMALL_STATE(3445)] = 183182,
  [SMALL_STATE(3446)] = 183262,
  [SMALL_STATE(3447)] = 183342,
  [SMALL_STATE(3448)] = 183422,
  [SMALL_STATE(3449)] = 183502,
  [SMALL_STATE(3450)] = 183546,
  [SMALL_STATE(3451)] = 183596,
  [SMALL_STATE(3452)] = 183640,
  [SMALL_STATE(3453)] = 183684,
  [SMALL_STATE(3454)] = 183764,
  [SMALL_STATE(3455)] = 183808,
  [SMALL_STATE(3456)] = 183858,
  [SMALL_STATE(3457)] = 183938,
  [SMALL_STATE(3458)] = 184015,
  [SMALL_STATE(3459)] = 184092,
  [SMALL_STATE(3460)] = 184169,
  [SMALL_STATE(3461)] = 184244,
  [SMALL_STATE(3462)] = 184321,
  [SMALL_STATE(3463)] = 184396,
  [SMALL_STATE(3464)] = 184473,
  [SMALL_STATE(3465)] = 184550,
  [SMALL_STATE(3466)] = 184627,
  [SMALL_STATE(3467)] = 184704,
  [SMALL_STATE(3468)] = 184781,
  [SMALL_STATE(3469)] = 184856,
  [SMALL_STATE(3470)] = 184933,
  [SMALL_STATE(3471)] = 185008,
  [SMALL_STATE(3472)] = 185085,
  [SMALL_STATE(3473)] = 185160,
  [SMALL_STATE(3474)] = 185235,
  [SMALL_STATE(3475)] = 185310,
  [SMALL_STATE(3476)] = 185387,
  [SMALL_STATE(3477)] = 185462,
  [SMALL_STATE(3478)] = 185537,
  [SMALL_STATE(3479)] = 185612,
  [SMALL_STATE(3480)] = 185687,
  [SMALL_STATE(3481)] = 185762,
  [SMALL_STATE(3482)] = 185837,
  [SMALL_STATE(3483)] = 185912,
  [SMALL_STATE(3484)] = 185987,
  [SMALL_STATE(3485)] = 186062,
  [SMALL_STATE(3486)] = 186137,
  [SMALL_STATE(3487)] = 186212,
  [SMALL_STATE(3488)] = 186287,
  [SMALL_STATE(3489)] = 186362,
  [SMALL_STATE(3490)] = 186437,
  [SMALL_STATE(3491)] = 186512,
  [SMALL_STATE(3492)] = 186551,
  [SMALL_STATE(3493)] = 186626,
  [SMALL_STATE(3494)] = 186703,
  [SMALL_STATE(3495)] = 186780,
  [SMALL_STATE(3496)] = 186857,
  [SMALL_STATE(3497)] = 186934,
  [SMALL_STATE(3498)] = 187011,
  [SMALL_STATE(3499)] = 187088,
  [SMALL_STATE(3500)] = 187163,
  [SMALL_STATE(3501)] = 187240,
  [SMALL_STATE(3502)] = 187317,
  [SMALL_STATE(3503)] = 187394,
  [SMALL_STATE(3504)] = 187465,
  [SMALL_STATE(3505)] = 187542,
  [SMALL_STATE(3506)] = 187619,
  [SMALL_STATE(3507)] = 187696,
  [SMALL_STATE(3508)] = 187771,
  [SMALL_STATE(3509)] = 187848,
  [SMALL_STATE(3510)] = 187897,
  [SMALL_STATE(3511)] = 187974,
  [SMALL_STATE(3512)] = 188051,
  [SMALL_STATE(3513)] = 188100,
  [SMALL_STATE(3514)] = 188177,
  [SMALL_STATE(3515)] = 188254,
  [SMALL_STATE(3516)] = 188331,
  [SMALL_STATE(3517)] = 188370,
  [SMALL_STATE(3518)] = 188445,
  [SMALL_STATE(3519)] = 188520,
  [SMALL_STATE(3520)] = 188597,
  [SMALL_STATE(3521)] = 188636,
  [SMALL_STATE(3522)] = 188713,
  [SMALL_STATE(3523)] = 188790,
  [SMALL_STATE(3524)] = 188867,
  [SMALL_STATE(3525)] = 188942,
  [SMALL_STATE(3526)] = 189019,
  [SMALL_STATE(3527)] = 189094,
  [SMALL_STATE(3528)] = 189171,
  [SMALL_STATE(3529)] = 189246,
  [SMALL_STATE(3530)] = 189321,
  [SMALL_STATE(3531)] = 189396,
  [SMALL_STATE(3532)] = 189473,
  [SMALL_STATE(3533)] = 189550,
  [SMALL_STATE(3534)] = 189627,
  [SMALL_STATE(3535)] = 189704,
  [SMALL_STATE(3536)] = 189779,
  [SMALL_STATE(3537)] = 189854,
  [SMALL_STATE(3538)] = 189931,
  [SMALL_STATE(3539)] = 190008,
  [SMALL_STATE(3540)] = 190085,
  [SMALL_STATE(3541)] = 190160,
  [SMALL_STATE(3542)] = 190235,
  [SMALL_STATE(3543)] = 190310,
  [SMALL_STATE(3544)] = 190387,
  [SMALL_STATE(3545)] = 190464,
  [SMALL_STATE(3546)] = 190539,
  [SMALL_STATE(3547)] = 190616,
  [SMALL_STATE(3548)] = 190693,
  [SMALL_STATE(3549)] = 190770,
  [SMALL_STATE(3550)] = 190847,
  [SMALL_STATE(3551)] = 190922,
  [SMALL_STATE(3552)] = 190997,
  [SMALL_STATE(3553)] = 191072,
  [SMALL_STATE(3554)] = 191149,
  [SMALL_STATE(3555)] = 191226,
  [SMALL_STATE(3556)] = 191303,
  [SMALL_STATE(3557)] = 191380,
  [SMALL_STATE(3558)] = 191457,
  [SMALL_STATE(3559)] = 191534,
  [SMALL_STATE(3560)] = 191611,
  [SMALL_STATE(3561)] = 191688,
  [SMALL_STATE(3562)] = 191763,
  [SMALL_STATE(3563)] = 191838,
  [SMALL_STATE(3564)] = 191915,
  [SMALL_STATE(3565)] = 191990,
  [SMALL_STATE(3566)] = 192067,
  [SMALL_STATE(3567)] = 192144,
  [SMALL_STATE(3568)] = 192221,
  [SMALL_STATE(3569)] = 192298,
  [SMALL_STATE(3570)] = 192375,
  [SMALL_STATE(3571)] = 192452,
  [SMALL_STATE(3572)] = 192529,
  [SMALL_STATE(3573)] = 192606,
  [SMALL_STATE(3574)] = 192683,
  [SMALL_STATE(3575)] = 192760,
  [SMALL_STATE(3576)] = 192837,
  [SMALL_STATE(3577)] = 192914,
  [SMALL_STATE(3578)] = 192991,
  [SMALL_STATE(3579)] = 193068,
  [SMALL_STATE(3580)] = 193145,
  [SMALL_STATE(3581)] = 193222,
  [SMALL_STATE(3582)] = 193299,
  [SMALL_STATE(3583)] = 193376,
  [SMALL_STATE(3584)] = 193453,
  [SMALL_STATE(3585)] = 193530,
  [SMALL_STATE(3586)] = 193607,
  [SMALL_STATE(3587)] = 193684,
  [SMALL_STATE(3588)] = 193761,
  [SMALL_STATE(3589)] = 193838,
  [SMALL_STATE(3590)] = 193915,
  [SMALL_STATE(3591)] = 193992,
  [SMALL_STATE(3592)] = 194069,
  [SMALL_STATE(3593)] = 194146,
  [SMALL_STATE(3594)] = 194223,
  [SMALL_STATE(3595)] = 194300,
  [SMALL_STATE(3596)] = 194377,
  [SMALL_STATE(3597)] = 194454,
  [SMALL_STATE(3598)] = 194531,
  [SMALL_STATE(3599)] = 194608,
  [SMALL_STATE(3600)] = 194685,
  [SMALL_STATE(3601)] = 194762,
  [SMALL_STATE(3602)] = 194839,
  [SMALL_STATE(3603)] = 194916,
  [SMALL_STATE(3604)] = 194993,
  [SMALL_STATE(3605)] = 195070,
  [SMALL_STATE(3606)] = 195147,
  [SMALL_STATE(3607)] = 195224,
  [SMALL_STATE(3608)] = 195301,
  [SMALL_STATE(3609)] = 195378,
  [SMALL_STATE(3610)] = 195455,
  [SMALL_STATE(3611)] = 195532,
  [SMALL_STATE(3612)] = 195609,
  [SMALL_STATE(3613)] = 195686,
  [SMALL_STATE(3614)] = 195763,
  [SMALL_STATE(3615)] = 195840,
  [SMALL_STATE(3616)] = 195917,
  [SMALL_STATE(3617)] = 195994,
  [SMALL_STATE(3618)] = 196071,
  [SMALL_STATE(3619)] = 196148,
  [SMALL_STATE(3620)] = 196225,
  [SMALL_STATE(3621)] = 196302,
  [SMALL_STATE(3622)] = 196379,
  [SMALL_STATE(3623)] = 196456,
  [SMALL_STATE(3624)] = 196533,
  [SMALL_STATE(3625)] = 196610,
  [SMALL_STATE(3626)] = 196687,
  [SMALL_STATE(3627)] = 196764,
  [SMALL_STATE(3628)] = 196841,
  [SMALL_STATE(3629)] = 196918,
  [SMALL_STATE(3630)] = 196995,
  [SMALL_STATE(3631)] = 197072,
  [SMALL_STATE(3632)] = 197149,
  [SMALL_STATE(3633)] = 197226,
  [SMALL_STATE(3634)] = 197303,
  [SMALL_STATE(3635)] = 197380,
  [SMALL_STATE(3636)] = 197457,
  [SMALL_STATE(3637)] = 197534,
  [SMALL_STATE(3638)] = 197611,
  [SMALL_STATE(3639)] = 197688,
  [SMALL_STATE(3640)] = 197765,
  [SMALL_STATE(3641)] = 197814,
  [SMALL_STATE(3642)] = 197891,
  [SMALL_STATE(3643)] = 197968,
  [SMALL_STATE(3644)] = 198017,
  [SMALL_STATE(3645)] = 198094,
  [SMALL_STATE(3646)] = 198171,
  [SMALL_STATE(3647)] = 198248,
  [SMALL_STATE(3648)] = 198325,
  [SMALL_STATE(3649)] = 198402,
  [SMALL_STATE(3650)] = 198479,
  [SMALL_STATE(3651)] = 198556,
  [SMALL_STATE(3652)] = 198633,
  [SMALL_STATE(3653)] = 198710,
  [SMALL_STATE(3654)] = 198787,
  [SMALL_STATE(3655)] = 198864,
  [SMALL_STATE(3656)] = 198941,
  [SMALL_STATE(3657)] = 199018,
  [SMALL_STATE(3658)] = 199095,
  [SMALL_STATE(3659)] = 199172,
  [SMALL_STATE(3660)] = 199249,
  [SMALL_STATE(3661)] = 199326,
  [SMALL_STATE(3662)] = 199403,
  [SMALL_STATE(3663)] = 199442,
  [SMALL_STATE(3664)] = 199519,
  [SMALL_STATE(3665)] = 199596,
  [SMALL_STATE(3666)] = 199673,
  [SMALL_STATE(3667)] = 199750,
  [SMALL_STATE(3668)] = 199827,
  [SMALL_STATE(3669)] = 199904,
  [SMALL_STATE(3670)] = 199981,
  [SMALL_STATE(3671)] = 200058,
  [SMALL_STATE(3672)] = 200135,
  [SMALL_STATE(3673)] = 200212,
  [SMALL_STATE(3674)] = 200289,
  [SMALL_STATE(3675)] = 200366,
  [SMALL_STATE(3676)] = 200443,
  [SMALL_STATE(3677)] = 200520,
  [SMALL_STATE(3678)] = 200597,
  [SMALL_STATE(3679)] = 200674,
  [SMALL_STATE(3680)] = 200751,
  [SMALL_STATE(3681)] = 200828,
  [SMALL_STATE(3682)] = 200905,
  [SMALL_STATE(3683)] = 200982,
  [SMALL_STATE(3684)] = 201059,
  [SMALL_STATE(3685)] = 201136,
  [SMALL_STATE(3686)] = 201213,
  [SMALL_STATE(3687)] = 201290,
  [SMALL_STATE(3688)] = 201339,
  [SMALL_STATE(3689)] = 201388,
  [SMALL_STATE(3690)] = 201463,
  [SMALL_STATE(3691)] = 201540,
  [SMALL_STATE(3692)] = 201579,
  [SMALL_STATE(3693)] = 201618,
  [SMALL_STATE(3694)] = 201695,
  [SMALL_STATE(3695)] = 201772,
  [SMALL_STATE(3696)] = 201849,
  [SMALL_STATE(3697)] = 201888,
  [SMALL_STATE(3698)] = 201965,
  [SMALL_STATE(3699)] = 202040,
  [SMALL_STATE(3700)] = 202117,
  [SMALL_STATE(3701)] = 202192,
  [SMALL_STATE(3702)] = 202231,
  [SMALL_STATE(3703)] = 202308,
  [SMALL_STATE(3704)] = 202347,
  [SMALL_STATE(3705)] = 202424,
  [SMALL_STATE(3706)] = 202501,
  [SMALL_STATE(3707)] = 202578,
  [SMALL_STATE(3708)] = 202627,
  [SMALL_STATE(3709)] = 202676,
  [SMALL_STATE(3710)] = 202753,
  [SMALL_STATE(3711)] = 202801,
  [SMALL_STATE(3712)] = 202873,
  [SMALL_STATE(3713)] = 202945,
  [SMALL_STATE(3714)] = 203019,
  [SMALL_STATE(3715)] = 203091,
  [SMALL_STATE(3716)] = 203161,
  [SMALL_STATE(3717)] = 203233,
  [SMALL_STATE(3718)] = 203305,
  [SMALL_STATE(3719)] = 203375,
  [SMALL_STATE(3720)] = 203447,
  [SMALL_STATE(3721)] = 203519,
  [SMALL_STATE(3722)] = 203591,
  [SMALL_STATE(3723)] = 203663,
  [SMALL_STATE(3724)] = 203735,
  [SMALL_STATE(3725)] = 203807,
  [SMALL_STATE(3726)] = 203879,
  [SMALL_STATE(3727)] = 203951,
  [SMALL_STATE(3728)] = 204023,
  [SMALL_STATE(3729)] = 204097,
  [SMALL_STATE(3730)] = 204167,
  [SMALL_STATE(3731)] = 204239,
  [SMALL_STATE(3732)] = 204311,
  [SMALL_STATE(3733)] = 204383,
  [SMALL_STATE(3734)] = 204455,
  [SMALL_STATE(3735)] = 204527,
  [SMALL_STATE(3736)] = 204597,
  [SMALL_STATE(3737)] = 204667,
  [SMALL_STATE(3738)] = 204739,
  [SMALL_STATE(3739)] = 204811,
  [SMALL_STATE(3740)] = 204883,
  [SMALL_STATE(3741)] = 204953,
  [SMALL_STATE(3742)] = 205025,
  [SMALL_STATE(3743)] = 205097,
  [SMALL_STATE(3744)] = 205171,
  [SMALL_STATE(3745)] = 205243,
  [SMALL_STATE(3746)] = 205315,
  [SMALL_STATE(3747)] = 205363,
  [SMALL_STATE(3748)] = 205433,
  [SMALL_STATE(3749)] = 205505,
  [SMALL_STATE(3750)] = 205577,
  [SMALL_STATE(3751)] = 205647,
  [SMALL_STATE(3752)] = 205719,
  [SMALL_STATE(3753)] = 205791,
  [SMALL_STATE(3754)] = 205863,
  [SMALL_STATE(3755)] = 205935,
  [SMALL_STATE(3756)] = 206007,
  [SMALL_STATE(3757)] = 206079,
  [SMALL_STATE(3758)] = 206151,
  [SMALL_STATE(3759)] = 206223,
  [SMALL_STATE(3760)] = 206293,
  [SMALL_STATE(3761)] = 206365,
  [SMALL_STATE(3762)] = 206435,
  [SMALL_STATE(3763)] = 206507,
  [SMALL_STATE(3764)] = 206579,
  [SMALL_STATE(3765)] = 206651,
  [SMALL_STATE(3766)] = 206723,
  [SMALL_STATE(3767)] = 206795,
  [SMALL_STATE(3768)] = 206865,
  [SMALL_STATE(3769)] = 206935,
  [SMALL_STATE(3770)] = 207007,
  [SMALL_STATE(3771)] = 207079,
  [SMALL_STATE(3772)] = 207151,
  [SMALL_STATE(3773)] = 207225,
  [SMALL_STATE(3774)] = 207297,
  [SMALL_STATE(3775)] = 207345,
  [SMALL_STATE(3776)] = 207393,
  [SMALL_STATE(3777)] = 207465,
  [SMALL_STATE(3778)] = 207513,
  [SMALL_STATE(3779)] = 207585,
  [SMALL_STATE(3780)] = 207657,
  [SMALL_STATE(3781)] = 207729,
  [SMALL_STATE(3782)] = 207801,
  [SMALL_STATE(3783)] = 207849,
  [SMALL_STATE(3784)] = 207921,
  [SMALL_STATE(3785)] = 207993,
  [SMALL_STATE(3786)] = 208041,
  [SMALL_STATE(3787)] = 208113,
  [SMALL_STATE(3788)] = 208185,
  [SMALL_STATE(3789)] = 208257,
  [SMALL_STATE(3790)] = 208331,
  [SMALL_STATE(3791)] = 208405,
  [SMALL_STATE(3792)] = 208477,
  [SMALL_STATE(3793)] = 208549,
  [SMALL_STATE(3794)] = 208621,
  [SMALL_STATE(3795)] = 208693,
  [SMALL_STATE(3796)] = 208767,
  [SMALL_STATE(3797)] = 208815,
  [SMALL_STATE(3798)] = 208882,
  [SMALL_STATE(3799)] = 208949,
  [SMALL_STATE(3800)] = 209016,
  [SMALL_STATE(3801)] = 209061,
  [SMALL_STATE(3802)] = 209128,
  [SMALL_STATE(3803)] = 209195,
  [SMALL_STATE(3804)] = 209262,
  [SMALL_STATE(3805)] = 209329,
  [SMALL_STATE(3806)] = 209396,
  [SMALL_STATE(3807)] = 209463,
  [SMALL_STATE(3808)] = 209530,
  [SMALL_STATE(3809)] = 209597,
  [SMALL_STATE(3810)] = 209664,
  [SMALL_STATE(3811)] = 209731,
  [SMALL_STATE(3812)] = 209798,
  [SMALL_STATE(3813)] = 209865,
  [SMALL_STATE(3814)] = 209932,
  [SMALL_STATE(3815)] = 209999,
  [SMALL_STATE(3816)] = 210066,
  [SMALL_STATE(3817)] = 210133,
  [SMALL_STATE(3818)] = 210200,
  [SMALL_STATE(3819)] = 210267,
  [SMALL_STATE(3820)] = 210334,
  [SMALL_STATE(3821)] = 210401,
  [SMALL_STATE(3822)] = 210468,
  [SMALL_STATE(3823)] = 210535,
  [SMALL_STATE(3824)] = 210602,
  [SMALL_STATE(3825)] = 210669,
  [SMALL_STATE(3826)] = 210736,
  [SMALL_STATE(3827)] = 210803,
  [SMALL_STATE(3828)] = 210870,
  [SMALL_STATE(3829)] = 210937,
  [SMALL_STATE(3830)] = 211004,
  [SMALL_STATE(3831)] = 211071,
  [SMALL_STATE(3832)] = 211138,
  [SMALL_STATE(3833)] = 211205,
  [SMALL_STATE(3834)] = 211272,
  [SMALL_STATE(3835)] = 211339,
  [SMALL_STATE(3836)] = 211406,
  [SMALL_STATE(3837)] = 211473,
  [SMALL_STATE(3838)] = 211540,
  [SMALL_STATE(3839)] = 211607,
  [SMALL_STATE(3840)] = 211674,
  [SMALL_STATE(3841)] = 211741,
  [SMALL_STATE(3842)] = 211812,
  [SMALL_STATE(3843)] = 211879,
  [SMALL_STATE(3844)] = 211946,
  [SMALL_STATE(3845)] = 212017,
  [SMALL_STATE(3846)] = 212084,
  [SMALL_STATE(3847)] = 212151,
  [SMALL_STATE(3848)] = 212218,
  [SMALL_STATE(3849)] = 212285,
  [SMALL_STATE(3850)] = 212352,
  [SMALL_STATE(3851)] = 212419,
  [SMALL_STATE(3852)] = 212490,
  [SMALL_STATE(3853)] = 212557,
  [SMALL_STATE(3854)] = 212624,
  [SMALL_STATE(3855)] = 212691,
  [SMALL_STATE(3856)] = 212766,
  [SMALL_STATE(3857)] = 212833,
  [SMALL_STATE(3858)] = 212904,
  [SMALL_STATE(3859)] = 212975,
  [SMALL_STATE(3860)] = 213046,
  [SMALL_STATE(3861)] = 213117,
  [SMALL_STATE(3862)] = 213188,
  [SMALL_STATE(3863)] = 213255,
  [SMALL_STATE(3864)] = 213322,
  [SMALL_STATE(3865)] = 213393,
  [SMALL_STATE(3866)] = 213460,
  [SMALL_STATE(3867)] = 213527,
  [SMALL_STATE(3868)] = 213594,
  [SMALL_STATE(3869)] = 213661,
  [SMALL_STATE(3870)] = 213728,
  [SMALL_STATE(3871)] = 213795,
  [SMALL_STATE(3872)] = 213862,
  [SMALL_STATE(3873)] = 213933,
  [SMALL_STATE(3874)] = 214004,
  [SMALL_STATE(3875)] = 214075,
  [SMALL_STATE(3876)] = 214146,
  [SMALL_STATE(3877)] = 214217,
  [SMALL_STATE(3878)] = 214288,
  [SMALL_STATE(3879)] = 214355,
  [SMALL_STATE(3880)] = 214422,
  [SMALL_STATE(3881)] = 214489,
  [SMALL_STATE(3882)] = 214556,
  [SMALL_STATE(3883)] = 214623,
  [SMALL_STATE(3884)] = 214694,
  [SMALL_STATE(3885)] = 214761,
  [SMALL_STATE(3886)] = 214832,
  [SMALL_STATE(3887)] = 214903,
  [SMALL_STATE(3888)] = 214974,
  [SMALL_STATE(3889)] = 215045,
  [SMALL_STATE(3890)] = 215112,
  [SMALL_STATE(3891)] = 215179,
  [SMALL_STATE(3892)] = 215246,
  [SMALL_STATE(3893)] = 215313,
  [SMALL_STATE(3894)] = 215384,
  [SMALL_STATE(3895)] = 215455,
  [SMALL_STATE(3896)] = 215526,
  [SMALL_STATE(3897)] = 215597,
  [SMALL_STATE(3898)] = 215668,
  [SMALL_STATE(3899)] = 215735,
  [SMALL_STATE(3900)] = 215806,
  [SMALL_STATE(3901)] = 215873,
  [SMALL_STATE(3902)] = 215940,
  [SMALL_STATE(3903)] = 216007,
  [SMALL_STATE(3904)] = 216074,
  [SMALL_STATE(3905)] = 216117,
  [SMALL_STATE(3906)] = 216174,
  [SMALL_STATE(3907)] = 216241,
  [SMALL_STATE(3908)] = 216312,
  [SMALL_STATE(3909)] = 216383,
  [SMALL_STATE(3910)] = 216450,
  [SMALL_STATE(3911)] = 216517,
  [SMALL_STATE(3912)] = 216584,
  [SMALL_STATE(3913)] = 216651,
  [SMALL_STATE(3914)] = 216722,
  [SMALL_STATE(3915)] = 216789,
  [SMALL_STATE(3916)] = 216856,
  [SMALL_STATE(3917)] = 216923,
  [SMALL_STATE(3918)] = 216990,
  [SMALL_STATE(3919)] = 217057,
  [SMALL_STATE(3920)] = 217128,
  [SMALL_STATE(3921)] = 217195,
  [SMALL_STATE(3922)] = 217266,
  [SMALL_STATE(3923)] = 217333,
  [SMALL_STATE(3924)] = 217400,
  [SMALL_STATE(3925)] = 217467,
  [SMALL_STATE(3926)] = 217534,
  [SMALL_STATE(3927)] = 217601,
  [SMALL_STATE(3928)] = 217668,
  [SMALL_STATE(3929)] = 217735,
  [SMALL_STATE(3930)] = 217802,
  [SMALL_STATE(3931)] = 217873,
  [SMALL_STATE(3932)] = 217940,
  [SMALL_STATE(3933)] = 218007,
  [SMALL_STATE(3934)] = 218078,
  [SMALL_STATE(3935)] = 218145,
  [SMALL_STATE(3936)] = 218212,
  [SMALL_STATE(3937)] = 218279,
  [SMALL_STATE(3938)] = 218346,
  [SMALL_STATE(3939)] = 218413,
  [SMALL_STATE(3940)] = 218480,
  [SMALL_STATE(3941)] = 218551,
  [SMALL_STATE(3942)] = 218618,
  [SMALL_STATE(3943)] = 218689,
  [SMALL_STATE(3944)] = 218756,
  [SMALL_STATE(3945)] = 218823,
  [SMALL_STATE(3946)] = 218890,
  [SMALL_STATE(3947)] = 218957,
  [SMALL_STATE(3948)] = 219024,
  [SMALL_STATE(3949)] = 219091,
  [SMALL_STATE(3950)] = 219158,
  [SMALL_STATE(3951)] = 219225,
  [SMALL_STATE(3952)] = 219292,
  [SMALL_STATE(3953)] = 219359,
  [SMALL_STATE(3954)] = 219430,
  [SMALL_STATE(3955)] = 219495,
  [SMALL_STATE(3956)] = 219566,
  [SMALL_STATE(3957)] = 219633,
  [SMALL_STATE(3958)] = 219700,
  [SMALL_STATE(3959)] = 219767,
  [SMALL_STATE(3960)] = 219834,
  [SMALL_STATE(3961)] = 219901,
  [SMALL_STATE(3962)] = 219968,
  [SMALL_STATE(3963)] = 220039,
  [SMALL_STATE(3964)] = 220106,
  [SMALL_STATE(3965)] = 220177,
  [SMALL_STATE(3966)] = 220244,
  [SMALL_STATE(3967)] = 220311,
  [SMALL_STATE(3968)] = 220378,
  [SMALL_STATE(3969)] = 220449,
  [SMALL_STATE(3970)] = 220516,
  [SMALL_STATE(3971)] = 220583,
  [SMALL_STATE(3972)] = 220650,
  [SMALL_STATE(3973)] = 220721,
  [SMALL_STATE(3974)] = 220788,
  [SMALL_STATE(3975)] = 220855,
  [SMALL_STATE(3976)] = 220926,
  [SMALL_STATE(3977)] = 220993,
  [SMALL_STATE(3978)] = 221060,
  [SMALL_STATE(3979)] = 221127,
  [SMALL_STATE(3980)] = 221194,
  [SMALL_STATE(3981)] = 221261,
  [SMALL_STATE(3982)] = 221328,
  [SMALL_STATE(3983)] = 221399,
  [SMALL_STATE(3984)] = 221466,
  [SMALL_STATE(3985)] = 221537,
  [SMALL_STATE(3986)] = 221604,
  [SMALL_STATE(3987)] = 221671,
  [SMALL_STATE(3988)] = 221738,
  [SMALL_STATE(3989)] = 221805,
  [SMALL_STATE(3990)] = 221872,
  [SMALL_STATE(3991)] = 221939,
  [SMALL_STATE(3992)] = 222006,
  [SMALL_STATE(3993)] = 222077,
  [SMALL_STATE(3994)] = 222148,
  [SMALL_STATE(3995)] = 222215,
  [SMALL_STATE(3996)] = 222282,
  [SMALL_STATE(3997)] = 222349,
  [SMALL_STATE(3998)] = 222416,
  [SMALL_STATE(3999)] = 222487,
  [SMALL_STATE(4000)] = 222554,
  [SMALL_STATE(4001)] = 222621,
  [SMALL_STATE(4002)] = 222692,
  [SMALL_STATE(4003)] = 222735,
  [SMALL_STATE(4004)] = 222802,
  [SMALL_STATE(4005)] = 222869,
  [SMALL_STATE(4006)] = 222936,
  [SMALL_STATE(4007)] = 223003,
  [SMALL_STATE(4008)] = 223070,
  [SMALL_STATE(4009)] = 223141,
  [SMALL_STATE(4010)] = 223212,
  [SMALL_STATE(4011)] = 223279,
  [SMALL_STATE(4012)] = 223346,
  [SMALL_STATE(4013)] = 223413,
  [SMALL_STATE(4014)] = 223484,
  [SMALL_STATE(4015)] = 223541,
  [SMALL_STATE(4016)] = 223612,
  [SMALL_STATE(4017)] = 223679,
  [SMALL_STATE(4018)] = 223746,
  [SMALL_STATE(4019)] = 223817,
  [SMALL_STATE(4020)] = 223884,
  [SMALL_STATE(4021)] = 223951,
  [SMALL_STATE(4022)] = 224018,
  [SMALL_STATE(4023)] = 224089,
  [SMALL_STATE(4024)] = 224156,
  [SMALL_STATE(4025)] = 224223,
  [SMALL_STATE(4026)] = 224266,
  [SMALL_STATE(4027)] = 224337,
  [SMALL_STATE(4028)] = 224404,
  [SMALL_STATE(4029)] = 224475,
  [SMALL_STATE(4030)] = 224542,
  [SMALL_STATE(4031)] = 224609,
  [SMALL_STATE(4032)] = 224676,
  [SMALL_STATE(4033)] = 224747,
  [SMALL_STATE(4034)] = 224814,
  [SMALL_STATE(4035)] = 224885,
  [SMALL_STATE(4036)] = 224952,
  [SMALL_STATE(4037)] = 225019,
  [SMALL_STATE(4038)] = 225086,
  [SMALL_STATE(4039)] = 225153,
  [SMALL_STATE(4040)] = 225220,
  [SMALL_STATE(4041)] = 225287,
  [SMALL_STATE(4042)] = 225354,
  [SMALL_STATE(4043)] = 225421,
  [SMALL_STATE(4044)] = 225488,
  [SMALL_STATE(4045)] = 225555,
  [SMALL_STATE(4046)] = 225622,
  [SMALL_STATE(4047)] = 225689,
  [SMALL_STATE(4048)] = 225756,
  [SMALL_STATE(4049)] = 225823,
  [SMALL_STATE(4050)] = 225894,
  [SMALL_STATE(4051)] = 225961,
  [SMALL_STATE(4052)] = 226028,
  [SMALL_STATE(4053)] = 226095,
  [SMALL_STATE(4054)] = 226162,
  [SMALL_STATE(4055)] = 226229,
  [SMALL_STATE(4056)] = 226296,
  [SMALL_STATE(4057)] = 226363,
  [SMALL_STATE(4058)] = 226430,
  [SMALL_STATE(4059)] = 226497,
  [SMALL_STATE(4060)] = 226568,
  [SMALL_STATE(4061)] = 226635,
  [SMALL_STATE(4062)] = 226702,
  [SMALL_STATE(4063)] = 226769,
  [SMALL_STATE(4064)] = 226836,
  [SMALL_STATE(4065)] = 226903,
  [SMALL_STATE(4066)] = 226970,
  [SMALL_STATE(4067)] = 227037,
  [SMALL_STATE(4068)] = 227104,
  [SMALL_STATE(4069)] = 227175,
  [SMALL_STATE(4070)] = 227250,
  [SMALL_STATE(4071)] = 227317,
  [SMALL_STATE(4072)] = 227384,
  [SMALL_STATE(4073)] = 227451,
  [SMALL_STATE(4074)] = 227518,
  [SMALL_STATE(4075)] = 227585,
  [SMALL_STATE(4076)] = 227652,
  [SMALL_STATE(4077)] = 227719,
  [SMALL_STATE(4078)] = 227786,
  [SMALL_STATE(4079)] = 227853,
  [SMALL_STATE(4080)] = 227920,
  [SMALL_STATE(4081)] = 227987,
  [SMALL_STATE(4082)] = 228054,
  [SMALL_STATE(4083)] = 228121,
  [SMALL_STATE(4084)] = 228188,
  [SMALL_STATE(4085)] = 228255,
  [SMALL_STATE(4086)] = 228322,
  [SMALL_STATE(4087)] = 228389,
  [SMALL_STATE(4088)] = 228456,
  [SMALL_STATE(4089)] = 228523,
  [SMALL_STATE(4090)] = 228590,
  [SMALL_STATE(4091)] = 228661,
  [SMALL_STATE(4092)] = 228728,
  [SMALL_STATE(4093)] = 228799,
  [SMALL_STATE(4094)] = 228866,
  [SMALL_STATE(4095)] = 228937,
  [SMALL_STATE(4096)] = 229008,
  [SMALL_STATE(4097)] = 229075,
  [SMALL_STATE(4098)] = 229142,
  [SMALL_STATE(4099)] = 229213,
  [SMALL_STATE(4100)] = 229288,
  [SMALL_STATE(4101)] = 229355,
  [SMALL_STATE(4102)] = 229422,
  [SMALL_STATE(4103)] = 229489,
  [SMALL_STATE(4104)] = 229556,
  [SMALL_STATE(4105)] = 229623,
  [SMALL_STATE(4106)] = 229694,
  [SMALL_STATE(4107)] = 229761,
  [SMALL_STATE(4108)] = 229828,
  [SMALL_STATE(4109)] = 229895,
  [SMALL_STATE(4110)] = 229962,
  [SMALL_STATE(4111)] = 230029,
  [SMALL_STATE(4112)] = 230100,
  [SMALL_STATE(4113)] = 230167,
  [SMALL_STATE(4114)] = 230234,
  [SMALL_STATE(4115)] = 230301,
  [SMALL_STATE(4116)] = 230368,
  [SMALL_STATE(4117)] = 230435,
  [SMALL_STATE(4118)] = 230502,
  [SMALL_STATE(4119)] = 230569,
  [SMALL_STATE(4120)] = 230640,
  [SMALL_STATE(4121)] = 230707,
  [SMALL_STATE(4122)] = 230778,
  [SMALL_STATE(4123)] = 230845,
  [SMALL_STATE(4124)] = 230912,
  [SMALL_STATE(4125)] = 230983,
  [SMALL_STATE(4126)] = 231054,
  [SMALL_STATE(4127)] = 231125,
  [SMALL_STATE(4128)] = 231200,
  [SMALL_STATE(4129)] = 231267,
  [SMALL_STATE(4130)] = 231334,
  [SMALL_STATE(4131)] = 231401,
  [SMALL_STATE(4132)] = 231468,
  [SMALL_STATE(4133)] = 231539,
  [SMALL_STATE(4134)] = 231581,
  [SMALL_STATE(4135)] = 231623,
  [SMALL_STATE(4136)] = 231665,
  [SMALL_STATE(4137)] = 231707,
  [SMALL_STATE(4138)] = 231749,
  [SMALL_STATE(4139)] = 231791,
  [SMALL_STATE(4140)] = 231833,
  [SMALL_STATE(4141)] = 231889,
  [SMALL_STATE(4142)] = 231935,
  [SMALL_STATE(4143)] = 231977,
  [SMALL_STATE(4144)] = 232019,
  [SMALL_STATE(4145)] = 232061,
  [SMALL_STATE(4146)] = 232103,
  [SMALL_STATE(4147)] = 232147,
  [SMALL_STATE(4148)] = 232189,
  [SMALL_STATE(4149)] = 232231,
  [SMALL_STATE(4150)] = 232303,
  [SMALL_STATE(4151)] = 232359,
  [SMALL_STATE(4152)] = 232431,
  [SMALL_STATE(4153)] = 232477,
  [SMALL_STATE(4154)] = 232519,
  [SMALL_STATE(4155)] = 232591,
  [SMALL_STATE(4156)] = 232633,
  [SMALL_STATE(4157)] = 232675,
  [SMALL_STATE(4158)] = 232717,
  [SMALL_STATE(4159)] = 232759,
  [SMALL_STATE(4160)] = 232801,
  [SMALL_STATE(4161)] = 232847,
  [SMALL_STATE(4162)] = 232889,
  [SMALL_STATE(4163)] = 232931,
  [SMALL_STATE(4164)] = 232973,
  [SMALL_STATE(4165)] = 233019,
  [SMALL_STATE(4166)] = 233061,
  [SMALL_STATE(4167)] = 233103,
  [SMALL_STATE(4168)] = 233138,
  [SMALL_STATE(4169)] = 233179,
  [SMALL_STATE(4170)] = 233220,
  [SMALL_STATE(4171)] = 233255,
  [SMALL_STATE(4172)] = 233290,
  [SMALL_STATE(4173)] = 233331,
  [SMALL_STATE(4174)] = 233366,
  [SMALL_STATE(4175)] = 233407,
  [SMALL_STATE(4176)] = 233446,
  [SMALL_STATE(4177)] = 233481,
  [SMALL_STATE(4178)] = 233516,
  [SMALL_STATE(4179)] = 233551,
  [SMALL_STATE(4180)] = 233592,
  [SMALL_STATE(4181)] = 233643,
  [SMALL_STATE(4182)] = 233682,
  [SMALL_STATE(4183)] = 233727,
  [SMALL_STATE(4184)] = 233762,
  [SMALL_STATE(4185)] = 233799,
  [SMALL_STATE(4186)] = 233840,
  [SMALL_STATE(4187)] = 233885,
  [SMALL_STATE(4188)] = 233920,
  [SMALL_STATE(4189)] = 233955,
  [SMALL_STATE(4190)] = 233990,
  [SMALL_STATE(4191)] = 234025,
  [SMALL_STATE(4192)] = 234060,
  [SMALL_STATE(4193)] = 234095,
  [SMALL_STATE(4194)] = 234136,
  [SMALL_STATE(4195)] = 234177,
  [SMALL_STATE(4196)] = 234212,
  [SMALL_STATE(4197)] = 234247,
  [SMALL_STATE(4198)] = 234282,
  [SMALL_STATE(4199)] = 234321,
  [SMALL_STATE(4200)] = 234356,
  [SMALL_STATE(4201)] = 234391,
  [SMALL_STATE(4202)] = 234426,
  [SMALL_STATE(4203)] = 234481,
  [SMALL_STATE(4204)] = 234516,
  [SMALL_STATE(4205)] = 234557,
  [SMALL_STATE(4206)] = 234598,
  [SMALL_STATE(4207)] = 234633,
  [SMALL_STATE(4208)] = 234668,
  [SMALL_STATE(4209)] = 234703,
  [SMALL_STATE(4210)] = 234738,
  [SMALL_STATE(4211)] = 234779,
  [SMALL_STATE(4212)] = 234820,
  [SMALL_STATE(4213)] = 234861,
  [SMALL_STATE(4214)] = 234900,
  [SMALL_STATE(4215)] = 234941,
  [SMALL_STATE(4216)] = 234978,
  [SMALL_STATE(4217)] = 235013,
  [SMALL_STATE(4218)] = 235058,
  [SMALL_STATE(4219)] = 235093,
  [SMALL_STATE(4220)] = 235128,
  [SMALL_STATE(4221)] = 235163,
  [SMALL_STATE(4222)] = 235204,
  [SMALL_STATE(4223)] = 235245,
  [SMALL_STATE(4224)] = 235284,
  [SMALL_STATE(4225)] = 235319,
  [SMALL_STATE(4226)] = 235374,
  [SMALL_STATE(4227)] = 235409,
  [SMALL_STATE(4228)] = 235444,
  [SMALL_STATE(4229)] = 235479,
  [SMALL_STATE(4230)] = 235514,
  [SMALL_STATE(4231)] = 235555,
  [SMALL_STATE(4232)] = 235590,
  [SMALL_STATE(4233)] = 235625,
  [SMALL_STATE(4234)] = 235662,
  [SMALL_STATE(4235)] = 235703,
  [SMALL_STATE(4236)] = 235744,
  [SMALL_STATE(4237)] = 235783,
  [SMALL_STATE(4238)] = 235824,
  [SMALL_STATE(4239)] = 235863,
  [SMALL_STATE(4240)] = 235904,
  [SMALL_STATE(4241)] = 235939,
  [SMALL_STATE(4242)] = 235974,
  [SMALL_STATE(4243)] = 236009,
  [SMALL_STATE(4244)] = 236044,
  [SMALL_STATE(4245)] = 236085,
  [SMALL_STATE(4246)] = 236124,
  [SMALL_STATE(4247)] = 236169,
  [SMALL_STATE(4248)] = 236210,
  [SMALL_STATE(4249)] = 236245,
  [SMALL_STATE(4250)] = 236280,
  [SMALL_STATE(4251)] = 236315,
  [SMALL_STATE(4252)] = 236356,
  [SMALL_STATE(4253)] = 236391,
  [SMALL_STATE(4254)] = 236430,
  [SMALL_STATE(4255)] = 236471,
  [SMALL_STATE(4256)] = 236506,
  [SMALL_STATE(4257)] = 236547,
  [SMALL_STATE(4258)] = 236582,
  [SMALL_STATE(4259)] = 236623,
  [SMALL_STATE(4260)] = 236658,
  [SMALL_STATE(4261)] = 236697,
  [SMALL_STATE(4262)] = 236732,
  [SMALL_STATE(4263)] = 236773,
  [SMALL_STATE(4264)] = 236808,
  [SMALL_STATE(4265)] = 236843,
  [SMALL_STATE(4266)] = 236882,
  [SMALL_STATE(4267)] = 236917,
  [SMALL_STATE(4268)] = 236952,
  [SMALL_STATE(4269)] = 236993,
  [SMALL_STATE(4270)] = 237038,
  [SMALL_STATE(4271)] = 237073,
  [SMALL_STATE(4272)] = 237108,
  [SMALL_STATE(4273)] = 237151,
  [SMALL_STATE(4274)] = 237186,
  [SMALL_STATE(4275)] = 237223,
  [SMALL_STATE(4276)] = 237260,
  [SMALL_STATE(4277)] = 237295,
  [SMALL_STATE(4278)] = 237330,
  [SMALL_STATE(4279)] = 237365,
  [SMALL_STATE(4280)] = 237420,
  [SMALL_STATE(4281)] = 237455,
  [SMALL_STATE(4282)] = 237496,
  [SMALL_STATE(4283)] = 237531,
  [SMALL_STATE(4284)] = 237566,
  [SMALL_STATE(4285)] = 237601,
  [SMALL_STATE(4286)] = 237642,
  [SMALL_STATE(4287)] = 237687,
  [SMALL_STATE(4288)] = 237742,
  [SMALL_STATE(4289)] = 237787,
  [SMALL_STATE(4290)] = 237828,
  [SMALL_STATE(4291)] = 237869,
  [SMALL_STATE(4292)] = 237908,
  [SMALL_STATE(4293)] = 237949,
  [SMALL_STATE(4294)] = 238000,
  [SMALL_STATE(4295)] = 238039,
  [SMALL_STATE(4296)] = 238074,
  [SMALL_STATE(4297)] = 238109,
  [SMALL_STATE(4298)] = 238150,
  [SMALL_STATE(4299)] = 238185,
  [SMALL_STATE(4300)] = 238220,
  [SMALL_STATE(4301)] = 238261,
  [SMALL_STATE(4302)] = 238296,
  [SMALL_STATE(4303)] = 238337,
  [SMALL_STATE(4304)] = 238378,
  [SMALL_STATE(4305)] = 238413,
  [SMALL_STATE(4306)] = 238456,
  [SMALL_STATE(4307)] = 238491,
  [SMALL_STATE(4308)] = 238546,
  [SMALL_STATE(4309)] = 238581,
  [SMALL_STATE(4310)] = 238616,
  [SMALL_STATE(4311)] = 238671,
  [SMALL_STATE(4312)] = 238712,
  [SMALL_STATE(4313)] = 238747,
  [SMALL_STATE(4314)] = 238790,
  [SMALL_STATE(4315)] = 238825,
  [SMALL_STATE(4316)] = 238866,
  [SMALL_STATE(4317)] = 238901,
  [SMALL_STATE(4318)] = 238940,
  [SMALL_STATE(4319)] = 238979,
  [SMALL_STATE(4320)] = 239014,
  [SMALL_STATE(4321)] = 239049,
  [SMALL_STATE(4322)] = 239093,
  [SMALL_STATE(4323)] = 239133,
  [SMALL_STATE(4324)] = 239173,
  [SMALL_STATE(4325)] = 239213,
  [SMALL_STATE(4326)] = 239253,
  [SMALL_STATE(4327)] = 239293,
  [SMALL_STATE(4328)] = 239327,
  [SMALL_STATE(4329)] = 239361,
  [SMALL_STATE(4330)] = 239401,
  [SMALL_STATE(4331)] = 239445,
  [SMALL_STATE(4332)] = 239485,
  [SMALL_STATE(4333)] = 239519,
  [SMALL_STATE(4334)] = 239563,
  [SMALL_STATE(4335)] = 239603,
  [SMALL_STATE(4336)] = 239655,
  [SMALL_STATE(4337)] = 239693,
  [SMALL_STATE(4338)] = 239745,
  [SMALL_STATE(4339)] = 239779,
  [SMALL_STATE(4340)] = 239813,
  [SMALL_STATE(4341)] = 239853,
  [SMALL_STATE(4342)] = 239893,
  [SMALL_STATE(4343)] = 239933,
  [SMALL_STATE(4344)] = 239973,
  [SMALL_STATE(4345)] = 240013,
  [SMALL_STATE(4346)] = 240053,
  [SMALL_STATE(4347)] = 240091,
  [SMALL_STATE(4348)] = 240129,
  [SMALL_STATE(4349)] = 240167,
  [SMALL_STATE(4350)] = 240201,
  [SMALL_STATE(4351)] = 240239,
  [SMALL_STATE(4352)] = 240273,
  [SMALL_STATE(4353)] = 240307,
  [SMALL_STATE(4354)] = 240345,
  [SMALL_STATE(4355)] = 240385,
  [SMALL_STATE(4356)] = 240419,
  [SMALL_STATE(4357)] = 240457,
  [SMALL_STATE(4358)] = 240491,
  [SMALL_STATE(4359)] = 240535,
  [SMALL_STATE(4360)] = 240569,
  [SMALL_STATE(4361)] = 240603,
  [SMALL_STATE(4362)] = 240653,
  [SMALL_STATE(4363)] = 240687,
  [SMALL_STATE(4364)] = 240731,
  [SMALL_STATE(4365)] = 240765,
  [SMALL_STATE(4366)] = 240809,
  [SMALL_STATE(4367)] = 240843,
  [SMALL_STATE(4368)] = 240877,
  [SMALL_STATE(4369)] = 240915,
  [SMALL_STATE(4370)] = 240955,
  [SMALL_STATE(4371)] = 240995,
  [SMALL_STATE(4372)] = 241033,
  [SMALL_STATE(4373)] = 241067,
  [SMALL_STATE(4374)] = 241107,
  [SMALL_STATE(4375)] = 241147,
  [SMALL_STATE(4376)] = 241187,
  [SMALL_STATE(4377)] = 241225,
  [SMALL_STATE(4378)] = 241259,
  [SMALL_STATE(4379)] = 241299,
  [SMALL_STATE(4380)] = 241351,
  [SMALL_STATE(4381)] = 241385,
  [SMALL_STATE(4382)] = 241419,
  [SMALL_STATE(4383)] = 241459,
  [SMALL_STATE(4384)] = 241493,
  [SMALL_STATE(4385)] = 241527,
  [SMALL_STATE(4386)] = 241561,
  [SMALL_STATE(4387)] = 241595,
  [SMALL_STATE(4388)] = 241633,
  [SMALL_STATE(4389)] = 241677,
  [SMALL_STATE(4390)] = 241711,
  [SMALL_STATE(4391)] = 241747,
  [SMALL_STATE(4392)] = 241781,
  [SMALL_STATE(4393)] = 241815,
  [SMALL_STATE(4394)] = 241849,
  [SMALL_STATE(4395)] = 241883,
  [SMALL_STATE(4396)] = 241917,
  [SMALL_STATE(4397)] = 241951,
  [SMALL_STATE(4398)] = 241985,
  [SMALL_STATE(4399)] = 242019,
  [SMALL_STATE(4400)] = 242053,
  [SMALL_STATE(4401)] = 242091,
  [SMALL_STATE(4402)] = 242125,
  [SMALL_STATE(4403)] = 242159,
  [SMALL_STATE(4404)] = 242193,
  [SMALL_STATE(4405)] = 242233,
  [SMALL_STATE(4406)] = 242271,
  [SMALL_STATE(4407)] = 242305,
  [SMALL_STATE(4408)] = 242343,
  [SMALL_STATE(4409)] = 242377,
  [SMALL_STATE(4410)] = 242421,
  [SMALL_STATE(4411)] = 242455,
  [SMALL_STATE(4412)] = 242489,
  [SMALL_STATE(4413)] = 242539,
  [SMALL_STATE(4414)] = 242573,
  [SMALL_STATE(4415)] = 242613,
  [SMALL_STATE(4416)] = 242647,
  [SMALL_STATE(4417)] = 242681,
  [SMALL_STATE(4418)] = 242715,
  [SMALL_STATE(4419)] = 242749,
  [SMALL_STATE(4420)] = 242787,
  [SMALL_STATE(4421)] = 242825,
  [SMALL_STATE(4422)] = 242865,
  [SMALL_STATE(4423)] = 242905,
  [SMALL_STATE(4424)] = 242939,
  [SMALL_STATE(4425)] = 242973,
  [SMALL_STATE(4426)] = 243007,
  [SMALL_STATE(4427)] = 243041,
  [SMALL_STATE(4428)] = 243075,
  [SMALL_STATE(4429)] = 243109,
  [SMALL_STATE(4430)] = 243147,
  [SMALL_STATE(4431)] = 243187,
  [SMALL_STATE(4432)] = 243227,
  [SMALL_STATE(4433)] = 243267,
  [SMALL_STATE(4434)] = 243301,
  [SMALL_STATE(4435)] = 243335,
  [SMALL_STATE(4436)] = 243369,
  [SMALL_STATE(4437)] = 243409,
  [SMALL_STATE(4438)] = 243451,
  [SMALL_STATE(4439)] = 243491,
  [SMALL_STATE(4440)] = 243531,
  [SMALL_STATE(4441)] = 243571,
  [SMALL_STATE(4442)] = 243611,
  [SMALL_STATE(4443)] = 243649,
  [SMALL_STATE(4444)] = 243683,
  [SMALL_STATE(4445)] = 243717,
  [SMALL_STATE(4446)] = 243751,
  [SMALL_STATE(4447)] = 243785,
  [SMALL_STATE(4448)] = 243819,
  [SMALL_STATE(4449)] = 243853,
  [SMALL_STATE(4450)] = 243887,
  [SMALL_STATE(4451)] = 243921,
  [SMALL_STATE(4452)] = 243955,
  [SMALL_STATE(4453)] = 243999,
  [SMALL_STATE(4454)] = 244039,
  [SMALL_STATE(4455)] = 244079,
  [SMALL_STATE(4456)] = 244119,
  [SMALL_STATE(4457)] = 244159,
  [SMALL_STATE(4458)] = 244193,
  [SMALL_STATE(4459)] = 244233,
  [SMALL_STATE(4460)] = 244273,
  [SMALL_STATE(4461)] = 244313,
  [SMALL_STATE(4462)] = 244353,
  [SMALL_STATE(4463)] = 244387,
  [SMALL_STATE(4464)] = 244421,
  [SMALL_STATE(4465)] = 244455,
  [SMALL_STATE(4466)] = 244489,
  [SMALL_STATE(4467)] = 244523,
  [SMALL_STATE(4468)] = 244557,
  [SMALL_STATE(4469)] = 244591,
  [SMALL_STATE(4470)] = 244625,
  [SMALL_STATE(4471)] = 244659,
  [SMALL_STATE(4472)] = 244693,
  [SMALL_STATE(4473)] = 244727,
  [SMALL_STATE(4474)] = 244761,
  [SMALL_STATE(4475)] = 244795,
  [SMALL_STATE(4476)] = 244835,
  [SMALL_STATE(4477)] = 244875,
  [SMALL_STATE(4478)] = 244915,
  [SMALL_STATE(4479)] = 244959,
  [SMALL_STATE(4480)] = 244999,
  [SMALL_STATE(4481)] = 245033,
  [SMALL_STATE(4482)] = 245067,
  [SMALL_STATE(4483)] = 245107,
  [SMALL_STATE(4484)] = 245141,
  [SMALL_STATE(4485)] = 245175,
  [SMALL_STATE(4486)] = 245227,
  [SMALL_STATE(4487)] = 245261,
  [SMALL_STATE(4488)] = 245301,
  [SMALL_STATE(4489)] = 245341,
  [SMALL_STATE(4490)] = 245381,
  [SMALL_STATE(4491)] = 245421,
  [SMALL_STATE(4492)] = 245461,
  [SMALL_STATE(4493)] = 245501,
  [SMALL_STATE(4494)] = 245541,
  [SMALL_STATE(4495)] = 245581,
  [SMALL_STATE(4496)] = 245621,
  [SMALL_STATE(4497)] = 245661,
  [SMALL_STATE(4498)] = 245701,
  [SMALL_STATE(4499)] = 245741,
  [SMALL_STATE(4500)] = 245781,
  [SMALL_STATE(4501)] = 245821,
  [SMALL_STATE(4502)] = 245861,
  [SMALL_STATE(4503)] = 245901,
  [SMALL_STATE(4504)] = 245941,
  [SMALL_STATE(4505)] = 245985,
  [SMALL_STATE(4506)] = 246019,
  [SMALL_STATE(4507)] = 246059,
  [SMALL_STATE(4508)] = 246098,
  [SMALL_STATE(4509)] = 246163,
  [SMALL_STATE(4510)] = 246196,
  [SMALL_STATE(4511)] = 246229,
  [SMALL_STATE(4512)] = 246262,
  [SMALL_STATE(4513)] = 246295,
  [SMALL_STATE(4514)] = 246328,
  [SMALL_STATE(4515)] = 246361,
  [SMALL_STATE(4516)] = 246394,
  [SMALL_STATE(4517)] = 246443,
  [SMALL_STATE(4518)] = 246482,
  [SMALL_STATE(4519)] = 246515,
  [SMALL_STATE(4520)] = 246548,
  [SMALL_STATE(4521)] = 246613,
  [SMALL_STATE(4522)] = 246652,
  [SMALL_STATE(4523)] = 246685,
  [SMALL_STATE(4524)] = 246724,
  [SMALL_STATE(4525)] = 246757,
  [SMALL_STATE(4526)] = 246794,
  [SMALL_STATE(4527)] = 246829,
  [SMALL_STATE(4528)] = 246868,
  [SMALL_STATE(4529)] = 246901,
  [SMALL_STATE(4530)] = 246944,
  [SMALL_STATE(4531)] = 246983,
  [SMALL_STATE(4532)] = 247026,
  [SMALL_STATE(4533)] = 247059,
  [SMALL_STATE(4534)] = 247102,
  [SMALL_STATE(4535)] = 247145,
  [SMALL_STATE(4536)] = 247184,
  [SMALL_STATE(4537)] = 247217,
  [SMALL_STATE(4538)] = 247260,
  [SMALL_STATE(4539)] = 247293,
  [SMALL_STATE(4540)] = 247326,
  [SMALL_STATE(4541)] = 247359,
  [SMALL_STATE(4542)] = 247392,
  [SMALL_STATE(4543)] = 247425,
  [SMALL_STATE(4544)] = 247458,
  [SMALL_STATE(4545)] = 247491,
  [SMALL_STATE(4546)] = 247524,
  [SMALL_STATE(4547)] = 247561,
  [SMALL_STATE(4548)] = 247594,
  [SMALL_STATE(4549)] = 247641,
  [SMALL_STATE(4550)] = 247674,
  [SMALL_STATE(4551)] = 247717,
  [SMALL_STATE(4552)] = 247760,
  [SMALL_STATE(4553)] = 247793,
  [SMALL_STATE(4554)] = 247836,
  [SMALL_STATE(4555)] = 247879,
  [SMALL_STATE(4556)] = 247928,
  [SMALL_STATE(4557)] = 247971,
  [SMALL_STATE(4558)] = 248004,
  [SMALL_STATE(4559)] = 248037,
  [SMALL_STATE(4560)] = 248070,
  [SMALL_STATE(4561)] = 248103,
  [SMALL_STATE(4562)] = 248146,
  [SMALL_STATE(4563)] = 248183,
  [SMALL_STATE(4564)] = 248248,
  [SMALL_STATE(4565)] = 248281,
  [SMALL_STATE(4566)] = 248314,
  [SMALL_STATE(4567)] = 248347,
  [SMALL_STATE(4568)] = 248386,
  [SMALL_STATE(4569)] = 248425,
  [SMALL_STATE(4570)] = 248464,
  [SMALL_STATE(4571)] = 248503,
  [SMALL_STATE(4572)] = 248542,
  [SMALL_STATE(4573)] = 248581,
  [SMALL_STATE(4574)] = 248620,
  [SMALL_STATE(4575)] = 248659,
  [SMALL_STATE(4576)] = 248692,
  [SMALL_STATE(4577)] = 248725,
  [SMALL_STATE(4578)] = 248764,
  [SMALL_STATE(4579)] = 248797,
  [SMALL_STATE(4580)] = 248830,
  [SMALL_STATE(4581)] = 248863,
  [SMALL_STATE(4582)] = 248900,
  [SMALL_STATE(4583)] = 248939,
  [SMALL_STATE(4584)] = 248972,
  [SMALL_STATE(4585)] = 249021,
  [SMALL_STATE(4586)] = 249054,
  [SMALL_STATE(4587)] = 249087,
  [SMALL_STATE(4588)] = 249124,
  [SMALL_STATE(4589)] = 249167,
  [SMALL_STATE(4590)] = 249216,
  [SMALL_STATE(4591)] = 249253,
  [SMALL_STATE(4592)] = 249292,
  [SMALL_STATE(4593)] = 249341,
  [SMALL_STATE(4594)] = 249374,
  [SMALL_STATE(4595)] = 249409,
  [SMALL_STATE(4596)] = 249442,
  [SMALL_STATE(4597)] = 249479,
  [SMALL_STATE(4598)] = 249514,
  [SMALL_STATE(4599)] = 249551,
  [SMALL_STATE(4600)] = 249594,
  [SMALL_STATE(4601)] = 249659,
  [SMALL_STATE(4602)] = 249702,
  [SMALL_STATE(4603)] = 249741,
  [SMALL_STATE(4604)] = 249780,
  [SMALL_STATE(4605)] = 249813,
  [SMALL_STATE(4606)] = 249852,
  [SMALL_STATE(4607)] = 249891,
  [SMALL_STATE(4608)] = 249928,
  [SMALL_STATE(4609)] = 249961,
  [SMALL_STATE(4610)] = 249994,
  [SMALL_STATE(4611)] = 250033,
  [SMALL_STATE(4612)] = 250080,
  [SMALL_STATE(4613)] = 250123,
  [SMALL_STATE(4614)] = 250156,
  [SMALL_STATE(4615)] = 250195,
  [SMALL_STATE(4616)] = 250228,
  [SMALL_STATE(4617)] = 250261,
  [SMALL_STATE(4618)] = 250310,
  [SMALL_STATE(4619)] = 250349,
  [SMALL_STATE(4620)] = 250388,
  [SMALL_STATE(4621)] = 250427,
  [SMALL_STATE(4622)] = 250460,
  [SMALL_STATE(4623)] = 250493,
  [SMALL_STATE(4624)] = 250558,
  [SMALL_STATE(4625)] = 250597,
  [SMALL_STATE(4626)] = 250636,
  [SMALL_STATE(4627)] = 250675,
  [SMALL_STATE(4628)] = 250714,
  [SMALL_STATE(4629)] = 250747,
  [SMALL_STATE(4630)] = 250786,
  [SMALL_STATE(4631)] = 250825,
  [SMALL_STATE(4632)] = 250864,
  [SMALL_STATE(4633)] = 250903,
  [SMALL_STATE(4634)] = 250942,
  [SMALL_STATE(4635)] = 250975,
  [SMALL_STATE(4636)] = 251014,
  [SMALL_STATE(4637)] = 251053,
  [SMALL_STATE(4638)] = 251092,
  [SMALL_STATE(4639)] = 251125,
  [SMALL_STATE(4640)] = 251158,
  [SMALL_STATE(4641)] = 251195,
  [SMALL_STATE(4642)] = 251234,
  [SMALL_STATE(4643)] = 251267,
  [SMALL_STATE(4644)] = 251300,
  [SMALL_STATE(4645)] = 251365,
  [SMALL_STATE(4646)] = 251408,
  [SMALL_STATE(4647)] = 251447,
  [SMALL_STATE(4648)] = 251480,
  [SMALL_STATE(4649)] = 251513,
  [SMALL_STATE(4650)] = 251552,
  [SMALL_STATE(4651)] = 251591,
  [SMALL_STATE(4652)] = 251630,
  [SMALL_STATE(4653)] = 251669,
  [SMALL_STATE(4654)] = 251708,
  [SMALL_STATE(4655)] = 251747,
  [SMALL_STATE(4656)] = 251786,
  [SMALL_STATE(4657)] = 251825,
  [SMALL_STATE(4658)] = 251858,
  [SMALL_STATE(4659)] = 251891,
  [SMALL_STATE(4660)] = 251924,
  [SMALL_STATE(4661)] = 251989,
  [SMALL_STATE(4662)] = 252028,
  [SMALL_STATE(4663)] = 252065,
  [SMALL_STATE(4664)] = 252098,
  [SMALL_STATE(4665)] = 252131,
  [SMALL_STATE(4666)] = 252164,
  [SMALL_STATE(4667)] = 252201,
  [SMALL_STATE(4668)] = 252240,
  [SMALL_STATE(4669)] = 252273,
  [SMALL_STATE(4670)] = 252316,
  [SMALL_STATE(4671)] = 252355,
  [SMALL_STATE(4672)] = 252420,
  [SMALL_STATE(4673)] = 252459,
  [SMALL_STATE(4674)] = 252524,
  [SMALL_STATE(4675)] = 252556,
  [SMALL_STATE(4676)] = 252618,
  [SMALL_STATE(4677)] = 252676,
  [SMALL_STATE(4678)] = 252708,
  [SMALL_STATE(4679)] = 252740,
  [SMALL_STATE(4680)] = 252798,
  [SMALL_STATE(4681)] = 252830,
  [SMALL_STATE(4682)] = 252862,
  [SMALL_STATE(4683)] = 252894,
  [SMALL_STATE(4684)] = 252926,
  [SMALL_STATE(4685)] = 252984,
  [SMALL_STATE(4686)] = 253016,
  [SMALL_STATE(4687)] = 253074,
  [SMALL_STATE(4688)] = 253106,
  [SMALL_STATE(4689)] = 253138,
  [SMALL_STATE(4690)] = 253196,
  [SMALL_STATE(4691)] = 253228,
  [SMALL_STATE(4692)] = 253286,
  [SMALL_STATE(4693)] = 253344,
  [SMALL_STATE(4694)] = 253376,
  [SMALL_STATE(4695)] = 253408,
  [SMALL_STATE(4696)] = 253466,
  [SMALL_STATE(4697)] = 253498,
  [SMALL_STATE(4698)] = 253556,
  [SMALL_STATE(4699)] = 253618,
  [SMALL_STATE(4700)] = 253676,
  [SMALL_STATE(4701)] = 253708,
  [SMALL_STATE(4702)] = 253766,
  [SMALL_STATE(4703)] = 253798,
  [SMALL_STATE(4704)] = 253856,
  [SMALL_STATE(4705)] = 253888,
  [SMALL_STATE(4706)] = 253920,
  [SMALL_STATE(4707)] = 253978,
  [SMALL_STATE(4708)] = 254010,
  [SMALL_STATE(4709)] = 254042,
  [SMALL_STATE(4710)] = 254074,
  [SMALL_STATE(4711)] = 254120,
  [SMALL_STATE(4712)] = 254178,
  [SMALL_STATE(4713)] = 254236,
  [SMALL_STATE(4714)] = 254268,
  [SMALL_STATE(4715)] = 254300,
  [SMALL_STATE(4716)] = 254332,
  [SMALL_STATE(4717)] = 254368,
  [SMALL_STATE(4718)] = 254400,
  [SMALL_STATE(4719)] = 254432,
  [SMALL_STATE(4720)] = 254464,
  [SMALL_STATE(4721)] = 254496,
  [SMALL_STATE(4722)] = 254554,
  [SMALL_STATE(4723)] = 254612,
  [SMALL_STATE(4724)] = 254644,
  [SMALL_STATE(4725)] = 254676,
  [SMALL_STATE(4726)] = 254708,
  [SMALL_STATE(4727)] = 254740,
  [SMALL_STATE(4728)] = 254798,
  [SMALL_STATE(4729)] = 254830,
  [SMALL_STATE(4730)] = 254888,
  [SMALL_STATE(4731)] = 254920,
  [SMALL_STATE(4732)] = 254962,
  [SMALL_STATE(4733)] = 254994,
  [SMALL_STATE(4734)] = 255036,
  [SMALL_STATE(4735)] = 255068,
  [SMALL_STATE(4736)] = 255100,
  [SMALL_STATE(4737)] = 255136,
  [SMALL_STATE(4738)] = 255168,
  [SMALL_STATE(4739)] = 255226,
  [SMALL_STATE(4740)] = 255260,
  [SMALL_STATE(4741)] = 255292,
  [SMALL_STATE(4742)] = 255334,
  [SMALL_STATE(4743)] = 255376,
  [SMALL_STATE(4744)] = 255408,
  [SMALL_STATE(4745)] = 255450,
  [SMALL_STATE(4746)] = 255482,
  [SMALL_STATE(4747)] = 255514,
  [SMALL_STATE(4748)] = 255546,
  [SMALL_STATE(4749)] = 255578,
  [SMALL_STATE(4750)] = 255610,
  [SMALL_STATE(4751)] = 255642,
  [SMALL_STATE(4752)] = 255700,
  [SMALL_STATE(4753)] = 255732,
  [SMALL_STATE(4754)] = 255764,
  [SMALL_STATE(4755)] = 255822,
  [SMALL_STATE(4756)] = 255880,
  [SMALL_STATE(4757)] = 255942,
  [SMALL_STATE(4758)] = 256000,
  [SMALL_STATE(4759)] = 256062,
  [SMALL_STATE(4760)] = 256094,
  [SMALL_STATE(4761)] = 256152,
  [SMALL_STATE(4762)] = 256184,
  [SMALL_STATE(4763)] = 256216,
  [SMALL_STATE(4764)] = 256248,
  [SMALL_STATE(4765)] = 256280,
  [SMALL_STATE(4766)] = 256312,
  [SMALL_STATE(4767)] = 256344,
  [SMALL_STATE(4768)] = 256376,
  [SMALL_STATE(4769)] = 256408,
  [SMALL_STATE(4770)] = 256440,
  [SMALL_STATE(4771)] = 256472,
  [SMALL_STATE(4772)] = 256504,
  [SMALL_STATE(4773)] = 256536,
  [SMALL_STATE(4774)] = 256568,
  [SMALL_STATE(4775)] = 256600,
  [SMALL_STATE(4776)] = 256632,
  [SMALL_STATE(4777)] = 256664,
  [SMALL_STATE(4778)] = 256696,
  [SMALL_STATE(4779)] = 256728,
  [SMALL_STATE(4780)] = 256786,
  [SMALL_STATE(4781)] = 256818,
  [SMALL_STATE(4782)] = 256876,
  [SMALL_STATE(4783)] = 256908,
  [SMALL_STATE(4784)] = 256940,
  [SMALL_STATE(4785)] = 256972,
  [SMALL_STATE(4786)] = 257004,
  [SMALL_STATE(4787)] = 257036,
  [SMALL_STATE(4788)] = 257094,
  [SMALL_STATE(4789)] = 257126,
  [SMALL_STATE(4790)] = 257158,
  [SMALL_STATE(4791)] = 257216,
  [SMALL_STATE(4792)] = 257278,
  [SMALL_STATE(4793)] = 257310,
  [SMALL_STATE(4794)] = 257368,
  [SMALL_STATE(4795)] = 257430,
  [SMALL_STATE(4796)] = 257462,
  [SMALL_STATE(4797)] = 257520,
  [SMALL_STATE(4798)] = 257552,
  [SMALL_STATE(4799)] = 257598,
  [SMALL_STATE(4800)] = 257656,
  [SMALL_STATE(4801)] = 257688,
  [SMALL_STATE(4802)] = 257720,
  [SMALL_STATE(4803)] = 257752,
  [SMALL_STATE(4804)] = 257810,
  [SMALL_STATE(4805)] = 257868,
  [SMALL_STATE(4806)] = 257900,
  [SMALL_STATE(4807)] = 257962,
  [SMALL_STATE(4808)] = 258020,
  [SMALL_STATE(4809)] = 258056,
  [SMALL_STATE(4810)] = 258114,
  [SMALL_STATE(4811)] = 258172,
  [SMALL_STATE(4812)] = 258218,
  [SMALL_STATE(4813)] = 258250,
  [SMALL_STATE(4814)] = 258282,
  [SMALL_STATE(4815)] = 258340,
  [SMALL_STATE(4816)] = 258372,
  [SMALL_STATE(4817)] = 258430,
  [SMALL_STATE(4818)] = 258462,
  [SMALL_STATE(4819)] = 258494,
  [SMALL_STATE(4820)] = 258526,
  [SMALL_STATE(4821)] = 258558,
  [SMALL_STATE(4822)] = 258594,
  [SMALL_STATE(4823)] = 258652,
  [SMALL_STATE(4824)] = 258684,
  [SMALL_STATE(4825)] = 258716,
  [SMALL_STATE(4826)] = 258748,
  [SMALL_STATE(4827)] = 258806,
  [SMALL_STATE(4828)] = 258838,
  [SMALL_STATE(4829)] = 258870,
  [SMALL_STATE(4830)] = 258902,
  [SMALL_STATE(4831)] = 258960,
  [SMALL_STATE(4832)] = 258992,
  [SMALL_STATE(4833)] = 259050,
  [SMALL_STATE(4834)] = 259082,
  [SMALL_STATE(4835)] = 259140,
  [SMALL_STATE(4836)] = 259172,
  [SMALL_STATE(4837)] = 259230,
  [SMALL_STATE(4838)] = 259262,
  [SMALL_STATE(4839)] = 259294,
  [SMALL_STATE(4840)] = 259326,
  [SMALL_STATE(4841)] = 259358,
  [SMALL_STATE(4842)] = 259390,
  [SMALL_STATE(4843)] = 259422,
  [SMALL_STATE(4844)] = 259454,
  [SMALL_STATE(4845)] = 259516,
  [SMALL_STATE(4846)] = 259574,
  [SMALL_STATE(4847)] = 259606,
  [SMALL_STATE(4848)] = 259664,
  [SMALL_STATE(4849)] = 259696,
  [SMALL_STATE(4850)] = 259728,
  [SMALL_STATE(4851)] = 259786,
  [SMALL_STATE(4852)] = 259848,
  [SMALL_STATE(4853)] = 259880,
  [SMALL_STATE(4854)] = 259912,
  [SMALL_STATE(4855)] = 259970,
  [SMALL_STATE(4856)] = 260028,
  [SMALL_STATE(4857)] = 260060,
  [SMALL_STATE(4858)] = 260118,
  [SMALL_STATE(4859)] = 260150,
  [SMALL_STATE(4860)] = 260182,
  [SMALL_STATE(4861)] = 260214,
  [SMALL_STATE(4862)] = 260246,
  [SMALL_STATE(4863)] = 260278,
  [SMALL_STATE(4864)] = 260336,
  [SMALL_STATE(4865)] = 260394,
  [SMALL_STATE(4866)] = 260452,
  [SMALL_STATE(4867)] = 260490,
  [SMALL_STATE(4868)] = 260528,
  [SMALL_STATE(4869)] = 260586,
  [SMALL_STATE(4870)] = 260618,
  [SMALL_STATE(4871)] = 260676,
  [SMALL_STATE(4872)] = 260708,
  [SMALL_STATE(4873)] = 260766,
  [SMALL_STATE(4874)] = 260798,
  [SMALL_STATE(4875)] = 260830,
  [SMALL_STATE(4876)] = 260868,
  [SMALL_STATE(4877)] = 260906,
  [SMALL_STATE(4878)] = 260944,
  [SMALL_STATE(4879)] = 260982,
  [SMALL_STATE(4880)] = 261020,
  [SMALL_STATE(4881)] = 261058,
  [SMALL_STATE(4882)] = 261096,
  [SMALL_STATE(4883)] = 261134,
  [SMALL_STATE(4884)] = 261192,
  [SMALL_STATE(4885)] = 261250,
  [SMALL_STATE(4886)] = 261282,
  [SMALL_STATE(4887)] = 261314,
  [SMALL_STATE(4888)] = 261346,
  [SMALL_STATE(4889)] = 261378,
  [SMALL_STATE(4890)] = 261436,
  [SMALL_STATE(4891)] = 261494,
  [SMALL_STATE(4892)] = 261526,
  [SMALL_STATE(4893)] = 261584,
  [SMALL_STATE(4894)] = 261616,
  [SMALL_STATE(4895)] = 261662,
  [SMALL_STATE(4896)] = 261720,
  [SMALL_STATE(4897)] = 261752,
  [SMALL_STATE(4898)] = 261784,
  [SMALL_STATE(4899)] = 261816,
  [SMALL_STATE(4900)] = 261862,
  [SMALL_STATE(4901)] = 261920,
  [SMALL_STATE(4902)] = 261952,
  [SMALL_STATE(4903)] = 261984,
  [SMALL_STATE(4904)] = 262042,
  [SMALL_STATE(4905)] = 262100,
  [SMALL_STATE(4906)] = 262158,
  [SMALL_STATE(4907)] = 262190,
  [SMALL_STATE(4908)] = 262222,
  [SMALL_STATE(4909)] = 262254,
  [SMALL_STATE(4910)] = 262312,
  [SMALL_STATE(4911)] = 262344,
  [SMALL_STATE(4912)] = 262402,
  [SMALL_STATE(4913)] = 262434,
  [SMALL_STATE(4914)] = 262492,
  [SMALL_STATE(4915)] = 262524,
  [SMALL_STATE(4916)] = 262556,
  [SMALL_STATE(4917)] = 262602,
  [SMALL_STATE(4918)] = 262634,
  [SMALL_STATE(4919)] = 262666,
  [SMALL_STATE(4920)] = 262698,
  [SMALL_STATE(4921)] = 262730,
  [SMALL_STATE(4922)] = 262762,
  [SMALL_STATE(4923)] = 262794,
  [SMALL_STATE(4924)] = 262826,
  [SMALL_STATE(4925)] = 262884,
  [SMALL_STATE(4926)] = 262942,
  [SMALL_STATE(4927)] = 263000,
  [SMALL_STATE(4928)] = 263032,
  [SMALL_STATE(4929)] = 263064,
  [SMALL_STATE(4930)] = 263122,
  [SMALL_STATE(4931)] = 263154,
  [SMALL_STATE(4932)] = 263212,
  [SMALL_STATE(4933)] = 263244,
  [SMALL_STATE(4934)] = 263276,
  [SMALL_STATE(4935)] = 263308,
  [SMALL_STATE(4936)] = 263340,
  [SMALL_STATE(4937)] = 263372,
  [SMALL_STATE(4938)] = 263404,
  [SMALL_STATE(4939)] = 263436,
  [SMALL_STATE(4940)] = 263494,
  [SMALL_STATE(4941)] = 263552,
  [SMALL_STATE(4942)] = 263583,
  [SMALL_STATE(4943)] = 263614,
  [SMALL_STATE(4944)] = 263649,
  [SMALL_STATE(4945)] = 263680,
  [SMALL_STATE(4946)] = 263715,
  [SMALL_STATE(4947)] = 263746,
  [SMALL_STATE(4948)] = 263793,
  [SMALL_STATE(4949)] = 263824,
  [SMALL_STATE(4950)] = 263855,
  [SMALL_STATE(4951)] = 263886,
  [SMALL_STATE(4952)] = 263917,
  [SMALL_STATE(4953)] = 263962,
  [SMALL_STATE(4954)] = 263993,
  [SMALL_STATE(4955)] = 264024,
  [SMALL_STATE(4956)] = 264055,
  [SMALL_STATE(4957)] = 264086,
  [SMALL_STATE(4958)] = 264121,
  [SMALL_STATE(4959)] = 264152,
  [SMALL_STATE(4960)] = 264183,
  [SMALL_STATE(4961)] = 264214,
  [SMALL_STATE(4962)] = 264245,
  [SMALL_STATE(4963)] = 264276,
  [SMALL_STATE(4964)] = 264307,
  [SMALL_STATE(4965)] = 264338,
  [SMALL_STATE(4966)] = 264373,
  [SMALL_STATE(4967)] = 264404,
  [SMALL_STATE(4968)] = 264435,
  [SMALL_STATE(4969)] = 264466,
  [SMALL_STATE(4970)] = 264497,
  [SMALL_STATE(4971)] = 264528,
  [SMALL_STATE(4972)] = 264573,
  [SMALL_STATE(4973)] = 264604,
  [SMALL_STATE(4974)] = 264635,
  [SMALL_STATE(4975)] = 264680,
  [SMALL_STATE(4976)] = 264711,
  [SMALL_STATE(4977)] = 264742,
  [SMALL_STATE(4978)] = 264773,
  [SMALL_STATE(4979)] = 264804,
  [SMALL_STATE(4980)] = 264835,
  [SMALL_STATE(4981)] = 264870,
  [SMALL_STATE(4982)] = 264901,
  [SMALL_STATE(4983)] = 264936,
  [SMALL_STATE(4984)] = 264967,
  [SMALL_STATE(4985)] = 264998,
  [SMALL_STATE(4986)] = 265029,
  [SMALL_STATE(4987)] = 265060,
  [SMALL_STATE(4988)] = 265091,
  [SMALL_STATE(4989)] = 265128,
  [SMALL_STATE(4990)] = 265159,
  [SMALL_STATE(4991)] = 265190,
  [SMALL_STATE(4992)] = 265221,
  [SMALL_STATE(4993)] = 265256,
  [SMALL_STATE(4994)] = 265287,
  [SMALL_STATE(4995)] = 265318,
  [SMALL_STATE(4996)] = 265349,
  [SMALL_STATE(4997)] = 265380,
  [SMALL_STATE(4998)] = 265411,
  [SMALL_STATE(4999)] = 265442,
  [SMALL_STATE(5000)] = 265489,
  [SMALL_STATE(5001)] = 265526,
  [SMALL_STATE(5002)] = 265557,
  [SMALL_STATE(5003)] = 265588,
  [SMALL_STATE(5004)] = 265619,
  [SMALL_STATE(5005)] = 265650,
  [SMALL_STATE(5006)] = 265681,
  [SMALL_STATE(5007)] = 265716,
  [SMALL_STATE(5008)] = 265751,
  [SMALL_STATE(5009)] = 265796,
  [SMALL_STATE(5010)] = 265841,
  [SMALL_STATE(5011)] = 265872,
  [SMALL_STATE(5012)] = 265903,
  [SMALL_STATE(5013)] = 265948,
  [SMALL_STATE(5014)] = 265979,
  [SMALL_STATE(5015)] = 266018,
  [SMALL_STATE(5016)] = 266049,
  [SMALL_STATE(5017)] = 266080,
  [SMALL_STATE(5018)] = 266117,
  [SMALL_STATE(5019)] = 266148,
  [SMALL_STATE(5020)] = 266184,
  [SMALL_STATE(5021)] = 266218,
  [SMALL_STATE(5022)] = 266252,
  [SMALL_STATE(5023)] = 266308,
  [SMALL_STATE(5024)] = 266364,
  [SMALL_STATE(5025)] = 266420,
  [SMALL_STATE(5026)] = 266476,
  [SMALL_STATE(5027)] = 266532,
  [SMALL_STATE(5028)] = 266588,
  [SMALL_STATE(5029)] = 266644,
  [SMALL_STATE(5030)] = 266700,
  [SMALL_STATE(5031)] = 266756,
  [SMALL_STATE(5032)] = 266812,
  [SMALL_STATE(5033)] = 266868,
  [SMALL_STATE(5034)] = 266924,
  [SMALL_STATE(5035)] = 266958,
  [SMALL_STATE(5036)] = 266992,
  [SMALL_STATE(5037)] = 267026,
  [SMALL_STATE(5038)] = 267060,
  [SMALL_STATE(5039)] = 267102,
  [SMALL_STATE(5040)] = 267138,
  [SMALL_STATE(5041)] = 267174,
  [SMALL_STATE(5042)] = 267208,
  [SMALL_STATE(5043)] = 267244,
  [SMALL_STATE(5044)] = 267280,
  [SMALL_STATE(5045)] = 267314,
  [SMALL_STATE(5046)] = 267348,
  [SMALL_STATE(5047)] = 267382,
  [SMALL_STATE(5048)] = 267416,
  [SMALL_STATE(5049)] = 267450,
  [SMALL_STATE(5050)] = 267492,
  [SMALL_STATE(5051)] = 267522,
  [SMALL_STATE(5052)] = 267564,
  [SMALL_STATE(5053)] = 267620,
  [SMALL_STATE(5054)] = 267656,
  [SMALL_STATE(5055)] = 267692,
  [SMALL_STATE(5056)] = 267728,
  [SMALL_STATE(5057)] = 267784,
  [SMALL_STATE(5058)] = 267824,
  [SMALL_STATE(5059)] = 267864,
  [SMALL_STATE(5060)] = 267920,
  [SMALL_STATE(5061)] = 267976,
  [SMALL_STATE(5062)] = 268016,
  [SMALL_STATE(5063)] = 268072,
  [SMALL_STATE(5064)] = 268128,
  [SMALL_STATE(5065)] = 268184,
  [SMALL_STATE(5066)] = 268240,
  [SMALL_STATE(5067)] = 268296,
  [SMALL_STATE(5068)] = 268332,
  [SMALL_STATE(5069)] = 268368,
  [SMALL_STATE(5070)] = 268404,
  [SMALL_STATE(5071)] = 268460,
  [SMALL_STATE(5072)] = 268516,
  [SMALL_STATE(5073)] = 268550,
  [SMALL_STATE(5074)] = 268606,
  [SMALL_STATE(5075)] = 268662,
  [SMALL_STATE(5076)] = 268718,
  [SMALL_STATE(5077)] = 268754,
  [SMALL_STATE(5078)] = 268790,
  [SMALL_STATE(5079)] = 268826,
  [SMALL_STATE(5080)] = 268862,
  [SMALL_STATE(5081)] = 268918,
  [SMALL_STATE(5082)] = 268974,
  [SMALL_STATE(5083)] = 269030,
  [SMALL_STATE(5084)] = 269086,
  [SMALL_STATE(5085)] = 269142,
  [SMALL_STATE(5086)] = 269198,
  [SMALL_STATE(5087)] = 269254,
  [SMALL_STATE(5088)] = 269310,
  [SMALL_STATE(5089)] = 269366,
  [SMALL_STATE(5090)] = 269422,
  [SMALL_STATE(5091)] = 269478,
  [SMALL_STATE(5092)] = 269520,
  [SMALL_STATE(5093)] = 269576,
  [SMALL_STATE(5094)] = 269610,
  [SMALL_STATE(5095)] = 269660,
  [SMALL_STATE(5096)] = 269702,
  [SMALL_STATE(5097)] = 269744,
  [SMALL_STATE(5098)] = 269800,
  [SMALL_STATE(5099)] = 269834,
  [SMALL_STATE(5100)] = 269868,
  [SMALL_STATE(5101)] = 269902,
  [SMALL_STATE(5102)] = 269938,
  [SMALL_STATE(5103)] = 269992,
  [SMALL_STATE(5104)] = 270028,
  [SMALL_STATE(5105)] = 270064,
  [SMALL_STATE(5106)] = 270100,
  [SMALL_STATE(5107)] = 270136,
  [SMALL_STATE(5108)] = 270172,
  [SMALL_STATE(5109)] = 270208,
  [SMALL_STATE(5110)] = 270244,
  [SMALL_STATE(5111)] = 270280,
  [SMALL_STATE(5112)] = 270316,
  [SMALL_STATE(5113)] = 270352,
  [SMALL_STATE(5114)] = 270388,
  [SMALL_STATE(5115)] = 270422,
  [SMALL_STATE(5116)] = 270463,
  [SMALL_STATE(5117)] = 270494,
  [SMALL_STATE(5118)] = 270527,
  [SMALL_STATE(5119)] = 270560,
  [SMALL_STATE(5120)] = 270621,
  [SMALL_STATE(5121)] = 270652,
  [SMALL_STATE(5122)] = 270685,
  [SMALL_STATE(5123)] = 270718,
  [SMALL_STATE(5124)] = 270751,
  [SMALL_STATE(5125)] = 270784,
  [SMALL_STATE(5126)] = 270813,
  [SMALL_STATE(5127)] = 270842,
  [SMALL_STATE(5128)] = 270871,
  [SMALL_STATE(5129)] = 270902,
  [SMALL_STATE(5130)] = 270931,
  [SMALL_STATE(5131)] = 270960,
  [SMALL_STATE(5132)] = 271003,
  [SMALL_STATE(5133)] = 271032,
  [SMALL_STATE(5134)] = 271061,
  [SMALL_STATE(5135)] = 271094,
  [SMALL_STATE(5136)] = 271129,
  [SMALL_STATE(5137)] = 271160,
  [SMALL_STATE(5138)] = 271193,
  [SMALL_STATE(5139)] = 271226,
  [SMALL_STATE(5140)] = 271259,
  [SMALL_STATE(5141)] = 271292,
  [SMALL_STATE(5142)] = 271325,
  [SMALL_STATE(5143)] = 271354,
  [SMALL_STATE(5144)] = 271383,
  [SMALL_STATE(5145)] = 271412,
  [SMALL_STATE(5146)] = 271441,
  [SMALL_STATE(5147)] = 271470,
  [SMALL_STATE(5148)] = 271503,
  [SMALL_STATE(5149)] = 271536,
  [SMALL_STATE(5150)] = 271565,
  [SMALL_STATE(5151)] = 271594,
  [SMALL_STATE(5152)] = 271625,
  [SMALL_STATE(5153)] = 271654,
  [SMALL_STATE(5154)] = 271683,
  [SMALL_STATE(5155)] = 271712,
  [SMALL_STATE(5156)] = 271741,
  [SMALL_STATE(5157)] = 271770,
  [SMALL_STATE(5158)] = 271831,
  [SMALL_STATE(5159)] = 271866,
  [SMALL_STATE(5160)] = 271901,
  [SMALL_STATE(5161)] = 271968,
  [SMALL_STATE(5162)] = 272001,
  [SMALL_STATE(5163)] = 272032,
  [SMALL_STATE(5164)] = 272071,
  [SMALL_STATE(5165)] = 272110,
  [SMALL_STATE(5166)] = 272143,
  [SMALL_STATE(5167)] = 272174,
  [SMALL_STATE(5168)] = 272213,
  [SMALL_STATE(5169)] = 272252,
  [SMALL_STATE(5170)] = 272291,
  [SMALL_STATE(5171)] = 272332,
  [SMALL_STATE(5172)] = 272375,
  [SMALL_STATE(5173)] = 272408,
  [SMALL_STATE(5174)] = 272443,
  [SMALL_STATE(5175)] = 272476,
  [SMALL_STATE(5176)] = 272523,
  [SMALL_STATE(5177)] = 272552,
  [SMALL_STATE(5178)] = 272583,
  [SMALL_STATE(5179)] = 272612,
  [SMALL_STATE(5180)] = 272641,
  [SMALL_STATE(5181)] = 272670,
  [SMALL_STATE(5182)] = 272705,
  [SMALL_STATE(5183)] = 272740,
  [SMALL_STATE(5184)] = 272769,
  [SMALL_STATE(5185)] = 272800,
  [SMALL_STATE(5186)] = 272831,
  [SMALL_STATE(5187)] = 272862,
  [SMALL_STATE(5188)] = 272895,
  [SMALL_STATE(5189)] = 272924,
  [SMALL_STATE(5190)] = 272955,
  [SMALL_STATE(5191)] = 272990,
  [SMALL_STATE(5192)] = 273037,
  [SMALL_STATE(5193)] = 273072,
  [SMALL_STATE(5194)] = 273105,
  [SMALL_STATE(5195)] = 273138,
  [SMALL_STATE(5196)] = 273169,
  [SMALL_STATE(5197)] = 273202,
  [SMALL_STATE(5198)] = 273235,
  [SMALL_STATE(5199)] = 273266,
  [SMALL_STATE(5200)] = 273313,
  [SMALL_STATE(5201)] = 273346,
  [SMALL_STATE(5202)] = 273375,
  [SMALL_STATE(5203)] = 273408,
  [SMALL_STATE(5204)] = 273437,
  [SMALL_STATE(5205)] = 273466,
  [SMALL_STATE(5206)] = 273497,
  [SMALL_STATE(5207)] = 273526,
  [SMALL_STATE(5208)] = 273555,
  [SMALL_STATE(5209)] = 273584,
  [SMALL_STATE(5210)] = 273613,
  [SMALL_STATE(5211)] = 273642,
  [SMALL_STATE(5212)] = 273671,
  [SMALL_STATE(5213)] = 273718,
  [SMALL_STATE(5214)] = 273749,
  [SMALL_STATE(5215)] = 273778,
  [SMALL_STATE(5216)] = 273807,
  [SMALL_STATE(5217)] = 273836,
  [SMALL_STATE(5218)] = 273869,
  [SMALL_STATE(5219)] = 273904,
  [SMALL_STATE(5220)] = 273939,
  [SMALL_STATE(5221)] = 273972,
  [SMALL_STATE(5222)] = 274019,
  [SMALL_STATE(5223)] = 274060,
  [SMALL_STATE(5224)] = 274091,
  [SMALL_STATE(5225)] = 274138,
  [SMALL_STATE(5226)] = 274171,
  [SMALL_STATE(5227)] = 274202,
  [SMALL_STATE(5228)] = 274233,
  [SMALL_STATE(5229)] = 274280,
  [SMALL_STATE(5230)] = 274311,
  [SMALL_STATE(5231)] = 274342,
  [SMALL_STATE(5232)] = 274373,
  [SMALL_STATE(5233)] = 274404,
  [SMALL_STATE(5234)] = 274435,
  [SMALL_STATE(5235)] = 274482,
  [SMALL_STATE(5236)] = 274523,
  [SMALL_STATE(5237)] = 274558,
  [SMALL_STATE(5238)] = 274593,
  [SMALL_STATE(5239)] = 274628,
  [SMALL_STATE(5240)] = 274663,
  [SMALL_STATE(5241)] = 274698,
  [SMALL_STATE(5242)] = 274733,
  [SMALL_STATE(5243)] = 274768,
  [SMALL_STATE(5244)] = 274803,
  [SMALL_STATE(5245)] = 274834,
  [SMALL_STATE(5246)] = 274863,
  [SMALL_STATE(5247)] = 274891,
  [SMALL_STATE(5248)] = 274923,
  [SMALL_STATE(5249)] = 274951,
  [SMALL_STATE(5250)] = 274979,
  [SMALL_STATE(5251)] = 275007,
  [SMALL_STATE(5252)] = 275035,
  [SMALL_STATE(5253)] = 275067,
  [SMALL_STATE(5254)] = 275099,
  [SMALL_STATE(5255)] = 275127,
  [SMALL_STATE(5256)] = 275155,
  [SMALL_STATE(5257)] = 275183,
  [SMALL_STATE(5258)] = 275211,
  [SMALL_STATE(5259)] = 275239,
  [SMALL_STATE(5260)] = 275267,
  [SMALL_STATE(5261)] = 275295,
  [SMALL_STATE(5262)] = 275327,
  [SMALL_STATE(5263)] = 275355,
  [SMALL_STATE(5264)] = 275387,
  [SMALL_STATE(5265)] = 275415,
  [SMALL_STATE(5266)] = 275443,
  [SMALL_STATE(5267)] = 275475,
  [SMALL_STATE(5268)] = 275503,
  [SMALL_STATE(5269)] = 275531,
  [SMALL_STATE(5270)] = 275559,
  [SMALL_STATE(5271)] = 275591,
  [SMALL_STATE(5272)] = 275623,
  [SMALL_STATE(5273)] = 275651,
  [SMALL_STATE(5274)] = 275679,
  [SMALL_STATE(5275)] = 275707,
  [SMALL_STATE(5276)] = 275735,
  [SMALL_STATE(5277)] = 275767,
  [SMALL_STATE(5278)] = 275795,
  [SMALL_STATE(5279)] = 275823,
  [SMALL_STATE(5280)] = 275855,
  [SMALL_STATE(5281)] = 275883,
  [SMALL_STATE(5282)] = 275911,
  [SMALL_STATE(5283)] = 275939,
  [SMALL_STATE(5284)] = 275967,
  [SMALL_STATE(5285)] = 275995,
  [SMALL_STATE(5286)] = 276023,
  [SMALL_STATE(5287)] = 276051,
  [SMALL_STATE(5288)] = 276083,
  [SMALL_STATE(5289)] = 276111,
  [SMALL_STATE(5290)] = 276139,
  [SMALL_STATE(5291)] = 276167,
  [SMALL_STATE(5292)] = 276195,
  [SMALL_STATE(5293)] = 276235,
  [SMALL_STATE(5294)] = 276263,
  [SMALL_STATE(5295)] = 276291,
  [SMALL_STATE(5296)] = 276319,
  [SMALL_STATE(5297)] = 276347,
  [SMALL_STATE(5298)] = 276375,
  [SMALL_STATE(5299)] = 276403,
  [SMALL_STATE(5300)] = 276435,
  [SMALL_STATE(5301)] = 276463,
  [SMALL_STATE(5302)] = 276491,
  [SMALL_STATE(5303)] = 276519,
  [SMALL_STATE(5304)] = 276551,
  [SMALL_STATE(5305)] = 276579,
  [SMALL_STATE(5306)] = 276607,
  [SMALL_STATE(5307)] = 276651,
  [SMALL_STATE(5308)] = 276679,
  [SMALL_STATE(5309)] = 276707,
  [SMALL_STATE(5310)] = 276735,
  [SMALL_STATE(5311)] = 276775,
  [SMALL_STATE(5312)] = 276803,
  [SMALL_STATE(5313)] = 276835,
  [SMALL_STATE(5314)] = 276863,
  [SMALL_STATE(5315)] = 276891,
  [SMALL_STATE(5316)] = 276919,
  [SMALL_STATE(5317)] = 276947,
  [SMALL_STATE(5318)] = 276975,
  [SMALL_STATE(5319)] = 277003,
  [SMALL_STATE(5320)] = 277031,
  [SMALL_STATE(5321)] = 277059,
  [SMALL_STATE(5322)] = 277087,
  [SMALL_STATE(5323)] = 277115,
  [SMALL_STATE(5324)] = 277143,
  [SMALL_STATE(5325)] = 277187,
  [SMALL_STATE(5326)] = 277227,
  [SMALL_STATE(5327)] = 277255,
  [SMALL_STATE(5328)] = 277283,
  [SMALL_STATE(5329)] = 277311,
  [SMALL_STATE(5330)] = 277345,
  [SMALL_STATE(5331)] = 277373,
  [SMALL_STATE(5332)] = 277407,
  [SMALL_STATE(5333)] = 277439,
  [SMALL_STATE(5334)] = 277467,
  [SMALL_STATE(5335)] = 277495,
  [SMALL_STATE(5336)] = 277523,
  [SMALL_STATE(5337)] = 277551,
  [SMALL_STATE(5338)] = 277579,
  [SMALL_STATE(5339)] = 277611,
  [SMALL_STATE(5340)] = 277639,
  [SMALL_STATE(5341)] = 277667,
  [SMALL_STATE(5342)] = 277695,
  [SMALL_STATE(5343)] = 277723,
  [SMALL_STATE(5344)] = 277751,
  [SMALL_STATE(5345)] = 277779,
  [SMALL_STATE(5346)] = 277807,
  [SMALL_STATE(5347)] = 277835,
  [SMALL_STATE(5348)] = 277863,
  [SMALL_STATE(5349)] = 277895,
  [SMALL_STATE(5350)] = 277923,
  [SMALL_STATE(5351)] = 277955,
  [SMALL_STATE(5352)] = 277983,
  [SMALL_STATE(5353)] = 278011,
  [SMALL_STATE(5354)] = 278069,
  [SMALL_STATE(5355)] = 278097,
  [SMALL_STATE(5356)] = 278125,
  [SMALL_STATE(5357)] = 278153,
  [SMALL_STATE(5358)] = 278181,
  [SMALL_STATE(5359)] = 278209,
  [SMALL_STATE(5360)] = 278241,
  [SMALL_STATE(5361)] = 278269,
  [SMALL_STATE(5362)] = 278297,
  [SMALL_STATE(5363)] = 278325,
  [SMALL_STATE(5364)] = 278353,
  [SMALL_STATE(5365)] = 278381,
  [SMALL_STATE(5366)] = 278409,
  [SMALL_STATE(5367)] = 278437,
  [SMALL_STATE(5368)] = 278465,
  [SMALL_STATE(5369)] = 278493,
  [SMALL_STATE(5370)] = 278521,
  [SMALL_STATE(5371)] = 278549,
  [SMALL_STATE(5372)] = 278583,
  [SMALL_STATE(5373)] = 278611,
  [SMALL_STATE(5374)] = 278641,
  [SMALL_STATE(5375)] = 278669,
  [SMALL_STATE(5376)] = 278697,
  [SMALL_STATE(5377)] = 278725,
  [SMALL_STATE(5378)] = 278753,
  [SMALL_STATE(5379)] = 278781,
  [SMALL_STATE(5380)] = 278809,
  [SMALL_STATE(5381)] = 278837,
  [SMALL_STATE(5382)] = 278879,
  [SMALL_STATE(5383)] = 278907,
  [SMALL_STATE(5384)] = 278935,
  [SMALL_STATE(5385)] = 278963,
  [SMALL_STATE(5386)] = 278991,
  [SMALL_STATE(5387)] = 279019,
  [SMALL_STATE(5388)] = 279047,
  [SMALL_STATE(5389)] = 279079,
  [SMALL_STATE(5390)] = 279107,
  [SMALL_STATE(5391)] = 279139,
  [SMALL_STATE(5392)] = 279167,
  [SMALL_STATE(5393)] = 279195,
  [SMALL_STATE(5394)] = 279223,
  [SMALL_STATE(5395)] = 279255,
  [SMALL_STATE(5396)] = 279287,
  [SMALL_STATE(5397)] = 279329,
  [SMALL_STATE(5398)] = 279361,
  [SMALL_STATE(5399)] = 279389,
  [SMALL_STATE(5400)] = 279417,
  [SMALL_STATE(5401)] = 279445,
  [SMALL_STATE(5402)] = 279473,
  [SMALL_STATE(5403)] = 279501,
  [SMALL_STATE(5404)] = 279529,
  [SMALL_STATE(5405)] = 279556,
  [SMALL_STATE(5406)] = 279587,
  [SMALL_STATE(5407)] = 279614,
  [SMALL_STATE(5408)] = 279641,
  [SMALL_STATE(5409)] = 279668,
  [SMALL_STATE(5410)] = 279695,
  [SMALL_STATE(5411)] = 279734,
  [SMALL_STATE(5412)] = 279761,
  [SMALL_STATE(5413)] = 279798,
  [SMALL_STATE(5414)] = 279829,
  [SMALL_STATE(5415)] = 279862,
  [SMALL_STATE(5416)] = 279889,
  [SMALL_STATE(5417)] = 279926,
  [SMALL_STATE(5418)] = 279965,
  [SMALL_STATE(5419)] = 280004,
  [SMALL_STATE(5420)] = 280031,
  [SMALL_STATE(5421)] = 280058,
  [SMALL_STATE(5422)] = 280097,
  [SMALL_STATE(5423)] = 280124,
  [SMALL_STATE(5424)] = 280151,
  [SMALL_STATE(5425)] = 280178,
  [SMALL_STATE(5426)] = 280205,
  [SMALL_STATE(5427)] = 280244,
  [SMALL_STATE(5428)] = 280271,
  [SMALL_STATE(5429)] = 280298,
  [SMALL_STATE(5430)] = 280325,
  [SMALL_STATE(5431)] = 280352,
  [SMALL_STATE(5432)] = 280383,
  [SMALL_STATE(5433)] = 280444,
  [SMALL_STATE(5434)] = 280471,
  [SMALL_STATE(5435)] = 280502,
  [SMALL_STATE(5436)] = 280541,
  [SMALL_STATE(5437)] = 280580,
  [SMALL_STATE(5438)] = 280607,
  [SMALL_STATE(5439)] = 280634,
  [SMALL_STATE(5440)] = 280661,
  [SMALL_STATE(5441)] = 280688,
  [SMALL_STATE(5442)] = 280719,
  [SMALL_STATE(5443)] = 280746,
  [SMALL_STATE(5444)] = 280777,
  [SMALL_STATE(5445)] = 280808,
  [SMALL_STATE(5446)] = 280847,
  [SMALL_STATE(5447)] = 280886,
  [SMALL_STATE(5448)] = 280913,
  [SMALL_STATE(5449)] = 280940,
  [SMALL_STATE(5450)] = 280967,
  [SMALL_STATE(5451)] = 280994,
  [SMALL_STATE(5452)] = 281033,
  [SMALL_STATE(5453)] = 281088,
  [SMALL_STATE(5454)] = 281115,
  [SMALL_STATE(5455)] = 281170,
  [SMALL_STATE(5456)] = 281196,
  [SMALL_STATE(5457)] = 281222,
  [SMALL_STATE(5458)] = 281258,
  [SMALL_STATE(5459)] = 281296,
  [SMALL_STATE(5460)] = 281322,
  [SMALL_STATE(5461)] = 281348,
  [SMALL_STATE(5462)] = 281374,
  [SMALL_STATE(5463)] = 281406,
  [SMALL_STATE(5464)] = 281432,
  [SMALL_STATE(5465)] = 281458,
  [SMALL_STATE(5466)] = 281484,
  [SMALL_STATE(5467)] = 281510,
  [SMALL_STATE(5468)] = 281536,
  [SMALL_STATE(5469)] = 281562,
  [SMALL_STATE(5470)] = 281588,
  [SMALL_STATE(5471)] = 281614,
  [SMALL_STATE(5472)] = 281640,
  [SMALL_STATE(5473)] = 281666,
  [SMALL_STATE(5474)] = 281692,
  [SMALL_STATE(5475)] = 281718,
  [SMALL_STATE(5476)] = 281744,
  [SMALL_STATE(5477)] = 281770,
  [SMALL_STATE(5478)] = 281796,
  [SMALL_STATE(5479)] = 281822,
  [SMALL_STATE(5480)] = 281848,
  [SMALL_STATE(5481)] = 281874,
  [SMALL_STATE(5482)] = 281900,
  [SMALL_STATE(5483)] = 281926,
  [SMALL_STATE(5484)] = 281958,
  [SMALL_STATE(5485)] = 281984,
  [SMALL_STATE(5486)] = 282010,
  [SMALL_STATE(5487)] = 282042,
  [SMALL_STATE(5488)] = 282068,
  [SMALL_STATE(5489)] = 282094,
  [SMALL_STATE(5490)] = 282126,
  [SMALL_STATE(5491)] = 282152,
  [SMALL_STATE(5492)] = 282190,
  [SMALL_STATE(5493)] = 282216,
  [SMALL_STATE(5494)] = 282242,
  [SMALL_STATE(5495)] = 282276,
  [SMALL_STATE(5496)] = 282302,
  [SMALL_STATE(5497)] = 282334,
  [SMALL_STATE(5498)] = 282360,
  [SMALL_STATE(5499)] = 282392,
  [SMALL_STATE(5500)] = 282426,
  [SMALL_STATE(5501)] = 282464,
  [SMALL_STATE(5502)] = 282502,
  [SMALL_STATE(5503)] = 282528,
  [SMALL_STATE(5504)] = 282560,
  [SMALL_STATE(5505)] = 282586,
  [SMALL_STATE(5506)] = 282612,
  [SMALL_STATE(5507)] = 282638,
  [SMALL_STATE(5508)] = 282664,
  [SMALL_STATE(5509)] = 282690,
  [SMALL_STATE(5510)] = 282722,
  [SMALL_STATE(5511)] = 282760,
  [SMALL_STATE(5512)] = 282786,
  [SMALL_STATE(5513)] = 282824,
  [SMALL_STATE(5514)] = 282856,
  [SMALL_STATE(5515)] = 282882,
  [SMALL_STATE(5516)] = 282908,
  [SMALL_STATE(5517)] = 282940,
  [SMALL_STATE(5518)] = 282978,
  [SMALL_STATE(5519)] = 283010,
  [SMALL_STATE(5520)] = 283048,
  [SMALL_STATE(5521)] = 283086,
  [SMALL_STATE(5522)] = 283112,
  [SMALL_STATE(5523)] = 283138,
  [SMALL_STATE(5524)] = 283164,
  [SMALL_STATE(5525)] = 283196,
  [SMALL_STATE(5526)] = 283228,
  [SMALL_STATE(5527)] = 283254,
  [SMALL_STATE(5528)] = 283286,
  [SMALL_STATE(5529)] = 283312,
  [SMALL_STATE(5530)] = 283337,
  [SMALL_STATE(5531)] = 283362,
  [SMALL_STATE(5532)] = 283387,
  [SMALL_STATE(5533)] = 283412,
  [SMALL_STATE(5534)] = 283437,
  [SMALL_STATE(5535)] = 283462,
  [SMALL_STATE(5536)] = 283487,
  [SMALL_STATE(5537)] = 283512,
  [SMALL_STATE(5538)] = 283537,
  [SMALL_STATE(5539)] = 283562,
  [SMALL_STATE(5540)] = 283587,
  [SMALL_STATE(5541)] = 283612,
  [SMALL_STATE(5542)] = 283637,
  [SMALL_STATE(5543)] = 283662,
  [SMALL_STATE(5544)] = 283687,
  [SMALL_STATE(5545)] = 283712,
  [SMALL_STATE(5546)] = 283737,
  [SMALL_STATE(5547)] = 283762,
  [SMALL_STATE(5548)] = 283787,
  [SMALL_STATE(5549)] = 283812,
  [SMALL_STATE(5550)] = 283837,
  [SMALL_STATE(5551)] = 283862,
  [SMALL_STATE(5552)] = 283887,
  [SMALL_STATE(5553)] = 283916,
  [SMALL_STATE(5554)] = 283941,
  [SMALL_STATE(5555)] = 283966,
  [SMALL_STATE(5556)] = 283991,
  [SMALL_STATE(5557)] = 284016,
  [SMALL_STATE(5558)] = 284041,
  [SMALL_STATE(5559)] = 284070,
  [SMALL_STATE(5560)] = 284095,
  [SMALL_STATE(5561)] = 284120,
  [SMALL_STATE(5562)] = 284145,
  [SMALL_STATE(5563)] = 284170,
  [SMALL_STATE(5564)] = 284195,
  [SMALL_STATE(5565)] = 284220,
  [SMALL_STATE(5566)] = 284245,
  [SMALL_STATE(5567)] = 284270,
  [SMALL_STATE(5568)] = 284295,
  [SMALL_STATE(5569)] = 284320,
  [SMALL_STATE(5570)] = 284345,
  [SMALL_STATE(5571)] = 284370,
  [SMALL_STATE(5572)] = 284395,
  [SMALL_STATE(5573)] = 284420,
  [SMALL_STATE(5574)] = 284445,
  [SMALL_STATE(5575)] = 284470,
  [SMALL_STATE(5576)] = 284495,
  [SMALL_STATE(5577)] = 284520,
  [SMALL_STATE(5578)] = 284545,
  [SMALL_STATE(5579)] = 284570,
  [SMALL_STATE(5580)] = 284595,
  [SMALL_STATE(5581)] = 284620,
  [SMALL_STATE(5582)] = 284645,
  [SMALL_STATE(5583)] = 284670,
  [SMALL_STATE(5584)] = 284695,
  [SMALL_STATE(5585)] = 284720,
  [SMALL_STATE(5586)] = 284745,
  [SMALL_STATE(5587)] = 284770,
  [SMALL_STATE(5588)] = 284795,
  [SMALL_STATE(5589)] = 284820,
  [SMALL_STATE(5590)] = 284845,
  [SMALL_STATE(5591)] = 284870,
  [SMALL_STATE(5592)] = 284895,
  [SMALL_STATE(5593)] = 284920,
  [SMALL_STATE(5594)] = 284945,
  [SMALL_STATE(5595)] = 284970,
  [SMALL_STATE(5596)] = 284999,
  [SMALL_STATE(5597)] = 285028,
  [SMALL_STATE(5598)] = 285053,
  [SMALL_STATE(5599)] = 285078,
  [SMALL_STATE(5600)] = 285103,
  [SMALL_STATE(5601)] = 285132,
  [SMALL_STATE(5602)] = 285157,
  [SMALL_STATE(5603)] = 285182,
  [SMALL_STATE(5604)] = 285207,
  [SMALL_STATE(5605)] = 285232,
  [SMALL_STATE(5606)] = 285257,
  [SMALL_STATE(5607)] = 285282,
  [SMALL_STATE(5608)] = 285307,
  [SMALL_STATE(5609)] = 285332,
  [SMALL_STATE(5610)] = 285357,
  [SMALL_STATE(5611)] = 285381,
  [SMALL_STATE(5612)] = 285404,
  [SMALL_STATE(5613)] = 285427,
  [SMALL_STATE(5614)] = 285450,
  [SMALL_STATE(5615)] = 285473,
  [SMALL_STATE(5616)] = 285504,
  [SMALL_STATE(5617)] = 285539,
  [SMALL_STATE(5618)] = 285570,
  [SMALL_STATE(5619)] = 285607,
  [SMALL_STATE(5620)] = 285647,
  [SMALL_STATE(5621)] = 285687,
  [SMALL_STATE(5622)] = 285727,
  [SMALL_STATE(5623)] = 285767,
  [SMALL_STATE(5624)] = 285807,
  [SMALL_STATE(5625)] = 285847,
  [SMALL_STATE(5626)] = 285887,
  [SMALL_STATE(5627)] = 285927,
  [SMALL_STATE(5628)] = 285967,
  [SMALL_STATE(5629)] = 286007,
  [SMALL_STATE(5630)] = 286047,
  [SMALL_STATE(5631)] = 286087,
  [SMALL_STATE(5632)] = 286127,
  [SMALL_STATE(5633)] = 286167,
  [SMALL_STATE(5634)] = 286207,
  [SMALL_STATE(5635)] = 286247,
  [SMALL_STATE(5636)] = 286287,
  [SMALL_STATE(5637)] = 286327,
  [SMALL_STATE(5638)] = 286367,
  [SMALL_STATE(5639)] = 286407,
  [SMALL_STATE(5640)] = 286447,
  [SMALL_STATE(5641)] = 286487,
  [SMALL_STATE(5642)] = 286527,
  [SMALL_STATE(5643)] = 286567,
  [SMALL_STATE(5644)] = 286607,
  [SMALL_STATE(5645)] = 286647,
  [SMALL_STATE(5646)] = 286687,
  [SMALL_STATE(5647)] = 286727,
  [SMALL_STATE(5648)] = 286767,
  [SMALL_STATE(5649)] = 286807,
  [SMALL_STATE(5650)] = 286847,
  [SMALL_STATE(5651)] = 286887,
  [SMALL_STATE(5652)] = 286927,
  [SMALL_STATE(5653)] = 286967,
  [SMALL_STATE(5654)] = 287007,
  [SMALL_STATE(5655)] = 287047,
  [SMALL_STATE(5656)] = 287087,
  [SMALL_STATE(5657)] = 287127,
  [SMALL_STATE(5658)] = 287167,
  [SMALL_STATE(5659)] = 287207,
  [SMALL_STATE(5660)] = 287247,
  [SMALL_STATE(5661)] = 287287,
  [SMALL_STATE(5662)] = 287327,
  [SMALL_STATE(5663)] = 287367,
  [SMALL_STATE(5664)] = 287407,
  [SMALL_STATE(5665)] = 287447,
  [SMALL_STATE(5666)] = 287487,
  [SMALL_STATE(5667)] = 287527,
  [SMALL_STATE(5668)] = 287567,
  [SMALL_STATE(5669)] = 287607,
  [SMALL_STATE(5670)] = 287647,
  [SMALL_STATE(5671)] = 287687,
  [SMALL_STATE(5672)] = 287727,
  [SMALL_STATE(5673)] = 287767,
  [SMALL_STATE(5674)] = 287807,
  [SMALL_STATE(5675)] = 287847,
  [SMALL_STATE(5676)] = 287887,
  [SMALL_STATE(5677)] = 287927,
  [SMALL_STATE(5678)] = 287967,
  [SMALL_STATE(5679)] = 288007,
  [SMALL_STATE(5680)] = 288047,
  [SMALL_STATE(5681)] = 288087,
  [SMALL_STATE(5682)] = 288127,
  [SMALL_STATE(5683)] = 288167,
  [SMALL_STATE(5684)] = 288207,
  [SMALL_STATE(5685)] = 288247,
  [SMALL_STATE(5686)] = 288287,
  [SMALL_STATE(5687)] = 288327,
  [SMALL_STATE(5688)] = 288367,
  [SMALL_STATE(5689)] = 288407,
  [SMALL_STATE(5690)] = 288447,
  [SMALL_STATE(5691)] = 288487,
  [SMALL_STATE(5692)] = 288527,
  [SMALL_STATE(5693)] = 288567,
  [SMALL_STATE(5694)] = 288607,
  [SMALL_STATE(5695)] = 288647,
  [SMALL_STATE(5696)] = 288687,
  [SMALL_STATE(5697)] = 288727,
  [SMALL_STATE(5698)] = 288767,
  [SMALL_STATE(5699)] = 288807,
  [SMALL_STATE(5700)] = 288847,
  [SMALL_STATE(5701)] = 288887,
  [SMALL_STATE(5702)] = 288927,
  [SMALL_STATE(5703)] = 288967,
  [SMALL_STATE(5704)] = 289007,
  [SMALL_STATE(5705)] = 289047,
  [SMALL_STATE(5706)] = 289087,
  [SMALL_STATE(5707)] = 289127,
  [SMALL_STATE(5708)] = 289167,
  [SMALL_STATE(5709)] = 289207,
  [SMALL_STATE(5710)] = 289247,
  [SMALL_STATE(5711)] = 289287,
  [SMALL_STATE(5712)] = 289327,
  [SMALL_STATE(5713)] = 289367,
  [SMALL_STATE(5714)] = 289407,
  [SMALL_STATE(5715)] = 289447,
  [SMALL_STATE(5716)] = 289487,
  [SMALL_STATE(5717)] = 289527,
  [SMALL_STATE(5718)] = 289567,
  [SMALL_STATE(5719)] = 289607,
  [SMALL_STATE(5720)] = 289647,
  [SMALL_STATE(5721)] = 289687,
  [SMALL_STATE(5722)] = 289727,
  [SMALL_STATE(5723)] = 289767,
  [SMALL_STATE(5724)] = 289807,
  [SMALL_STATE(5725)] = 289847,
  [SMALL_STATE(5726)] = 289887,
  [SMALL_STATE(5727)] = 289927,
  [SMALL_STATE(5728)] = 289967,
  [SMALL_STATE(5729)] = 290007,
  [SMALL_STATE(5730)] = 290047,
  [SMALL_STATE(5731)] = 290087,
  [SMALL_STATE(5732)] = 290127,
  [SMALL_STATE(5733)] = 290167,
  [SMALL_STATE(5734)] = 290207,
  [SMALL_STATE(5735)] = 290247,
  [SMALL_STATE(5736)] = 290287,
  [SMALL_STATE(5737)] = 290327,
  [SMALL_STATE(5738)] = 290367,
  [SMALL_STATE(5739)] = 290407,
  [SMALL_STATE(5740)] = 290447,
  [SMALL_STATE(5741)] = 290487,
  [SMALL_STATE(5742)] = 290527,
  [SMALL_STATE(5743)] = 290567,
  [SMALL_STATE(5744)] = 290607,
  [SMALL_STATE(5745)] = 290647,
  [SMALL_STATE(5746)] = 290687,
  [SMALL_STATE(5747)] = 290727,
  [SMALL_STATE(5748)] = 290767,
  [SMALL_STATE(5749)] = 290807,
  [SMALL_STATE(5750)] = 290847,
  [SMALL_STATE(5751)] = 290887,
  [SMALL_STATE(5752)] = 290927,
  [SMALL_STATE(5753)] = 290967,
  [SMALL_STATE(5754)] = 291007,
  [SMALL_STATE(5755)] = 291047,
  [SMALL_STATE(5756)] = 291087,
  [SMALL_STATE(5757)] = 291127,
  [SMALL_STATE(5758)] = 291167,
  [SMALL_STATE(5759)] = 291207,
  [SMALL_STATE(5760)] = 291247,
  [SMALL_STATE(5761)] = 291287,
  [SMALL_STATE(5762)] = 291327,
  [SMALL_STATE(5763)] = 291367,
  [SMALL_STATE(5764)] = 291407,
  [SMALL_STATE(5765)] = 291447,
  [SMALL_STATE(5766)] = 291487,
  [SMALL_STATE(5767)] = 291527,
  [SMALL_STATE(5768)] = 291567,
  [SMALL_STATE(5769)] = 291607,
  [SMALL_STATE(5770)] = 291647,
  [SMALL_STATE(5771)] = 291687,
  [SMALL_STATE(5772)] = 291727,
  [SMALL_STATE(5773)] = 291767,
  [SMALL_STATE(5774)] = 291807,
  [SMALL_STATE(5775)] = 291834,
  [SMALL_STATE(5776)] = 291861,
  [SMALL_STATE(5777)] = 291888,
  [SMALL_STATE(5778)] = 291915,
  [SMALL_STATE(5779)] = 291944,
  [SMALL_STATE(5780)] = 291971,
  [SMALL_STATE(5781)] = 291998,
  [SMALL_STATE(5782)] = 292025,
  [SMALL_STATE(5783)] = 292052,
  [SMALL_STATE(5784)] = 292079,
  [SMALL_STATE(5785)] = 292106,
  [SMALL_STATE(5786)] = 292135,
  [SMALL_STATE(5787)] = 292162,
  [SMALL_STATE(5788)] = 292189,
  [SMALL_STATE(5789)] = 292216,
  [SMALL_STATE(5790)] = 292243,
  [SMALL_STATE(5791)] = 292270,
  [SMALL_STATE(5792)] = 292297,
  [SMALL_STATE(5793)] = 292324,
  [SMALL_STATE(5794)] = 292351,
  [SMALL_STATE(5795)] = 292378,
  [SMALL_STATE(5796)] = 292405,
  [SMALL_STATE(5797)] = 292432,
  [SMALL_STATE(5798)] = 292461,
  [SMALL_STATE(5799)] = 292488,
  [SMALL_STATE(5800)] = 292515,
  [SMALL_STATE(5801)] = 292542,
  [SMALL_STATE(5802)] = 292569,
  [SMALL_STATE(5803)] = 292596,
  [SMALL_STATE(5804)] = 292623,
  [SMALL_STATE(5805)] = 292650,
  [SMALL_STATE(5806)] = 292677,
  [SMALL_STATE(5807)] = 292704,
  [SMALL_STATE(5808)] = 292731,
  [SMALL_STATE(5809)] = 292758,
  [SMALL_STATE(5810)] = 292785,
  [SMALL_STATE(5811)] = 292812,
  [SMALL_STATE(5812)] = 292839,
  [SMALL_STATE(5813)] = 292866,
  [SMALL_STATE(5814)] = 292893,
  [SMALL_STATE(5815)] = 292920,
  [SMALL_STATE(5816)] = 292947,
  [SMALL_STATE(5817)] = 292974,
  [SMALL_STATE(5818)] = 293001,
  [SMALL_STATE(5819)] = 293028,
  [SMALL_STATE(5820)] = 293055,
  [SMALL_STATE(5821)] = 293082,
  [SMALL_STATE(5822)] = 293109,
  [SMALL_STATE(5823)] = 293136,
  [SMALL_STATE(5824)] = 293163,
  [SMALL_STATE(5825)] = 293190,
  [SMALL_STATE(5826)] = 293217,
  [SMALL_STATE(5827)] = 293244,
  [SMALL_STATE(5828)] = 293271,
  [SMALL_STATE(5829)] = 293298,
  [SMALL_STATE(5830)] = 293325,
  [SMALL_STATE(5831)] = 293352,
  [SMALL_STATE(5832)] = 293379,
  [SMALL_STATE(5833)] = 293406,
  [SMALL_STATE(5834)] = 293433,
  [SMALL_STATE(5835)] = 293460,
  [SMALL_STATE(5836)] = 293487,
  [SMALL_STATE(5837)] = 293514,
  [SMALL_STATE(5838)] = 293541,
  [SMALL_STATE(5839)] = 293568,
  [SMALL_STATE(5840)] = 293595,
  [SMALL_STATE(5841)] = 293622,
  [SMALL_STATE(5842)] = 293649,
  [SMALL_STATE(5843)] = 293676,
  [SMALL_STATE(5844)] = 293703,
  [SMALL_STATE(5845)] = 293730,
  [SMALL_STATE(5846)] = 293757,
  [SMALL_STATE(5847)] = 293784,
  [SMALL_STATE(5848)] = 293811,
  [SMALL_STATE(5849)] = 293838,
  [SMALL_STATE(5850)] = 293865,
  [SMALL_STATE(5851)] = 293892,
  [SMALL_STATE(5852)] = 293919,
  [SMALL_STATE(5853)] = 293946,
  [SMALL_STATE(5854)] = 293973,
  [SMALL_STATE(5855)] = 294002,
  [SMALL_STATE(5856)] = 294029,
  [SMALL_STATE(5857)] = 294056,
  [SMALL_STATE(5858)] = 294083,
  [SMALL_STATE(5859)] = 294110,
  [SMALL_STATE(5860)] = 294137,
  [SMALL_STATE(5861)] = 294164,
  [SMALL_STATE(5862)] = 294191,
  [SMALL_STATE(5863)] = 294218,
  [SMALL_STATE(5864)] = 294245,
  [SMALL_STATE(5865)] = 294272,
  [SMALL_STATE(5866)] = 294299,
  [SMALL_STATE(5867)] = 294326,
  [SMALL_STATE(5868)] = 294353,
  [SMALL_STATE(5869)] = 294380,
  [SMALL_STATE(5870)] = 294407,
  [SMALL_STATE(5871)] = 294434,
  [SMALL_STATE(5872)] = 294461,
  [SMALL_STATE(5873)] = 294488,
  [SMALL_STATE(5874)] = 294515,
  [SMALL_STATE(5875)] = 294542,
  [SMALL_STATE(5876)] = 294569,
  [SMALL_STATE(5877)] = 294596,
  [SMALL_STATE(5878)] = 294623,
  [SMALL_STATE(5879)] = 294650,
  [SMALL_STATE(5880)] = 294677,
  [SMALL_STATE(5881)] = 294704,
  [SMALL_STATE(5882)] = 294731,
  [SMALL_STATE(5883)] = 294758,
  [SMALL_STATE(5884)] = 294785,
  [SMALL_STATE(5885)] = 294812,
  [SMALL_STATE(5886)] = 294839,
  [SMALL_STATE(5887)] = 294866,
  [SMALL_STATE(5888)] = 294893,
  [SMALL_STATE(5889)] = 294920,
  [SMALL_STATE(5890)] = 294947,
  [SMALL_STATE(5891)] = 294974,
  [SMALL_STATE(5892)] = 295001,
  [SMALL_STATE(5893)] = 295028,
  [SMALL_STATE(5894)] = 295055,
  [SMALL_STATE(5895)] = 295082,
  [SMALL_STATE(5896)] = 295109,
  [SMALL_STATE(5897)] = 295136,
  [SMALL_STATE(5898)] = 295163,
  [SMALL_STATE(5899)] = 295190,
  [SMALL_STATE(5900)] = 295217,
  [SMALL_STATE(5901)] = 295244,
  [SMALL_STATE(5902)] = 295271,
  [SMALL_STATE(5903)] = 295298,
  [SMALL_STATE(5904)] = 295327,
  [SMALL_STATE(5905)] = 295354,
  [SMALL_STATE(5906)] = 295381,
  [SMALL_STATE(5907)] = 295408,
  [SMALL_STATE(5908)] = 295435,
  [SMALL_STATE(5909)] = 295462,
  [SMALL_STATE(5910)] = 295489,
  [SMALL_STATE(5911)] = 295516,
  [SMALL_STATE(5912)] = 295543,
  [SMALL_STATE(5913)] = 295570,
  [SMALL_STATE(5914)] = 295597,
  [SMALL_STATE(5915)] = 295624,
  [SMALL_STATE(5916)] = 295651,
  [SMALL_STATE(5917)] = 295678,
  [SMALL_STATE(5918)] = 295705,
  [SMALL_STATE(5919)] = 295732,
  [SMALL_STATE(5920)] = 295759,
  [SMALL_STATE(5921)] = 295786,
  [SMALL_STATE(5922)] = 295813,
  [SMALL_STATE(5923)] = 295840,
  [SMALL_STATE(5924)] = 295867,
  [SMALL_STATE(5925)] = 295894,
  [SMALL_STATE(5926)] = 295921,
  [SMALL_STATE(5927)] = 295948,
  [SMALL_STATE(5928)] = 295975,
  [SMALL_STATE(5929)] = 296002,
  [SMALL_STATE(5930)] = 296029,
  [SMALL_STATE(5931)] = 296056,
  [SMALL_STATE(5932)] = 296083,
  [SMALL_STATE(5933)] = 296110,
  [SMALL_STATE(5934)] = 296139,
  [SMALL_STATE(5935)] = 296166,
  [SMALL_STATE(5936)] = 296193,
  [SMALL_STATE(5937)] = 296220,
  [SMALL_STATE(5938)] = 296247,
  [SMALL_STATE(5939)] = 296274,
  [SMALL_STATE(5940)] = 296301,
  [SMALL_STATE(5941)] = 296328,
  [SMALL_STATE(5942)] = 296355,
  [SMALL_STATE(5943)] = 296382,
  [SMALL_STATE(5944)] = 296409,
  [SMALL_STATE(5945)] = 296436,
  [SMALL_STATE(5946)] = 296463,
  [SMALL_STATE(5947)] = 296490,
  [SMALL_STATE(5948)] = 296517,
  [SMALL_STATE(5949)] = 296544,
  [SMALL_STATE(5950)] = 296571,
  [SMALL_STATE(5951)] = 296598,
  [SMALL_STATE(5952)] = 296625,
  [SMALL_STATE(5953)] = 296652,
  [SMALL_STATE(5954)] = 296679,
  [SMALL_STATE(5955)] = 296706,
  [SMALL_STATE(5956)] = 296733,
  [SMALL_STATE(5957)] = 296760,
  [SMALL_STATE(5958)] = 296787,
  [SMALL_STATE(5959)] = 296814,
  [SMALL_STATE(5960)] = 296841,
  [SMALL_STATE(5961)] = 296868,
  [SMALL_STATE(5962)] = 296895,
  [SMALL_STATE(5963)] = 296922,
  [SMALL_STATE(5964)] = 296949,
  [SMALL_STATE(5965)] = 296978,
  [SMALL_STATE(5966)] = 297005,
  [SMALL_STATE(5967)] = 297032,
  [SMALL_STATE(5968)] = 297059,
  [SMALL_STATE(5969)] = 297086,
  [SMALL_STATE(5970)] = 297113,
  [SMALL_STATE(5971)] = 297140,
  [SMALL_STATE(5972)] = 297167,
  [SMALL_STATE(5973)] = 297194,
  [SMALL_STATE(5974)] = 297221,
  [SMALL_STATE(5975)] = 297248,
  [SMALL_STATE(5976)] = 297275,
  [SMALL_STATE(5977)] = 297302,
  [SMALL_STATE(5978)] = 297329,
  [SMALL_STATE(5979)] = 297356,
  [SMALL_STATE(5980)] = 297383,
  [SMALL_STATE(5981)] = 297412,
  [SMALL_STATE(5982)] = 297439,
  [SMALL_STATE(5983)] = 297466,
  [SMALL_STATE(5984)] = 297493,
  [SMALL_STATE(5985)] = 297520,
  [SMALL_STATE(5986)] = 297547,
  [SMALL_STATE(5987)] = 297574,
  [SMALL_STATE(5988)] = 297601,
  [SMALL_STATE(5989)] = 297628,
  [SMALL_STATE(5990)] = 297655,
  [SMALL_STATE(5991)] = 297682,
  [SMALL_STATE(5992)] = 297709,
  [SMALL_STATE(5993)] = 297736,
  [SMALL_STATE(5994)] = 297763,
  [SMALL_STATE(5995)] = 297790,
  [SMALL_STATE(5996)] = 297817,
  [SMALL_STATE(5997)] = 297844,
  [SMALL_STATE(5998)] = 297871,
  [SMALL_STATE(5999)] = 297898,
  [SMALL_STATE(6000)] = 297925,
  [SMALL_STATE(6001)] = 297951,
  [SMALL_STATE(6002)] = 297977,
  [SMALL_STATE(6003)] = 298003,
  [SMALL_STATE(6004)] = 298029,
  [SMALL_STATE(6005)] = 298049,
  [SMALL_STATE(6006)] = 298069,
  [SMALL_STATE(6007)] = 298095,
  [SMALL_STATE(6008)] = 298121,
  [SMALL_STATE(6009)] = 298147,
  [SMALL_STATE(6010)] = 298173,
  [SMALL_STATE(6011)] = 298197,
  [SMALL_STATE(6012)] = 298223,
  [SMALL_STATE(6013)] = 298246,
  [SMALL_STATE(6014)] = 298277,
  [SMALL_STATE(6015)] = 298300,
  [SMALL_STATE(6016)] = 298319,
  [SMALL_STATE(6017)] = 298340,
  [SMALL_STATE(6018)] = 298363,
  [SMALL_STATE(6019)] = 298386,
  [SMALL_STATE(6020)] = 298407,
  [SMALL_STATE(6021)] = 298430,
  [SMALL_STATE(6022)] = 298453,
  [SMALL_STATE(6023)] = 298476,
  [SMALL_STATE(6024)] = 298507,
  [SMALL_STATE(6025)] = 298528,
  [SMALL_STATE(6026)] = 298551,
  [SMALL_STATE(6027)] = 298574,
  [SMALL_STATE(6028)] = 298597,
  [SMALL_STATE(6029)] = 298618,
  [SMALL_STATE(6030)] = 298641,
  [SMALL_STATE(6031)] = 298662,
  [SMALL_STATE(6032)] = 298693,
  [SMALL_STATE(6033)] = 298714,
  [SMALL_STATE(6034)] = 298737,
  [SMALL_STATE(6035)] = 298760,
  [SMALL_STATE(6036)] = 298783,
  [SMALL_STATE(6037)] = 298806,
  [SMALL_STATE(6038)] = 298829,
  [SMALL_STATE(6039)] = 298852,
  [SMALL_STATE(6040)] = 298875,
  [SMALL_STATE(6041)] = 298898,
  [SMALL_STATE(6042)] = 298919,
  [SMALL_STATE(6043)] = 298942,
  [SMALL_STATE(6044)] = 298965,
  [SMALL_STATE(6045)] = 298988,
  [SMALL_STATE(6046)] = 299009,
  [SMALL_STATE(6047)] = 299032,
  [SMALL_STATE(6048)] = 299055,
  [SMALL_STATE(6049)] = 299078,
  [SMALL_STATE(6050)] = 299101,
  [SMALL_STATE(6051)] = 299122,
  [SMALL_STATE(6052)] = 299145,
  [SMALL_STATE(6053)] = 299173,
  [SMALL_STATE(6054)] = 299201,
  [SMALL_STATE(6055)] = 299229,
  [SMALL_STATE(6056)] = 299247,
  [SMALL_STATE(6057)] = 299265,
  [SMALL_STATE(6058)] = 299293,
  [SMALL_STATE(6059)] = 299321,
  [SMALL_STATE(6060)] = 299349,
  [SMALL_STATE(6061)] = 299367,
  [SMALL_STATE(6062)] = 299395,
  [SMALL_STATE(6063)] = 299423,
  [SMALL_STATE(6064)] = 299441,
  [SMALL_STATE(6065)] = 299469,
  [SMALL_STATE(6066)] = 299497,
  [SMALL_STATE(6067)] = 299525,
  [SMALL_STATE(6068)] = 299553,
  [SMALL_STATE(6069)] = 299581,
  [SMALL_STATE(6070)] = 299599,
  [SMALL_STATE(6071)] = 299617,
  [SMALL_STATE(6072)] = 299645,
  [SMALL_STATE(6073)] = 299673,
  [SMALL_STATE(6074)] = 299701,
  [SMALL_STATE(6075)] = 299729,
  [SMALL_STATE(6076)] = 299747,
  [SMALL_STATE(6077)] = 299775,
  [SMALL_STATE(6078)] = 299793,
  [SMALL_STATE(6079)] = 299821,
  [SMALL_STATE(6080)] = 299849,
  [SMALL_STATE(6081)] = 299867,
  [SMALL_STATE(6082)] = 299895,
  [SMALL_STATE(6083)] = 299913,
  [SMALL_STATE(6084)] = 299931,
  [SMALL_STATE(6085)] = 299959,
  [SMALL_STATE(6086)] = 299975,
  [SMALL_STATE(6087)] = 300003,
  [SMALL_STATE(6088)] = 300031,
  [SMALL_STATE(6089)] = 300059,
  [SMALL_STATE(6090)] = 300074,
  [SMALL_STATE(6091)] = 300097,
  [SMALL_STATE(6092)] = 300128,
  [SMALL_STATE(6093)] = 300143,
  [SMALL_STATE(6094)] = 300167,
  [SMALL_STATE(6095)] = 300193,
  [SMALL_STATE(6096)] = 300217,
  [SMALL_STATE(6097)] = 300241,
  [SMALL_STATE(6098)] = 300267,
  [SMALL_STATE(6099)] = 300289,
  [SMALL_STATE(6100)] = 300311,
  [SMALL_STATE(6101)] = 300337,
  [SMALL_STATE(6102)] = 300359,
  [SMALL_STATE(6103)] = 300383,
  [SMALL_STATE(6104)] = 300407,
  [SMALL_STATE(6105)] = 300431,
  [SMALL_STATE(6106)] = 300455,
  [SMALL_STATE(6107)] = 300479,
  [SMALL_STATE(6108)] = 300503,
  [SMALL_STATE(6109)] = 300527,
  [SMALL_STATE(6110)] = 300540,
  [SMALL_STATE(6111)] = 300555,
  [SMALL_STATE(6112)] = 300570,
  [SMALL_STATE(6113)] = 300591,
  [SMALL_STATE(6114)] = 300606,
  [SMALL_STATE(6115)] = 300619,
  [SMALL_STATE(6116)] = 300632,
  [SMALL_STATE(6117)] = 300645,
  [SMALL_STATE(6118)] = 300666,
  [SMALL_STATE(6119)] = 300681,
  [SMALL_STATE(6120)] = 300696,
  [SMALL_STATE(6121)] = 300711,
  [SMALL_STATE(6122)] = 300730,
  [SMALL_STATE(6123)] = 300745,
  [SMALL_STATE(6124)] = 300760,
  [SMALL_STATE(6125)] = 300775,
  [SMALL_STATE(6126)] = 300790,
  [SMALL_STATE(6127)] = 300805,
  [SMALL_STATE(6128)] = 300820,
  [SMALL_STATE(6129)] = 300835,
  [SMALL_STATE(6130)] = 300848,
  [SMALL_STATE(6131)] = 300861,
  [SMALL_STATE(6132)] = 300876,
  [SMALL_STATE(6133)] = 300891,
  [SMALL_STATE(6134)] = 300912,
  [SMALL_STATE(6135)] = 300927,
  [SMALL_STATE(6136)] = 300944,
  [SMALL_STATE(6137)] = 300965,
  [SMALL_STATE(6138)] = 300980,
  [SMALL_STATE(6139)] = 300995,
  [SMALL_STATE(6140)] = 301008,
  [SMALL_STATE(6141)] = 301021,
  [SMALL_STATE(6142)] = 301036,
  [SMALL_STATE(6143)] = 301051,
  [SMALL_STATE(6144)] = 301066,
  [SMALL_STATE(6145)] = 301081,
  [SMALL_STATE(6146)] = 301096,
  [SMALL_STATE(6147)] = 301111,
  [SMALL_STATE(6148)] = 301128,
  [SMALL_STATE(6149)] = 301143,
  [SMALL_STATE(6150)] = 301158,
  [SMALL_STATE(6151)] = 301173,
  [SMALL_STATE(6152)] = 301186,
  [SMALL_STATE(6153)] = 301206,
  [SMALL_STATE(6154)] = 301226,
  [SMALL_STATE(6155)] = 301246,
  [SMALL_STATE(6156)] = 301266,
  [SMALL_STATE(6157)] = 301286,
  [SMALL_STATE(6158)] = 301300,
  [SMALL_STATE(6159)] = 301320,
  [SMALL_STATE(6160)] = 301334,
  [SMALL_STATE(6161)] = 301354,
  [SMALL_STATE(6162)] = 301368,
  [SMALL_STATE(6163)] = 301388,
  [SMALL_STATE(6164)] = 301408,
  [SMALL_STATE(6165)] = 301428,
  [SMALL_STATE(6166)] = 301442,
  [SMALL_STATE(6167)] = 301462,
  [SMALL_STATE(6168)] = 301482,
  [SMALL_STATE(6169)] = 301502,
  [SMALL_STATE(6170)] = 301522,
  [SMALL_STATE(6171)] = 301542,
  [SMALL_STATE(6172)] = 301556,
  [SMALL_STATE(6173)] = 301576,
  [SMALL_STATE(6174)] = 301590,
  [SMALL_STATE(6175)] = 301604,
  [SMALL_STATE(6176)] = 301618,
  [SMALL_STATE(6177)] = 301640,
  [SMALL_STATE(6178)] = 301660,
  [SMALL_STATE(6179)] = 301680,
  [SMALL_STATE(6180)] = 301700,
  [SMALL_STATE(6181)] = 301720,
  [SMALL_STATE(6182)] = 301740,
  [SMALL_STATE(6183)] = 301760,
  [SMALL_STATE(6184)] = 301780,
  [SMALL_STATE(6185)] = 301800,
  [SMALL_STATE(6186)] = 301820,
  [SMALL_STATE(6187)] = 301840,
  [SMALL_STATE(6188)] = 301860,
  [SMALL_STATE(6189)] = 301880,
  [SMALL_STATE(6190)] = 301900,
  [SMALL_STATE(6191)] = 301920,
  [SMALL_STATE(6192)] = 301934,
  [SMALL_STATE(6193)] = 301954,
  [SMALL_STATE(6194)] = 301974,
  [SMALL_STATE(6195)] = 301996,
  [SMALL_STATE(6196)] = 302016,
  [SMALL_STATE(6197)] = 302036,
  [SMALL_STATE(6198)] = 302056,
  [SMALL_STATE(6199)] = 302072,
  [SMALL_STATE(6200)] = 302092,
  [SMALL_STATE(6201)] = 302112,
  [SMALL_STATE(6202)] = 302132,
  [SMALL_STATE(6203)] = 302152,
  [SMALL_STATE(6204)] = 302172,
  [SMALL_STATE(6205)] = 302192,
  [SMALL_STATE(6206)] = 302206,
  [SMALL_STATE(6207)] = 302226,
  [SMALL_STATE(6208)] = 302246,
  [SMALL_STATE(6209)] = 302260,
  [SMALL_STATE(6210)] = 302280,
  [SMALL_STATE(6211)] = 302300,
  [SMALL_STATE(6212)] = 302320,
  [SMALL_STATE(6213)] = 302340,
  [SMALL_STATE(6214)] = 302360,
  [SMALL_STATE(6215)] = 302380,
  [SMALL_STATE(6216)] = 302400,
  [SMALL_STATE(6217)] = 302414,
  [SMALL_STATE(6218)] = 302434,
  [SMALL_STATE(6219)] = 302456,
  [SMALL_STATE(6220)] = 302476,
  [SMALL_STATE(6221)] = 302496,
  [SMALL_STATE(6222)] = 302516,
  [SMALL_STATE(6223)] = 302536,
  [SMALL_STATE(6224)] = 302556,
  [SMALL_STATE(6225)] = 302576,
  [SMALL_STATE(6226)] = 302590,
  [SMALL_STATE(6227)] = 302610,
  [SMALL_STATE(6228)] = 302630,
  [SMALL_STATE(6229)] = 302650,
  [SMALL_STATE(6230)] = 302670,
  [SMALL_STATE(6231)] = 302690,
  [SMALL_STATE(6232)] = 302710,
  [SMALL_STATE(6233)] = 302730,
  [SMALL_STATE(6234)] = 302744,
  [SMALL_STATE(6235)] = 302764,
  [SMALL_STATE(6236)] = 302784,
  [SMALL_STATE(6237)] = 302804,
  [SMALL_STATE(6238)] = 302824,
  [SMALL_STATE(6239)] = 302844,
  [SMALL_STATE(6240)] = 302858,
  [SMALL_STATE(6241)] = 302878,
  [SMALL_STATE(6242)] = 302898,
  [SMALL_STATE(6243)] = 302918,
  [SMALL_STATE(6244)] = 302938,
  [SMALL_STATE(6245)] = 302958,
  [SMALL_STATE(6246)] = 302972,
  [SMALL_STATE(6247)] = 302992,
  [SMALL_STATE(6248)] = 303012,
  [SMALL_STATE(6249)] = 303032,
  [SMALL_STATE(6250)] = 303046,
  [SMALL_STATE(6251)] = 303066,
  [SMALL_STATE(6252)] = 303086,
  [SMALL_STATE(6253)] = 303106,
  [SMALL_STATE(6254)] = 303120,
  [SMALL_STATE(6255)] = 303140,
  [SMALL_STATE(6256)] = 303160,
  [SMALL_STATE(6257)] = 303174,
  [SMALL_STATE(6258)] = 303194,
  [SMALL_STATE(6259)] = 303214,
  [SMALL_STATE(6260)] = 303234,
  [SMALL_STATE(6261)] = 303254,
  [SMALL_STATE(6262)] = 303276,
  [SMALL_STATE(6263)] = 303296,
  [SMALL_STATE(6264)] = 303316,
  [SMALL_STATE(6265)] = 303336,
  [SMALL_STATE(6266)] = 303350,
  [SMALL_STATE(6267)] = 303370,
  [SMALL_STATE(6268)] = 303390,
  [SMALL_STATE(6269)] = 303410,
  [SMALL_STATE(6270)] = 303430,
  [SMALL_STATE(6271)] = 303450,
  [SMALL_STATE(6272)] = 303470,
  [SMALL_STATE(6273)] = 303484,
  [SMALL_STATE(6274)] = 303504,
  [SMALL_STATE(6275)] = 303524,
  [SMALL_STATE(6276)] = 303541,
  [SMALL_STATE(6277)] = 303554,
  [SMALL_STATE(6278)] = 303569,
  [SMALL_STATE(6279)] = 303588,
  [SMALL_STATE(6280)] = 303605,
  [SMALL_STATE(6281)] = 303622,
  [SMALL_STATE(6282)] = 303639,
  [SMALL_STATE(6283)] = 303658,
  [SMALL_STATE(6284)] = 303677,
  [SMALL_STATE(6285)] = 303694,
  [SMALL_STATE(6286)] = 303711,
  [SMALL_STATE(6287)] = 303730,
  [SMALL_STATE(6288)] = 303749,
  [SMALL_STATE(6289)] = 303766,
  [SMALL_STATE(6290)] = 303785,
  [SMALL_STATE(6291)] = 303804,
  [SMALL_STATE(6292)] = 303823,
  [SMALL_STATE(6293)] = 303840,
  [SMALL_STATE(6294)] = 303857,
  [SMALL_STATE(6295)] = 303872,
  [SMALL_STATE(6296)] = 303887,
  [SMALL_STATE(6297)] = 303902,
  [SMALL_STATE(6298)] = 303919,
  [SMALL_STATE(6299)] = 303938,
  [SMALL_STATE(6300)] = 303957,
  [SMALL_STATE(6301)] = 303976,
  [SMALL_STATE(6302)] = 303991,
  [SMALL_STATE(6303)] = 304008,
  [SMALL_STATE(6304)] = 304025,
  [SMALL_STATE(6305)] = 304036,
  [SMALL_STATE(6306)] = 304051,
  [SMALL_STATE(6307)] = 304064,
  [SMALL_STATE(6308)] = 304083,
  [SMALL_STATE(6309)] = 304102,
  [SMALL_STATE(6310)] = 304117,
  [SMALL_STATE(6311)] = 304134,
  [SMALL_STATE(6312)] = 304149,
  [SMALL_STATE(6313)] = 304166,
  [SMALL_STATE(6314)] = 304181,
  [SMALL_STATE(6315)] = 304196,
  [SMALL_STATE(6316)] = 304213,
  [SMALL_STATE(6317)] = 304224,
  [SMALL_STATE(6318)] = 304239,
  [SMALL_STATE(6319)] = 304254,
  [SMALL_STATE(6320)] = 304271,
  [SMALL_STATE(6321)] = 304286,
  [SMALL_STATE(6322)] = 304303,
  [SMALL_STATE(6323)] = 304320,
  [SMALL_STATE(6324)] = 304333,
  [SMALL_STATE(6325)] = 304348,
  [SMALL_STATE(6326)] = 304359,
  [SMALL_STATE(6327)] = 304378,
  [SMALL_STATE(6328)] = 304393,
  [SMALL_STATE(6329)] = 304410,
  [SMALL_STATE(6330)] = 304429,
  [SMALL_STATE(6331)] = 304446,
  [SMALL_STATE(6332)] = 304461,
  [SMALL_STATE(6333)] = 304480,
  [SMALL_STATE(6334)] = 304499,
  [SMALL_STATE(6335)] = 304512,
  [SMALL_STATE(6336)] = 304527,
  [SMALL_STATE(6337)] = 304544,
  [SMALL_STATE(6338)] = 304561,
  [SMALL_STATE(6339)] = 304580,
  [SMALL_STATE(6340)] = 304599,
  [SMALL_STATE(6341)] = 304616,
  [SMALL_STATE(6342)] = 304631,
  [SMALL_STATE(6343)] = 304650,
  [SMALL_STATE(6344)] = 304669,
  [SMALL_STATE(6345)] = 304688,
  [SMALL_STATE(6346)] = 304703,
  [SMALL_STATE(6347)] = 304722,
  [SMALL_STATE(6348)] = 304741,
  [SMALL_STATE(6349)] = 304758,
  [SMALL_STATE(6350)] = 304773,
  [SMALL_STATE(6351)] = 304790,
  [SMALL_STATE(6352)] = 304807,
  [SMALL_STATE(6353)] = 304824,
  [SMALL_STATE(6354)] = 304843,
  [SMALL_STATE(6355)] = 304862,
  [SMALL_STATE(6356)] = 304879,
  [SMALL_STATE(6357)] = 304898,
  [SMALL_STATE(6358)] = 304915,
  [SMALL_STATE(6359)] = 304934,
  [SMALL_STATE(6360)] = 304949,
  [SMALL_STATE(6361)] = 304968,
  [SMALL_STATE(6362)] = 304985,
  [SMALL_STATE(6363)] = 305002,
  [SMALL_STATE(6364)] = 305019,
  [SMALL_STATE(6365)] = 305034,
  [SMALL_STATE(6366)] = 305053,
  [SMALL_STATE(6367)] = 305072,
  [SMALL_STATE(6368)] = 305089,
  [SMALL_STATE(6369)] = 305108,
  [SMALL_STATE(6370)] = 305127,
  [SMALL_STATE(6371)] = 305146,
  [SMALL_STATE(6372)] = 305163,
  [SMALL_STATE(6373)] = 305182,
  [SMALL_STATE(6374)] = 305197,
  [SMALL_STATE(6375)] = 305210,
  [SMALL_STATE(6376)] = 305225,
  [SMALL_STATE(6377)] = 305244,
  [SMALL_STATE(6378)] = 305259,
  [SMALL_STATE(6379)] = 305276,
  [SMALL_STATE(6380)] = 305291,
  [SMALL_STATE(6381)] = 305308,
  [SMALL_STATE(6382)] = 305327,
  [SMALL_STATE(6383)] = 305342,
  [SMALL_STATE(6384)] = 305359,
  [SMALL_STATE(6385)] = 305378,
  [SMALL_STATE(6386)] = 305395,
  [SMALL_STATE(6387)] = 305412,
  [SMALL_STATE(6388)] = 305422,
  [SMALL_STATE(6389)] = 305432,
  [SMALL_STATE(6390)] = 305442,
  [SMALL_STATE(6391)] = 305452,
  [SMALL_STATE(6392)] = 305462,
  [SMALL_STATE(6393)] = 305472,
  [SMALL_STATE(6394)] = 305482,
  [SMALL_STATE(6395)] = 305496,
  [SMALL_STATE(6396)] = 305508,
  [SMALL_STATE(6397)] = 305518,
  [SMALL_STATE(6398)] = 305534,
  [SMALL_STATE(6399)] = 305550,
  [SMALL_STATE(6400)] = 305560,
  [SMALL_STATE(6401)] = 305570,
  [SMALL_STATE(6402)] = 305580,
  [SMALL_STATE(6403)] = 305590,
  [SMALL_STATE(6404)] = 305600,
  [SMALL_STATE(6405)] = 305610,
  [SMALL_STATE(6406)] = 305620,
  [SMALL_STATE(6407)] = 305630,
  [SMALL_STATE(6408)] = 305640,
  [SMALL_STATE(6409)] = 305650,
  [SMALL_STATE(6410)] = 305666,
  [SMALL_STATE(6411)] = 305676,
  [SMALL_STATE(6412)] = 305686,
  [SMALL_STATE(6413)] = 305696,
  [SMALL_STATE(6414)] = 305710,
  [SMALL_STATE(6415)] = 305724,
  [SMALL_STATE(6416)] = 305734,
  [SMALL_STATE(6417)] = 305748,
  [SMALL_STATE(6418)] = 305764,
  [SMALL_STATE(6419)] = 305774,
  [SMALL_STATE(6420)] = 305788,
  [SMALL_STATE(6421)] = 305804,
  [SMALL_STATE(6422)] = 305814,
  [SMALL_STATE(6423)] = 305824,
  [SMALL_STATE(6424)] = 305840,
  [SMALL_STATE(6425)] = 305850,
  [SMALL_STATE(6426)] = 305860,
  [SMALL_STATE(6427)] = 305870,
  [SMALL_STATE(6428)] = 305880,
  [SMALL_STATE(6429)] = 305890,
  [SMALL_STATE(6430)] = 305902,
  [SMALL_STATE(6431)] = 305912,
  [SMALL_STATE(6432)] = 305922,
  [SMALL_STATE(6433)] = 305932,
  [SMALL_STATE(6434)] = 305948,
  [SMALL_STATE(6435)] = 305958,
  [SMALL_STATE(6436)] = 305968,
  [SMALL_STATE(6437)] = 305978,
  [SMALL_STATE(6438)] = 305992,
  [SMALL_STATE(6439)] = 306002,
  [SMALL_STATE(6440)] = 306014,
  [SMALL_STATE(6441)] = 306030,
  [SMALL_STATE(6442)] = 306044,
  [SMALL_STATE(6443)] = 306058,
  [SMALL_STATE(6444)] = 306074,
  [SMALL_STATE(6445)] = 306090,
  [SMALL_STATE(6446)] = 306100,
  [SMALL_STATE(6447)] = 306110,
  [SMALL_STATE(6448)] = 306120,
  [SMALL_STATE(6449)] = 306136,
  [SMALL_STATE(6450)] = 306146,
  [SMALL_STATE(6451)] = 306159,
  [SMALL_STATE(6452)] = 306172,
  [SMALL_STATE(6453)] = 306185,
  [SMALL_STATE(6454)] = 306198,
  [SMALL_STATE(6455)] = 306211,
  [SMALL_STATE(6456)] = 306224,
  [SMALL_STATE(6457)] = 306237,
  [SMALL_STATE(6458)] = 306248,
  [SMALL_STATE(6459)] = 306261,
  [SMALL_STATE(6460)] = 306274,
  [SMALL_STATE(6461)] = 306285,
  [SMALL_STATE(6462)] = 306298,
  [SMALL_STATE(6463)] = 306311,
  [SMALL_STATE(6464)] = 306322,
  [SMALL_STATE(6465)] = 306335,
  [SMALL_STATE(6466)] = 306346,
  [SMALL_STATE(6467)] = 306359,
  [SMALL_STATE(6468)] = 306372,
  [SMALL_STATE(6469)] = 306385,
  [SMALL_STATE(6470)] = 306396,
  [SMALL_STATE(6471)] = 306407,
  [SMALL_STATE(6472)] = 306420,
  [SMALL_STATE(6473)] = 306433,
  [SMALL_STATE(6474)] = 306444,
  [SMALL_STATE(6475)] = 306455,
  [SMALL_STATE(6476)] = 306468,
  [SMALL_STATE(6477)] = 306479,
  [SMALL_STATE(6478)] = 306492,
  [SMALL_STATE(6479)] = 306505,
  [SMALL_STATE(6480)] = 306514,
  [SMALL_STATE(6481)] = 306525,
  [SMALL_STATE(6482)] = 306536,
  [SMALL_STATE(6483)] = 306549,
  [SMALL_STATE(6484)] = 306562,
  [SMALL_STATE(6485)] = 306571,
  [SMALL_STATE(6486)] = 306580,
  [SMALL_STATE(6487)] = 306591,
  [SMALL_STATE(6488)] = 306604,
  [SMALL_STATE(6489)] = 306617,
  [SMALL_STATE(6490)] = 306628,
  [SMALL_STATE(6491)] = 306641,
  [SMALL_STATE(6492)] = 306652,
  [SMALL_STATE(6493)] = 306663,
  [SMALL_STATE(6494)] = 306676,
  [SMALL_STATE(6495)] = 306689,
  [SMALL_STATE(6496)] = 306700,
  [SMALL_STATE(6497)] = 306711,
  [SMALL_STATE(6498)] = 306724,
  [SMALL_STATE(6499)] = 306737,
  [SMALL_STATE(6500)] = 306750,
  [SMALL_STATE(6501)] = 306763,
  [SMALL_STATE(6502)] = 306776,
  [SMALL_STATE(6503)] = 306789,
  [SMALL_STATE(6504)] = 306802,
  [SMALL_STATE(6505)] = 306815,
  [SMALL_STATE(6506)] = 306828,
  [SMALL_STATE(6507)] = 306841,
  [SMALL_STATE(6508)] = 306854,
  [SMALL_STATE(6509)] = 306867,
  [SMALL_STATE(6510)] = 306880,
  [SMALL_STATE(6511)] = 306893,
  [SMALL_STATE(6512)] = 306906,
  [SMALL_STATE(6513)] = 306919,
  [SMALL_STATE(6514)] = 306932,
  [SMALL_STATE(6515)] = 306945,
  [SMALL_STATE(6516)] = 306958,
  [SMALL_STATE(6517)] = 306971,
  [SMALL_STATE(6518)] = 306984,
  [SMALL_STATE(6519)] = 306997,
  [SMALL_STATE(6520)] = 307010,
  [SMALL_STATE(6521)] = 307023,
  [SMALL_STATE(6522)] = 307036,
  [SMALL_STATE(6523)] = 307049,
  [SMALL_STATE(6524)] = 307062,
  [SMALL_STATE(6525)] = 307073,
  [SMALL_STATE(6526)] = 307084,
  [SMALL_STATE(6527)] = 307097,
  [SMALL_STATE(6528)] = 307110,
  [SMALL_STATE(6529)] = 307119,
  [SMALL_STATE(6530)] = 307132,
  [SMALL_STATE(6531)] = 307145,
  [SMALL_STATE(6532)] = 307158,
  [SMALL_STATE(6533)] = 307171,
  [SMALL_STATE(6534)] = 307180,
  [SMALL_STATE(6535)] = 307193,
  [SMALL_STATE(6536)] = 307202,
  [SMALL_STATE(6537)] = 307215,
  [SMALL_STATE(6538)] = 307228,
  [SMALL_STATE(6539)] = 307239,
  [SMALL_STATE(6540)] = 307252,
  [SMALL_STATE(6541)] = 307265,
  [SMALL_STATE(6542)] = 307278,
  [SMALL_STATE(6543)] = 307291,
  [SMALL_STATE(6544)] = 307304,
  [SMALL_STATE(6545)] = 307317,
  [SMALL_STATE(6546)] = 307330,
  [SMALL_STATE(6547)] = 307343,
  [SMALL_STATE(6548)] = 307356,
  [SMALL_STATE(6549)] = 307369,
  [SMALL_STATE(6550)] = 307382,
  [SMALL_STATE(6551)] = 307395,
  [SMALL_STATE(6552)] = 307408,
  [SMALL_STATE(6553)] = 307421,
  [SMALL_STATE(6554)] = 307434,
  [SMALL_STATE(6555)] = 307447,
  [SMALL_STATE(6556)] = 307460,
  [SMALL_STATE(6557)] = 307471,
  [SMALL_STATE(6558)] = 307484,
  [SMALL_STATE(6559)] = 307497,
  [SMALL_STATE(6560)] = 307508,
  [SMALL_STATE(6561)] = 307521,
  [SMALL_STATE(6562)] = 307532,
  [SMALL_STATE(6563)] = 307545,
  [SMALL_STATE(6564)] = 307558,
  [SMALL_STATE(6565)] = 307571,
  [SMALL_STATE(6566)] = 307584,
  [SMALL_STATE(6567)] = 307597,
  [SMALL_STATE(6568)] = 307608,
  [SMALL_STATE(6569)] = 307621,
  [SMALL_STATE(6570)] = 307630,
  [SMALL_STATE(6571)] = 307639,
  [SMALL_STATE(6572)] = 307652,
  [SMALL_STATE(6573)] = 307665,
  [SMALL_STATE(6574)] = 307678,
  [SMALL_STATE(6575)] = 307687,
  [SMALL_STATE(6576)] = 307700,
  [SMALL_STATE(6577)] = 307709,
  [SMALL_STATE(6578)] = 307718,
  [SMALL_STATE(6579)] = 307731,
  [SMALL_STATE(6580)] = 307744,
  [SMALL_STATE(6581)] = 307757,
  [SMALL_STATE(6582)] = 307770,
  [SMALL_STATE(6583)] = 307783,
  [SMALL_STATE(6584)] = 307796,
  [SMALL_STATE(6585)] = 307809,
  [SMALL_STATE(6586)] = 307822,
  [SMALL_STATE(6587)] = 307835,
  [SMALL_STATE(6588)] = 307846,
  [SMALL_STATE(6589)] = 307857,
  [SMALL_STATE(6590)] = 307870,
  [SMALL_STATE(6591)] = 307881,
  [SMALL_STATE(6592)] = 307890,
  [SMALL_STATE(6593)] = 307903,
  [SMALL_STATE(6594)] = 307912,
  [SMALL_STATE(6595)] = 307921,
  [SMALL_STATE(6596)] = 307932,
  [SMALL_STATE(6597)] = 307945,
  [SMALL_STATE(6598)] = 307958,
  [SMALL_STATE(6599)] = 307971,
  [SMALL_STATE(6600)] = 307984,
  [SMALL_STATE(6601)] = 307997,
  [SMALL_STATE(6602)] = 308010,
  [SMALL_STATE(6603)] = 308023,
  [SMALL_STATE(6604)] = 308036,
  [SMALL_STATE(6605)] = 308049,
  [SMALL_STATE(6606)] = 308062,
  [SMALL_STATE(6607)] = 308075,
  [SMALL_STATE(6608)] = 308086,
  [SMALL_STATE(6609)] = 308097,
  [SMALL_STATE(6610)] = 308110,
  [SMALL_STATE(6611)] = 308121,
  [SMALL_STATE(6612)] = 308134,
  [SMALL_STATE(6613)] = 308147,
  [SMALL_STATE(6614)] = 308160,
  [SMALL_STATE(6615)] = 308173,
  [SMALL_STATE(6616)] = 308186,
  [SMALL_STATE(6617)] = 308199,
  [SMALL_STATE(6618)] = 308212,
  [SMALL_STATE(6619)] = 308225,
  [SMALL_STATE(6620)] = 308236,
  [SMALL_STATE(6621)] = 308249,
  [SMALL_STATE(6622)] = 308262,
  [SMALL_STATE(6623)] = 308275,
  [SMALL_STATE(6624)] = 308286,
  [SMALL_STATE(6625)] = 308297,
  [SMALL_STATE(6626)] = 308310,
  [SMALL_STATE(6627)] = 308323,
  [SMALL_STATE(6628)] = 308336,
  [SMALL_STATE(6629)] = 308344,
  [SMALL_STATE(6630)] = 308354,
  [SMALL_STATE(6631)] = 308364,
  [SMALL_STATE(6632)] = 308372,
  [SMALL_STATE(6633)] = 308382,
  [SMALL_STATE(6634)] = 308390,
  [SMALL_STATE(6635)] = 308398,
  [SMALL_STATE(6636)] = 308406,
  [SMALL_STATE(6637)] = 308414,
  [SMALL_STATE(6638)] = 308422,
  [SMALL_STATE(6639)] = 308432,
  [SMALL_STATE(6640)] = 308442,
  [SMALL_STATE(6641)] = 308452,
  [SMALL_STATE(6642)] = 308460,
  [SMALL_STATE(6643)] = 308468,
  [SMALL_STATE(6644)] = 308476,
  [SMALL_STATE(6645)] = 308486,
  [SMALL_STATE(6646)] = 308496,
  [SMALL_STATE(6647)] = 308504,
  [SMALL_STATE(6648)] = 308512,
  [SMALL_STATE(6649)] = 308520,
  [SMALL_STATE(6650)] = 308528,
  [SMALL_STATE(6651)] = 308536,
  [SMALL_STATE(6652)] = 308544,
  [SMALL_STATE(6653)] = 308552,
  [SMALL_STATE(6654)] = 308562,
  [SMALL_STATE(6655)] = 308572,
  [SMALL_STATE(6656)] = 308580,
  [SMALL_STATE(6657)] = 308588,
  [SMALL_STATE(6658)] = 308596,
  [SMALL_STATE(6659)] = 308606,
  [SMALL_STATE(6660)] = 308614,
  [SMALL_STATE(6661)] = 308622,
  [SMALL_STATE(6662)] = 308632,
  [SMALL_STATE(6663)] = 308640,
  [SMALL_STATE(6664)] = 308650,
  [SMALL_STATE(6665)] = 308658,
  [SMALL_STATE(6666)] = 308668,
  [SMALL_STATE(6667)] = 308678,
  [SMALL_STATE(6668)] = 308688,
  [SMALL_STATE(6669)] = 308698,
  [SMALL_STATE(6670)] = 308706,
  [SMALL_STATE(6671)] = 308716,
  [SMALL_STATE(6672)] = 308724,
  [SMALL_STATE(6673)] = 308732,
  [SMALL_STATE(6674)] = 308740,
  [SMALL_STATE(6675)] = 308748,
  [SMALL_STATE(6676)] = 308756,
  [SMALL_STATE(6677)] = 308766,
  [SMALL_STATE(6678)] = 308776,
  [SMALL_STATE(6679)] = 308784,
  [SMALL_STATE(6680)] = 308792,
  [SMALL_STATE(6681)] = 308802,
  [SMALL_STATE(6682)] = 308810,
  [SMALL_STATE(6683)] = 308820,
  [SMALL_STATE(6684)] = 308830,
  [SMALL_STATE(6685)] = 308840,
  [SMALL_STATE(6686)] = 308848,
  [SMALL_STATE(6687)] = 308856,
  [SMALL_STATE(6688)] = 308866,
  [SMALL_STATE(6689)] = 308874,
  [SMALL_STATE(6690)] = 308884,
  [SMALL_STATE(6691)] = 308894,
  [SMALL_STATE(6692)] = 308902,
  [SMALL_STATE(6693)] = 308910,
  [SMALL_STATE(6694)] = 308918,
  [SMALL_STATE(6695)] = 308928,
  [SMALL_STATE(6696)] = 308936,
  [SMALL_STATE(6697)] = 308946,
  [SMALL_STATE(6698)] = 308954,
  [SMALL_STATE(6699)] = 308964,
  [SMALL_STATE(6700)] = 308972,
  [SMALL_STATE(6701)] = 308982,
  [SMALL_STATE(6702)] = 308990,
  [SMALL_STATE(6703)] = 308998,
  [SMALL_STATE(6704)] = 309006,
  [SMALL_STATE(6705)] = 309013,
  [SMALL_STATE(6706)] = 309020,
  [SMALL_STATE(6707)] = 309027,
  [SMALL_STATE(6708)] = 309034,
  [SMALL_STATE(6709)] = 309041,
  [SMALL_STATE(6710)] = 309048,
  [SMALL_STATE(6711)] = 309055,
  [SMALL_STATE(6712)] = 309062,
  [SMALL_STATE(6713)] = 309069,
  [SMALL_STATE(6714)] = 309076,
  [SMALL_STATE(6715)] = 309083,
  [SMALL_STATE(6716)] = 309090,
  [SMALL_STATE(6717)] = 309097,
  [SMALL_STATE(6718)] = 309104,
  [SMALL_STATE(6719)] = 309111,
  [SMALL_STATE(6720)] = 309118,
  [SMALL_STATE(6721)] = 309125,
  [SMALL_STATE(6722)] = 309132,
  [SMALL_STATE(6723)] = 309139,
  [SMALL_STATE(6724)] = 309146,
  [SMALL_STATE(6725)] = 309153,
  [SMALL_STATE(6726)] = 309160,
  [SMALL_STATE(6727)] = 309167,
  [SMALL_STATE(6728)] = 309174,
  [SMALL_STATE(6729)] = 309181,
  [SMALL_STATE(6730)] = 309188,
  [SMALL_STATE(6731)] = 309195,
  [SMALL_STATE(6732)] = 309202,
  [SMALL_STATE(6733)] = 309209,
  [SMALL_STATE(6734)] = 309216,
  [SMALL_STATE(6735)] = 309223,
  [SMALL_STATE(6736)] = 309230,
  [SMALL_STATE(6737)] = 309237,
  [SMALL_STATE(6738)] = 309244,
  [SMALL_STATE(6739)] = 309251,
  [SMALL_STATE(6740)] = 309258,
  [SMALL_STATE(6741)] = 309265,
  [SMALL_STATE(6742)] = 309272,
  [SMALL_STATE(6743)] = 309279,
  [SMALL_STATE(6744)] = 309286,
  [SMALL_STATE(6745)] = 309293,
  [SMALL_STATE(6746)] = 309300,
  [SMALL_STATE(6747)] = 309307,
  [SMALL_STATE(6748)] = 309314,
  [SMALL_STATE(6749)] = 309321,
  [SMALL_STATE(6750)] = 309328,
  [SMALL_STATE(6751)] = 309335,
  [SMALL_STATE(6752)] = 309342,
  [SMALL_STATE(6753)] = 309349,
  [SMALL_STATE(6754)] = 309356,
  [SMALL_STATE(6755)] = 309363,
  [SMALL_STATE(6756)] = 309370,
  [SMALL_STATE(6757)] = 309377,
  [SMALL_STATE(6758)] = 309384,
  [SMALL_STATE(6759)] = 309391,
  [SMALL_STATE(6760)] = 309398,
  [SMALL_STATE(6761)] = 309405,
  [SMALL_STATE(6762)] = 309412,
  [SMALL_STATE(6763)] = 309419,
  [SMALL_STATE(6764)] = 309426,
  [SMALL_STATE(6765)] = 309433,
  [SMALL_STATE(6766)] = 309440,
  [SMALL_STATE(6767)] = 309447,
  [SMALL_STATE(6768)] = 309454,
  [SMALL_STATE(6769)] = 309461,
  [SMALL_STATE(6770)] = 309468,
  [SMALL_STATE(6771)] = 309475,
  [SMALL_STATE(6772)] = 309482,
  [SMALL_STATE(6773)] = 309489,
  [SMALL_STATE(6774)] = 309496,
  [SMALL_STATE(6775)] = 309503,
  [SMALL_STATE(6776)] = 309510,
  [SMALL_STATE(6777)] = 309517,
  [SMALL_STATE(6778)] = 309524,
  [SMALL_STATE(6779)] = 309531,
  [SMALL_STATE(6780)] = 309538,
  [SMALL_STATE(6781)] = 309545,
  [SMALL_STATE(6782)] = 309552,
  [SMALL_STATE(6783)] = 309559,
  [SMALL_STATE(6784)] = 309566,
  [SMALL_STATE(6785)] = 309573,
  [SMALL_STATE(6786)] = 309580,
  [SMALL_STATE(6787)] = 309587,
  [SMALL_STATE(6788)] = 309594,
  [SMALL_STATE(6789)] = 309601,
  [SMALL_STATE(6790)] = 309608,
  [SMALL_STATE(6791)] = 309615,
  [SMALL_STATE(6792)] = 309622,
  [SMALL_STATE(6793)] = 309629,
  [SMALL_STATE(6794)] = 309636,
  [SMALL_STATE(6795)] = 309643,
  [SMALL_STATE(6796)] = 309650,
  [SMALL_STATE(6797)] = 309657,
  [SMALL_STATE(6798)] = 309664,
  [SMALL_STATE(6799)] = 309671,
  [SMALL_STATE(6800)] = 309678,
  [SMALL_STATE(6801)] = 309685,
  [SMALL_STATE(6802)] = 309692,
  [SMALL_STATE(6803)] = 309699,
  [SMALL_STATE(6804)] = 309706,
  [SMALL_STATE(6805)] = 309713,
  [SMALL_STATE(6806)] = 309720,
  [SMALL_STATE(6807)] = 309727,
  [SMALL_STATE(6808)] = 309734,
  [SMALL_STATE(6809)] = 309741,
  [SMALL_STATE(6810)] = 309748,
  [SMALL_STATE(6811)] = 309755,
  [SMALL_STATE(6812)] = 309762,
  [SMALL_STATE(6813)] = 309769,
  [SMALL_STATE(6814)] = 309776,
  [SMALL_STATE(6815)] = 309783,
  [SMALL_STATE(6816)] = 309790,
  [SMALL_STATE(6817)] = 309797,
  [SMALL_STATE(6818)] = 309804,
  [SMALL_STATE(6819)] = 309811,
  [SMALL_STATE(6820)] = 309818,
  [SMALL_STATE(6821)] = 309825,
  [SMALL_STATE(6822)] = 309832,
  [SMALL_STATE(6823)] = 309839,
  [SMALL_STATE(6824)] = 309846,
  [SMALL_STATE(6825)] = 309853,
  [SMALL_STATE(6826)] = 309860,
  [SMALL_STATE(6827)] = 309867,
  [SMALL_STATE(6828)] = 309874,
  [SMALL_STATE(6829)] = 309881,
  [SMALL_STATE(6830)] = 309888,
  [SMALL_STATE(6831)] = 309895,
  [SMALL_STATE(6832)] = 309902,
  [SMALL_STATE(6833)] = 309909,
  [SMALL_STATE(6834)] = 309916,
  [SMALL_STATE(6835)] = 309923,
  [SMALL_STATE(6836)] = 309930,
  [SMALL_STATE(6837)] = 309937,
  [SMALL_STATE(6838)] = 309944,
  [SMALL_STATE(6839)] = 309951,
  [SMALL_STATE(6840)] = 309958,
  [SMALL_STATE(6841)] = 309965,
  [SMALL_STATE(6842)] = 309972,
  [SMALL_STATE(6843)] = 309979,
  [SMALL_STATE(6844)] = 309986,
  [SMALL_STATE(6845)] = 309993,
  [SMALL_STATE(6846)] = 310000,
  [SMALL_STATE(6847)] = 310007,
  [SMALL_STATE(6848)] = 310014,
  [SMALL_STATE(6849)] = 310021,
  [SMALL_STATE(6850)] = 310028,
  [SMALL_STATE(6851)] = 310035,
  [SMALL_STATE(6852)] = 310042,
  [SMALL_STATE(6853)] = 310049,
  [SMALL_STATE(6854)] = 310056,
  [SMALL_STATE(6855)] = 310063,
  [SMALL_STATE(6856)] = 310070,
  [SMALL_STATE(6857)] = 310077,
  [SMALL_STATE(6858)] = 310084,
  [SMALL_STATE(6859)] = 310091,
  [SMALL_STATE(6860)] = 310098,
  [SMALL_STATE(6861)] = 310105,
  [SMALL_STATE(6862)] = 310112,
  [SMALL_STATE(6863)] = 310119,
  [SMALL_STATE(6864)] = 310126,
  [SMALL_STATE(6865)] = 310133,
  [SMALL_STATE(6866)] = 310140,
  [SMALL_STATE(6867)] = 310147,
  [SMALL_STATE(6868)] = 310154,
  [SMALL_STATE(6869)] = 310161,
  [SMALL_STATE(6870)] = 310168,
  [SMALL_STATE(6871)] = 310175,
  [SMALL_STATE(6872)] = 310182,
  [SMALL_STATE(6873)] = 310189,
  [SMALL_STATE(6874)] = 310196,
  [SMALL_STATE(6875)] = 310203,
  [SMALL_STATE(6876)] = 310210,
  [SMALL_STATE(6877)] = 310217,
  [SMALL_STATE(6878)] = 310224,
  [SMALL_STATE(6879)] = 310231,
  [SMALL_STATE(6880)] = 310238,
  [SMALL_STATE(6881)] = 310245,
  [SMALL_STATE(6882)] = 310252,
  [SMALL_STATE(6883)] = 310259,
  [SMALL_STATE(6884)] = 310266,
  [SMALL_STATE(6885)] = 310273,
  [SMALL_STATE(6886)] = 310280,
  [SMALL_STATE(6887)] = 310287,
  [SMALL_STATE(6888)] = 310294,
  [SMALL_STATE(6889)] = 310301,
  [SMALL_STATE(6890)] = 310308,
  [SMALL_STATE(6891)] = 310315,
  [SMALL_STATE(6892)] = 310322,
  [SMALL_STATE(6893)] = 310329,
  [SMALL_STATE(6894)] = 310336,
  [SMALL_STATE(6895)] = 310343,
  [SMALL_STATE(6896)] = 310350,
  [SMALL_STATE(6897)] = 310357,
  [SMALL_STATE(6898)] = 310364,
  [SMALL_STATE(6899)] = 310371,
  [SMALL_STATE(6900)] = 310378,
  [SMALL_STATE(6901)] = 310385,
  [SMALL_STATE(6902)] = 310392,
  [SMALL_STATE(6903)] = 310399,
  [SMALL_STATE(6904)] = 310406,
  [SMALL_STATE(6905)] = 310413,
  [SMALL_STATE(6906)] = 310420,
  [SMALL_STATE(6907)] = 310427,
  [SMALL_STATE(6908)] = 310434,
  [SMALL_STATE(6909)] = 310441,
  [SMALL_STATE(6910)] = 310448,
  [SMALL_STATE(6911)] = 310455,
  [SMALL_STATE(6912)] = 310462,
  [SMALL_STATE(6913)] = 310469,
  [SMALL_STATE(6914)] = 310476,
  [SMALL_STATE(6915)] = 310483,
  [SMALL_STATE(6916)] = 310490,
  [SMALL_STATE(6917)] = 310497,
  [SMALL_STATE(6918)] = 310504,
  [SMALL_STATE(6919)] = 310511,
  [SMALL_STATE(6920)] = 310518,
  [SMALL_STATE(6921)] = 310525,
  [SMALL_STATE(6922)] = 310532,
  [SMALL_STATE(6923)] = 310539,
  [SMALL_STATE(6924)] = 310546,
  [SMALL_STATE(6925)] = 310553,
  [SMALL_STATE(6926)] = 310560,
  [SMALL_STATE(6927)] = 310567,
  [SMALL_STATE(6928)] = 310574,
  [SMALL_STATE(6929)] = 310581,
  [SMALL_STATE(6930)] = 310588,
  [SMALL_STATE(6931)] = 310595,
  [SMALL_STATE(6932)] = 310602,
  [SMALL_STATE(6933)] = 310609,
  [SMALL_STATE(6934)] = 310616,
  [SMALL_STATE(6935)] = 310623,
  [SMALL_STATE(6936)] = 310630,
  [SMALL_STATE(6937)] = 310637,
  [SMALL_STATE(6938)] = 310644,
  [SMALL_STATE(6939)] = 310651,
  [SMALL_STATE(6940)] = 310658,
  [SMALL_STATE(6941)] = 310665,
  [SMALL_STATE(6942)] = 310672,
  [SMALL_STATE(6943)] = 310679,
  [SMALL_STATE(6944)] = 310686,
  [SMALL_STATE(6945)] = 310693,
  [SMALL_STATE(6946)] = 310700,
  [SMALL_STATE(6947)] = 310707,
  [SMALL_STATE(6948)] = 310714,
  [SMALL_STATE(6949)] = 310721,
  [SMALL_STATE(6950)] = 310728,
  [SMALL_STATE(6951)] = 310735,
  [SMALL_STATE(6952)] = 310742,
  [SMALL_STATE(6953)] = 310749,
  [SMALL_STATE(6954)] = 310756,
  [SMALL_STATE(6955)] = 310763,
  [SMALL_STATE(6956)] = 310770,
  [SMALL_STATE(6957)] = 310777,
  [SMALL_STATE(6958)] = 310784,
  [SMALL_STATE(6959)] = 310791,
  [SMALL_STATE(6960)] = 310798,
  [SMALL_STATE(6961)] = 310805,
  [SMALL_STATE(6962)] = 310812,
  [SMALL_STATE(6963)] = 310819,
  [SMALL_STATE(6964)] = 310826,
  [SMALL_STATE(6965)] = 310833,
  [SMALL_STATE(6966)] = 310840,
  [SMALL_STATE(6967)] = 310847,
  [SMALL_STATE(6968)] = 310854,
  [SMALL_STATE(6969)] = 310861,
  [SMALL_STATE(6970)] = 310868,
  [SMALL_STATE(6971)] = 310875,
  [SMALL_STATE(6972)] = 310882,
  [SMALL_STATE(6973)] = 310889,
  [SMALL_STATE(6974)] = 310896,
  [SMALL_STATE(6975)] = 310903,
  [SMALL_STATE(6976)] = 310910,
  [SMALL_STATE(6977)] = 310917,
  [SMALL_STATE(6978)] = 310924,
  [SMALL_STATE(6979)] = 310931,
  [SMALL_STATE(6980)] = 310938,
  [SMALL_STATE(6981)] = 310945,
  [SMALL_STATE(6982)] = 310952,
  [SMALL_STATE(6983)] = 310959,
  [SMALL_STATE(6984)] = 310966,
  [SMALL_STATE(6985)] = 310973,
  [SMALL_STATE(6986)] = 310980,
  [SMALL_STATE(6987)] = 310987,
  [SMALL_STATE(6988)] = 310994,
  [SMALL_STATE(6989)] = 311001,
  [SMALL_STATE(6990)] = 311008,
  [SMALL_STATE(6991)] = 311015,
  [SMALL_STATE(6992)] = 311022,
  [SMALL_STATE(6993)] = 311029,
  [SMALL_STATE(6994)] = 311036,
  [SMALL_STATE(6995)] = 311043,
  [SMALL_STATE(6996)] = 311050,
  [SMALL_STATE(6997)] = 311057,
  [SMALL_STATE(6998)] = 311064,
  [SMALL_STATE(6999)] = 311071,
  [SMALL_STATE(7000)] = 311078,
  [SMALL_STATE(7001)] = 311085,
  [SMALL_STATE(7002)] = 311092,
  [SMALL_STATE(7003)] = 311099,
  [SMALL_STATE(7004)] = 311106,
  [SMALL_STATE(7005)] = 311113,
  [SMALL_STATE(7006)] = 311120,
  [SMALL_STATE(7007)] = 311127,
  [SMALL_STATE(7008)] = 311134,
  [SMALL_STATE(7009)] = 311141,
  [SMALL_STATE(7010)] = 311148,
  [SMALL_STATE(7011)] = 311155,
  [SMALL_STATE(7012)] = 311162,
  [SMALL_STATE(7013)] = 311169,
  [SMALL_STATE(7014)] = 311176,
  [SMALL_STATE(7015)] = 311183,
  [SMALL_STATE(7016)] = 311190,
  [SMALL_STATE(7017)] = 311197,
  [SMALL_STATE(7018)] = 311204,
  [SMALL_STATE(7019)] = 311211,
  [SMALL_STATE(7020)] = 311218,
  [SMALL_STATE(7021)] = 311225,
  [SMALL_STATE(7022)] = 311232,
  [SMALL_STATE(7023)] = 311239,
  [SMALL_STATE(7024)] = 311246,
  [SMALL_STATE(7025)] = 311253,
  [SMALL_STATE(7026)] = 311260,
  [SMALL_STATE(7027)] = 311267,
  [SMALL_STATE(7028)] = 311274,
  [SMALL_STATE(7029)] = 311281,
  [SMALL_STATE(7030)] = 311288,
  [SMALL_STATE(7031)] = 311295,
  [SMALL_STATE(7032)] = 311302,
  [SMALL_STATE(7033)] = 311309,
  [SMALL_STATE(7034)] = 311316,
  [SMALL_STATE(7035)] = 311323,
  [SMALL_STATE(7036)] = 311330,
  [SMALL_STATE(7037)] = 311337,
  [SMALL_STATE(7038)] = 311344,
  [SMALL_STATE(7039)] = 311351,
  [SMALL_STATE(7040)] = 311358,
  [SMALL_STATE(7041)] = 311365,
  [SMALL_STATE(7042)] = 311372,
  [SMALL_STATE(7043)] = 311379,
  [SMALL_STATE(7044)] = 311386,
  [SMALL_STATE(7045)] = 311393,
  [SMALL_STATE(7046)] = 311400,
  [SMALL_STATE(7047)] = 311407,
  [SMALL_STATE(7048)] = 311414,
  [SMALL_STATE(7049)] = 311421,
  [SMALL_STATE(7050)] = 311428,
  [SMALL_STATE(7051)] = 311435,
  [SMALL_STATE(7052)] = 311442,
  [SMALL_STATE(7053)] = 311449,
  [SMALL_STATE(7054)] = 311456,
  [SMALL_STATE(7055)] = 311463,
  [SMALL_STATE(7056)] = 311470,
  [SMALL_STATE(7057)] = 311477,
  [SMALL_STATE(7058)] = 311484,
  [SMALL_STATE(7059)] = 311491,
  [SMALL_STATE(7060)] = 311498,
  [SMALL_STATE(7061)] = 311505,
  [SMALL_STATE(7062)] = 311512,
  [SMALL_STATE(7063)] = 311519,
  [SMALL_STATE(7064)] = 311526,
  [SMALL_STATE(7065)] = 311533,
  [SMALL_STATE(7066)] = 311540,
  [SMALL_STATE(7067)] = 311547,
  [SMALL_STATE(7068)] = 311554,
  [SMALL_STATE(7069)] = 311561,
  [SMALL_STATE(7070)] = 311568,
  [SMALL_STATE(7071)] = 311575,
  [SMALL_STATE(7072)] = 311582,
  [SMALL_STATE(7073)] = 311589,
  [SMALL_STATE(7074)] = 311596,
  [SMALL_STATE(7075)] = 311603,
  [SMALL_STATE(7076)] = 311610,
  [SMALL_STATE(7077)] = 311617,
  [SMALL_STATE(7078)] = 311624,
  [SMALL_STATE(7079)] = 311631,
  [SMALL_STATE(7080)] = 311638,
  [SMALL_STATE(7081)] = 311645,
  [SMALL_STATE(7082)] = 311652,
  [SMALL_STATE(7083)] = 311659,
  [SMALL_STATE(7084)] = 311666,
  [SMALL_STATE(7085)] = 311673,
  [SMALL_STATE(7086)] = 311680,
  [SMALL_STATE(7087)] = 311687,
  [SMALL_STATE(7088)] = 311694,
  [SMALL_STATE(7089)] = 311701,
  [SMALL_STATE(7090)] = 311708,
  [SMALL_STATE(7091)] = 311715,
  [SMALL_STATE(7092)] = 311722,
  [SMALL_STATE(7093)] = 311729,
  [SMALL_STATE(7094)] = 311736,
  [SMALL_STATE(7095)] = 311743,
  [SMALL_STATE(7096)] = 311750,
  [SMALL_STATE(7097)] = 311757,
  [SMALL_STATE(7098)] = 311764,
  [SMALL_STATE(7099)] = 311771,
  [SMALL_STATE(7100)] = 311778,
  [SMALL_STATE(7101)] = 311785,
  [SMALL_STATE(7102)] = 311792,
  [SMALL_STATE(7103)] = 311799,
  [SMALL_STATE(7104)] = 311806,
  [SMALL_STATE(7105)] = 311813,
  [SMALL_STATE(7106)] = 311820,
  [SMALL_STATE(7107)] = 311827,
  [SMALL_STATE(7108)] = 311834,
  [SMALL_STATE(7109)] = 311841,
  [SMALL_STATE(7110)] = 311848,
  [SMALL_STATE(7111)] = 311855,
  [SMALL_STATE(7112)] = 311862,
  [SMALL_STATE(7113)] = 311869,
  [SMALL_STATE(7114)] = 311876,
  [SMALL_STATE(7115)] = 311883,
  [SMALL_STATE(7116)] = 311890,
  [SMALL_STATE(7117)] = 311897,
  [SMALL_STATE(7118)] = 311904,
  [SMALL_STATE(7119)] = 311911,
  [SMALL_STATE(7120)] = 311918,
  [SMALL_STATE(7121)] = 311925,
  [SMALL_STATE(7122)] = 311932,
  [SMALL_STATE(7123)] = 311939,
  [SMALL_STATE(7124)] = 311946,
  [SMALL_STATE(7125)] = 311953,
  [SMALL_STATE(7126)] = 311960,
  [SMALL_STATE(7127)] = 311967,
  [SMALL_STATE(7128)] = 311974,
  [SMALL_STATE(7129)] = 311981,
  [SMALL_STATE(7130)] = 311988,
  [SMALL_STATE(7131)] = 311995,
  [SMALL_STATE(7132)] = 312002,
  [SMALL_STATE(7133)] = 312009,
  [SMALL_STATE(7134)] = 312016,
  [SMALL_STATE(7135)] = 312023,
  [SMALL_STATE(7136)] = 312030,
  [SMALL_STATE(7137)] = 312037,
  [SMALL_STATE(7138)] = 312044,
  [SMALL_STATE(7139)] = 312051,
  [SMALL_STATE(7140)] = 312058,
  [SMALL_STATE(7141)] = 312065,
  [SMALL_STATE(7142)] = 312072,
  [SMALL_STATE(7143)] = 312079,
  [SMALL_STATE(7144)] = 312086,
  [SMALL_STATE(7145)] = 312093,
  [SMALL_STATE(7146)] = 312100,
  [SMALL_STATE(7147)] = 312107,
  [SMALL_STATE(7148)] = 312114,
  [SMALL_STATE(7149)] = 312121,
  [SMALL_STATE(7150)] = 312128,
  [SMALL_STATE(7151)] = 312135,
  [SMALL_STATE(7152)] = 312142,
  [SMALL_STATE(7153)] = 312149,
  [SMALL_STATE(7154)] = 312156,
  [SMALL_STATE(7155)] = 312163,
  [SMALL_STATE(7156)] = 312170,
  [SMALL_STATE(7157)] = 312177,
  [SMALL_STATE(7158)] = 312184,
  [SMALL_STATE(7159)] = 312191,
  [SMALL_STATE(7160)] = 312198,
  [SMALL_STATE(7161)] = 312205,
  [SMALL_STATE(7162)] = 312212,
  [SMALL_STATE(7163)] = 312219,
  [SMALL_STATE(7164)] = 312226,
  [SMALL_STATE(7165)] = 312233,
  [SMALL_STATE(7166)] = 312240,
  [SMALL_STATE(7167)] = 312247,
  [SMALL_STATE(7168)] = 312254,
  [SMALL_STATE(7169)] = 312261,
  [SMALL_STATE(7170)] = 312268,
  [SMALL_STATE(7171)] = 312275,
  [SMALL_STATE(7172)] = 312282,
  [SMALL_STATE(7173)] = 312289,
  [SMALL_STATE(7174)] = 312296,
  [SMALL_STATE(7175)] = 312303,
  [SMALL_STATE(7176)] = 312310,
  [SMALL_STATE(7177)] = 312317,
  [SMALL_STATE(7178)] = 312324,
  [SMALL_STATE(7179)] = 312331,
  [SMALL_STATE(7180)] = 312338,
  [SMALL_STATE(7181)] = 312345,
  [SMALL_STATE(7182)] = 312352,
  [SMALL_STATE(7183)] = 312359,
  [SMALL_STATE(7184)] = 312366,
  [SMALL_STATE(7185)] = 312373,
  [SMALL_STATE(7186)] = 312380,
  [SMALL_STATE(7187)] = 312387,
  [SMALL_STATE(7188)] = 312394,
  [SMALL_STATE(7189)] = 312401,
  [SMALL_STATE(7190)] = 312408,
  [SMALL_STATE(7191)] = 312415,
  [SMALL_STATE(7192)] = 312422,
  [SMALL_STATE(7193)] = 312429,
  [SMALL_STATE(7194)] = 312436,
  [SMALL_STATE(7195)] = 312443,
  [SMALL_STATE(7196)] = 312450,
  [SMALL_STATE(7197)] = 312457,
  [SMALL_STATE(7198)] = 312464,
  [SMALL_STATE(7199)] = 312471,
  [SMALL_STATE(7200)] = 312478,
  [SMALL_STATE(7201)] = 312485,
  [SMALL_STATE(7202)] = 312492,
  [SMALL_STATE(7203)] = 312499,
  [SMALL_STATE(7204)] = 312506,
  [SMALL_STATE(7205)] = 312513,
  [SMALL_STATE(7206)] = 312520,
  [SMALL_STATE(7207)] = 312527,
  [SMALL_STATE(7208)] = 312534,
  [SMALL_STATE(7209)] = 312541,
  [SMALL_STATE(7210)] = 312548,
  [SMALL_STATE(7211)] = 312555,
  [SMALL_STATE(7212)] = 312562,
  [SMALL_STATE(7213)] = 312569,
  [SMALL_STATE(7214)] = 312576,
  [SMALL_STATE(7215)] = 312583,
  [SMALL_STATE(7216)] = 312590,
  [SMALL_STATE(7217)] = 312597,
  [SMALL_STATE(7218)] = 312604,
  [SMALL_STATE(7219)] = 312611,
  [SMALL_STATE(7220)] = 312618,
  [SMALL_STATE(7221)] = 312625,
  [SMALL_STATE(7222)] = 312632,
  [SMALL_STATE(7223)] = 312639,
  [SMALL_STATE(7224)] = 312646,
  [SMALL_STATE(7225)] = 312653,
  [SMALL_STATE(7226)] = 312660,
  [SMALL_STATE(7227)] = 312667,
  [SMALL_STATE(7228)] = 312674,
  [SMALL_STATE(7229)] = 312681,
  [SMALL_STATE(7230)] = 312688,
  [SMALL_STATE(7231)] = 312695,
  [SMALL_STATE(7232)] = 312702,
  [SMALL_STATE(7233)] = 312709,
  [SMALL_STATE(7234)] = 312716,
  [SMALL_STATE(7235)] = 312723,
  [SMALL_STATE(7236)] = 312730,
  [SMALL_STATE(7237)] = 312737,
  [SMALL_STATE(7238)] = 312744,
  [SMALL_STATE(7239)] = 312751,
  [SMALL_STATE(7240)] = 312758,
  [SMALL_STATE(7241)] = 312765,
  [SMALL_STATE(7242)] = 312772,
  [SMALL_STATE(7243)] = 312779,
  [SMALL_STATE(7244)] = 312786,
  [SMALL_STATE(7245)] = 312793,
  [SMALL_STATE(7246)] = 312800,
  [SMALL_STATE(7247)] = 312807,
  [SMALL_STATE(7248)] = 312814,
  [SMALL_STATE(7249)] = 312821,
  [SMALL_STATE(7250)] = 312828,
  [SMALL_STATE(7251)] = 312835,
  [SMALL_STATE(7252)] = 312842,
  [SMALL_STATE(7253)] = 312849,
  [SMALL_STATE(7254)] = 312856,
  [SMALL_STATE(7255)] = 312863,
  [SMALL_STATE(7256)] = 312870,
  [SMALL_STATE(7257)] = 312877,
  [SMALL_STATE(7258)] = 312884,
  [SMALL_STATE(7259)] = 312891,
  [SMALL_STATE(7260)] = 312898,
  [SMALL_STATE(7261)] = 312905,
  [SMALL_STATE(7262)] = 312912,
  [SMALL_STATE(7263)] = 312919,
  [SMALL_STATE(7264)] = 312926,
  [SMALL_STATE(7265)] = 312933,
  [SMALL_STATE(7266)] = 312940,
  [SMALL_STATE(7267)] = 312947,
  [SMALL_STATE(7268)] = 312954,
  [SMALL_STATE(7269)] = 312961,
  [SMALL_STATE(7270)] = 312968,
  [SMALL_STATE(7271)] = 312975,
  [SMALL_STATE(7272)] = 312982,
  [SMALL_STATE(7273)] = 312989,
  [SMALL_STATE(7274)] = 312996,
  [SMALL_STATE(7275)] = 313003,
  [SMALL_STATE(7276)] = 313010,
  [SMALL_STATE(7277)] = 313017,
  [SMALL_STATE(7278)] = 313024,
  [SMALL_STATE(7279)] = 313031,
  [SMALL_STATE(7280)] = 313038,
  [SMALL_STATE(7281)] = 313045,
  [SMALL_STATE(7282)] = 313052,
  [SMALL_STATE(7283)] = 313059,
  [SMALL_STATE(7284)] = 313066,
  [SMALL_STATE(7285)] = 313073,
  [SMALL_STATE(7286)] = 313080,
  [SMALL_STATE(7287)] = 313087,
  [SMALL_STATE(7288)] = 313094,
  [SMALL_STATE(7289)] = 313101,
  [SMALL_STATE(7290)] = 313108,
  [SMALL_STATE(7291)] = 313115,
  [SMALL_STATE(7292)] = 313122,
  [SMALL_STATE(7293)] = 313129,
  [SMALL_STATE(7294)] = 313136,
  [SMALL_STATE(7295)] = 313143,
  [SMALL_STATE(7296)] = 313150,
  [SMALL_STATE(7297)] = 313157,
  [SMALL_STATE(7298)] = 313164,
  [SMALL_STATE(7299)] = 313171,
  [SMALL_STATE(7300)] = 313178,
  [SMALL_STATE(7301)] = 313185,
  [SMALL_STATE(7302)] = 313192,
  [SMALL_STATE(7303)] = 313199,
  [SMALL_STATE(7304)] = 313206,
  [SMALL_STATE(7305)] = 313213,
  [SMALL_STATE(7306)] = 313220,
  [SMALL_STATE(7307)] = 313227,
  [SMALL_STATE(7308)] = 313234,
  [SMALL_STATE(7309)] = 313241,
  [SMALL_STATE(7310)] = 313248,
  [SMALL_STATE(7311)] = 313255,
  [SMALL_STATE(7312)] = 313262,
  [SMALL_STATE(7313)] = 313269,
  [SMALL_STATE(7314)] = 313276,
  [SMALL_STATE(7315)] = 313283,
  [SMALL_STATE(7316)] = 313290,
  [SMALL_STATE(7317)] = 313297,
  [SMALL_STATE(7318)] = 313304,
  [SMALL_STATE(7319)] = 313311,
  [SMALL_STATE(7320)] = 313318,
  [SMALL_STATE(7321)] = 313325,
  [SMALL_STATE(7322)] = 313332,
  [SMALL_STATE(7323)] = 313339,
  [SMALL_STATE(7324)] = 313346,
  [SMALL_STATE(7325)] = 313353,
  [SMALL_STATE(7326)] = 313360,
  [SMALL_STATE(7327)] = 313367,
  [SMALL_STATE(7328)] = 313374,
  [SMALL_STATE(7329)] = 313381,
  [SMALL_STATE(7330)] = 313388,
  [SMALL_STATE(7331)] = 313395,
  [SMALL_STATE(7332)] = 313402,
  [SMALL_STATE(7333)] = 313409,
  [SMALL_STATE(7334)] = 313416,
  [SMALL_STATE(7335)] = 313423,
  [SMALL_STATE(7336)] = 313430,
  [SMALL_STATE(7337)] = 313437,
  [SMALL_STATE(7338)] = 313444,
  [SMALL_STATE(7339)] = 313451,
  [SMALL_STATE(7340)] = 313458,
  [SMALL_STATE(7341)] = 313465,
  [SMALL_STATE(7342)] = 313472,
  [SMALL_STATE(7343)] = 313479,
  [SMALL_STATE(7344)] = 313486,
  [SMALL_STATE(7345)] = 313493,
  [SMALL_STATE(7346)] = 313500,
  [SMALL_STATE(7347)] = 313507,
  [SMALL_STATE(7348)] = 313514,
  [SMALL_STATE(7349)] = 313521,
  [SMALL_STATE(7350)] = 313528,
  [SMALL_STATE(7351)] = 313535,
  [SMALL_STATE(7352)] = 313542,
  [SMALL_STATE(7353)] = 313549,
  [SMALL_STATE(7354)] = 313556,
  [SMALL_STATE(7355)] = 313563,
  [SMALL_STATE(7356)] = 313570,
  [SMALL_STATE(7357)] = 313577,
  [SMALL_STATE(7358)] = 313584,
  [SMALL_STATE(7359)] = 313591,
  [SMALL_STATE(7360)] = 313598,
  [SMALL_STATE(7361)] = 313605,
  [SMALL_STATE(7362)] = 313612,
  [SMALL_STATE(7363)] = 313619,
  [SMALL_STATE(7364)] = 313626,
  [SMALL_STATE(7365)] = 313633,
  [SMALL_STATE(7366)] = 313640,
  [SMALL_STATE(7367)] = 313647,
  [SMALL_STATE(7368)] = 313654,
  [SMALL_STATE(7369)] = 313661,
  [SMALL_STATE(7370)] = 313668,
  [SMALL_STATE(7371)] = 313675,
  [SMALL_STATE(7372)] = 313682,
  [SMALL_STATE(7373)] = 313689,
  [SMALL_STATE(7374)] = 313696,
  [SMALL_STATE(7375)] = 313703,
  [SMALL_STATE(7376)] = 313710,
  [SMALL_STATE(7377)] = 313717,
  [SMALL_STATE(7378)] = 313724,
  [SMALL_STATE(7379)] = 313731,
  [SMALL_STATE(7380)] = 313738,
  [SMALL_STATE(7381)] = 313745,
  [SMALL_STATE(7382)] = 313752,
  [SMALL_STATE(7383)] = 313759,
  [SMALL_STATE(7384)] = 313766,
  [SMALL_STATE(7385)] = 313773,
  [SMALL_STATE(7386)] = 313780,
  [SMALL_STATE(7387)] = 313787,
  [SMALL_STATE(7388)] = 313794,
  [SMALL_STATE(7389)] = 313801,
  [SMALL_STATE(7390)] = 313808,
  [SMALL_STATE(7391)] = 313815,
  [SMALL_STATE(7392)] = 313822,
  [SMALL_STATE(7393)] = 313829,
  [SMALL_STATE(7394)] = 313836,
  [SMALL_STATE(7395)] = 313843,
  [SMALL_STATE(7396)] = 313850,
  [SMALL_STATE(7397)] = 313857,
  [SMALL_STATE(7398)] = 313864,
  [SMALL_STATE(7399)] = 313871,
  [SMALL_STATE(7400)] = 313878,
  [SMALL_STATE(7401)] = 313885,
  [SMALL_STATE(7402)] = 313892,
  [SMALL_STATE(7403)] = 313899,
  [SMALL_STATE(7404)] = 313906,
  [SMALL_STATE(7405)] = 313913,
  [SMALL_STATE(7406)] = 313920,
  [SMALL_STATE(7407)] = 313927,
  [SMALL_STATE(7408)] = 313934,
  [SMALL_STATE(7409)] = 313941,
  [SMALL_STATE(7410)] = 313948,
  [SMALL_STATE(7411)] = 313955,
  [SMALL_STATE(7412)] = 313962,
  [SMALL_STATE(7413)] = 313969,
  [SMALL_STATE(7414)] = 313976,
  [SMALL_STATE(7415)] = 313983,
  [SMALL_STATE(7416)] = 313990,
  [SMALL_STATE(7417)] = 313997,
  [SMALL_STATE(7418)] = 314004,
  [SMALL_STATE(7419)] = 314011,
  [SMALL_STATE(7420)] = 314018,
  [SMALL_STATE(7421)] = 314025,
  [SMALL_STATE(7422)] = 314032,
  [SMALL_STATE(7423)] = 314039,
  [SMALL_STATE(7424)] = 314046,
  [SMALL_STATE(7425)] = 314053,
  [SMALL_STATE(7426)] = 314060,
  [SMALL_STATE(7427)] = 314067,
  [SMALL_STATE(7428)] = 314074,
  [SMALL_STATE(7429)] = 314081,
  [SMALL_STATE(7430)] = 314088,
  [SMALL_STATE(7431)] = 314095,
  [SMALL_STATE(7432)] = 314102,
  [SMALL_STATE(7433)] = 314109,
  [SMALL_STATE(7434)] = 314116,
  [SMALL_STATE(7435)] = 314123,
  [SMALL_STATE(7436)] = 314130,
  [SMALL_STATE(7437)] = 314137,
  [SMALL_STATE(7438)] = 314144,
  [SMALL_STATE(7439)] = 314151,
  [SMALL_STATE(7440)] = 314158,
  [SMALL_STATE(7441)] = 314165,
  [SMALL_STATE(7442)] = 314172,
  [SMALL_STATE(7443)] = 314179,
  [SMALL_STATE(7444)] = 314186,
  [SMALL_STATE(7445)] = 314193,
  [SMALL_STATE(7446)] = 314200,
  [SMALL_STATE(7447)] = 314207,
  [SMALL_STATE(7448)] = 314214,
  [SMALL_STATE(7449)] = 314221,
  [SMALL_STATE(7450)] = 314228,
  [SMALL_STATE(7451)] = 314235,
  [SMALL_STATE(7452)] = 314242,
  [SMALL_STATE(7453)] = 314249,
  [SMALL_STATE(7454)] = 314256,
  [SMALL_STATE(7455)] = 314263,
  [SMALL_STATE(7456)] = 314270,
  [SMALL_STATE(7457)] = 314277,
  [SMALL_STATE(7458)] = 314284,
  [SMALL_STATE(7459)] = 314291,
  [SMALL_STATE(7460)] = 314298,
  [SMALL_STATE(7461)] = 314305,
  [SMALL_STATE(7462)] = 314312,
  [SMALL_STATE(7463)] = 314319,
  [SMALL_STATE(7464)] = 314326,
  [SMALL_STATE(7465)] = 314333,
  [SMALL_STATE(7466)] = 314340,
  [SMALL_STATE(7467)] = 314347,
  [SMALL_STATE(7468)] = 314354,
  [SMALL_STATE(7469)] = 314361,
  [SMALL_STATE(7470)] = 314368,
  [SMALL_STATE(7471)] = 314375,
  [SMALL_STATE(7472)] = 314382,
  [SMALL_STATE(7473)] = 314389,
  [SMALL_STATE(7474)] = 314396,
  [SMALL_STATE(7475)] = 314403,
  [SMALL_STATE(7476)] = 314410,
  [SMALL_STATE(7477)] = 314417,
  [SMALL_STATE(7478)] = 314424,
  [SMALL_STATE(7479)] = 314431,
  [SMALL_STATE(7480)] = 314438,
  [SMALL_STATE(7481)] = 314445,
  [SMALL_STATE(7482)] = 314452,
  [SMALL_STATE(7483)] = 314459,
  [SMALL_STATE(7484)] = 314466,
  [SMALL_STATE(7485)] = 314473,
  [SMALL_STATE(7486)] = 314480,
  [SMALL_STATE(7487)] = 314487,
  [SMALL_STATE(7488)] = 314494,
  [SMALL_STATE(7489)] = 314501,
  [SMALL_STATE(7490)] = 314508,
  [SMALL_STATE(7491)] = 314515,
  [SMALL_STATE(7492)] = 314522,
  [SMALL_STATE(7493)] = 314529,
  [SMALL_STATE(7494)] = 314536,
  [SMALL_STATE(7495)] = 314543,
  [SMALL_STATE(7496)] = 314550,
  [SMALL_STATE(7497)] = 314557,
  [SMALL_STATE(7498)] = 314564,
  [SMALL_STATE(7499)] = 314571,
  [SMALL_STATE(7500)] = 314578,
  [SMALL_STATE(7501)] = 314585,
  [SMALL_STATE(7502)] = 314592,
  [SMALL_STATE(7503)] = 314599,
  [SMALL_STATE(7504)] = 314606,
  [SMALL_STATE(7505)] = 314613,
  [SMALL_STATE(7506)] = 314620,
  [SMALL_STATE(7507)] = 314627,
  [SMALL_STATE(7508)] = 314634,
  [SMALL_STATE(7509)] = 314641,
  [SMALL_STATE(7510)] = 314648,
  [SMALL_STATE(7511)] = 314655,
  [SMALL_STATE(7512)] = 314662,
  [SMALL_STATE(7513)] = 314669,
  [SMALL_STATE(7514)] = 314676,
  [SMALL_STATE(7515)] = 314683,
  [SMALL_STATE(7516)] = 314690,
  [SMALL_STATE(7517)] = 314697,
  [SMALL_STATE(7518)] = 314704,
  [SMALL_STATE(7519)] = 314711,
  [SMALL_STATE(7520)] = 314718,
  [SMALL_STATE(7521)] = 314725,
  [SMALL_STATE(7522)] = 314732,
  [SMALL_STATE(7523)] = 314739,
  [SMALL_STATE(7524)] = 314746,
  [SMALL_STATE(7525)] = 314753,
  [SMALL_STATE(7526)] = 314760,
  [SMALL_STATE(7527)] = 314767,
  [SMALL_STATE(7528)] = 314774,
  [SMALL_STATE(7529)] = 314781,
  [SMALL_STATE(7530)] = 314788,
  [SMALL_STATE(7531)] = 314795,
  [SMALL_STATE(7532)] = 314802,
  [SMALL_STATE(7533)] = 314809,
  [SMALL_STATE(7534)] = 314816,
  [SMALL_STATE(7535)] = 314823,
  [SMALL_STATE(7536)] = 314830,
  [SMALL_STATE(7537)] = 314837,
  [SMALL_STATE(7538)] = 314844,
  [SMALL_STATE(7539)] = 314851,
  [SMALL_STATE(7540)] = 314858,
  [SMALL_STATE(7541)] = 314865,
  [SMALL_STATE(7542)] = 314872,
  [SMALL_STATE(7543)] = 314879,
  [SMALL_STATE(7544)] = 314886,
  [SMALL_STATE(7545)] = 314893,
  [SMALL_STATE(7546)] = 314900,
  [SMALL_STATE(7547)] = 314907,
  [SMALL_STATE(7548)] = 314914,
  [SMALL_STATE(7549)] = 314921,
  [SMALL_STATE(7550)] = 314928,
  [SMALL_STATE(7551)] = 314935,
  [SMALL_STATE(7552)] = 314942,
  [SMALL_STATE(7553)] = 314949,
  [SMALL_STATE(7554)] = 314956,
  [SMALL_STATE(7555)] = 314963,
  [SMALL_STATE(7556)] = 314970,
  [SMALL_STATE(7557)] = 314977,
  [SMALL_STATE(7558)] = 314984,
  [SMALL_STATE(7559)] = 314991,
  [SMALL_STATE(7560)] = 314998,
  [SMALL_STATE(7561)] = 315005,
  [SMALL_STATE(7562)] = 315012,
  [SMALL_STATE(7563)] = 315019,
  [SMALL_STATE(7564)] = 315026,
  [SMALL_STATE(7565)] = 315033,
  [SMALL_STATE(7566)] = 315040,
  [SMALL_STATE(7567)] = 315047,
  [SMALL_STATE(7568)] = 315054,
  [SMALL_STATE(7569)] = 315061,
  [SMALL_STATE(7570)] = 315068,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6684),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7369),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3438),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3742),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3742),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(103),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(416),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(414),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3913),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7312),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(565),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3851),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3532),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5851),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5773),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1093),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6154),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4870),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6046),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6496),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7381),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(468),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3778),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3778),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7140),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(521),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4105),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2033),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3573),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3574),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5836),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(465),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5762),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6244),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4711),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6040),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6595),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7522),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6690),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7137),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3445),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3748),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(419),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(426),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4068),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7318),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(522),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4767),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3968),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2071),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3539),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5944),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(497),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5753),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6274),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4684),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6047),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6556),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7510),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5533),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4528),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5511),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4728),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4541),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4802),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4976),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2344),
  [237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 1),
  [239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 1),
  [241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 1), REDUCE(sym__expression, 1, 0, 1),
  [244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2040),
  [246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2025),
  [248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2032),
  [250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3543),
  [252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3544),
  [254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3989),
  [256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5957),
  [258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2277),
  [260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5760),
  [262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2230),
  [264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6235),
  [266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4822),
  [268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_name, 1, 0, 1),
  [278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3989),
  [280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7511),
  [284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1127),
  [286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3769),
  [288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4707),
  [292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(417),
  [294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(91),
  [296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7281),
  [298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(631),
  [300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(607),
  [302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3522),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3523),
  [312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5895),
  [314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1129),
  [316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5737),
  [318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6155),
  [324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4834),
  [326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6048),
  [336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6587),
  [338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7502),
  [342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4544),
  [344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5523),
  [346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4524),
  [348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5456),
  [350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4543),
  [352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4552),
  [354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4846),
  [356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2309),
  [358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 1),
  [360] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_command_name, 1, 0, 1), REDUCE(sym__expression, 1, 0, 1),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1915),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3557),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3558),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4024),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5988),
  [375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2246),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5701),
  [379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2309),
  [381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2482),
  [383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6158),
  [385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4804),
  [387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7515),
  [399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6653),
  [403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7278),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3430),
  [407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3771),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3771),
  [411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4098),
  [419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 4, 0, 109),
  [421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5136),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5248),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5293),
  [427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7499),
  [429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(534),
  [439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3982),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3634),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3635),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5866),
  [451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(805),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5736),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(811),
  [459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6255),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4712),
  [463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(324),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6051),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6476),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7546),
  [479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 2, 0, 59),
  [481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5195),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5288),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 4, 0, 112),
  [487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5128),
  [489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5323),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5364),
  [493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(1127),
  [496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(6684),
  [499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(7369),
  [502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(3438),
  [505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(3769),
  [508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(3769),
  [511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(103),
  [514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(416),
  [517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0),
  [519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(414),
  [522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(3913),
  [525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(7281),
  [528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(64),
  [531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(631),
  [534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(9),
  [537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(1805),
  [540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(607),
  [543] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(736),
  [546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(737),
  [549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(4090),
  [552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(3522),
  [555] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(3523),
  [558] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(5895),
  [561] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(1129),
  [564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(5737),
  [567] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(1126),
  [570] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(1054),
  [573] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(6155),
  [576] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(4834),
  [579] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(115),
  [582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(116),
  [585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(117),
  [588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(112),
  [591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(6048),
  [594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(6587),
  [597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(1125),
  [600] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0), SHIFT_REPEAT(7502),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 2, 0, 60),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5198),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5301),
  [609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 3, 0, 45),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5229),
  [613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5372),
  [615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 3, 0, 79),
  [617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5227),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5366),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5368),
  [623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 3, 0, 46),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5230),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5374),
  [629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 3, 0, 83),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5232),
  [633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5378),
  [635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5379),
  [637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5233),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5385),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5387),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5244),
  [645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5383),
  [647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5380),
  [649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5185),
  [651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5264),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5265),
  [655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5120),
  [657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5311),
  [659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5314),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6682),
  [665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7380),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3714),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3714),
  [673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(125),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(421),
  [677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(428),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4126),
  [681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5257),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6779),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(624),
  [689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4013),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3663),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5935),
  [707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(840),
  [709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5629),
  [711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6243),
  [717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4855),
  [719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6017),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6489),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7559),
  [735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5369),
  [737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5399),
  [739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5398),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5400),
  [743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5402),
  [745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5259),
  [747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5268),
  [749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5274),
  [751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5282),
  [753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5313),
  [755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5315),
  [757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_clause, 4, 0, 0),
  [759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_clause, 3, 0, 0),
  [761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(85),
  [763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6088),
  [769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(610),
  [771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(877),
  [773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6071),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6066),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6068),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6072),
  [787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6054),
  [791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6062),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6067),
  [795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4734),
  [797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4776),
  [801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__terminated_statement, 2, 0, 0),
  [803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5560),
  [805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4522),
  [807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5540),
  [809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4690),
  [811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4763),
  [813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6635),
  [815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6649),
  [817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5526),
  [819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5508),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4648),
  [823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4638),
  [825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5538),
  [827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5563),
  [829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5493),
  [831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4665),
  [833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5484),
  [835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4575),
  [837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4752),
  [839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4869),
  [841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4682),
  [843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4748),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4536),
  [847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 1, 0, 0),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4514),
  [851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4743),
  [853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4770),
  [855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5001),
  [857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4949),
  [859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4946),
  [861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4958),
  [863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4841),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4838),
  [867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1032),
  [869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7383),
  [871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
  [881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [885] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4658),
  [889] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(1127),
  [892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(6684),
  [895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(7369),
  [898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(3438),
  [901] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(3769),
  [904] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(3769),
  [907] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(103),
  [910] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(416),
  [913] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(414),
  [916] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(3913),
  [919] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(7281),
  [922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(64),
  [925] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(631),
  [928] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [931] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(1805),
  [934] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(607),
  [937] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(736),
  [940] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(737),
  [943] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(4090),
  [946] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(3522),
  [949] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(3523),
  [952] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(5895),
  [955] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(1129),
  [958] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(5737),
  [961] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(1126),
  [964] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(1054),
  [967] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(6155),
  [970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(4834),
  [973] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(115),
  [976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [979] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(117),
  [982] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(112),
  [985] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(6048),
  [988] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(6587),
  [991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(1125),
  [994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0), SHIFT_REPEAT(7502),
  [997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1693),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3786),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7410),
  [1005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(637),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(863),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4119),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1697),
  [1017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [1019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6035),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6607),
  [1023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [1025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1882),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3732),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3732),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [1033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(634),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3940),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3581),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3582),
  [1043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5973),
  [1045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1886),
  [1047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5659),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [1051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1969),
  [1053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6260),
  [1055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4854),
  [1057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [1059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6043),
  [1067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [1069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7526),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2403),
  [1073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2041),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [1079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2015),
  [1083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3917),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2259),
  [1089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [1091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [1093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3735),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4274),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3715),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3543),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3835),
  [1115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2277),
  [1117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5760),
  [1119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2344),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4822),
  [1123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2361),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2058),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [1133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1938),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [1137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2299),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6334),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3750),
  [1147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2381),
  [1149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [1153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2048),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2048),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2284),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6610),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3767),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2557),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2173),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2184),
  [1173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2185),
  [1175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2557),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenation, 4, 0, 0),
  [1185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(479),
  [1187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5762),
  [1189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [1191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenation, 4, 0, 0),
  [1193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenation, 4, 0, 1),
  [1197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenation, 4, 0, 1),
  [1199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(511),
  [1201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5753),
  [1203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(515),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenation, 2, 0, 0),
  [1209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenation, 2, 0, 0),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3870),
  [1213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0),
  [1215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0),
  [1217] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3989),
  [1220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3989),
  [1223] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 1, 0, 0),
  [1225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 1, 0, 0),
  [1227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenation, 2, 0, 1),
  [1229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenation, 2, 0, 1),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3856),
  [1233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0),
  [1235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [1237] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [1240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_name, 1, 0, 0),
  [1242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_command_name, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [1245] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0), SHIFT(7144),
  [1248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [1250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [1252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_translated_string, 2, 0, 0),
  [1254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_translated_string, 2, 0, 0),
  [1256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 4, 0, 0),
  [1258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 4, 0, 0),
  [1260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arithmetic_expansion, 3, 0, 0),
  [1262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arithmetic_expansion, 3, 0, 0),
  [1264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [1266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [1268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arithmetic_expansion, 4, 0, 0),
  [1270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arithmetic_expansion, 4, 0, 0),
  [1272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 1, 0, 0),
  [1274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 1, 0, 0),
  [1276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_simple_expansion, 2, 0, 0),
  [1278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_expansion, 2, 0, 0),
  [1280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 2, 0, 0),
  [1282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 2, 0, 0),
  [1284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 10),
  [1286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 10),
  [1288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_simple_expansion, 2, 0, 11),
  [1290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_expansion, 2, 0, 11),
  [1292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expansion, 2, 0, 0),
  [1294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expansion, 2, 0, 0),
  [1296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expansion, 3, 0, 31),
  [1298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expansion, 3, 0, 31),
  [1300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_substitution, 3, 0, 0),
  [1302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_substitution, 3, 0, 0),
  [1304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_substitution, 3, 0, 35),
  [1306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_substitution, 3, 0, 35),
  [1308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_brace_expression, 5, 0, 0),
  [1310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_expression, 5, 0, 0),
  [1312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_process_substitution, 3, 0, 0),
  [1314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_process_substitution, 3, 0, 0),
  [1316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0),
  [1318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0),
  [1320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(491),
  [1323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(491),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3991),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3999),
  [1329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4024),
  [1332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [1334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_command_name, 1, 0, 0), SHIFT(7356),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(519),
  [1339] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(519),
  [1342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(467),
  [1344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3741),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3741),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [1350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [1352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3861),
  [1354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6036),
  [1356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [1358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [1360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(839),
  [1362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 19),
  [1364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3790),
  [1366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command, 2, 0, 19),
  [1368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3998),
  [1370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3652),
  [1372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3653),
  [1374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5912),
  [1376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(826),
  [1378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5769),
  [1380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
  [1382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6183),
  [1384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4816),
  [1386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(360),
  [1388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [1390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [1392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(303),
  [1394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [1396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7554),
  [1400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 1, 0, 2),
  [1402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command, 1, 0, 2),
  [1404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [1406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3728),
  [1408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4026),
  [1410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3674),
  [1412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3675),
  [1414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5968),
  [1416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(912),
  [1418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5640),
  [1420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1024),
  [1422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6196),
  [1424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4890),
  [1426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [1428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(392),
  [1430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [1432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(343),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [1436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7564),
  [1440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 18),
  [1442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command, 2, 0, 18),
  [1444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [1446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3713),
  [1448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3841),
  [1450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3555),
  [1452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3556),
  [1454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5830),
  [1456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [1458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5658),
  [1460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [1462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6262),
  [1464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4686),
  [1466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(156),
  [1468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [1470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [1472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(143),
  [1474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [1478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7514),
  [1480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(839),
  [1483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38),
  [1485] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3790),
  [1488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38),
  [1490] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3998),
  [1493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3652),
  [1496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3653),
  [1499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5912),
  [1502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(826),
  [1505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5769),
  [1508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(903),
  [1511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(6183),
  [1514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(4816),
  [1517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(360),
  [1520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(361),
  [1523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(362),
  [1526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(303),
  [1529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(6859),
  [1532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(828),
  [1535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1196),
  [1538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7554),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3795),
  [1545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3897),
  [1547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3567),
  [1549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3568),
  [1551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5972),
  [1553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [1555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5711),
  [1557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [1559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6203),
  [1561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4925),
  [1563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [1565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [1567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [1569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7519),
  [1577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 3, 0, 39),
  [1579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command, 3, 0, 39),
  [1581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1064),
  [1583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_command, 1, 0, 0),
  [1585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_command, 1, 0, 0),
  [1587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3648),
  [1589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3649),
  [1591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5901),
  [1593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(992),
  [1595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5763),
  [1597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1170),
  [1599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6258),
  [1601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4803),
  [1603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(352),
  [1605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [1607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(354),
  [1609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [1611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(539),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6481),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [1617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7552),
  [1619] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(952),
  [1622] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3728),
  [1625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(4026),
  [1628] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3674),
  [1631] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3675),
  [1634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5968),
  [1637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(912),
  [1640] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5640),
  [1643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1024),
  [1646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(6196),
  [1649] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(4890),
  [1652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(391),
  [1655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(392),
  [1658] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(393),
  [1661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(343),
  [1664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7093),
  [1667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(951),
  [1670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1330),
  [1673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7564),
  [1676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(825),
  [1678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5736),
  [1680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(824),
  [1682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [1684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [1686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3772),
  [1688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4094),
  [1690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1283),
  [1692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [1694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_command, 2, 0, 0),
  [1696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_command, 2, 0, 0),
  [1698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [1700] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1064),
  [1703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0),
  [1707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3648),
  [1710] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3649),
  [1713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5901),
  [1716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(992),
  [1719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5763),
  [1722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1170),
  [1725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6258),
  [1728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4803),
  [1731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(352),
  [1734] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(353),
  [1737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(354),
  [1740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(295),
  [1743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(541),
  [1746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6481),
  [1749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1063),
  [1752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7552),
  [1755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(921),
  [1757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5629),
  [1759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(920),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [1763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(909),
  [1765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(908),
  [1767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [1769] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1227),
  [1772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3670),
  [1775] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3671),
  [1778] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5956),
  [1781] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1239),
  [1784] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5635),
  [1787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1319),
  [1790] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6251),
  [1793] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4872),
  [1796] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(385),
  [1799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(386),
  [1802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(387),
  [1805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(335),
  [1808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(550),
  [1811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6491),
  [1814] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1226),
  [1817] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7562),
  [1820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1095),
  [1823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3713),
  [1826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3841),
  [1829] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3555),
  [1832] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3556),
  [1835] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5830),
  [1838] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1112),
  [1841] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5658),
  [1844] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1260),
  [1847] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(6262),
  [1850] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(4686),
  [1853] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(156),
  [1856] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(157),
  [1859] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(158),
  [1862] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(143),
  [1865] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7375),
  [1868] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1094),
  [1871] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1606),
  [1874] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7514),
  [1877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1227),
  [1879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3670),
  [1881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3671),
  [1883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5956),
  [1885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [1887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5635),
  [1889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1319),
  [1891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6251),
  [1893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4872),
  [1895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [1897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(386),
  [1899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [1901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(335),
  [1903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(557),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6491),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7562),
  [1911] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1118),
  [1914] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3795),
  [1917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3897),
  [1920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3567),
  [1923] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3568),
  [1926] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5972),
  [1929] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1119),
  [1932] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5711),
  [1935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1148),
  [1938] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(6203),
  [1941] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(4925),
  [1944] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(184),
  [1947] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(185),
  [1950] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(186),
  [1953] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(163),
  [1956] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7357),
  [1959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1117),
  [1962] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1649),
  [1965] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7519),
  [1968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(550),
  [1970] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1445),
  [1973] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3546),
  [1976] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3547),
  [1979] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5970),
  [1982] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1371),
  [1985] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5772),
  [1988] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1624),
  [1991] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6269),
  [1994] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4689),
  [1997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(136),
  [2000] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(137),
  [2003] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(138),
  [2006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(134),
  [2009] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(559),
  [2012] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6559),
  [2015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1437),
  [2018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7512),
  [2021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1031),
  [2023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [2027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [2029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3563),
  [2031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3457),
  [2033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5841),
  [2035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1443),
  [2037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5675),
  [2039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1520),
  [2041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6192),
  [2043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4809),
  [2045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [2047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [2049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [2051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [2053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(566),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6460),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7517),
  [2061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1445),
  [2063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3546),
  [2065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3547),
  [2067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5970),
  [2069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1371),
  [2071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5772),
  [2073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1624),
  [2075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6269),
  [2077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4689),
  [2079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(136),
  [2081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(137),
  [2083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [2085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(134),
  [2087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6559),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7512),
  [2095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(568),
  [2097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1086),
  [2099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5773),
  [2101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1085),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [2105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1368),
  [2108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3563),
  [2111] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3457),
  [2114] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5841),
  [2117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1443),
  [2120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5675),
  [2123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1520),
  [2126] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6192),
  [2129] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4809),
  [2132] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(176),
  [2135] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(177),
  [2138] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(178),
  [2141] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(155),
  [2144] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(568),
  [2147] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6460),
  [2150] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1367),
  [2153] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7517),
  [2156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_file_redirect, 2, 0, 8),
  [2158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_file_redirect, 2, 0, 8),
  [2160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_file_redirect, 3, 0, 21),
  [2162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_file_redirect, 3, 0, 21),
  [2164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1021),
  [2167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0),
  [2169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0),
  [2171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3646),
  [2174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3647),
  [2177] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5893),
  [2180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(991),
  [2183] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5758),
  [2186] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1167),
  [2189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6238),
  [2192] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4796),
  [2195] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(348),
  [2198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(349),
  [2201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(350),
  [2204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(291),
  [2207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1020),
  [2210] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7551),
  [2213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(559),
  [2215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [2217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5737),
  [2219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [2221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [2223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1270),
  [2226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3772),
  [2229] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(4094),
  [2232] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1283),
  [2235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7273),
  [2238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1269),
  [2241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0),
  [2243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__statements_repeat1, 2, 0, 0),
  [2245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statements, 3, 0, 0),
  [2247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statements, 3, 0, 0),
  [2249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1890),
  [2251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3789),
  [2253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4124),
  [2255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1902),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [2259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [2261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [2263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [2265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [2267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1174),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [2271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_file_redirect, 1, 0, 0),
  [2273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_file_redirect, 1, 0, 0),
  [2275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_file_redirect, 2, 0, 4),
  [2277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_file_redirect, 2, 0, 4),
  [2279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [2281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unset_command, 1, 0, 0),
  [2283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unset_command, 1, 0, 0),
  [2285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3650),
  [2287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3651),
  [2289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5906),
  [2291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1147),
  [2293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5766),
  [2295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1406),
  [2297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6172),
  [2299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4810),
  [2301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [2303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [2305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [2307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [2309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [2311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [2313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7553),
  [2315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1666),
  [2317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1689),
  [2319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [2321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6588),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [2325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unset_command, 2, 0, 0),
  [2327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unset_command, 2, 0, 0),
  [2329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(598),
  [2331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [2333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3658),
  [2335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3659),
  [2337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5925),
  [2339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1169),
  [2341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5623),
  [2343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1380),
  [2345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6220),
  [2347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4836),
  [2349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [2351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [2353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [2355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(315),
  [2357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [2359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7557),
  [2361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1165),
  [2364] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3658),
  [2367] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3659),
  [2370] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5925),
  [2373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1169),
  [2376] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5623),
  [2379] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1380),
  [2382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6220),
  [2385] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4836),
  [2388] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [2391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(371),
  [2394] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(372),
  [2397] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(315),
  [2400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1158),
  [2403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7557),
  [2406] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1210),
  [2409] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3668),
  [2412] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3669),
  [2415] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5949),
  [2418] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1225),
  [2421] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5633),
  [2424] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1428),
  [2427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6263),
  [2430] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4868),
  [2433] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(382),
  [2436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(383),
  [2439] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(384),
  [2442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(331),
  [2445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1200),
  [2448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7561),
  [2451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1137),
  [2454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0),
  [2456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0),
  [2458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3650),
  [2461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3651),
  [2464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5906),
  [2467] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1147),
  [2470] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5766),
  [2473] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1406),
  [2476] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6172),
  [2479] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4810),
  [2482] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(356),
  [2485] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(357),
  [2488] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(358),
  [2491] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(299),
  [2494] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(598),
  [2497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1190),
  [2500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7553),
  [2503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statements, 2, 0, 0),
  [2505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statements, 2, 0, 0),
  [2507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(589),
  [2509] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1666),
  [2512] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1689),
  [2515] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(603),
  [2518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6588),
  [2521] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1665),
  [2524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(601),
  [2526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [2528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [2530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [2534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1324),
  [2536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3672),
  [2538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3673),
  [2540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5962),
  [2542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1402),
  [2544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5638),
  [2546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1539),
  [2548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6228),
  [2550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4884),
  [2552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [2554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(389),
  [2556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(390),
  [2558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(339),
  [2560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(614),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [2564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7563),
  [2566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [2568] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1355),
  [2571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3559),
  [2574] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3560),
  [2577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5975),
  [2580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1416),
  [2583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5662),
  [2586] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1490),
  [2589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6254),
  [2592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4738),
  [2595] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(172),
  [2598] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(173),
  [2601] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(174),
  [2604] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(151),
  [2607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1354),
  [2610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7516),
  [2613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1348),
  [2615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3680),
  [2617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3681),
  [2619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5990),
  [2621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1317),
  [2623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5647),
  [2625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1553),
  [2627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6266),
  [2629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4903),
  [2631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [2633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [2635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(402),
  [2637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [2641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7567),
  [2643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1126),
  [2645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2177),
  [2647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3743),
  [2649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3919),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3709),
  [2655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3580),
  [2657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5929),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5656),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2177),
  [2665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2258),
  [2667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6211),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4830),
  [2671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2449),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7525),
  [2685] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1348),
  [2688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3680),
  [2691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3681),
  [2694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5990),
  [2697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1317),
  [2700] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5647),
  [2703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1553),
  [2706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6266),
  [2709] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4903),
  [2712] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(400),
  [2715] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(401),
  [2718] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(402),
  [2721] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(355),
  [2724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1346),
  [2727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7567),
  [2730] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1325),
  [2733] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3510),
  [2736] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3511),
  [2739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5842),
  [2742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1341),
  [2745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5718),
  [2748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1529),
  [2751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6230),
  [2754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4691),
  [2757] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(109),
  [2760] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(110),
  [2763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(111),
  [2766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [2769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1322),
  [2772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7493),
  [2775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [2777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [2779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1193),
  [2781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5758),
  [2783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1192),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [2787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [2789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1459),
  [2791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1383),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [2795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1292),
  [2797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3654),
  [2799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3655),
  [2801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5917),
  [2803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1311),
  [2805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5703),
  [2807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1489),
  [2809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6201),
  [2811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4826),
  [2813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [2815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [2817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [2819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [2821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [2823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7555),
  [2825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1879),
  [2827] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1324),
  [2830] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3672),
  [2833] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3673),
  [2836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5962),
  [2839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1402),
  [2842] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5638),
  [2845] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1539),
  [2848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6228),
  [2851] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4884),
  [2854] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(388),
  [2857] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [2860] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(390),
  [2863] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(339),
  [2866] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(636),
  [2869] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1323),
  [2872] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7563),
  [2875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1692),
  [2877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1292),
  [2880] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3654),
  [2883] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3655),
  [2886] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5917),
  [2889] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1311),
  [2892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5703),
  [2895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1489),
  [2898] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6201),
  [2901] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4826),
  [2904] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(364),
  [2907] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(365),
  [2910] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(366),
  [2913] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(307),
  [2916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1379),
  [2919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7555),
  [2922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4133),
  [2924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3660),
  [2926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3661),
  [2928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5928),
  [2930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4025),
  [2932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5627),
  [2934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4189),
  [2936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6231),
  [2938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4847),
  [2940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [2942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [2944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [2946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [2948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4147),
  [2950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7558),
  [2952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4165),
  [2954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4161),
  [2956] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1615),
  [2959] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3565),
  [2962] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3566),
  [2965] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5948),
  [2968] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1671),
  [2971] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5691),
  [2974] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1872),
  [2977] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6212),
  [2980] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4863),
  [2983] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(180),
  [2986] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [2989] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(182),
  [2992] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(159),
  [2995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(644),
  [2998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1614),
  [3001] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7518),
  [3004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1653),
  [3006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3601),
  [3008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3602),
  [3010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5793),
  [3012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1603),
  [3014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5683),
  [3016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1804),
  [3018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6156),
  [3020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4850),
  [3022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [3024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(249),
  [3026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [3028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [3030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [3032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7534),
  [3034] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1653),
  [3037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3601),
  [3040] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3602),
  [3043] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5793),
  [3046] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1603),
  [3049] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5683),
  [3052] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1804),
  [3055] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6156),
  [3058] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4850),
  [3061] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(248),
  [3064] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [3067] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(250),
  [3070] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(223),
  [3073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1652),
  [3076] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7534),
  [3079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1615),
  [3081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3565),
  [3083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3566),
  [3085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5948),
  [3087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1671),
  [3089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5691),
  [3091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1872),
  [3093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6212),
  [3095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4863),
  [3097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [3099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [3101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [3103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [3105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(657),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7518),
  [3111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1558),
  [3113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1557),
  [3115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [3117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4268),
  [3119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3656),
  [3121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3657),
  [3123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5921),
  [3125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4155),
  [3127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5621),
  [3129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4399),
  [3131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6213),
  [3133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4832),
  [3135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [3137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(368),
  [3139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [3141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [3143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4311),
  [3145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7556),
  [3147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4168),
  [3149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4315),
  [3151] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1598),
  [3154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3548),
  [3157] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3549),
  [3160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5995),
  [3163] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1623),
  [3166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5689),
  [3169] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1848),
  [3172] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6184),
  [3175] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4940),
  [3178] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [3181] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(141),
  [3184] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [3187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(139),
  [3190] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(656),
  [3193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1594),
  [3196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7513),
  [3199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(644),
  [3201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1611),
  [3203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3587),
  [3205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3588),
  [3207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5951),
  [3209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1588),
  [3211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5667),
  [3213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [3215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6186),
  [3217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4939),
  [3219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [3221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [3223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [3225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [3229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7529),
  [3231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1524),
  [3233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3676),
  [3235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3677),
  [3237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5976),
  [3239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1523),
  [3241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5643),
  [3243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1712),
  [3245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6210),
  [3247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4892),
  [3249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [3251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [3253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(396),
  [3255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(347),
  [3257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [3259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7565),
  [3261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1524),
  [3264] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3676),
  [3267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3677),
  [3270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5976),
  [3273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1523),
  [3276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5643),
  [3279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1712),
  [3282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6210),
  [3285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4892),
  [3288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(394),
  [3291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(395),
  [3294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(396),
  [3297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(347),
  [3300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1522),
  [3303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7565),
  [3306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1598),
  [3308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3548),
  [3310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3549),
  [3312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5995),
  [3314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1623),
  [3316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5689),
  [3318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1848),
  [3320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6184),
  [3322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4940),
  [3324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [3326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [3328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [3330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(139),
  [3332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(681),
  [3334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1594),
  [3336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7513),
  [3338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4234),
  [3340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3682),
  [3342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3683),
  [3344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5998),
  [3346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4134),
  [3348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5648),
  [3350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4366),
  [3352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6185),
  [3354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4905),
  [3356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(403),
  [3358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(404),
  [3360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(405),
  [3362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [3364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [3366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7568),
  [3368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4254),
  [3370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4247),
  [3372] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1611),
  [3375] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3587),
  [3378] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3588),
  [3381] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5951),
  [3384] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1588),
  [3387] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5667),
  [3390] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1752),
  [3393] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6186),
  [3396] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4939),
  [3399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(224),
  [3402] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(225),
  [3405] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(226),
  [3408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(203),
  [3411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1610),
  [3414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7529),
  [3417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [3419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [3421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [3423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1328),
  [3425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1327),
  [3427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [3429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1512),
  [3431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1511),
  [3433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [3435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1399),
  [3437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5633),
  [3439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1394),
  [3441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [3443] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1663),
  [3446] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1688),
  [3449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1662),
  [3452] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1890),
  [3455] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3789),
  [3458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(4124),
  [3461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1902),
  [3464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7376),
  [3467] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(1889),
  [3470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [3472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4414),
  [3474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3678),
  [3476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3679),
  [3478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5985),
  [3480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4230),
  [3482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5645),
  [3484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4642),
  [3486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6195),
  [3488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4900),
  [3490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(397),
  [3492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [3494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [3496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(351),
  [3498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4404),
  [3500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7566),
  [3502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4454),
  [3504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3589),
  [3506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3590),
  [3508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5986),
  [3510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4185),
  [3512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5670),
  [3514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4173),
  [3516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6236),
  [3518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4926),
  [3520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(228),
  [3522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [3524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(230),
  [3526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [3528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4453),
  [3530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7530),
  [3532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4343),
  [3534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4340),
  [3536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4456),
  [3538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4455),
  [3540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5043),
  [3542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [3544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(429),
  [3546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3744),
  [3548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1541),
  [3550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6279),
  [3552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3953),
  [3554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3593),
  [3556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3594),
  [3558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5781),
  [3560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5055),
  [3562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5679),
  [3564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4740),
  [3566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6217),
  [3568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4755),
  [3570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [3572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [3574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [3576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [3578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6018),
  [3580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5042),
  [3582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7532),
  [3584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6280),
  [3586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6348),
  [3588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1800),
  [3590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3583),
  [3592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3584),
  [3594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5799),
  [3596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1723),
  [3598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5663),
  [3600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2002),
  [3602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6259),
  [3604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4895),
  [3606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [3608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [3610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [3612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [3614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [3616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7527),
  [3618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1647),
  [3620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5718),
  [3622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1645),
  [3624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [3626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6322),
  [3628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6319),
  [3630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6302),
  [3632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1851),
  [3634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3596),
  [3636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3597),
  [3638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5788),
  [3640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1791),
  [3642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5681),
  [3644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2005),
  [3646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6268),
  [3648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4807),
  [3650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [3652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [3654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [3656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [3658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [3660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7533),
  [3662] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(2177),
  [3665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3743),
  [3668] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3919),
  [3671] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3709),
  [3674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(3580),
  [3677] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5929),
  [3680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(2078),
  [3683] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(5656),
  [3686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(2177),
  [3689] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(2258),
  [3692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(6211),
  [3695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(4830),
  [3698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(208),
  [3701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(209),
  [3704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(210),
  [3707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(187),
  [3710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(6981),
  [3713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(2142),
  [3716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(2449),
  [3719] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 38), SHIFT_REPEAT(7525),
  [3722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4441),
  [3724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4302),
  [3726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4440),
  [3728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6362),
  [3730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1876),
  [3732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1887),
  [3734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [3736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [3738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6321),
  [3740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1851),
  [3743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3596),
  [3746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3597),
  [3749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5788),
  [3752] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1791),
  [3755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5681),
  [3758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2005),
  [3761] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6268),
  [3764] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4807),
  [3767] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(244),
  [3770] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [3773] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(246),
  [3776] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(219),
  [3779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1850),
  [3782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7533),
  [3785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6330),
  [3787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4476),
  [3789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4475),
  [3791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6293),
  [3793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1761),
  [3795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1750),
  [3797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [3799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1718),
  [3801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1717),
  [3803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [3805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1419),
  [3807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1417),
  [3809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [3811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [3813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1815),
  [3815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1812),
  [3817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [3819] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1800),
  [3822] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3583),
  [3825] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3584),
  [3828] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5799),
  [3831] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1723),
  [3834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5663),
  [3837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2002),
  [3840] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6259),
  [3843] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4895),
  [3846] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(216),
  [3849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(217),
  [3852] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(218),
  [3855] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(195),
  [3858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1799),
  [3861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7527),
  [3864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1761),
  [3867] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1750),
  [3870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1760),
  [3873] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1876),
  [3876] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1887),
  [3879] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(725),
  [3882] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1875),
  [3885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1550),
  [3887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1549),
  [3889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [3891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2289),
  [3893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2304),
  [3895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [3897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6608),
  [3899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2288),
  [3901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1775),
  [3903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1774),
  [3905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [3907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1552),
  [3909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5662),
  [3911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1551),
  [3913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [3915] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2289),
  [3918] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2304),
  [3921] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(731),
  [3924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6608),
  [3927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2288),
  [3930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [3932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [3934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1853),
  [3936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1852),
  [3938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [3940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4635),
  [3942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3585),
  [3944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3586),
  [3946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5867),
  [3948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4369),
  [3950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5665),
  [3952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4392),
  [3954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6169),
  [3956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4911),
  [3958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [3960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [3962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(222),
  [3964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(199),
  [3966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4633),
  [3968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7528),
  [3970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1630),
  [3972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1629),
  [3974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [3976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2014),
  [3978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2013),
  [3980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [3982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1773),
  [3984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1738),
  [3986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [3988] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2321),
  [3991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3575),
  [3994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3576),
  [3997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5880),
  [4000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2354),
  [4003] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5624),
  [4006] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2321),
  [4009] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2494),
  [4012] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6160),
  [4015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4754),
  [4018] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(200),
  [4021] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(201),
  [4024] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(202),
  [4027] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(179),
  [4030] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(747),
  [4033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6469),
  [4036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2395),
  [4039] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7523),
  [4042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2006),
  [4044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5659),
  [4046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2003),
  [4048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [4050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2054),
  [4052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2052),
  [4054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [4056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1931),
  [4058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1995),
  [4060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1930),
  [4062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2321),
  [4064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3575),
  [4066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3576),
  [4068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5880),
  [4070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2354),
  [4072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5624),
  [4074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2321),
  [4076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2494),
  [4078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6160),
  [4080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4754),
  [4082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(200),
  [4084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [4086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [4088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [4090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(779),
  [4092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6469),
  [4094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [4096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7523),
  [4098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4495),
  [4100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4290),
  [4102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4494),
  [4104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4497),
  [4106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4496),
  [4108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1931),
  [4111] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1995),
  [4114] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1930),
  [4117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4568),
  [4119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4430),
  [4121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4567),
  [4123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4572),
  [4125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4571),
  [4127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4625),
  [4129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4482),
  [4131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4624),
  [4133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4627),
  [4135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4626),
  [4137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4637),
  [4139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4636),
  [4141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1680),
  [4143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1679),
  [4145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [4147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [4149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4117),
  [4151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4117),
  [4153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0),
  [4155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 3, 0, 0),
  [4157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement_not_pipeline, 1, 0, 0),
  [4159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 3, 0, 0),
  [4161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0),
  [4163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0), SHIFT(6486),
  [4166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0), SHIFT(6979),
  [4169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [4171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(437),
  [4173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7388),
  [4175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [4177] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2283),
  [4180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3571),
  [4183] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3572),
  [4186] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5804),
  [4189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2270),
  [4192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5739),
  [4195] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2283),
  [4198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2370),
  [4201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6170),
  [4204] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4695),
  [4207] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(192),
  [4210] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(193),
  [4213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(194),
  [4216] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(171),
  [4219] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2282),
  [4222] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7521),
  [4225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4650),
  [4227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4421),
  [4229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4507),
  [4231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4876),
  [4233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4618),
  [4235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4875),
  [4237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4880),
  [4239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4879),
  [4241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4654),
  [4243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4653),
  [4245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2266),
  [4247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5656),
  [4249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2263),
  [4251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2263),
  [4253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(599),
  [4255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statements, 1, 0, 0),
  [4257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [4259] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2287),
  [4262] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2303),
  [4265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2286),
  [4268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement_not_pipeline, 1, 0, 0),
  [4270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4082),
  [4272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4086),
  [4274] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4117),
  [4277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4117),
  [4280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_herestring_redirect, 2, 0, 10),
  [4282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_herestring_redirect, 2, 0, 10),
  [4284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3807),
  [4286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3807),
  [4288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3995),
  [4290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(590),
  [4292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(439),
  [4294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7413),
  [4296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [4298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0), SHIFT(6495),
  [4301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4035),
  [4303] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 37),
  [4305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 37),
  [4307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_herestring_redirect, 3, 0, 23),
  [4309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_herestring_redirect, 3, 0, 23),
  [4311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_herestring_redirect, 3, 0, 4),
  [4313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_herestring_redirect, 3, 0, 4),
  [4315] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3807),
  [4318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3807),
  [4321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2382),
  [4323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3616),
  [4325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3617),
  [4327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5820),
  [4329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2350),
  [4331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5698),
  [4333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2382),
  [4335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2454),
  [4337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6271),
  [4339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4751),
  [4341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [4343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [4345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [4347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [4349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2380),
  [4351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7539),
  [4353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2413),
  [4356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2425),
  [4359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2411),
  [4362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2413),
  [4364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2425),
  [4366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2411),
  [4368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 1, 0, 16),
  [4370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 1, 0, 16),
  [4372] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2382),
  [4375] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3616),
  [4378] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3617),
  [4381] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5820),
  [4384] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2350),
  [4387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5698),
  [4390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2382),
  [4393] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2454),
  [4396] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6271),
  [4399] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4751),
  [4402] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(268),
  [4405] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(269),
  [4408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(270),
  [4411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(243),
  [4414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2380),
  [4417] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7539),
  [4420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0), SHIFT(6856),
  [4423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3816),
  [4425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [4427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4010),
  [4429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [4431] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3816),
  [4434] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3816),
  [4437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_herestring_redirect, 2, 0, 0),
  [4439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_herestring_redirect, 2, 0, 0),
  [4441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 1, 0, 17),
  [4443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 1, 0, 17),
  [4445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [4447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2308),
  [4449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [4451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [4453] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2335),
  [4456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3607),
  [4459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3608),
  [4462] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5807),
  [4465] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2369),
  [4468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5688),
  [4471] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2335),
  [4474] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2510),
  [4477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6187),
  [4480] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4799),
  [4483] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(256),
  [4486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(257),
  [4489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(258),
  [4492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(231),
  [4495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2426),
  [4498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7536),
  [4501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2393),
  [4504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2308),
  [4507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(851),
  [4510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2392),
  [4513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [4515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [4517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 2, 0, 36),
  [4519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 2, 0, 36),
  [4521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [4523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statements, 1, 0, 0),
  [4525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [4527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [4529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7422),
  [4531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [4533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0), SHIFT(6624),
  [4536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2540),
  [4538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3641),
  [4540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [4542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5883),
  [4544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [4546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5747),
  [4548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [4550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2600),
  [4552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6163),
  [4554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4757),
  [4556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(336),
  [4558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [4560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [4562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [4564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [4566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7549),
  [4568] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2540),
  [4571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3641),
  [4574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3642),
  [4577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5883),
  [4580] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2531),
  [4583] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5747),
  [4586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2540),
  [4589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2600),
  [4592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6163),
  [4595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4757),
  [4598] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(336),
  [4601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(337),
  [4604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(338),
  [4607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(283),
  [4610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2504),
  [4613] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7549),
  [4616] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0), SHIFT(6463),
  [4619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2319),
  [4621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5739),
  [4623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2318),
  [4625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2318),
  [4627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2513),
  [4629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3577),
  [4631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3578),
  [4633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5900),
  [4635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2465),
  [4637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5652),
  [4639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [4641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2753),
  [4643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6167),
  [4645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4793),
  [4647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(204),
  [4649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [4651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [4653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [4655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [4657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2526),
  [4659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7524),
  [4661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3902),
  [4663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3902),
  [4665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3826),
  [4667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3826),
  [4669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [4671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6457),
  [4673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4012),
  [4675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(933),
  [4677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [4679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(984),
  [4682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3902),
  [4685] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3902),
  [4688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3815),
  [4690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3818),
  [4692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3826),
  [4695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3826),
  [4698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3958),
  [4700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3958),
  [4702] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2513),
  [4705] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3577),
  [4708] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3578),
  [4711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5900),
  [4714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2465),
  [4717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(5652),
  [4720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2513),
  [4723] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2753),
  [4726] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(6167),
  [4729] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(4793),
  [4732] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(204),
  [4735] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(205),
  [4738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(206),
  [4741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(183),
  [4744] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(933),
  [4747] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2526),
  [4750] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 2, 0, 0), SHIFT_REPEAT(7524),
  [4753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [4755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [4757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2562),
  [4759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5698),
  [4761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2552),
  [4763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [4765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [4767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(984),
  [4769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3879),
  [4771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2556),
  [4773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2561),
  [4775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [4777] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2556),
  [4780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2561),
  [4783] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2555),
  [4786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [4788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3810),
  [4790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [4792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [4794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0), SHIFT(7338),
  [4797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(430),
  [4799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [4801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2538),
  [4803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [4805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [4807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5812),
  [4809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2490),
  [4811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5692),
  [4813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [4815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2794),
  [4817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6209),
  [4819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4703),
  [4821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [4823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [4825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [4827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [4829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [4831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7537),
  [4833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5035),
  [4835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [4837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [4839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5826),
  [4841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5007),
  [4843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5700),
  [4845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5035),
  [4847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5201),
  [4849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6207),
  [4851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4779),
  [4853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(272),
  [4855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [4857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [4859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [4861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5034),
  [4863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7540),
  [4865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5037),
  [4867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5037),
  [4869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5036),
  [4871] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3958),
  [4874] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3958),
  [4877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2538),
  [4880] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3611),
  [4883] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3612),
  [4886] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5812),
  [4889] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2490),
  [4892] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5692),
  [4895] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2538),
  [4898] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2794),
  [4901] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6209),
  [4904] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4703),
  [4907] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(260),
  [4910] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(261),
  [4913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(262),
  [4916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(235),
  [4919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2536),
  [4922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7537),
  [4925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2564),
  [4927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5701),
  [4929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2441),
  [4931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2441),
  [4933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [4935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5108),
  [4937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4988),
  [4939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5107),
  [4941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5110),
  [4943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5109),
  [4945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2800),
  [4947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5692),
  [4949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2799),
  [4951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2799),
  [4953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2233),
  [4955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2232),
  [4957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2232),
  [4959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3960),
  [4961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4073),
  [4963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3799),
  [4965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4030),
  [4967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4040),
  [4969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3799),
  [4972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3799),
  [4975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3802),
  [4977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3881),
  [4979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3869),
  [4981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3802),
  [4984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3802),
  [4987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3799),
  [4989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3802),
  [4991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [4993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [4995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [4997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0), SHIFT(6474),
  [5000] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3960),
  [5003] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3960),
  [5006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1163),
  [5009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2655),
  [5011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3636),
  [5013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3637),
  [5015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5873),
  [5017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2578),
  [5019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5741),
  [5021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2655),
  [5023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2856),
  [5025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6273),
  [5027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4721),
  [5029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [5031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [5033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [5035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [5037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2654),
  [5039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7547),
  [5041] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2655),
  [5044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3636),
  [5047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3637),
  [5050] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5873),
  [5053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2578),
  [5056] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5741),
  [5059] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2655),
  [5062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2856),
  [5065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6273),
  [5068] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4721),
  [5071] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(328),
  [5074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(329),
  [5077] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(330),
  [5080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(275),
  [5083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2654),
  [5086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7547),
  [5089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5141),
  [5091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3644),
  [5093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3645),
  [5095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5887),
  [5097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5100),
  [5099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5751),
  [5101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5141),
  [5103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5334),
  [5105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6214),
  [5107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4781),
  [5109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(340),
  [5111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [5113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [5115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [5117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5140),
  [5119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7550),
  [5121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5148),
  [5123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5148),
  [5125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5147),
  [5127] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1214),
  [5130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 1, 0, 1),
  [5132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 1, 0, 1),
  [5134] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 1, 0, 0),
  [5136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 1, 0, 0),
  [5138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3960),
  [5140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [5142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0), SHIFT(7387),
  [5145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__extglob_blob, 1, 0, 0),
  [5147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extglob_blob, 1, 0, 0),
  [5149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5728),
  [5151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4676),
  [5153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [5155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [5157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [5159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(741),
  [5161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [5163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [5165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0), SHIFT(6465),
  [5168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3906),
  [5170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [5172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2607),
  [5174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5747),
  [5176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2606),
  [5178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2606),
  [5180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(682),
  [5182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [5184] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 1, 0, 1),
  [5186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 1, 0, 1),
  [5188] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declaration_command_repeat1, 1, 0, 0),
  [5190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_command_repeat1, 1, 0, 0),
  [5192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2434),
  [5194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5688),
  [5196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2433),
  [5198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2433),
  [5200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3914),
  [5202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [5204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [5206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(570),
  [5208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [5210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [5212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [5214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5139),
  [5216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3614),
  [5218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3615),
  [5220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5815),
  [5222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5114),
  [5224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5695),
  [5226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5139),
  [5228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5286),
  [5230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6252),
  [5232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4722),
  [5234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [5236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [5238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [5240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [5242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5138),
  [5244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7538),
  [5246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5174),
  [5248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5174),
  [5250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5172),
  [5252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4087),
  [5254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4114),
  [5256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3906),
  [5259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3906),
  [5262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4071),
  [5264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 3, 0, 25),
  [5266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 3, 0, 25),
  [5268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 3, 0, 24),
  [5270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 3, 0, 24),
  [5272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0), SHIFT(7285),
  [5275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5237),
  [5277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5019),
  [5279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5236),
  [5281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5241),
  [5283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5240),
  [5285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [5287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [5289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 1, 0, 0),
  [5291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 1, 0, 0),
  [5293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3805),
  [5295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3805),
  [5297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1438),
  [5300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3813),
  [5302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3813),
  [5304] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1361),
  [5307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3878),
  [5309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3903),
  [5311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3813),
  [5314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3813),
  [5317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5350),
  [5319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3638),
  [5321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3639),
  [5323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5877),
  [5325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5217),
  [5327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5743),
  [5329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5350),
  [5331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5448),
  [5333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6241),
  [5335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4729),
  [5337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(332),
  [5339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [5341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [5343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [5345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5348),
  [5347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7548),
  [5349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2759),
  [5351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5652),
  [5353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2758),
  [5355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [5357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1339),
  [5359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5397),
  [5361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5397),
  [5363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5395),
  [5365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2357),
  [5367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [5369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4),
  [5371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [5373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2357),
  [5375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [5377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [5379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2892),
  [5381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5741),
  [5383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2891),
  [5385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [5387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unset_command_repeat1, 1, 0, 1),
  [5389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unset_command_repeat1, 1, 0, 1),
  [5391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3819),
  [5393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3966),
  [5395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3977),
  [5397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat2, 1, 0, 3),
  [5399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat2, 1, 0, 3),
  [5401] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3819),
  [5404] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3819),
  [5407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2342),
  [5409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2342),
  [5411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [5413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3819),
  [5415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4021),
  [5417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4072),
  [5419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [5421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3988),
  [5423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2431),
  [5425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2431),
  [5427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [5429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3822),
  [5431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4047),
  [5433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4053),
  [5435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2362),
  [5437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2362),
  [5439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [5441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5734),
  [5443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4706),
  [5445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [5447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [5449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [5451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2418),
  [5453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2418),
  [5455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [5457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2355),
  [5459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2355),
  [5461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [5463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3822),
  [5466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3822),
  [5469] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3805),
  [5472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3805),
  [5475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3822),
  [5477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1438),
  [5479] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1339),
  [5482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1361),
  [5484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2471),
  [5486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5624),
  [5488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2461),
  [5490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2461),
  [5492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3809),
  [5494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3809),
  [5496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3829),
  [5498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3865),
  [5500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3889),
  [5502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3889),
  [5504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3082),
  [5507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3628),
  [5510] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3629),
  [5513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5850),
  [5516] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3073),
  [5519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5730),
  [5522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3344),
  [5525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6215),
  [5528] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4692),
  [5531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(312),
  [5534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(313),
  [5537] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(314),
  [5540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(263),
  [5543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3080),
  [5546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7544),
  [5549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3829),
  [5551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1687),
  [5553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3824),
  [5555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3824),
  [5557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4116),
  [5559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1646),
  [5561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_file_redirect, 3, 0, 22),
  [5563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_file_redirect, 3, 0, 22),
  [5565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4122),
  [5567] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3824),
  [5570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3824),
  [5573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4062),
  [5575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [5577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3928),
  [5579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3928),
  [5581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3938),
  [5583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3938),
  [5585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3868),
  [5587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3868),
  [5589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3862),
  [5591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3854),
  [5593] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3868),
  [5596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3868),
  [5599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [5601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5724),
  [5603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4929),
  [5605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [5607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [5609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [5611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1643),
  [5613] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3889),
  [5616] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3889),
  [5619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3082),
  [5621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3628),
  [5623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3629),
  [5625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5850),
  [5627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3073),
  [5629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5730),
  [5631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3344),
  [5633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6215),
  [5635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4692),
  [5637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [5639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [5641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [5643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [5645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3080),
  [5647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7544),
  [5649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3866),
  [5651] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1646),
  [5654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4074),
  [5656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1465),
  [5659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3957),
  [5661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [5663] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3809),
  [5666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3809),
  [5669] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1687),
  [5672] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1643),
  [5675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1465),
  [5677] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3928),
  [5680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3928),
  [5683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3801),
  [5685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3806),
  [5687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_file_redirect, 2, 0, 9),
  [5689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_file_redirect, 2, 0, 9),
  [5691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3938),
  [5694] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3938),
  [5697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3829),
  [5700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3829),
  [5703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1762),
  [5705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 3, 0, 0),
  [5707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 3, 0, 0),
  [5709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3316),
  [5711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3312),
  [5713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3312),
  [5715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1829),
  [5717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1762),
  [5720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1776),
  [5722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1888),
  [5725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3948),
  [5728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3948),
  [5731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1888),
  [5733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3948),
  [5735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [5737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1776),
  [5740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3827),
  [5742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3831),
  [5744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3833),
  [5746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1829),
  [5749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3827),
  [5752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3827),
  [5755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [5757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [5759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [5761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5489),
  [5763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3630),
  [5765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3631),
  [5767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5858),
  [5769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5414),
  [5771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5732),
  [5773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5545),
  [5775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6234),
  [5777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4701),
  [5779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(316),
  [5781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(317),
  [5783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(318),
  [5785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [5787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5486),
  [5789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7545),
  [5791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5498),
  [5793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5496),
  [5795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [5797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2246),
  [5799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [5801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4038),
  [5803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [5805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [5807] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4038),
  [5810] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4038),
  [5813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2259),
  [5815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [5817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4038),
  [5819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [5821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3969),
  [5823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3973),
  [5825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3978),
  [5827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3891),
  [5829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3891),
  [5831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3916),
  [5833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4061),
  [5835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4051),
  [5837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4054),
  [5839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4061),
  [5842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4061),
  [5845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [5847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__heredoc_expression, 2, 0, 66),
  [5849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0), SHIFT(6480),
  [5852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__heredoc_pipeline, 2, 0, 0),
  [5854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4061),
  [5856] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_negated_command, 2, 0, 0),
  [5858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_negated_command, 2, 0, 0),
  [5860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 1, 0, 3),
  [5862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0),
  [5864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), REDUCE(aux_sym_command_repeat1, 1, 0, 3),
  [5867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0),
  [5869] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), REDUCE(aux_sym_command_repeat1, 1, 0, 3),
  [5872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 3),
  [5874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3948),
  [5876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3976),
  [5878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3820),
  [5880] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3891),
  [5883] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3891),
  [5886] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 2, 0, 0),
  [5888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 2, 0, 0),
  [5890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2299),
  [5892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_command_name, 1, 0, 0), SHIFT(7412),
  [5895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3918),
  [5897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2442),
  [5899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4023),
  [5901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [5903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4023),
  [5906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4023),
  [5909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2127),
  [5911] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2214),
  [5914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2004),
  [5916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4023),
  [5918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 1, 0, 0), SHIFT(6470),
  [5921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2651),
  [5923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [5925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7145),
  [5927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7145),
  [5929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4065),
  [5931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4067),
  [5933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4056),
  [5935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4036),
  [5937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2053),
  [5939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4039),
  [5941] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4056),
  [5944] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4056),
  [5947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3979),
  [5949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3981),
  [5951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3936),
  [5953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [5955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2122),
  [5957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4056),
  [5959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2076),
  [5961] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2004),
  [5964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2195),
  [5966] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2053),
  [5969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2076),
  [5972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4016),
  [5974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3890),
  [5976] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3373),
  [5979] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3569),
  [5982] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3570),
  [5985] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5994),
  [5988] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3354),
  [5991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5722),
  [5994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3373),
  [5997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3404),
  [6000] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6264),
  [6003] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4679),
  [6006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(188),
  [6009] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(189),
  [6012] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(190),
  [6015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(167),
  [6018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3358),
  [6021] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7520),
  [6024] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2122),
  [6027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3898),
  [6029] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2127),
  [6032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6812),
  [6034] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4016),
  [6037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2195),
  [6040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3923),
  [6042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2880),
  [6044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2214),
  [6046] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6056),
  [6049] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4463),
  [6052] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4471),
  [6055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4011),
  [6057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3867),
  [6059] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2785),
  [6062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2247),
  [6064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3871),
  [6066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [6068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [6070] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1050),
  [6073] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2281),
  [6076] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1573),
  [6079] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2298),
  [6082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2298),
  [6084] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1080),
  [6087] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3835),
  [6090] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4011),
  [6093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2235),
  [6095] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6126),
  [6098] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(503),
  [6101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2242),
  [6104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1640),
  [6107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1863),
  [6110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2247),
  [6113] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(3193),
  [6116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4559),
  [6119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1581),
  [6122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1238),
  [6125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2459),
  [6128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2950),
  [6131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(3184),
  [6134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1700),
  [6137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2235),
  [6140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1486),
  [6143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1731),
  [6146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1229),
  [6149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(3414),
  [6152] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2316),
  [6155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(483),
  [6158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2554),
  [6161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2763),
  [6164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2220),
  [6167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2063),
  [6170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1950),
  [6173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4425),
  [6176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1795),
  [6179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4208),
  [6182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(5155),
  [6185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(3237),
  [6188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4824),
  [6191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2038),
  [6194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1822),
  [6197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6411),
  [6200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2276),
  [6202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2281),
  [6204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2553),
  [6207] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2574),
  [6210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(5319),
  [6213] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2464),
  [6216] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(5215),
  [6219] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6115),
  [6222] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6431),
  [6225] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4220),
  [6228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(3233),
  [6231] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6593),
  [6234] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(5246),
  [6237] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2276),
  [6240] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2598),
  [6243] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2415),
  [6246] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6304),
  [6249] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(3337),
  [6252] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(5531),
  [6255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2537),
  [6258] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(847),
  [6261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2848),
  [6264] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(5404),
  [6267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(2621),
  [6270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(5304),
  [6273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6119),
  [6276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1141),
  [6279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1145),
  [6282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1342),
  [6285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(923),
  [6288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1545),
  [6291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4468),
  [6294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1434),
  [6297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4298),
  [6300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(935),
  [6303] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(4178),
  [6306] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1302),
  [6309] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1315),
  [6312] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1570),
  [6315] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1039),
  [6318] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(1735),
  [6321] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 1, 0, 0), SHIFT(6392),
  [6324] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2352),
  [6327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3980),
  [6329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2402),
  [6332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2352),
  [6334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3924),
  [6336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3925),
  [6338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [6340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3931),
  [6342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3410),
  [6344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5722),
  [6346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3409),
  [6348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3409),
  [6350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3980),
  [6353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [6355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3892),
  [6357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2351),
  [6359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2351),
  [6362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2402),
  [6364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3934),
  [6366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3935),
  [6368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2522),
  [6370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3939),
  [6372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3941),
  [6374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [6376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6223),
  [6378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3209),
  [6380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3689),
  [6382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5018),
  [6384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3209),
  [6386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3604),
  [6388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3605),
  [6390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5801),
  [6392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6198),
  [6394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5685),
  [6396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6387),
  [6398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6162),
  [6400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4889),
  [6402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [6404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [6406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [6408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [6410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6204),
  [6412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6076),
  [6414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7535),
  [6416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3996),
  [6418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3163),
  [6420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5530),
  [6422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3163),
  [6424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [6426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4066),
  [6428] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2502),
  [6431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3166),
  [6433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5539),
  [6435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [6437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2502),
  [6439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7261),
  [6441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3963),
  [6443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3222),
  [6445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4983),
  [6447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3222),
  [6449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3917),
  [6452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3240),
  [6454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4786),
  [6456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3240),
  [6458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4070),
  [6460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3219),
  [6462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4782),
  [6464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3219),
  [6466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__extglob_blob, 2, 0, 0),
  [6468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extglob_blob, 2, 0, 0),
  [6470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2508),
  [6472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [6474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [6476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6777),
  [6478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2568),
  [6481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4091),
  [6483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6306),
  [6485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3759),
  [6487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4080),
  [6489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6623),
  [6491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3768),
  [6493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7348),
  [6495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4275),
  [6497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3718),
  [6499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7222),
  [6501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4081),
  [6503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3996),
  [6506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7154),
  [6508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4070),
  [6511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6988),
  [6513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3160),
  [6515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5597),
  [6517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [6519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3183),
  [6521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4766),
  [6523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3183),
  [6525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4104),
  [6527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3185),
  [6529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4777),
  [6531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3185),
  [6533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3161),
  [6535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5599),
  [6537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3161),
  [6539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3289),
  [6541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4928),
  [6543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3289),
  [6545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3187),
  [6547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4797),
  [6549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [6551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4106),
  [6553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3188),
  [6555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4859),
  [6557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [6559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4130),
  [6561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3168),
  [6563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4750),
  [6565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3168),
  [6567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3225),
  [6569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4978),
  [6571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3225),
  [6573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3920),
  [6575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4131),
  [6577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3922),
  [6579] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4091),
  [6582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2522),
  [6585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3967),
  [6587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3956),
  [6589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2960),
  [6591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [6593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3808),
  [6595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [6597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3997),
  [6599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3226),
  [6601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4984),
  [6603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3226),
  [6605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2878),
  [6607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3761),
  [6609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2666),
  [6611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 43),
  [6613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 43),
  [6615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2792),
  [6617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2658),
  [6620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4005),
  [6622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4079),
  [6624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4088),
  [6626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3842),
  [6628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4089),
  [6630] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4079),
  [6633] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4005),
  [6636] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2666),
  [6639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 5, 0, 41),
  [6641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 5, 0, 41),
  [6643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2596),
  [6645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_literal, 1, 0, 0),
  [6647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_literal, 1, 0, 0),
  [6649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [6651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 5, 0, 40),
  [6653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 5, 0, 40),
  [6655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2595),
  [6657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3845),
  [6659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [6661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__extglob_blob, 3, 0, 0),
  [6663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extglob_blob, 3, 0, 0),
  [6665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [6667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [6669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [6671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [6673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 4, 0, 40),
  [6675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 4, 0, 40),
  [6677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2587),
  [6679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4129),
  [6682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4027),
  [6684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4031),
  [6686] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2792),
  [6689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3846),
  [6691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [6693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 12),
  [6695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [6697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 12),
  [6699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3848),
  [6701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2658),
  [6703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 4, 0, 41),
  [6705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 4, 0, 41),
  [6707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2588),
  [6709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_expression, 2, 0, 27),
  [6711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_expression, 2, 0, 27),
  [6713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4120),
  [6715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4078),
  [6717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3823),
  [6719] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4120),
  [6722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2872),
  [6724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 6, 0, 40),
  [6726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 6, 0, 40),
  [6728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 6, 0, 41),
  [6730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 6, 0, 41),
  [6732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_expression_not_assignment, 1, 0, 0),
  [6734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4756),
  [6736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_expression_not_assignment, 1, 0, 0),
  [6738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [6740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [6742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_unary_expression, 2, 0, 12),
  [6744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_unary_expression, 2, 0, 12),
  [6746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2631),
  [6748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3519),
  [6750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3521),
  [6752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3537),
  [6754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3686),
  [6756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2628),
  [6758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1960),
  [6760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1961),
  [6762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1963),
  [6764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1964),
  [6766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [6768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_ternary_expression, 5, 0, 76),
  [6770] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_ternary_expression, 5, 0, 76),
  [6772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [6774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3498),
  [6776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3500),
  [6778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3667),
  [6780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3704),
  [6782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3508),
  [6784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3515),
  [6786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3515),
  [6788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3007),
  [6790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_postfix_expression, 2, 0, 27),
  [6792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_postfix_expression, 2, 0, 27),
  [6794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [6796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [6798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1955),
  [6800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1957),
  [6802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1958),
  [6804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [6806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1959),
  [6808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [6810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2133),
  [6812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1942),
  [6814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [6816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4252),
  [6818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4320),
  [6820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [6822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [6824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3502),
  [6826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3493),
  [6828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [6830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3493),
  [6832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [6834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6776),
  [6836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [6838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6987),
  [6840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7153),
  [6842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [6844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7260),
  [6846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2225),
  [6848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7347),
  [6850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [6852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [6854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6082),
  [6856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [6858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2443),
  [6860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [6862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [6864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [6866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [6868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3382),
  [6870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2397),
  [6872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [6874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [6876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2747),
  [6878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2274),
  [6880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [6882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [6884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4364),
  [6886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1745),
  [6888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4284),
  [6890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5132),
  [6892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4677),
  [6894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [6896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [6898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6389),
  [6900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [6902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [6904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5391),
  [6906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2570),
  [6908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5245),
  [6910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6479),
  [6912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4309),
  [6914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5305),
  [6916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3295),
  [6918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5529),
  [6920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [6922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [6924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5429),
  [6926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2585),
  [6928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_expression, 1, 0, 5),
  [6930] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_expression, 1, 0, 5),
  [6932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5352),
  [6934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [6936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_expression, 1, 0, 6),
  [6938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_expression, 1, 0, 6),
  [6940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [6942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [6944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [6946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [6948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4416),
  [6950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [6952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4216),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [6956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4319),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [6960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [6962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_expression, 1, 0, 7),
  [6964] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_expression, 1, 0, 7),
  [6966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [6968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [6970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [6972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4578),
  [6974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [6976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4385),
  [6978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4423),
  [6980] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2898),
  [6983] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 5, 0, 76),
  [6985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, 0, 76),
  [6987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_parenthesized_expression, 3, 0, 0),
  [6989] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_parenthesized_expression, 3, 0, 0),
  [6991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arithmetic_binary_expression, 3, 0, 43),
  [6993] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arithmetic_binary_expression, 3, 0, 43),
  [6995] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2991),
  [6998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7500),
  [7000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [7002] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(3007),
  [7005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6132),
  [7007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2138),
  [7009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2145),
  [7011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2157),
  [7013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2175),
  [7015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2815),
  [7017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2067),
  [7019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [7021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2118),
  [7023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2129),
  [7025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2181),
  [7027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1965),
  [7029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [7031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2050),
  [7033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [7035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2115),
  [7037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2119),
  [7039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2120),
  [7041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2190),
  [7043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4812),
  [7045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [7047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2126),
  [7049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [7051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1873),
  [7053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2135),
  [7055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2147),
  [7057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2152),
  [7059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2154),
  [7061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2178),
  [7063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2180),
  [7065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [7067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2188),
  [7069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2188),
  [7071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2191),
  [7073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2209),
  [7075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2212),
  [7077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1913),
  [7079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [7081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [7083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2131),
  [7085] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_binary_expression, 3, 0, 43),
  [7087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2932),
  [7089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5065),
  [7091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5066),
  [7093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5087),
  [7095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5088),
  [7097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5089),
  [7099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5090),
  [7101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_binary_expression, 3, 0, 43),
  [7103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5528),
  [7105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5490),
  [7107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4622),
  [7109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4873),
  [7111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5005),
  [7113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4639),
  [7115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [7117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4887),
  [7119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5010),
  [7121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4891),
  [7123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3151),
  [7125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_expression_not_assignment, 1, 0, 7),
  [7127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_expression_not_assignment, 1, 0, 7),
  [7129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4918),
  [7131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(3230),
  [7134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4794),
  [7136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3256),
  [7138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_parenthesized_expression, 4, 0, 0),
  [7140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_parenthesized_expression, 4, 0, 0),
  [7142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [7144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3101),
  [7146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1989),
  [7148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1976),
  [7150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [7152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [7154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [7156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1926),
  [7158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1927),
  [7160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1928),
  [7162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [7164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1932),
  [7166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [7168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1935),
  [7170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1944),
  [7172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1945),
  [7174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1947),
  [7176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [7178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [7180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1977),
  [7182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1917),
  [7184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arithmetic_expansion_repeat1, 2, 0, 0),
  [7186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4328),
  [7188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4327),
  [7190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4327),
  [7192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_expression, 1, 0, 0),
  [7194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5056),
  [7196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5059),
  [7198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5060),
  [7200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5062),
  [7202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5063),
  [7204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5064),
  [7206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_expression, 1, 0, 0),
  [7208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1966),
  [7210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_expression_not_assignment, 1, 0, 5),
  [7212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_expression_not_assignment, 1, 0, 5),
  [7214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_parenthesized_expression, 3, 0, 0),
  [7216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_parenthesized_expression, 3, 0, 0),
  [7218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [7220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2099),
  [7222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [7224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1993),
  [7226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1983),
  [7228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1998),
  [7230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2066),
  [7232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [7234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2089),
  [7236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [7238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [7240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [7242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2132),
  [7244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [7246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(3151),
  [7249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [7251] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_unary_expression, 2, 0, 12),
  [7253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_unary_expression, 2, 0, 12),
  [7255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_postfix_expression, 2, 0, 27),
  [7257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_postfix_expression, 2, 0, 27),
  [7259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3153),
  [7261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4844),
  [7263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4259),
  [7265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5631),
  [7267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4242),
  [7269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4242),
  [7271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4418),
  [7273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4417),
  [7275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4417),
  [7277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5579),
  [7279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5587),
  [7281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [7283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [7285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2080),
  [7287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3200),
  [7289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [7291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3230),
  [7293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3206),
  [7295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3207),
  [7297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4717),
  [7299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4593),
  [7301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6647),
  [7303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2635),
  [7305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [7307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3000),
  [7309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5497),
  [7311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(3256),
  [7314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2172),
  [7316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4509),
  [7318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6678),
  [7320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [7322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2167),
  [7324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2168),
  [7326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2169),
  [7328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2170),
  [7330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2159),
  [7332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3595),
  [7334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3176),
  [7336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3598),
  [7338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3599),
  [7340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3600),
  [7342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3603),
  [7344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3606),
  [7346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3609),
  [7348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3610),
  [7350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3613),
  [7352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [7354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3626),
  [7356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3627),
  [7358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3632),
  [7360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3633),
  [7362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3595),
  [7364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [7366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3223),
  [7368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3702),
  [7370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3579),
  [7372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3458),
  [7374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3459),
  [7376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [7378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3463),
  [7380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3463),
  [7382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3465),
  [7384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3466),
  [7386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3469),
  [7388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3475),
  [7390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3264),
  [7392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5071),
  [7394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5073),
  [7396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5074),
  [7398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5075),
  [7400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5080),
  [7402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5081),
  [7404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5082),
  [7406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5082),
  [7408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5083),
  [7410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5084),
  [7412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5085),
  [7414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5086),
  [7416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4191),
  [7418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4190),
  [7420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4190),
  [7422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4110),
  [7424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4110),
  [7426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [7428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5023),
  [7430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5024),
  [7432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5025),
  [7434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5026),
  [7436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5027),
  [7438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5028),
  [7440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5029),
  [7442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5029),
  [7444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5030),
  [7446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5031),
  [7448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5032),
  [7450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5033),
  [7452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 2, 0, 20),
  [7454] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 2, 0, 20), SHIFT_REPEAT(3741),
  [7457] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 20), SHIFT_REPEAT(3741),
  [7460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 20), SHIFT_REPEAT(2148),
  [7463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 20), SHIFT_REPEAT(3861),
  [7466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 20),
  [7468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 20), SHIFT_REPEAT(6036),
  [7471] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 20), SHIFT_REPEAT(6457),
  [7474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3298),
  [7476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4566),
  [7478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4565),
  [7480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4565),
  [7482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4435),
  [7484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5650),
  [7486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4434),
  [7488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4434),
  [7490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3693),
  [7492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3695),
  [7494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3699),
  [7496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [7498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3693),
  [7500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3527),
  [7502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2751),
  [7504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3690),
  [7506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3689),
  [7508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3604),
  [7510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3605),
  [7512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6198),
  [7514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5685),
  [7516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6223),
  [7518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4889),
  [7520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [7522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [7524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [7526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5568),
  [7528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5070),
  [7530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5585),
  [7532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4885),
  [7534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [7536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [7538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2162),
  [7540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2163),
  [7542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2164),
  [7544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [7546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2166),
  [7548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [7550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3282),
  [7552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3694),
  [7554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4774),
  [7556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4858),
  [7558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5022),
  [7560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3706),
  [7562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [7564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [7566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4972),
  [7568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4973),
  [7570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(3298),
  [7573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2213),
  [7575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [7577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3834),
  [7579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3849),
  [7581] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4110),
  [7584] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4110),
  [7587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4840),
  [7589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4283),
  [7591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5712),
  [7593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4282),
  [7595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4282),
  [7597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4408),
  [7599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4406),
  [7601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4406),
  [7603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3971),
  [7605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4614),
  [7607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6644),
  [7609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6644),
  [7611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4661),
  [7613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4610),
  [7615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6676),
  [7617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6676),
  [7619] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6152),
  [7622] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3499),
  [7625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3604),
  [7628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3605),
  [7631] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5801),
  [7634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6198),
  [7637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5685),
  [7640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6152),
  [7643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6387),
  [7646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6162),
  [7649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4889),
  [7652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(252),
  [7655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(253),
  [7658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(254),
  [7661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(227),
  [7664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6190),
  [7667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6076),
  [7670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7535),
  [7673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3971),
  [7676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4614),
  [7679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3593),
  [7682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3594),
  [7685] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5781),
  [7688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4661),
  [7691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5679),
  [7694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4740),
  [7697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6217),
  [7700] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4755),
  [7703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(240),
  [7706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(241),
  [7709] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(242),
  [7712] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(215),
  [7715] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4610),
  [7718] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7532),
  [7721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3847),
  [7723] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(3419),
  [7726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6654),
  [7728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6654),
  [7730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6629),
  [7732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6091),
  [7734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6100),
  [7736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5353),
  [7738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6100),
  [7740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 2, 0, 12),
  [7742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6015),
  [7744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7224),
  [7746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5102),
  [7748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6091),
  [7750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6629),
  [7752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6418),
  [7754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6698),
  [7756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6698),
  [7758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6312),
  [7760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3542),
  [7762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [7764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3621),
  [7766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5846),
  [7768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6492),
  [7770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5709),
  [7772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6312),
  [7774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6139),
  [7776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6250),
  [7778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4814),
  [7780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 3, 0, 51),
  [7782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [7784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [7786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [7788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [7790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6567),
  [7792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6677),
  [7794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6310),
  [7796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7543),
  [7798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3419),
  [7800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6315),
  [7802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6315),
  [7804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 2, 0, 49),
  [7806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6640),
  [7808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6292),
  [7810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6371),
  [7812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6371),
  [7814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 4, 0, 89),
  [7816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6696),
  [7818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6275),
  [7820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3863),
  [7822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6085),
  [7824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2346),
  [7826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3480),
  [7828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3607),
  [7830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3608),
  [7832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5807),
  [7834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2369),
  [7836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5688),
  [7838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [7840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2510),
  [7842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6187),
  [7844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4799),
  [7846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [7848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [7850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [7852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [7854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2852),
  [7856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2852),
  [7858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2387),
  [7860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7536),
  [7862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1363),
  [7864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3561),
  [7866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [7868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3511),
  [7870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5842),
  [7872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [7874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5718),
  [7876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [7878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1529),
  [7880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6230),
  [7882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4691),
  [7884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [7886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [7888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [7890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [7892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2036),
  [7894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [7896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [7898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7493),
  [7900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 1, 0, 13),
  [7902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 1, 0, 0),
  [7904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1447),
  [7906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3524),
  [7908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3546),
  [7910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [7912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [7914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5772),
  [7916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [7918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4689),
  [7920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [7922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [7924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [7926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1911),
  [7928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [7930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [7932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4375),
  [7934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [7936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [7938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3623),
  [7940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5831),
  [7942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4289),
  [7944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5712),
  [7946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4375),
  [7948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4243),
  [7950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6180),
  [7952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4845),
  [7954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [7956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [7958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [7960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [7962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4668),
  [7964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4668),
  [7966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4373),
  [7968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7541),
  [7970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3352),
  [7972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3698),
  [7974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3569),
  [7976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3570),
  [7978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5994),
  [7980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3354),
  [7982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5722),
  [7984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3352),
  [7986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3404),
  [7988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6264),
  [7990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4679),
  [7992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [7994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [7996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [7998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [8000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3701),
  [8002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3701),
  [8004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3349),
  [8006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7520),
  [8008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1377),
  [8010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3460),
  [8012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3563),
  [8014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3457),
  [8016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [8018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5675),
  [8020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [8022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4809),
  [8024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [8028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [8030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2056),
  [8032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [8034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [8036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4422),
  [8038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4303),
  [8040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4422),
  [8042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4506),
  [8044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4603),
  [8046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4378),
  [8048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4603),
  [8050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4602),
  [8052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2371),
  [8054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3468),
  [8056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [8058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2901),
  [8060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2901),
  [8062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2367),
  [8064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5124),
  [8066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3472),
  [8068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3624),
  [8070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3625),
  [8072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5839),
  [8074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5093),
  [8076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5720),
  [8078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5124),
  [8080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5337),
  [8082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6202),
  [8084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4924),
  [8086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [8088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [8090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [8092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [8094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5507),
  [8096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5507),
  [8098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5123),
  [8100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7542),
  [8102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4503),
  [8104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4169),
  [8106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4503),
  [8108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4502),
  [8110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [8112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3476),
  [8114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3646),
  [8116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3647),
  [8118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5893),
  [8120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [8122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5758),
  [8124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [8126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [8128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6238),
  [8130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4796),
  [8132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(348),
  [8134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [8136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [8138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [8140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1655),
  [8142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [8144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [8146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7551),
  [8148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5077),
  [8150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5000),
  [8152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5077),
  [8154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5076),
  [8156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1124),
  [8158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [8160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3648),
  [8162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3649),
  [8164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [8166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5763),
  [8168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [8170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4803),
  [8172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [8174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [8176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [8178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1660),
  [8180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [8182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [8184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4148),
  [8186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [8188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [8190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3666),
  [8192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5940),
  [8194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4002),
  [8196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5631),
  [8198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [8200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4312),
  [8202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6257),
  [8204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4857),
  [8206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [8208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [8210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [8212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [8214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4604),
  [8216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4604),
  [8218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4163),
  [8220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7560),
  [8222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [8224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3483),
  [8226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3668),
  [8228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3669),
  [8230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5949),
  [8232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [8234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5633),
  [8236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [8238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1428),
  [8240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6263),
  [8242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4868),
  [8244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [8246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [8248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [8250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [8252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1906),
  [8254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [8256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [8258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7561),
  [8260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1265),
  [8262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3486),
  [8264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3670),
  [8266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3671),
  [8268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [8270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5635),
  [8272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [8274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4872),
  [8276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [8278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [8280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [8282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1874),
  [8284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [8286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [8288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 2, 0, 33),
  [8290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4765),
  [8292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4764),
  [8294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4764),
  [8296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1678),
  [8298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3564),
  [8300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3559),
  [8302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [8304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5975),
  [8306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [8308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5662),
  [8310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [8312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1490),
  [8314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6254),
  [8316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4738),
  [8318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [8320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [8322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [8324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [8326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2043),
  [8328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [8330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [8332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7516),
  [8334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1686),
  [8336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [8338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [8340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [8342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1386),
  [8344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [8346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [8348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [8350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2297),
  [8352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2303),
  [8354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [8356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2296),
  [8358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2301),
  [8360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2304),
  [8362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2301),
  [8364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2300),
  [8366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4237),
  [8368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3489),
  [8370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3684),
  [8372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [8374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5859),
  [8376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4144),
  [8378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5650),
  [8380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4237),
  [8382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4391),
  [8384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6164),
  [8386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4913),
  [8388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [8390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [8392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [8394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [8396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4700),
  [8398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4700),
  [8400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4281),
  [8402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7569),
  [8404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3703),
  [8406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3697),
  [8408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3494),
  [8410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [8412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3501),
  [8414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3501),
  [8416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6030),
  [8418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5693),
  [8420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3017),
  [8422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2664),
  [8424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6221),
  [8426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4864),
  [8428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [8430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [8432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [8434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3017),
  [8436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [8438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [8440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2809),
  [8442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2810),
  [8444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2810),
  [8446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2981),
  [8448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2981),
  [8450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5209),
  [8452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5700),
  [8454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5208),
  [8456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5208),
  [8458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [8460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2816),
  [8462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [8464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2817),
  [8466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [8468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2821),
  [8470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [8472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2823),
  [8474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2863),
  [8476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2863),
  [8478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [8480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2827),
  [8482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [8484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2828),
  [8486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [8488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2830),
  [8490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3697),
  [8493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3494),
  [8496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3496),
  [8499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3501),
  [8502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3501),
  [8505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6030),
  [8508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5693),
  [8511] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3214),
  [8514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2664),
  [8517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6221),
  [8520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4864),
  [8523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(62),
  [8526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(104),
  [8529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [8532] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3214),
  [8535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2491),
  [8538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2942),
  [8540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2942),
  [8542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2980),
  [8544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2980),
  [8546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2947),
  [8548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2947),
  [8550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2986),
  [8552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2986),
  [8554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2993),
  [8556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2993),
  [8558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(3703),
  [8561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3010),
  [8563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3010),
  [8565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3513),
  [8567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3705),
  [8569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3464),
  [8571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3467),
  [8573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3467),
  [8575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6041),
  [8577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5625),
  [8579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3030),
  [8581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3141),
  [8583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6237),
  [8585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4931),
  [8587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [8589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [8591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [8593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3030),
  [8595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [8597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3525),
  [8599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [8601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3505),
  [8603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3506),
  [8605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [8607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6028),
  [8609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5636),
  [8611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3029),
  [8613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3075),
  [8615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6182),
  [8617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4699),
  [8619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [8621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [8623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [8625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3029),
  [8627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2908),
  [8629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3032),
  [8631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3032),
  [8633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5021),
  [8635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [8637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3591),
  [8639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3592),
  [8641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5777),
  [8643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5046),
  [8645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5673),
  [8647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5021),
  [8649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5142),
  [8651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6166),
  [8653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4865),
  [8655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [8657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [8659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [8661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [8663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5020),
  [8665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7531),
  [8667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3035),
  [8669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3035),
  [8671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [8673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3037),
  [8675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3037),
  [8677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3173),
  [8679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3173),
  [8681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3039),
  [8683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3039),
  [8685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3041),
  [8687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3041),
  [8689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [8691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3175),
  [8693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [8695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3043),
  [8697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3043),
  [8699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2841),
  [8701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3212),
  [8703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3212),
  [8705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5522),
  [8707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5495),
  [8709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [8711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3045),
  [8713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3045),
  [8715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [8717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [8719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [8721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [8723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2876),
  [8725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4621),
  [8727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4532),
  [8729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [8731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [8733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [8735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [8737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [8739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5021),
  [8742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3591),
  [8745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3592),
  [8748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5777),
  [8751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5046),
  [8754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5673),
  [8757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5021),
  [8760] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5142),
  [8763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6166),
  [8766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4865),
  [8769] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [8772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(233),
  [8775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(234),
  [8778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(211),
  [8781] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5020),
  [8784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7531),
  [8787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4921),
  [8789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4718),
  [8791] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(5043),
  [8794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67),
  [8796] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(3593),
  [8799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(3594),
  [8802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(5781),
  [8805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(5055),
  [8808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(5679),
  [8811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(4740),
  [8814] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(6217),
  [8817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(4755),
  [8820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(240),
  [8823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(241),
  [8826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(242),
  [8829] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(215),
  [8832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(5042),
  [8835] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__heredoc_command, 2, 0, 67), SHIFT_REPEAT(7532),
  [8838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2752),
  [8840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2752),
  [8842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2617),
  [8844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2617),
  [8846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [8848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2765),
  [8850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2619),
  [8852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2619),
  [8854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [8856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2766),
  [8858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [8860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2767),
  [8862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6248),
  [8864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6248),
  [8866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6246),
  [8868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [8870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2768),
  [8872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [8874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2623),
  [8876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2889),
  [8878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2889),
  [8880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [8882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3203),
  [8884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3203),
  [8886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3208),
  [8888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3208),
  [8890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [8892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3210),
  [8894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6313),
  [8896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6313),
  [8898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6382),
  [8900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [8902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2771),
  [8904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2656),
  [8906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2656),
  [8908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3147),
  [8910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3147),
  [8912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3149),
  [8914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3149),
  [8916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3158),
  [8918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3158),
  [8920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [8922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2772),
  [8924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6376),
  [8926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6291),
  [8928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2773),
  [8930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2773),
  [8932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [8934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2774),
  [8936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2659),
  [8938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2659),
  [8940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3179),
  [8942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3179),
  [8944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [8946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [8948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3180),
  [8950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6344),
  [8952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [8954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3181),
  [8956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6354),
  [8958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6365),
  [8960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1979),
  [8962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [8964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2791),
  [8966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3155),
  [8968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3155),
  [8970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2803),
  [8972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2803),
  [8974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3197),
  [8976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3197),
  [8978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6333),
  [8980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6339),
  [8982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [8984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2775),
  [8986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2667),
  [8988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [8990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3235),
  [8992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3235),
  [8994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6283),
  [8996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6287),
  [8998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6434),
  [9000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2669),
  [9002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2669),
  [9004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3257),
  [9006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3257),
  [9008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6438),
  [9010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [9012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2671),
  [9014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3268),
  [9016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3268),
  [9018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2672),
  [9020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2672),
  [9022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3280),
  [9024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3280),
  [9026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4608),
  [9028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6372),
  [9030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4515),
  [9032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2673),
  [9034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2673),
  [9036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3020),
  [9038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3020),
  [9040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2674),
  [9042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2674),
  [9044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [9046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3023),
  [9048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2675),
  [9050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2675),
  [9052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3026),
  [9054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3026),
  [9056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2676),
  [9058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2676),
  [9060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3028),
  [9062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3028),
  [9064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [9066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [9068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2678),
  [9070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2678),
  [9072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [9074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2679),
  [9076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2679),
  [9078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [9080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3033),
  [9082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2680),
  [9084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2680),
  [9086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3036),
  [9088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3036),
  [9090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2681),
  [9092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2681),
  [9094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3038),
  [9096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3038),
  [9098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2682),
  [9100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2682),
  [9102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3040),
  [9104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3040),
  [9106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [9108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2683),
  [9110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [9112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3042),
  [9114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2684),
  [9116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2684),
  [9118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3044),
  [9120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3044),
  [9122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2685),
  [9124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2685),
  [9126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [9128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3046),
  [9130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3025),
  [9132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3025),
  [9134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3048),
  [9136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3048),
  [9138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2688),
  [9140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2688),
  [9142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3050),
  [9144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3050),
  [9146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2689),
  [9148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2689),
  [9150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3052),
  [9152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3052),
  [9154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2690),
  [9156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2690),
  [9158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [9160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3054),
  [9162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2691),
  [9164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2691),
  [9166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3055),
  [9168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3055),
  [9170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2692),
  [9172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2692),
  [9174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3057),
  [9176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3057),
  [9178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [9180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2693),
  [9182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3058),
  [9184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3058),
  [9186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [9188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2694),
  [9190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3060),
  [9192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3060),
  [9194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3266),
  [9196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3266),
  [9198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2695),
  [9200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2695),
  [9202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [9204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3061),
  [9206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3269),
  [9208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3269),
  [9210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [9212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3270),
  [9214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3271),
  [9216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3271),
  [9218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2696),
  [9220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2696),
  [9222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3063),
  [9224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3063),
  [9226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3273),
  [9228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3273),
  [9230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [9232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2697),
  [9234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3065),
  [9236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3065),
  [9238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3276),
  [9240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3276),
  [9242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2698),
  [9244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2698),
  [9246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [9248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3067),
  [9250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3278),
  [9252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3278),
  [9254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3285),
  [9256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3285),
  [9258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2699),
  [9260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2699),
  [9262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3069),
  [9264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3069),
  [9266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3286),
  [9268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3286),
  [9270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2700),
  [9272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2700),
  [9274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3071),
  [9276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3071),
  [9278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [9280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2701),
  [9282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3072),
  [9284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3072),
  [9286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2702),
  [9288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2702),
  [9290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3074),
  [9292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3074),
  [9294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2703),
  [9296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2703),
  [9298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3076),
  [9300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3076),
  [9302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [9304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2704),
  [9306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3079),
  [9308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3079),
  [9310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [9312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2705),
  [9314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [9316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3081),
  [9318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3287),
  [9320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3287),
  [9322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3288),
  [9324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3288),
  [9326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [9328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2706),
  [9330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [9332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3083),
  [9334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2707),
  [9336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2707),
  [9338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [9340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3084),
  [9342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3251),
  [9344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3251),
  [9346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3089),
  [9348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3089),
  [9350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2708),
  [9352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2708),
  [9354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3085),
  [9356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3085),
  [9358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2709),
  [9360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2709),
  [9362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3086),
  [9364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3086),
  [9366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2710),
  [9368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2710),
  [9370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3088),
  [9372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3088),
  [9374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5386),
  [9376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5751),
  [9378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5377),
  [9380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5377),
  [9382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2711),
  [9384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2711),
  [9386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3090),
  [9388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3090),
  [9390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2713),
  [9392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2713),
  [9394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3093),
  [9396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3093),
  [9398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [9400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2714),
  [9402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3094),
  [9404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3094),
  [9406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [9408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2716),
  [9410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3096),
  [9412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3096),
  [9414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2717),
  [9416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2717),
  [9418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3098),
  [9420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3098),
  [9422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2718),
  [9424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2718),
  [9426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3100),
  [9428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3100),
  [9430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2719),
  [9432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2719),
  [9434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3102),
  [9436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3102),
  [9438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [9440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2720),
  [9442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3104),
  [9444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3104),
  [9446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [9448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2721),
  [9450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3106),
  [9452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3106),
  [9454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [9456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2722),
  [9458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3108),
  [9460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3108),
  [9462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [9464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2723),
  [9466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3110),
  [9468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3110),
  [9470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [9472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2724),
  [9474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [9476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3112),
  [9478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [9480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2769),
  [9482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2725),
  [9484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2725),
  [9486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3115),
  [9488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3115),
  [9490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [9492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2726),
  [9494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3118),
  [9496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3118),
  [9498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [9500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2728),
  [9502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3121),
  [9504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3121),
  [9506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2730),
  [9508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2730),
  [9510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3124),
  [9512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3124),
  [9514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2731),
  [9516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2731),
  [9518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [9520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3126),
  [9522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2732),
  [9524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2732),
  [9526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3128),
  [9528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3128),
  [9530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2733),
  [9532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2733),
  [9534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3130),
  [9536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3130),
  [9538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [9540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2734),
  [9542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [9544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3132),
  [9546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2735),
  [9548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2735),
  [9550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3134),
  [9552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3134),
  [9554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [9556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2776),
  [9558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6153),
  [9560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6153),
  [9562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6199),
  [9564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [9566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3113),
  [9568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3284),
  [9570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3284),
  [9572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [9574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3159),
  [9576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [9578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3156),
  [9580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3150),
  [9582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3150),
  [9584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [9586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3021),
  [9588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3021),
  [9590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [9592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [9594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3022),
  [9596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [9598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2770),
  [9600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3172),
  [9602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3172),
  [9604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2629),
  [9606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2629),
  [9608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5298),
  [9610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5695),
  [9612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5297),
  [9614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5297),
  [9616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2687),
  [9618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2687),
  [9620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5150),
  [9622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5673),
  [9624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5149),
  [9626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5149),
  [9628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [9630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3659),
  [9632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [9634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [9636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [9638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4836),
  [9640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [9642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [9644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [9646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [9648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3555),
  [9650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3556),
  [9652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [9654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5658),
  [9656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [9658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4686),
  [9660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [9662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [9664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [9666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [9668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [9670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [9672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [9674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [9676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2517),
  [9678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4184),
  [9680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2516),
  [9682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [9684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2516),
  [9686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3601),
  [9688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3602),
  [9690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1750),
  [9692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5683),
  [9694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [9696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4850),
  [9698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [9700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [9702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [9704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4215),
  [9706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3583),
  [9708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3584),
  [9710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [9712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5663),
  [9714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [9716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4895),
  [9718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [9720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [9722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [9724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3676),
  [9726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [9728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [9730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5643),
  [9732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [9734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4892),
  [9736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [9738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [9740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [9742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3680),
  [9744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [9746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [9748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5647),
  [9750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [9752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4903),
  [9754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [9756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [9758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [9760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(960),
  [9762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3674),
  [9764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3675),
  [9766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [9768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5640),
  [9770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [9772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4890),
  [9774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [9776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [9778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [9780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [9782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [9784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [9786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3593),
  [9788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3594),
  [9790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4661),
  [9792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5679),
  [9794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4614),
  [9796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4755),
  [9798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [9800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [9802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [9804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3596),
  [9806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3597),
  [9808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [9810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5681),
  [9812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [9814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4807),
  [9816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [9818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [9820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [9822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2335),
  [9824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2335),
  [9826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [9828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2350),
  [9830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2976),
  [9832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2977),
  [9834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3587),
  [9836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3588),
  [9838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [9840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5667),
  [9842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [9844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4939),
  [9846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [9848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [9850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [9852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [9854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3373),
  [9856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3373),
  [9858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3358),
  [9860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1325),
  [9862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [9864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [9866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1916),
  [9868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [9870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1914),
  [9872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [9874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [9876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [9878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3073),
  [9880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5730),
  [9882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3082),
  [9884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4692),
  [9886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [9888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [9890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [9892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [9894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2283),
  [9896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3571),
  [9898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3572),
  [9900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5804),
  [9902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2270),
  [9904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5739),
  [9906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2283),
  [9908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2370),
  [9910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6170),
  [9912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4695),
  [9914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [9916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [9918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [9920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [9922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2282),
  [9924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7521),
  [9926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6276),
  [9928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2490),
  [9930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3654),
  [9932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3655),
  [9934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [9936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5703),
  [9938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [9940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4826),
  [9942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [9944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [9946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [9948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [9950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [9952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6374),
  [9954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2933),
  [9956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6524),
  [9958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6525),
  [9960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1663),
  [9962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [9964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [9966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1021),
  [9968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [9970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [9972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [9974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3567),
  [9976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [9978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [9980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5711),
  [9982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [9984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4925),
  [9986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [9988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [9990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [9992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [9994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1483),
  [9996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5346),
  [9998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5720),
  [10000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5345),
  [10002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5345),
  [10004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5437),
  [10006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5743),
  [10008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5406),
  [10010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5406),
  [10012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [10014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [10016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [10018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [10020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [10022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [10024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [10026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2287),
  [10028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [10030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2286),
  [10032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1894),
  [10034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [10036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [10038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [10040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(816),
  [10042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3652),
  [10044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3653),
  [10046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [10048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5769),
  [10050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [10052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4816),
  [10054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [10056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [10058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [10060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [10062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [10064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [10066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2413),
  [10068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [10070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [10072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [10074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [10076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4271),
  [10078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3290),
  [10080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4270),
  [10082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4271),
  [10084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4270),
  [10086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5342),
  [10088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5341),
  [10090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5342),
  [10092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5341),
  [10094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [10096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [10098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [10100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1155),
  [10102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3992),
  [10104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1703),
  [10106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [10108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [10110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [10112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1702),
  [10114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1171),
  [10116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [10118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [10120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [10122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5281),
  [10124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3774),
  [10126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5280),
  [10128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5281),
  [10130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5280),
  [10132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4898),
  [10134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3782),
  [10136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4896),
  [10138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4898),
  [10140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4896),
  [10142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1304),
  [10144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3650),
  [10146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3651),
  [10148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [10150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5766),
  [10152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [10154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4810),
  [10156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [10158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [10160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [10162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1460),
  [10164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [10166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(889),
  [10168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [10170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [10172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(888),
  [10174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2446),
  [10176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [10178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [10180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2446),
  [10182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2542),
  [10184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1467),
  [10186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1466),
  [10188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [10190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1466),
  [10192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1110),
  [10194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [10196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [10198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [10200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [10202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4466),
  [10204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [10206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [10208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4433),
  [10210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5621),
  [10212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4466),
  [10214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4832),
  [10216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [10218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [10220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [10222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4433),
  [10224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3746),
  [10226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [10228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [10230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [10232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1321),
  [10234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4301),
  [10236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3660),
  [10238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3661),
  [10240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4257),
  [10242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5627),
  [10244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4301),
  [10246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4847),
  [10248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [10250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [10252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [10254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4257),
  [10256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [10258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(560),
  [10260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [10262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [10264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [10266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [10268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [10270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [10272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [10274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4200),
  [10276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4199),
  [10278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4200),
  [10280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4199),
  [10282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(564),
  [10284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1441),
  [10286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [10288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [10290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1440),
  [10292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1841),
  [10294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3548),
  [10296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3549),
  [10298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [10300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [10302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5689),
  [10304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [10306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4940),
  [10308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [10310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [10312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [10314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1840),
  [10316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6138),
  [10318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3533),
  [10320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [10322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5499),
  [10324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6137),
  [10326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5745),
  [10328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6138),
  [10330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6113),
  [10332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6193),
  [10334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4727),
  [10336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [10338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [10340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [10342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [10344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6137),
  [10346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7509),
  [10348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1309),
  [10350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [10352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [10354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [10356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2834),
  [10358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [10360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [10362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2834),
  [10364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2814),
  [10366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [10368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [10370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3673),
  [10372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [10374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5638),
  [10376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [10378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4884),
  [10380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [10382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [10384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [10386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [10388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2580),
  [10390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1058),
  [10392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2579),
  [10394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2580),
  [10396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2579),
  [10398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1831),
  [10400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [10402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [10404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1830),
  [10406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4511),
  [10408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [10410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [10412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4510),
  [10414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5645),
  [10416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4511),
  [10418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4900),
  [10420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [10422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [10424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [10426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4510),
  [10428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1526),
  [10430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [10432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [10434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1525),
  [10436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4339),
  [10438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [10440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3683),
  [10442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4338),
  [10444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5648),
  [10446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4339),
  [10448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4905),
  [10450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [10452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [10454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [10456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4338),
  [10458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [10460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4362),
  [10462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4360),
  [10464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4362),
  [10466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4360),
  [10468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [10470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3342),
  [10472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1469),
  [10474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [10476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [10478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3341),
  [10480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2224),
  [10482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2223),
  [10484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2224),
  [10486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2223),
  [10488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4352),
  [10490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [10492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3586),
  [10494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3509),
  [10496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4351),
  [10498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5665),
  [10500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4352),
  [10502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4911),
  [10504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [10506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [10508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [10510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4351),
  [10512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3512),
  [10514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4229),
  [10516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3589),
  [10518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3590),
  [10520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3450),
  [10522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4227),
  [10524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5670),
  [10526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4229),
  [10528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4926),
  [10530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [10532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [10534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [10536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4227),
  [10538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3455),
  [10540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3377),
  [10542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1100),
  [10544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [10546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [10548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2740),
  [10550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [10552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2739),
  [10554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2740),
  [10556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2739),
  [10558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3353),
  [10560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1102),
  [10562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [10564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [10566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [10568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1924),
  [10570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1022),
  [10572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1923),
  [10574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [10576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1923),
  [10578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3402),
  [10580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2305),
  [10582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [10584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [10586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3418),
  [10588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1023),
  [10590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1470),
  [10592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3138),
  [10594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1307),
  [10596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [10598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [10600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5559),
  [10602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3630),
  [10604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3631),
  [10606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4164),
  [10608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5556),
  [10610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5732),
  [10612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5559),
  [10614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4701),
  [10616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [10618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [10620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [10622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5556),
  [10624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3139),
  [10626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1618),
  [10628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(744),
  [10630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [10632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [10634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1617),
  [10636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4149),
  [10638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5052),
  [10640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4698),
  [10642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2602),
  [10644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4149),
  [10646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6019),
  [10648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5749),
  [10650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2879),
  [10652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6226),
  [10654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4909),
  [10656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [10658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [10660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [10662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(486),
  [10664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(460),
  [10666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [10668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [10670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(478),
  [10672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4570),
  [10674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4430),
  [10676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4570),
  [10678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4569),
  [10680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4574),
  [10682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4574),
  [10684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4573),
  [10686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4459),
  [10688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4185),
  [10690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4459),
  [10692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4458),
  [10694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4461),
  [10696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4461),
  [10698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4460),
  [10700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3356),
  [10702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3356),
  [10704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3364),
  [10706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [10708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2262),
  [10710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3351),
  [10712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3351),
  [10714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3376),
  [10716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [10718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [10720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2222),
  [10722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [10724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [10726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2222),
  [10728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2302),
  [10730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(668),
  [10732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(459),
  [10734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(799),
  [10736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4382),
  [10738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4302),
  [10740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4382),
  [10742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4491),
  [10744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4342),
  [10746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4342),
  [10748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4329),
  [10750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4878),
  [10752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4618),
  [10754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4878),
  [10756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4877),
  [10758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4882),
  [10760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4882),
  [10762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4881),
  [10764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4630),
  [10766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4482),
  [10768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4630),
  [10770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4629),
  [10772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4632),
  [10774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4632),
  [10776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4631),
  [10778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [10780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(574),
  [10782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2936),
  [10784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(667),
  [10786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1855),
  [10788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3565),
  [10790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [10792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(760),
  [10794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [10796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5691),
  [10798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [10800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4863),
  [10802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [10804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [10806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [10808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1836),
  [10810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1357),
  [10812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [10814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [10816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2940),
  [10818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4652),
  [10820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4421),
  [10822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4652),
  [10824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4651),
  [10826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4656),
  [10828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4656),
  [10830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4655),
  [10832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4499),
  [10834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4290),
  [10836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4499),
  [10838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4498),
  [10840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4501),
  [10842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4501),
  [10844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4500),
  [10846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1527),
  [10848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [10850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [10852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1505),
  [10854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2144),
  [10856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [10858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2137),
  [10860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [10862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2137),
  [10864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2333),
  [10866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [10868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [10870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2333),
  [10872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2372),
  [10874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5239),
  [10876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5019),
  [10878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5239),
  [10880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5238),
  [10882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5243),
  [10884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5243),
  [10886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5242),
  [10888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5112),
  [10890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4988),
  [10892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5112),
  [10894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5111),
  [10896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5067),
  [10898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5067),
  [10900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5113),
  [10902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [10904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [10906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [10908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [10910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [10912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [10914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [10916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2937),
  [10918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [10920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [10922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [10924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [10926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(996),
  [10928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [10930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3753),
  [10932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [10934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5964),
  [10936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [10938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [10940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [10942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [10944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5118),
  [10946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5114),
  [10948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5118),
  [10950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5117),
  [10952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5122),
  [10954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5122),
  [10956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5121),
  [10958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2652),
  [10960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2653),
  [10962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5930),
  [10964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2941),
  [10966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6108),
  [10968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6090),
  [10970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6108),
  [10972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6105),
  [10974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(602),
  [10976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [10978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [10980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [10982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2114),
  [10984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2114),
  [10986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2113),
  [10988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(980),
  [10990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2117),
  [10992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [10994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [10996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [10998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1910),
  [11000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(751),
  [11002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [11004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [11006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2069),
  [11008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1664),
  [11010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [11012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [11014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [11016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1661),
  [11018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [11020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [11022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [11024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [11026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5045),
  [11028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5007),
  [11030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5045),
  [11032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5044),
  [11034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1004),
  [11036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(692),
  [11038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5048),
  [11040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5048),
  [11042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5047),
  [11044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1006),
  [11046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [11048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1154),
  [11050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(754),
  [11052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [11054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [11056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1149),
  [11058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [11060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [11062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2391),
  [11064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2391),
  [11066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2388),
  [11068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [11070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2423),
  [11072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [11074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2410),
  [11076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3375),
  [11078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3640),
  [11080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3348),
  [11082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3317),
  [11084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3308),
  [11086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3321),
  [11088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3309),
  [11090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3142),
  [11092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3143),
  [11094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5525),
  [11096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5414),
  [11098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5525),
  [11100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5524),
  [11102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5513),
  [11104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5513),
  [11106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5503),
  [11108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1059),
  [11110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [11112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3315),
  [11114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3338),
  [11116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5253),
  [11118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5253),
  [11120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5252),
  [11122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1061),
  [11124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5271),
  [11126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5271),
  [11128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5270),
  [11130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [11132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [11134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1783),
  [11136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(925),
  [11138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [11140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [11142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1782),
  [11144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2238),
  [11146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2238),
  [11148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2231),
  [11150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [11152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1740),
  [11154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [11156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [11158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1740),
  [11160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1739),
  [11162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2306),
  [11164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2306),
  [11166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [11168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [11170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [11172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5202),
  [11174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5202),
  [11176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5200),
  [11178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [11180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [11182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [11184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [11186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(808),
  [11188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [11190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [11192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [11194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4160),
  [11196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [11198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [11200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [11202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [11204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [11206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3204),
  [11208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(632),
  [11210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3205),
  [11212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(508),
  [11214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(462),
  [11216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [11218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [11220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(507),
  [11222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4258),
  [11224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4155),
  [11226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4258),
  [11228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4256),
  [11230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4235),
  [11232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4235),
  [11234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4221),
  [11236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(732),
  [11238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [11240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(926),
  [11242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [11244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [11246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [11248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [11250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5420),
  [11252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3775),
  [11254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5419),
  [11256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5420),
  [11258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5419),
  [11260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [11262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [11264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [11266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3817),
  [11268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3817),
  [11270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3339),
  [11272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5127),
  [11274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3710),
  [11276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5126),
  [11278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5127),
  [11280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5126),
  [11282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [11284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3796),
  [11286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4158),
  [11288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4025),
  [11290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4158),
  [11292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [11294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4138),
  [11296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4138),
  [11298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4135),
  [11300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [11302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(575),
  [11304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1291),
  [11306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [11308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [11310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [11312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [11314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [11316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [11318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4489),
  [11320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4230),
  [11322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4489),
  [11324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4487),
  [11326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3416),
  [11328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3417),
  [11330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [11332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4325),
  [11334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4325),
  [11336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4324),
  [11338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3814),
  [11340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3814),
  [11342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(879),
  [11344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [11346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [11348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [11350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(882),
  [11352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [11354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [11356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(642),
  [11358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [11360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4300),
  [11362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4134),
  [11364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4300),
  [11366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4297),
  [11368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3311),
  [11370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4193),
  [11372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4193),
  [11374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4251),
  [11376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [11378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(745),
  [11380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3318),
  [11382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [11384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [11386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3241),
  [11388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3062),
  [11390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3687),
  [11392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3688),
  [11394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3343),
  [11396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [11398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4535),
  [11400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4369),
  [11402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4535),
  [11404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4530),
  [11406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5494),
  [11408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(735),
  [11410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [11412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(719),
  [11414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3228),
  [11416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [11418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(784),
  [11420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4646),
  [11422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4646),
  [11424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4641),
  [11426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3785),
  [11428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(671),
  [11430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6447),
  [11432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6446),
  [11434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6447),
  [11436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6446),
  [11438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3229),
  [11440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [11442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(973),
  [11444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [11446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6103),
  [11448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6103),
  [11450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6096),
  [11452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2468),
  [11454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2466),
  [11456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2468),
  [11458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2466),
  [11460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [11462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [11464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(585),
  [11466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(672),
  [11468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5617),
  [11470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [11472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5615),
  [11474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [11476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2780),
  [11478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [11480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [11482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2779),
  [11484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1135),
  [11486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [11488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [11490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(536),
  [11492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [11494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [11496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [11498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3777),
  [11500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5328),
  [11502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5327),
  [11504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5328),
  [11506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5327),
  [11508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(576),
  [11510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(537),
  [11512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [11514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [11516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [11518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [11520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [11522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [11524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2521),
  [11526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2515),
  [11528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2521),
  [11530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2515),
  [11532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1676),
  [11534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [11536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [11538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5179),
  [11540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5178),
  [11542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5179),
  [11544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5178),
  [11546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1280),
  [11548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [11550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [11552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [11554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [11556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [11558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2896),
  [11560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6093),
  [11562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6093),
  [11564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6107),
  [11566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3707),
  [11568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3708),
  [11570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2897),
  [11572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [11574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1374),
  [11576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [11578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [11580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(941),
  [11582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3643),
  [11584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1103),
  [11586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3345),
  [11588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1456),
  [11590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1456),
  [11592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [11594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3433),
  [11596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3443),
  [11598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(583),
  [11600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [11602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3291),
  [11604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2292),
  [11606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2292),
  [11608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2291),
  [11610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2295),
  [11612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2295),
  [11614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [11616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [11618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1899),
  [11620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [11622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1898),
  [11624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1901),
  [11626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [11628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [11630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6106),
  [11632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6106),
  [11634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6102),
  [11636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3292),
  [11638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1104),
  [11640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [11642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5197),
  [11644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5197),
  [11646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5196),
  [11648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3830),
  [11650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3830),
  [11652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3880),
  [11654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3900),
  [11656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0),
  [11658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0),
  [11660] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0), SHIFT_REPEAT(6486),
  [11663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3721),
  [11665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(683),
  [11667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4018),
  [11669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5980),
  [11671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0),
  [11673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3711),
  [11676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(640),
  [11679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0),
  [11681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(4008),
  [11684] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6042),
  [11687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [11689] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3817),
  [11692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3817),
  [11695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3832),
  [11697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3832),
  [11699] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4044),
  [11702] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4044),
  [11705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4600),
  [11707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4600),
  [11709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4508),
  [11711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4508),
  [11713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redirected_statement, 1, -1, 3),
  [11715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3711),
  [11717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [11719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redirected_statement, 1, -1, 3),
  [11721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4008),
  [11723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6042),
  [11725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4673),
  [11727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4673),
  [11729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3811),
  [11731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3811),
  [11733] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4096),
  [11736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4096),
  [11739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignments, 2, 0, 0),
  [11741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignments, 2, 0, 0),
  [11743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6486),
  [11745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5609),
  [11747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5572),
  [11749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5572),
  [11751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3909),
  [11753] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3814),
  [11756] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3814),
  [11759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4096),
  [11761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4096),
  [11763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3857),
  [11765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6495),
  [11767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4465),
  [11769] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3811),
  [11772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3811),
  [11775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6009),
  [11777] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4486),
  [11780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redirected_statement, 2, -1, 14),
  [11782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redirected_statement, 2, -1, 14),
  [11784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4480),
  [11786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4044),
  [11788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4044),
  [11790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 3, 0, 29),
  [11792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 29),
  [11794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6025),
  [11796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4097),
  [11798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3781),
  [11800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [11802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5854),
  [11804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4102),
  [11806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0), SHIFT_REPEAT(6495),
  [11809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3885),
  [11811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3951),
  [11813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4396),
  [11815] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4029),
  [11818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4029),
  [11821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4481),
  [11823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3724),
  [11825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [11827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4032),
  [11829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6021),
  [11831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3952),
  [11833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4505),
  [11835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3719),
  [11837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [11839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4049),
  [11841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5778),
  [11843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3828),
  [11845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [11847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3884),
  [11849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3832),
  [11852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3832),
  [11855] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3724),
  [11858] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(664),
  [11861] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(4032),
  [11864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6021),
  [11867] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4465),
  [11870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3912),
  [11872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0),
  [11874] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3753),
  [11877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7388),
  [11880] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(652),
  [11883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0),
  [11885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6009),
  [11888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4473),
  [11890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4474),
  [11892] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 54),
  [11894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 54),
  [11896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3752),
  [11898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [11900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5933),
  [11902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 61),
  [11904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 61),
  [11906] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3830),
  [11909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3830),
  [11912] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4505),
  [11915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4486),
  [11917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4396),
  [11920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3779),
  [11922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(684),
  [11924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3859),
  [11926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6022),
  [11928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [11930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4042),
  [11932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3850),
  [11934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6034),
  [11936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3853),
  [11938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3737),
  [11940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [11942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3872),
  [11944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6049),
  [11946] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0), SHIFT_REPEAT(6624),
  [11949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3731),
  [11951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [11953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3874),
  [11955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5785),
  [11957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4664),
  [11959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6624),
  [11961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3797),
  [11963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4109),
  [11965] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4615),
  [11968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4513),
  [11970] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3828),
  [11973] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3828),
  [11976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4615),
  [11978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6011),
  [11980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3726),
  [11982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [11984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3887),
  [11986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6038),
  [11988] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3737),
  [11991] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(703),
  [11994] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3872),
  [11997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6049),
  [12000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4029),
  [12002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4029),
  [12004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3987),
  [12006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3990),
  [12008] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4513),
  [12011] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3721),
  [12014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7413),
  [12017] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(683),
  [12020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6011),
  [12023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4547),
  [12025] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3726),
  [12028] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(762),
  [12031] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3887),
  [12034] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6038),
  [12037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4664),
  [12040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4055),
  [12042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4064),
  [12044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6463),
  [12046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0), SHIFT_REPEAT(6463),
  [12049] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4547),
  [12052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4118),
  [12054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4128),
  [12056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3959),
  [12058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3961),
  [12060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6474),
  [12062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0), SHIFT_REPEAT(6474),
  [12065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3779),
  [12068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(684),
  [12071] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3859),
  [12074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6022),
  [12077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 4, 0, 71),
  [12079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5097),
  [12081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4791),
  [12083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [12085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6032),
  [12087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5714),
  [12089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [12091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6189),
  [12093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4883),
  [12095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [12097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [12099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [12101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_statement, 4, 0, 0),
  [12103] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_statement, 4, 0, 0),
  [12105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_statement, 3, 0, 0),
  [12107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_statement, 3, 0, 0),
  [12109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6006),
  [12111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3843),
  [12113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 44),
  [12115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 44),
  [12117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 4, 0, 73),
  [12119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [12121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_group, 2, 0, 0),
  [12123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_group, 2, 0, 0),
  [12125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [12127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 44),
  [12129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 44),
  [12131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0),
  [12133] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT(433),
  [12136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0),
  [12138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3950),
  [12140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_test_command, 2, 0, 0),
  [12142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_test_command, 2, 0, 0),
  [12144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3717),
  [12146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [12148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3876),
  [12150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6044),
  [12152] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3717),
  [12155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(769),
  [12158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3876),
  [12161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6044),
  [12164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3781),
  [12167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7422),
  [12170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(766),
  [12173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6006),
  [12176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6027),
  [12178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_statement, 2, 0, 0),
  [12180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_statement, 2, 0, 0),
  [12182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6026),
  [12184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 44),
  [12186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 44),
  [12188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(436),
  [12191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6033),
  [12193] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3719),
  [12196] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(771),
  [12199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6001),
  [12202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6001),
  [12204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 5, 0, 97),
  [12206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 28),
  [12208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 3, 0, 28),
  [12210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_test_command, 3, 0, 30),
  [12212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_test_command, 3, 0, 30),
  [12214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4052),
  [12216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4019),
  [12218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pipeline, 2, 0, 0),
  [12220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [12222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pipeline, 2, 0, 0),
  [12224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4020),
  [12226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6002),
  [12228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subshell, 3, 0, 0),
  [12230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subshell, 3, 0, 0),
  [12232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 44),
  [12234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 44),
  [12236] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4052),
  [12239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4052),
  [12242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_test_command, 3, 0, 0),
  [12244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_test_command, 3, 0, 0),
  [12246] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(4694),
  [12249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4694),
  [12251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 2, 0, 0),
  [12253] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3752),
  [12256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(788),
  [12259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6002),
  [12262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6465),
  [12264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0), SHIFT_REPEAT(6465),
  [12267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4052),
  [12269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [12271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3949),
  [12273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 5, 0, 99),
  [12275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 3, 0, 44),
  [12277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4037),
  [12279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_group, 3, 0, 0),
  [12281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_group, 3, 0, 0),
  [12283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 6, 0, 131),
  [12285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [12287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3840),
  [12289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 4, 0, 69),
  [12291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4033),
  [12293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 3, 0, 57),
  [12295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 5, 0, 4),
  [12297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 5, 0, 4),
  [12299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5092),
  [12301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4675),
  [12303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2935),
  [12305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6016),
  [12307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5676),
  [12309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [12311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6179),
  [12313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4697),
  [12315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [12317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [12319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [12321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3385),
  [12323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3385),
  [12325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2390),
  [12327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5618),
  [12329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5616),
  [12331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [12333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [12335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [12337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3386),
  [12339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3954),
  [12341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 84),
  [12343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 84),
  [12345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3411),
  [12347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 7, 0, 149),
  [12349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 7, 0, 149),
  [12351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 5, 0, 0),
  [12353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 5, 0, 0),
  [12355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 8, 0, 46),
  [12357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 8, 0, 46),
  [12359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [12361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_c_style_for_statement, 6, 0, 68),
  [12363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_c_style_for_statement, 6, 0, 68),
  [12365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [12367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [12369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [12371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3305),
  [12373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 5, 0, 93),
  [12375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 5, 0, 93),
  [12377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [12379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3224),
  [12381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3145),
  [12383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5561),
  [12385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command, 3, 0, 19),
  [12387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 3, 0, 19),
  [12389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [12391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, 0, 75),
  [12393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 75),
  [12395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 5, 0, 94),
  [12397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 5, 0, 94),
  [12399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [12401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 65),
  [12403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 65),
  [12405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [12407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [12409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 6, 0, 126),
  [12411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 6, 0, 126),
  [12413] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(438),
  [12416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_c_style_for_statement, 5, 0, 56),
  [12418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_c_style_for_statement, 5, 0, 56),
  [12420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [12422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5302),
  [12424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 6, 0, 127),
  [12426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 6, 0, 127),
  [12428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6146),
  [12430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5449),
  [12432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6000),
  [12434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 6, 0, 4),
  [12436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 6, 0, 4),
  [12438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6014),
  [12440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [12442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3731),
  [12445] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(789),
  [12448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6000),
  [12451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 4, 0, 0),
  [12453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 4, 0, 0),
  [12455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 5, 0, 46),
  [12457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 5, 0, 46),
  [12459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [12461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2506),
  [12463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4768),
  [12465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5052),
  [12467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4698),
  [12469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2602),
  [12471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5749),
  [12473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2879),
  [12475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4909),
  [12477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [12479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [12481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [12483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2613),
  [12485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6080),
  [12487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 5, 0, 95),
  [12489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 5, 0, 95),
  [12491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 4, 0, 45),
  [12493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 4, 0, 45),
  [12495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 6, 0, 45),
  [12497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 6, 0, 45),
  [12499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 4, 0, 46),
  [12501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 4, 0, 46),
  [12503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 7, 0, 45),
  [12505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 7, 0, 45),
  [12507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5210),
  [12509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 6, 0, 124),
  [12511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 6, 0, 124),
  [12513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5392),
  [12515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6129),
  [12517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6148),
  [12519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 42),
  [12521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 4, 0, 42),
  [12523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [12525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 7, 0, 46),
  [12527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 7, 0, 46),
  [12529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [12531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 5, 0, 45),
  [12533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 5, 0, 45),
  [12535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2447),
  [12537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heredoc_redirect, 6, 0, 125),
  [12539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_redirect, 6, 0, 125),
  [12541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [12543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [12545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [12547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1683),
  [12549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [12551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6425),
  [12553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redirected_statement, 2, -1, 15),
  [12555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redirected_statement, 2, -1, 15),
  [12557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [12559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 47),
  [12561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 47),
  [12563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(438),
  [12565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2237),
  [12567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [12569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2267),
  [12571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4383),
  [12573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [12575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [12577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 2),
  [12579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command, 2, 0, 2),
  [12581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4201),
  [12583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4314),
  [12585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [12587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [12589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [12591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 8, 0, 45),
  [12593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 8, 0, 45),
  [12595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4224),
  [12597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 6, 0, 46),
  [12599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 6, 0, 46),
  [12601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [12603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [12605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5152),
  [12607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3943),
  [12609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3945),
  [12611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [12613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [12615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [12617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3095),
  [12619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [12621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6407),
  [12623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [12625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [12627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [12629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4539),
  [12631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [12633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6570),
  [12635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4444),
  [12637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_heredoc_body, 2, 0, 0),
  [12639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_heredoc_body, 2, 0, 0),
  [12641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__heredoc_body, 2, 0, 0),
  [12643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__heredoc_body, 2, 0, 0),
  [12645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2926),
  [12647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4411),
  [12649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4449),
  [12651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5358),
  [12653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [12655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4192),
  [12657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2590),
  [12659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [12661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [12663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [12665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(5050),
  [12668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(440),
  [12670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3783),
  [12672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [12674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3893),
  [12676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5797),
  [12678] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(440),
  [12681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [12683] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(446),
  [12686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5050),
  [12688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [12690] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(434),
  [12693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4093),
  [12695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [12697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3105),
  [12699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3107),
  [12701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3114),
  [12703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3119),
  [12705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3120),
  [12707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3122),
  [12709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3123),
  [12711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3125),
  [12713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3127),
  [12715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3131),
  [12717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3133),
  [12719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3135),
  [12721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3734),
  [12723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [12725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [12727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3930),
  [12729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6029),
  [12731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4004),
  [12733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4007),
  [12735] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4048),
  [12738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 1, 0, 16),
  [12740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__heredoc_command, 1, 0, 16),
  [12742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__heredoc_command, 1, 0, 17),
  [12744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__heredoc_command, 1, 0, 17),
  [12746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3734),
  [12749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3734),
  [12752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(966),
  [12755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3930),
  [12758] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6029),
  [12761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2931),
  [12763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [12765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [12767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2978),
  [12769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3793),
  [12771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [12773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3895),
  [12775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6012),
  [12777] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3793),
  [12780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(975),
  [12783] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3895),
  [12786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6012),
  [12789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2984),
  [12791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2985),
  [12793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3962),
  [12795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2996),
  [12797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2919),
  [12799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [12801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [12803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2826),
  [12805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4112),
  [12807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4113),
  [12809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3047),
  [12811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3049),
  [12813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4093),
  [12816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3051),
  [12818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3053),
  [12820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3056),
  [12822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3838),
  [12824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3839),
  [12826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3059),
  [12828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3064),
  [12830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3066),
  [12832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3068),
  [12834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3070),
  [12836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3077),
  [12838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3078),
  [12840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [12842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2835),
  [12844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [12846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [12848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3263),
  [12850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4103),
  [12852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3751),
  [12854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3751),
  [12856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [12858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3907),
  [12860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5903),
  [12862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3275),
  [12864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(443),
  [12866] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(443),
  [12869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3798),
  [12871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6437),
  [12873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6024),
  [12875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_expression, 1, 0, 12),
  [12877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [12879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [12881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [12883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4043),
  [12885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4045),
  [12887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6480),
  [12889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0), SHIFT_REPEAT(6480),
  [12892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4084),
  [12894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6003),
  [12896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 134),
  [12898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 134),
  [12900] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 5, 0, 79),
  [12902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1972),
  [12904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7371),
  [12906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3620),
  [12908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3621),
  [12910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6050),
  [12912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4787),
  [12914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_max_length, 2, 0, 49),
  [12916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [12918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [12920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [12922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6208),
  [12924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 142),
  [12926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 142),
  [12928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 5, 0, 112),
  [12930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6008),
  [12932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5278),
  [12934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6470),
  [12936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 138),
  [12938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 138),
  [12940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 5, 0, 109),
  [12942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 144),
  [12944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 144),
  [12946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 5, 0, 83),
  [12948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6980),
  [12950] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_max_length, 3, 0, 51),
  [12952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6239),
  [12954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [12956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4101),
  [12958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7129),
  [12960] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_max_length, 3, 0, 64),
  [12962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6171),
  [12964] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4084),
  [12967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6037),
  [12969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3783),
  [12972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1132),
  [12975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6003),
  [12978] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3751),
  [12981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7145),
  [12984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3751),
  [12987] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1111),
  [12990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7145),
  [12993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6008),
  [12996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_assignments_repeat1, 2, 0, 0), SHIFT_REPEAT(6470),
  [12999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3836),
  [13001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3837),
  [13003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 136),
  [13005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 136),
  [13007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 5, 0, 45),
  [13009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 6, 0, 153),
  [13011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 6, 0, 153),
  [13013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 6, 0, 109),
  [13015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 6, 0, 155),
  [13017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 6, 0, 155),
  [13019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 6, 0, 112),
  [13021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4083),
  [13023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3803),
  [13025] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(5278),
  [13028] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4103),
  [13031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 3, 0, 77),
  [13033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 3, 0, 77),
  [13035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 3, 0, 59),
  [13037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 3, 0, 81),
  [13039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 3, 0, 81),
  [13041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 3, 0, 60),
  [13043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [13045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3944),
  [13047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4107),
  [13049] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3798),
  [13052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3763),
  [13054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3763),
  [13056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [13058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4132),
  [13060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6039),
  [13062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 140),
  [13064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 140),
  [13066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 5, 0, 46),
  [13068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 103),
  [13070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 103),
  [13072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 4, 0, 59),
  [13074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 105),
  [13076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 105),
  [13078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 4, 0, 79),
  [13080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 107),
  [13082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 107),
  [13084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 4, 0, 45),
  [13086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 110),
  [13088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 110),
  [13090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 4, 0, 46),
  [13092] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 113),
  [13094] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 113),
  [13096] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 4, 0, 60),
  [13098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 115),
  [13100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 115),
  [13102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_last_case_item, 4, 0, 83),
  [13104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3763),
  [13107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3763),
  [13110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1001),
  [13113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(4132),
  [13116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6039),
  [13119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(5427),
  [13122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 139),
  [13124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 139),
  [13126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 135),
  [13128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 135),
  [13130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5438),
  [13132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 137),
  [13134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 137),
  [13136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5427),
  [13138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 6, 0, 154),
  [13140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 6, 0, 154),
  [13142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 6, 0, 156),
  [13144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 6, 0, 156),
  [13146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5411),
  [13148] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 3, 0, 78),
  [13150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 3, 0, 78),
  [13152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3756),
  [13154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3756),
  [13156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [13158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6020),
  [13160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 145),
  [13162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 145),
  [13164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 3, 0, 82),
  [13166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 3, 0, 82),
  [13168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(5411),
  [13171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 143),
  [13173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 143),
  [13175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6435),
  [13177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4000),
  [13179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4060),
  [13181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4123),
  [13184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6661),
  [13186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5119),
  [13188] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_max_length, 1, 0, 12),
  [13190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6135),
  [13192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(5438),
  [13195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 104),
  [13197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 104),
  [13199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 106),
  [13201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 106),
  [13203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 108),
  [13205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 108),
  [13207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 111),
  [13209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 111),
  [13211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 114),
  [13213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 114),
  [13215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 4, 0, 116),
  [13217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 4, 0, 116),
  [13219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7286),
  [13221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7286),
  [13223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6007),
  [13225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5409),
  [13227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(5409),
  [13230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3756),
  [13233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7286),
  [13236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3756),
  [13239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1176),
  [13242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7286),
  [13245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6007),
  [13248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_item, 5, 0, 141),
  [13250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_item, 5, 0, 141),
  [13252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5492),
  [13254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6350),
  [13256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4115),
  [13258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4115),
  [13260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6336),
  [13262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6340),
  [13264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6378),
  [13266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6297),
  [13268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(5492),
  [13271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6799),
  [13273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_max_length, 4, 0, 64),
  [13275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6191),
  [13277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6284),
  [13279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6288),
  [13281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(444),
  [13283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(444),
  [13286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6355),
  [13288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6367),
  [13290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6385),
  [13292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7092),
  [13294] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_max_length, 3, 0, 49),
  [13296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6157),
  [13298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7163),
  [13300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_max_length, 4, 0, 51),
  [13302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6159),
  [13304] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3744),
  [13307] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1541),
  [13310] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(3953),
  [13313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redirected_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(6018),
  [13316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [13318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [13320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [13322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7422),
  [13324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3852),
  [13326] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4115),
  [13329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4115),
  [13332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0),
  [13334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_compound_statement_repeat1, 2, 0, 0),
  [13336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6142),
  [13338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5745),
  [13340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6141),
  [13342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6141),
  [13344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [13346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3783),
  [13348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [13350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [13352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3752),
  [13354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [13356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT(433),
  [13359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [13361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [13363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [13365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7388),
  [13367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [13369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3731),
  [13371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [13373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [13375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [13377] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(433),
  [13380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pipeline_repeat1, 2, 0, 0), SHIFT_REPEAT(433),
  [13383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [13385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3721),
  [13387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [13389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7413),
  [13391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [13393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3719),
  [13395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [13397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3983),
  [13399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(5610),
  [13402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5610),
  [13404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6406),
  [13406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6405),
  [13408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6405),
  [13410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6341),
  [13412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6341),
  [13414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6305),
  [13416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6951),
  [13418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3403),
  [13420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3403),
  [13422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3366),
  [13424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3503),
  [13426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3553),
  [13428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3554),
  [13430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5874),
  [13432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [13434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6063),
  [13436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4760),
  [13438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(148),
  [13440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [13442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(150),
  [13444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5838),
  [13446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1535),
  [13448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5784),
  [13450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4381),
  [13452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5803),
  [13454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4386),
  [13456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5832),
  [13458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1400),
  [13460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5821),
  [13462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2507),
  [13464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5860),
  [13466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3169),
  [13468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5853),
  [13470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [13472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5882),
  [13474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4304),
  [13476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5894),
  [13478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4196),
  [13480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5942),
  [13482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(927),
  [13484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5979),
  [13486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [13488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5775),
  [13490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4308),
  [13492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5782),
  [13494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4250),
  [13496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5774),
  [13498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1449),
  [13500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5795),
  [13502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1453),
  [13504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5806),
  [13506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [13508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5923),
  [13510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3091),
  [13512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5810),
  [13514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [13516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5816),
  [13518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1559),
  [13520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5823),
  [13522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1561),
  [13524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5828),
  [13526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1033),
  [13528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5840),
  [13530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2505),
  [13532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5835),
  [13534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1035),
  [13536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5843),
  [13538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1725),
  [13540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5848),
  [13542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1727),
  [13544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5856),
  [13546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4538),
  [13548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5863),
  [13550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4540),
  [13552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5869),
  [13554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1575),
  [13556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5879),
  [13558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4443),
  [13560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5885),
  [13562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4445),
  [13564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5892),
  [13566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4448),
  [13568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5898),
  [13570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4450),
  [13572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5941),
  [13574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2754),
  [13576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5945),
  [13578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3190),
  [13580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5958),
  [13582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3109),
  [13584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5946),
  [13586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2756),
  [13588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5969),
  [13590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2261),
  [13592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5977),
  [13594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2265),
  [13596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5791),
  [13598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [13600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5996),
  [13602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1981),
  [13604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5999),
  [13606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1637),
  [13608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5776),
  [13610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1988),
  [13612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5787),
  [13614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1494),
  [13616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5779),
  [13618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2011),
  [13620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5780),
  [13622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2028),
  [13624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5783),
  [13626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4394),
  [13628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5786),
  [13630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4398),
  [13632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5789),
  [13634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1755),
  [13636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5796),
  [13638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1500),
  [13640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5792),
  [13642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [13644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5798),
  [13646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4176),
  [13648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5818),
  [13650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [13652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5800),
  [13654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4183),
  [13656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5802),
  [13658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5143),
  [13660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5805),
  [13662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5145),
  [13664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5825),
  [13666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1555),
  [13668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5809),
  [13670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3213),
  [13672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5811),
  [13674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3216),
  [13676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5939),
  [13678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1043),
  [13680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5813),
  [13682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4745),
  [13684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5814),
  [13686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4753),
  [13688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5817),
  [13690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2007),
  [13692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5819),
  [13694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2009),
  [13696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5822),
  [13698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1806),
  [13700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5824),
  [13702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1808),
  [13704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5827),
  [13706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6401),
  [13708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5833),
  [13710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [13712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5829),
  [13714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6403),
  [13716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5834),
  [13718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2437),
  [13720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5919),
  [13722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1854),
  [13724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5837),
  [13726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2453),
  [13728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5868),
  [13730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1880),
  [13732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5844),
  [13734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2795),
  [13736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5852),
  [13738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2742),
  [13740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5845),
  [13742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2797),
  [13744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5847),
  [13746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5289),
  [13748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5849),
  [13750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5291),
  [13752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5865),
  [13754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2778),
  [13756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5855),
  [13758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2457),
  [13760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5857),
  [13762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2572),
  [13764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5862),
  [13766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5203),
  [13768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5907),
  [13770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2523),
  [13772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5864),
  [13774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5206),
  [13776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5808),
  [13778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1532),
  [13780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5870),
  [13782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6225),
  [13784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5872),
  [13786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1891),
  [13788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5871),
  [13790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6245),
  [13792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5875),
  [13794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6528),
  [13796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5876),
  [13798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6533),
  [13800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5878),
  [13802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6424),
  [13804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5881),
  [13806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6426),
  [13808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5889),
  [13810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1151),
  [13812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5884),
  [13814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4187),
  [13816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5886),
  [13818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4231),
  [13820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5890),
  [13822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3087),
  [13824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5891),
  [13826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3144),
  [13828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5896),
  [13830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [13832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5897),
  [13834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6569),
  [13836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5902),
  [13838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [13840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5899),
  [13842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6574),
  [13844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5904),
  [13846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5357),
  [13848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5908),
  [13850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1556),
  [13852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5910),
  [13854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3405),
  [13856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5905),
  [13858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5365),
  [13860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5909),
  [13862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2589),
  [13864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5914),
  [13866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2563),
  [13868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5911),
  [13870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2591),
  [13872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5913),
  [13874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3407),
  [13876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5915),
  [13878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2428),
  [13880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5916),
  [13882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2340),
  [13884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5918),
  [13886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3301),
  [13888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5920),
  [13890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3313),
  [13892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5922),
  [13894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5557),
  [13896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5924),
  [13898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5571),
  [13900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5926),
  [13902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2444),
  [13904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5927),
  [13906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2558),
  [13908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5931),
  [13910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [13912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5932),
  [13914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [13916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5934),
  [13918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(836),
  [13920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5953),
  [13922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2401),
  [13924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5936),
  [13926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [13928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5937),
  [13930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3009),
  [13932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5938),
  [13934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2808),
  [13936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5943),
  [13938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5440),
  [13940] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3553),
  [13943] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3554),
  [13946] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6010),
  [13949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [13951] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6063),
  [13954] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(4760),
  [13957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(148),
  [13960] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(149),
  [13963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(150),
  [13966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5950),
  [13968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6143),
  [13970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5947),
  [13972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5453),
  [13974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5954),
  [13976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2612),
  [13978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5952),
  [13980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6123),
  [13982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5984),
  [13984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2881),
  [13986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5955),
  [13988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2614),
  [13990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5959),
  [13992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5375),
  [13994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5960),
  [13996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2341),
  [13998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5963),
  [14000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(498),
  [14002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5961),
  [14004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5330),
  [14006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5965),
  [14008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6691),
  [14010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5966),
  [14012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [14014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5967),
  [14016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6648),
  [14018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5971),
  [14020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [14022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5991),
  [14024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1860),
  [14026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5978),
  [14028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2234),
  [14030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5974),
  [14032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1255),
  [14034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5992),
  [14036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [14038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5982),
  [14040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [14042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5981),
  [14044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2239),
  [14046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5983),
  [14048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1287),
  [14050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5987),
  [14052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1331),
  [14054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5989),
  [14056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [14058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5888),
  [14060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2888),
  [14062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5993),
  [14064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [14066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5997),
  [14068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [14070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5794),
  [14072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [14074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5790),
  [14076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1631),
  [14078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5861),
  [14080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [14082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6077),
  [14084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6069),
  [14086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6083),
  [14088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6083),
  [14090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1997),
  [14092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3722),
  [14094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6928),
  [14096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3722),
  [14098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [14100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6928),
  [14102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4059),
  [14104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2051),
  [14106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4171),
  [14108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3749),
  [14110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3749),
  [14112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [14114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3875),
  [14116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4402),
  [14118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1772),
  [14120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(471),
  [14122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1384),
  [14124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1507),
  [14126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3792),
  [14128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3792),
  [14130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [14132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3894),
  [14134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4188),
  [14136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4410),
  [14138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5146),
  [14140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [14142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3218),
  [14144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4759),
  [14146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1272),
  [14148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2010),
  [14150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1566),
  [14152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1810),
  [14154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6404),
  [14156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1659),
  [14158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [14160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2485),
  [14162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1538),
  [14164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2438),
  [14166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2798),
  [14168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6422),
  [14170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5755),
  [14172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6421),
  [14174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6421),
  [14176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1729),
  [14178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5294),
  [14180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [14182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3755),
  [14184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3755),
  [14186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [14188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3858),
  [14190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2532),
  [14192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4545),
  [14194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5207),
  [14196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2584),
  [14198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6256),
  [14200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1719),
  [14202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1579),
  [14204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6535),
  [14206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6428),
  [14208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4447),
  [14210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4266),
  [14212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2899),
  [14214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3148),
  [14216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4232),
  [14218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [14220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4457),
  [14222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6577),
  [14224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3766),
  [14226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7150),
  [14228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3766),
  [14230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [14232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7150),
  [14234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [14236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5370),
  [14238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1584),
  [14240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2593),
  [14242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3408),
  [14244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2571),
  [14246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2348),
  [14248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3294),
  [14250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5606),
  [14252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2501),
  [14254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3765),
  [14256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3765),
  [14258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [14260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3886),
  [14262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(867),
  [14264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1084),
  [14266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2832),
  [14268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1073),
  [14270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3198),
  [14272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2757),
  [14274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5424),
  [14276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6131),
  [14278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2616),
  [14280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3129),
  [14282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2358),
  [14284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5256),
  [14286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3754),
  [14288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7392),
  [14290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [14292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [14294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7392),
  [14296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3993),
  [14298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(505),
  [14300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6674),
  [14302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1263),
  [14304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2260),
  [14306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [14308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3723),
  [14310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7416),
  [14312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3723),
  [14314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [14316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7416),
  [14318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4022),
  [14320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2244),
  [14322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1290),
  [14324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1426),
  [14326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1866),
  [14328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(919),
  [14330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1642),
  [14332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3757),
  [14334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7290),
  [14336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3757),
  [14338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [14340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7290),
  [14342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3794),
  [14344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3794),
  [14346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [14348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3896),
  [14350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6045),
  [14352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4790),
  [14354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [14356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [14358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [14360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6023),
  [14362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_body, 2, 0, 0),
  [14364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 3, 0, 51),
  [14366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7182),
  [14368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3221),
  [14370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3220),
  [14372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3220),
  [14374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3716),
  [14376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3716),
  [14378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [14380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4015),
  [14382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3745),
  [14384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3745),
  [14386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [14388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [14390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2925),
  [14392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2924),
  [14394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2924),
  [14396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3964),
  [14398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3725),
  [14400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3725),
  [14402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [14404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [14406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3784),
  [14408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [14410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [14412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3860),
  [14414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_heredoc_body_repeat1, 2, 0, 0), SHIFT_REPEAT(6045),
  [14417] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_heredoc_body_repeat1, 2, 0, 0), SHIFT_REPEAT(4790),
  [14420] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_heredoc_body_repeat1, 2, 0, 0), SHIFT_REPEAT(344),
  [14423] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_heredoc_body_repeat1, 2, 0, 0), SHIFT_REPEAT(345),
  [14426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_heredoc_body_repeat1, 2, 0, 0), SHIFT_REPEAT(346),
  [14429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_heredoc_body_repeat1, 2, 0, 0), SHIFT_REPEAT(6023),
  [14432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_heredoc_body_repeat1, 2, 0, 0),
  [14434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3140),
  [14436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3137),
  [14438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [14440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3739),
  [14442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3739),
  [14444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [14446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3933),
  [14448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2741),
  [14450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2738),
  [14452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [14454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6013),
  [14456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heredoc_body, 1, 0, 0),
  [14458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3231),
  [14460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3189),
  [14462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3189),
  [14464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3787),
  [14466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [14468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [14470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4121),
  [14472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3788),
  [14474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [14476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1925),
  [14478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3864),
  [14480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3727),
  [14482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [14484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [14486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [14488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3764),
  [14490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [14492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [14494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3975),
  [14496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3780),
  [14498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3780),
  [14500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [14502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4111),
  [14504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3167),
  [14506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3162),
  [14508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [14510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3712),
  [14512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [14514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [14516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4009),
  [14518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3733),
  [14520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3733),
  [14522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [14524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3942),
  [14526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3720),
  [14528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [14530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [14532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3877),
  [14534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6150),
  [14536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6144),
  [14538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6144),
  [14540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3758),
  [14542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3758),
  [14544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [14546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3883),
  [14548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3762),
  [14550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3762),
  [14552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [14554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3972),
  [14556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3770),
  [14558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3770),
  [14560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [14562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4092),
  [14564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3738),
  [14566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [14568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [14570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3873),
  [14572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6005),
  [14574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6004),
  [14576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6004),
  [14578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3773),
  [14580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3773),
  [14582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [14584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3984),
  [14586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3453),
  [14588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [14590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [14592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [14594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [14596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [14598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3428),
  [14600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [14602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [14604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [14606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [14608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [14610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3440),
  [14612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [14614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [14616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [14618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [14620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [14622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(135),
  [14624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [14626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 1, 0, 0),
  [14628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6089),
  [14630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(54),
  [14632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3435),
  [14634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(130),
  [14636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [14638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [14640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [14642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [14644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6092),
  [14646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(52),
  [14648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5717),
  [14650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4904),
  [14652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [14654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [14656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [14658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [14660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [14662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [14664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [14666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3911),
  [14668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3911),
  [14670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3370),
  [14672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5707),
  [14674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 1, 0, 12),
  [14676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [14678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [14680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [14682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6638),
  [14684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 3, 0, 0),
  [14686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2377),
  [14688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7059),
  [14690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7059),
  [14692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6272),
  [14694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5704),
  [14696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6097),
  [14698] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_regex, 2, 0, 12),
  [14700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6272),
  [14702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6097),
  [14704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4787),
  [14706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6128),
  [14708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2374),
  [14710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7362),
  [14712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7362),
  [14714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__expansion_regex_repeat1, 2, 0, 0), SHIFT_REPEAT(6272),
  [14717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__expansion_regex_repeat1, 2, 0, 0), SHIFT_REPEAT(5704),
  [14720] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__expansion_regex_repeat1, 2, 0, 0), SHIFT_REPEAT(6097),
  [14723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__expansion_regex_repeat1, 2, 0, 0),
  [14725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__expansion_regex_repeat1, 2, 0, 0), SHIFT_REPEAT(6272),
  [14728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__expansion_regex_repeat1, 2, 0, 0), SHIFT_REPEAT(6097),
  [14731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3911),
  [14734] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(3911),
  [14737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3821),
  [14739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6094),
  [14741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expansion_regex, 1, 0, 12),
  [14743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6094),
  [14745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4050),
  [14747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2320),
  [14749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6862),
  [14751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6862),
  [14753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2378),
  [14755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7363),
  [14757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7363),
  [14759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6130),
  [14761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2336),
  [14763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7317),
  [14765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7317),
  [14767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2331),
  [14769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6870),
  [14771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6870),
  [14773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2375),
  [14775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7050),
  [14777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7050),
  [14779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2334),
  [14781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7321),
  [14783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7321),
  [14785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6233),
  [14787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(6233),
  [14790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length_binary_expression, 3, 0, 27),
  [14792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6104),
  [14794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length_expression, 1, 0, 0),
  [14796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5157),
  [14798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 2, 0, 12),
  [14800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length_expression, 1, 0, 7),
  [14802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5160),
  [14804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 2, 0, 50),
  [14806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3507),
  [14808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [14810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4063),
  [14812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [14814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [14816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [14818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [14820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 4, 0, 49),
  [14822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [14824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 5, 0, 51),
  [14826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [14828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 5, 0, 122),
  [14830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [14832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [14834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [14836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 4, 0, 91),
  [14838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [14840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [14842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4520),
  [14844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4758),
  [14846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4520),
  [14848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [14850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [14852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 4, 0, 64),
  [14854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [14856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 4, 0, 92),
  [14858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6326),
  [14860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [14862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4846),
  [14864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [14866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [14868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4151),
  [14870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4151),
  [14872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [14874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4897),
  [14876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [14878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [14880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [14882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [14884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [14886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4671),
  [14888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4671),
  [14890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [14892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 5, 0, 64),
  [14894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [14896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [14898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6300),
  [14900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [14902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [14904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [14906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7143),
  [14908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5324),
  [14910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 5, 0, 89),
  [14912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6670),
  [14914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [14916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4544),
  [14918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [14920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [14922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [14924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [14926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4660),
  [14928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4660),
  [14930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [14932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 3, 0, 49),
  [14934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [14936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [14938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [14940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [14942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [14944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [14946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [14948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [14950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6308),
  [14952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [14954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5456),
  [14956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [14958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4552),
  [14960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [14962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6946),
  [14964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 3, 0, 49),
  [14966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6700),
  [14968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4563),
  [14970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4563),
  [14972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [14974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4586),
  [14976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [14978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [14980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6708),
  [14982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 4, 0, 51),
  [14984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6645),
  [14986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [14988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [14990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [14992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [14994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 4, 0, 51),
  [14996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4623),
  [14998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4623),
  [15000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [15002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4644),
  [15004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4644),
  [15006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [15008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [15010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [15012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4657),
  [15014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [15016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 5, 0, 123),
  [15018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [15020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [15022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 3, 0, 63),
  [15024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [15026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [15028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [15030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [15032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [15034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [15036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6346),
  [15038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [15040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [15042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [15044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [15046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_max_length, 4, 0, 90),
  [15048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [15050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4154),
  [15052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4154),
  [15054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [15056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [15058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5463),
  [15060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [15062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__expansion_regex_repeat1, 1, 0, 48),
  [15064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__expansion_regex_repeat1, 1, 0, 48),
  [15066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [15068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [15070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6977),
  [15072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 5, 0, 121),
  [15074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6399),
  [15076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 3, 0, 52),
  [15078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6484),
  [15080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7266),
  [15082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6031),
  [15084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6813),
  [15086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6938),
  [15088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 3, 0, 62),
  [15090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7023),
  [15092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 3, 0, 53),
  [15094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4077),
  [15096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6396),
  [15098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__concatenation_in_expansion, 2, 0, 0),
  [15100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7045),
  [15102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 4, 0, 85),
  [15104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 1, 0, 7),
  [15106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_item_repeat1, 2, 0, 46),
  [15108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__concatenation_in_expansion_repeat1, 2, 0, 0),
  [15110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__concatenation_in_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(5324),
  [15113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 2, 0, 31),
  [15115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_body, 2, 0, 32),
  [15117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6891),
  [15119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3776),
  [15121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6632),
  [15123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6632),
  [15125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7180),
  [15127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6095),
  [15129] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(4063),
  [15132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3730),
  [15134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6680),
  [15136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6680),
  [15138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6436),
  [15140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [15142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(417),
  [15145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__for_body_repeat1, 2, 0, 0),
  [15147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__for_body_repeat1, 2, 0, 0), SHIFT_REPEAT(4758),
  [15150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__for_body_repeat1, 2, 0, 0),
  [15152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3791),
  [15154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6689),
  [15156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6689),
  [15158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6400),
  [15160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3760),
  [15162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6630),
  [15164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6630),
  [15166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__expansion_body_repeat1, 2, 0, 34),
  [15168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__expansion_body_repeat1, 2, 0, 34), SHIFT_REPEAT(6418),
  [15171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_item_repeat1, 2, 0, 45),
  [15173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4075),
  [15175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(6484),
  [15178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_expression, 1, 0, 26),
  [15180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_expression, 1, 0, 26),
  [15182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_case_item, 5, 0, 109),
  [15184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5186),
  [15186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5267),
  [15188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5269),
  [15190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_case_item, 5, 0, 112),
  [15192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5189),
  [15194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5283),
  [15196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5296),
  [15198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_case_item, 3, 0, 59),
  [15200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5226),
  [15202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5363),
  [15204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_case_item, 3, 0, 60),
  [15206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5231),
  [15208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5376),
  [15210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5205),
  [15212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5317),
  [15214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5326),
  [15216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__expansion_body_repeat1, 1, 0, 12),
  [15218] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__literal_repeat1, 2, 0, 0), SHIFT_REPEAT(6492),
  [15221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5213),
  [15223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5361),
  [15225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5362),
  [15227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_variable_assignment, 3, 0, 55),
  [15229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_variable_assignment, 3, 0, 55),
  [15231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_expression, 2, 0, 12),
  [15233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_case_item, 4, 0, 79),
  [15235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5116),
  [15237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5255),
  [15239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5258),
  [15241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_case_item, 4, 0, 45),
  [15243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5184),
  [15245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5262),
  [15247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_case_item, 4, 0, 46),
  [15249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5223),
  [15251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5401),
  [15253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_case_item, 4, 0, 83),
  [15255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5151),
  [15257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5300),
  [15259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5333),
  [15261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5162),
  [15263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5336),
  [15265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5356),
  [15267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5177),
  [15269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5250),
  [15271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5251),
  [15273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [15275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [15277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4688),
  [15279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [15281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [15283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5354),
  [15285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3389),
  [15287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [15289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [15291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [15293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [15295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4427),
  [15297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [15299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3391),
  [15301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 4, 0, 70),
  [15303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4806),
  [15305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3392),
  [15307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 4, 0, 72),
  [15309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1984),
  [15311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 4, 0, 74),
  [15313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3393),
  [15315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3394),
  [15317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [15319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 6, 0, 132),
  [15321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5254),
  [15323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3395),
  [15325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 6, 0, 133),
  [15327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3396),
  [15329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__for_body_repeat1, 2, 0, 0), SHIFT_REPEAT(4806),
  [15332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 7, 0, 150),
  [15334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3397),
  [15336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3398),
  [15338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 6, 0, 129),
  [15340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5430),
  [15342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [15344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4226),
  [15346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [15348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3400),
  [15350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [15352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3401),
  [15354] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_item_repeat1, 2, 0, 80), SHIFT_REPEAT(3507),
  [15357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_item_repeat1, 2, 0, 80),
  [15359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [15361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3426),
  [15363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3384),
  [15365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [15367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [15369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4851),
  [15371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3261),
  [15373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [15375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [15377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [15379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [15381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3111),
  [15383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [15385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4197),
  [15387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6390),
  [15389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [15391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [15393] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__for_body_repeat1, 2, 0, 0), SHIFT_REPEAT(4851),
  [15396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [15398] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arithmetic_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3502),
  [15401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [15403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [15405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [15407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [15409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [15411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [15413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 7, 0, 151),
  [15415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [15417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [15419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6693),
  [15421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6643),
  [15423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [15425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2586),
  [15427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [15429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [15431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [15433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 7, 0, 152),
  [15435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3103),
  [15437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4512),
  [15439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2866),
  [15441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6688),
  [15443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3157),
  [15445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2455),
  [15447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5316),
  [15449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [15451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3368),
  [15453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 2, 0, 12),
  [15455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6694),
  [15457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6075),
  [15459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5322),
  [15461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5403),
  [15463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5355),
  [15465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2353),
  [15467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4403),
  [15469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [15471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 8, 0, 158),
  [15473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4428),
  [15475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [15477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4299),
  [15479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [15481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3381),
  [15483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [15485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5188),
  [15487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3387),
  [15489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [15491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5389),
  [15493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2907),
  [15495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6134),
  [15497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6485),
  [15499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 6, 0, 130),
  [15501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [15503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4316),
  [15505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5335),
  [15507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1994),
  [15509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [15511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [15513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 5, 0, 96),
  [15515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 5, 0, 98),
  [15517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 5, 0, 100),
  [15519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [15521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [15523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [15525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 5, 0, 101),
  [15527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 5, 0, 102),
  [15529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5308),
  [15531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3420),
  [15533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3421),
  [15535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5272),
  [15537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5273),
  [15539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [15541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3423),
  [15543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5133),
  [15545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3297),
  [15547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [15549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2227),
  [15551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [15553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5339),
  [15555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [15557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [15559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 3, 0, 58),
  [15561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [15563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3424),
  [15565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3425),
  [15567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [15569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6699),
  [15571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [15573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5534),
  [15575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [15577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [15579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3383),
  [15581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [15583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [15585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5277),
  [15587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5344),
  [15589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_body, 6, 0, 128),
  [15591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [15593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6631),
  [15595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3388),
  [15597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [15599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4367),
  [15601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5393),
  [15603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_removal, 1, 0, 12),
  [15605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6954),
  [15607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6970),
  [15609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 5, 0, 119),
  [15611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4099),
  [15613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6320),
  [15615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6720),
  [15617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 6, 0, 89),
  [15619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4127),
  [15621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6364),
  [15623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3855),
  [15625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6327),
  [15627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4069),
  [15629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6375),
  [15631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3371),
  [15633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 3, 0, 12),
  [15635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7179),
  [15637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 4, 0, 88),
  [15639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [15641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [15643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 5, 0, 118),
  [15645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [15647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7131),
  [15649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [15651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6261),
  [15653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [15655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6427),
  [15657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6576),
  [15659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [15661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7292),
  [15663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 7, 0, 157),
  [15665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3234),
  [15667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [15669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [15671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2432),
  [15673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [15675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6912),
  [15677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6328),
  [15679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6114),
  [15681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [15683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [15685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4519),
  [15687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2343),
  [15689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [15691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7126),
  [15693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2218),
  [15695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [15697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6116),
  [15699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4195),
  [15701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2221),
  [15703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [15705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5129),
  [15707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6735),
  [15709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [15711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [15713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [15715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [15717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5367),
  [15719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6591),
  [15721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6774),
  [15723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6594),
  [15725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6329),
  [15727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [15729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6415),
  [15731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4885),
  [15733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7257),
  [15735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5130),
  [15737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4839),
  [15739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4783),
  [15741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [15743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [15745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6849),
  [15747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [15749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4853),
  [15751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [15753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6057),
  [15755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6978),
  [15757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5428),
  [15759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [15761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [15763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [15765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7089),
  [15767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2499),
  [15769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5530),
  [15771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [15773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5539),
  [15775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7220),
  [15777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4296),
  [15779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [15781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [15783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6388),
  [15785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4264),
  [15787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7364),
  [15789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4249),
  [15791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2592),
  [15793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5568),
  [15795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5382),
  [15797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5585),
  [15799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7258),
  [15801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [15803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [15805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__test_command_binary_expression, 3, 0, 43),
  [15807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5466),
  [15809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5467),
  [15811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7431),
  [15813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [15815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4914),
  [15817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [15819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2615),
  [15821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5474),
  [15823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5548),
  [15825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6765),
  [15827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5549),
  [15829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [15831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5153),
  [15833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2849),
  [15835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [15837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6908),
  [15839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5575),
  [15841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5580),
  [15843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5384),
  [15845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4207),
  [15847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [15849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7210),
  [15851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4209),
  [15853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2470),
  [15855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [15857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2743),
  [15859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7386),
  [15861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [15863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6430),
  [15865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [15867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5249),
  [15869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5442),
  [15871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [15873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6798),
  [15875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5439),
  [15877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [15879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [15881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [15883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6058),
  [15885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6844),
  [15887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [15889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4001),
  [15891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7155),
  [15893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6176),
  [15895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2394),
  [15897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [15899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6894),
  [15901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2934),
  [15903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2489),
  [15905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [15907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [15909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5154),
  [15911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [15913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6942),
  [15915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2439),
  [15917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6111),
  [15919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2620),
  [15921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5156),
  [15923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2622),
  [15925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7015),
  [15927] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [15929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4829),
  [15931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2065),
  [15933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [15935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7069),
  [15937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [15939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6352),
  [15941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2781),
  [15943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4917),
  [15945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4927),
  [15947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7106),
  [15949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [15951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6366),
  [15953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [15955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6070),
  [15957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7164),
  [15959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [15961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [15963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5295),
  [15965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6055),
  [15967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5309),
  [15969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7208),
  [15971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [15973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4923),
  [15975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [15977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6432),
  [15979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [15981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [15983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7269),
  [15985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6060),
  [15987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [15989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [15991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4775),
  [15993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3236),
  [15995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4769),
  [15997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7345),
  [15999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6386),
  [16001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6662),
  [16003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [16005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [16007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6332),
  [16009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6118),
  [16011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7415),
  [16013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [16015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6120),
  [16017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [16019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4933),
  [16021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6750),
  [16023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [16025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5343),
  [16027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4576),
  [16029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 4, 0, 86),
  [16031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [16033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [16035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7265),
  [16037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5360),
  [16039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2597),
  [16041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [16043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [16045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 4, 0, 87),
  [16047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [16049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7139),
  [16051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [16053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [16055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6337),
  [16057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6338),
  [16059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_removal, 2, 0, 12),
  [16061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7428),
  [16063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1312),
  [16065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2599),
  [16067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6342),
  [16069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [16071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6732),
  [16073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [16075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6343),
  [16077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [16079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4583),
  [16081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6771),
  [16083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 6, 0, 146),
  [16085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [16087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4659),
  [16089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [16091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6853),
  [16093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 6, 0, 147),
  [16095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2248),
  [16097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6065),
  [16099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3921),
  [16101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [16103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6973),
  [16105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [16107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4823),
  [16109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [16111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [16113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7068),
  [16115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6381),
  [16117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [16119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [16121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4825),
  [16123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [16125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7211),
  [16127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [16129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4797),
  [16131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6989),
  [16133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4859),
  [16135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7311),
  [16137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [16139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2582),
  [16141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [16143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6194),
  [16145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7429),
  [16147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2529),
  [16149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [16151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2550),
  [16153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4774),
  [16155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6743),
  [16157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4858),
  [16159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [16161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [16163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2486),
  [16165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5574),
  [16167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5578),
  [16169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6800),
  [16171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [16173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [16175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [16177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4663),
  [16179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4778),
  [16181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6834),
  [16183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4795),
  [16185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4372),
  [16187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [16189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4377),
  [16191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6858),
  [16193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4856),
  [16195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4683),
  [16197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2429),
  [16199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4415),
  [16201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [16203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 5, 0, 117),
  [16205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6887),
  [16207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [16209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2037),
  [16211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2383),
  [16213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [16215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6911),
  [16217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4389),
  [16219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [16221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5180),
  [16223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [16225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [16227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [16229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6935),
  [16231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4401),
  [16233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1943),
  [16235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [16237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4413),
  [16239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4750),
  [16241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6972),
  [16243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [16245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5183),
  [16247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [16249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [16251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3413),
  [16253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3154),
  [16255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7006),
  [16257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3415),
  [16259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [16261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [16263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [16265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7038),
  [16267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [16269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [16271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [16273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2949),
  [16275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6408),
  [16277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [16279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7065),
  [16281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [16283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4206),
  [16285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4467),
  [16287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4028),
  [16289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4469),
  [16291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [16293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7262),
  [16295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1953),
  [16297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [16299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4585),
  [16301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4280),
  [16303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [16305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [16307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2953),
  [16309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [16311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5514),
  [16313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3379),
  [16315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6281),
  [16317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6282),
  [16319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [16321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [16323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [16325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [16327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6122),
  [16329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4278),
  [16331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4295),
  [16333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3380),
  [16335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4170),
  [16337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [16339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6285),
  [16341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2492),
  [16343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6286),
  [16345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6410),
  [16347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2583),
  [16349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6078),
  [16351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7358),
  [16353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6412),
  [16355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 6, 0, 148),
  [16357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6087),
  [16359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [16361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6289),
  [16363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [16365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [16367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [16369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [16371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [16373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6149),
  [16375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5284),
  [16377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6290),
  [16379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5541),
  [16381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4978),
  [16383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5285),
  [16385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4984),
  [16387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [16389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [16391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4273),
  [16393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6316),
  [16395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4203),
  [16397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4972),
  [16399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [16401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4973),
  [16403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [16405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_regex_replacement, 5, 0, 120),
  [16407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4906),
  [16409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4907),
  [16411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expansion_operator, 2, 0, 49),
  [16413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2328),
  [16415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [16417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [16419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4833),
  [16421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4969),
  [16423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4968),
  [16425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [16427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2789),
  [16429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [16431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6325),
  [16433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4951),
  [16435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4956),
  [16437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [16439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [16441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [16443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6449),
  [16445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [16447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6360),
  [16449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4483),
  [16451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [16453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6642),
  [16455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5423),
  [16457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [16459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4332),
  [16461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 1, 0, 0),
  [16463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [16465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [16467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [16469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [16471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [16473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5485),
  [16475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [16477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [16479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4542),
  [16481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [16483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4813),
  [16485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6391),
  [16487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [16489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5307),
  [16491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6124),
  [16493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6125),
  [16495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2445),
  [16497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6127),
  [16499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [16501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2662),
  [16503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2271),
  [16505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2573),
  [16507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6351),
  [16509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [16511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [16513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6353),
  [16515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2762),
  [16517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [16519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [16521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [16523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7349),
  [16525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [16527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [16529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5425),
  [16531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4961),
  [16533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4964),
  [16535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2559),
  [16537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3335),
  [16539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [16541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3340),
  [16543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4095),
  [16545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4446),
  [16547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [16549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6357),
  [16551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4558),
  [16553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [16555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6079),
  [16557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7002),
  [16559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4560),
  [16561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6084),
  [16563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [16565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6393),
  [16567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [16569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [16571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [16573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4451),
  [16575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [16577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [16579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [16581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6358),
  [16583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4462),
  [16585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [16587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4464),
  [16589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4470),
  [16591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [16593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4472),
  [16595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [16597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [16599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7404),
  [16601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6368),
  [16603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [16605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6064),
  [16607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1784),
  [16609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4871),
  [16611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [16613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2379),
  [16615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6053),
  [16617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4628),
  [16619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2389),
  [16621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4424),
  [16623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5318),
  [16625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [16627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5320),
  [16629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [16631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [16633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [16635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2226),
  [16637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4255),
  [16639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [16641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5598),
  [16643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4426),
  [16645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6059),
  [16647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4928),
  [16649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5576),
  [16651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6369),
  [16653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [16655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5603),
  [16657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2493),
  [16659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2229),
  [16661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [16663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [16665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [16667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4357),
  [16669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6909),
  [16671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6061),
  [16673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3899),
  [16675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6778),
  [16677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3146),
  [16679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6218),
  [16681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [16683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2326),
  [16685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4359),
  [16687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5211),
  [16689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4840),
  [16691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4634),
  [16693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [16695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4219),
  [16697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4989),
  [16699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [16701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3844),
  [16703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4125),
  [16705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4228),
  [16707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5607),
  [16709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7070),
  [16711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7401),
  [16713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6086),
  [16715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6860),
  [16717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2469),
  [16719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [16721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6052),
  [16723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [16725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2240),
  [16727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [16729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6783),
  [16731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [16733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2243),
  [16735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [16737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6363),
  [16739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6370),
  [16741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5532),
  [16743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7391),
  [16745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [16747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5608),
  [16749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [16751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4276),
  [16753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6380),
  [16755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5349),
  [16757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6384),
  [16759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6073),
  [16761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7097),
  [16763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6074),
  [16765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [16767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [16769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [16771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6298),
  [16773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2338),
  [16775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6299),
  [16777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7012),
  [16779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [16781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5351),
  [16783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4306),
  [16785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4263),
  [16787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [16789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6109),
  [16791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7259),
  [16793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7308),
  [16795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7355),
  [16797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7379),
  [16799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7421),
  [16801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7503),
  [16803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6710),
  [16805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6719),
  [16807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6728),
  [16809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6737),
  [16811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6746),
  [16813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6755),
  [16815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6764),
  [16817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6773),
  [16819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6780),
  [16821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6787),
  [16823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6794),
  [16825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6801),
  [16827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6808),
  [16829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6815),
  [16831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6822),
  [16833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6829),
  [16835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6836),
  [16837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6843),
  [16839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6850),
  [16841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6857),
  [16843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6864),
  [16845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6871),
  [16847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6878),
  [16849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6885),
  [16851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6892),
  [16853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6899),
  [16855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6906),
  [16857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6913),
  [16859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6920),
  [16861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6927),
  [16863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6934),
  [16865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6941),
  [16867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6948),
  [16869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6955),
  [16871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6962),
  [16873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6969),
  [16875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6976),
  [16877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6983),
  [16879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6990),
  [16881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6997),
  [16883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7004),
  [16885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7011),
  [16887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7018),
  [16889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7025),
  [16891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7032),
  [16893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7039),
  [16895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7046),
  [16897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7053),
  [16899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7060),
  [16901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7067),
  [16903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7074),
  [16905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7081),
  [16907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7088),
  [16909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7141),
  [16911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5214),
  [16913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4772),
  [16915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5216),
  [16917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6081),
  [16919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [16921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7282),
  [16923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7021),
  [16925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [16927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4920),
  [16929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5011),
  [16931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7384),
  [16933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7411),
  [16935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7434),
  [16937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7435),
  [16939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7436),
  [16941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7437),
  [16943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7438),
  [16945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7439),
  [16947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7440),
  [16949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7441),
  [16951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7442),
  [16953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7443),
  [16955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7444),
  [16957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7445),
  [16959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7446),
  [16961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7447),
  [16963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7448),
  [16965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7449),
  [16967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7450),
  [16969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7451),
  [16971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7452),
  [16973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7453),
  [16975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7454),
  [16977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7455),
  [16979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7456),
  [16981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7457),
  [16983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7458),
  [16985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7459),
  [16987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7460),
  [16989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7461),
  [16991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7462),
  [16993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7463),
  [16995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7464),
  [16997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7465),
  [16999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7466),
  [17001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7467),
  [17003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7468),
  [17005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7469),
  [17007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7470),
  [17009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7471),
  [17011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7472),
  [17013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7473),
  [17015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7474),
  [17017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7475),
  [17019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7476),
  [17021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7477),
  [17023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7478),
  [17025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7479),
  [17027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7480),
  [17029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7481),
  [17031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7482),
  [17033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7483),
  [17035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7484),
  [17037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7485),
  [17039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7486),
  [17041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7487),
  [17043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7488),
  [17045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7489),
  [17047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7490),
  [17049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7491),
  [17051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7492),
  [17053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2802),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_heredoc_start = 0,
  ts_external_token_simple_heredoc_body = 1,
  ts_external_token__heredoc_body_beginning = 2,
  ts_external_token_heredoc_content = 3,
  ts_external_token_heredoc_end = 4,
  ts_external_token_file_descriptor = 5,
  ts_external_token__empty_value = 6,
  ts_external_token__concat = 7,
  ts_external_token_variable_name = 8,
  ts_external_token_test_operator = 9,
  ts_external_token_regex = 10,
  ts_external_token__regex_no_slash = 11,
  ts_external_token__regex_no_space = 12,
  ts_external_token__expansion_word = 13,
  ts_external_token_extglob_pattern = 14,
  ts_external_token__bare_dollar = 15,
  ts_external_token__brace_start = 16,
  ts_external_token__immediate_double_hash = 17,
  ts_external_token__external_expansion_sym_hash = 18,
  ts_external_token__external_expansion_sym_bang = 19,
  ts_external_token__external_expansion_sym_equal = 20,
  ts_external_token_RBRACE = 21,
  ts_external_token_RBRACK = 22,
  ts_external_token_LT_LT = 23,
  ts_external_token_LT_LT_DASH = 24,
  ts_external_token_heredoc_redirect_token1 = 25,
  ts_external_token_LPAREN = 26,
  ts_external_token_esac = 27,
  ts_external_token___error_recovery = 28,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_heredoc_start] = sym_heredoc_start,
  [ts_external_token_simple_heredoc_body] = sym_simple_heredoc_body,
  [ts_external_token__heredoc_body_beginning] = sym__heredoc_body_beginning,
  [ts_external_token_heredoc_content] = sym_heredoc_content,
  [ts_external_token_heredoc_end] = sym_heredoc_end,
  [ts_external_token_file_descriptor] = sym_file_descriptor,
  [ts_external_token__empty_value] = sym__empty_value,
  [ts_external_token__concat] = sym__concat,
  [ts_external_token_variable_name] = sym_variable_name,
  [ts_external_token_test_operator] = sym_test_operator,
  [ts_external_token_regex] = sym_regex,
  [ts_external_token__regex_no_slash] = sym__regex_no_slash,
  [ts_external_token__regex_no_space] = sym__regex_no_space,
  [ts_external_token__expansion_word] = sym__expansion_word,
  [ts_external_token_extglob_pattern] = sym_extglob_pattern,
  [ts_external_token__bare_dollar] = sym__bare_dollar,
  [ts_external_token__brace_start] = sym__brace_start,
  [ts_external_token__immediate_double_hash] = sym__immediate_double_hash,
  [ts_external_token__external_expansion_sym_hash] = sym__external_expansion_sym_hash,
  [ts_external_token__external_expansion_sym_bang] = sym__external_expansion_sym_bang,
  [ts_external_token__external_expansion_sym_equal] = sym__external_expansion_sym_equal,
  [ts_external_token_RBRACE] = anon_sym_RBRACE3,
  [ts_external_token_RBRACK] = anon_sym_RBRACK,
  [ts_external_token_LT_LT] = anon_sym_LT_LT,
  [ts_external_token_LT_LT_DASH] = anon_sym_LT_LT_DASH,
  [ts_external_token_heredoc_redirect_token1] = aux_sym_heredoc_redirect_token1,
  [ts_external_token_LPAREN] = anon_sym_LPAREN,
  [ts_external_token_esac] = anon_sym_esac,
  [ts_external_token___error_recovery] = sym___error_recovery,
};

static const bool ts_external_scanner_states[131][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_heredoc_start] = true,
    [ts_external_token_simple_heredoc_body] = true,
    [ts_external_token__heredoc_body_beginning] = true,
    [ts_external_token_heredoc_content] = true,
    [ts_external_token_heredoc_end] = true,
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__empty_value] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token_regex] = true,
    [ts_external_token__regex_no_slash] = true,
    [ts_external_token__regex_no_space] = true,
    [ts_external_token__expansion_word] = true,
    [ts_external_token_extglob_pattern] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token__immediate_double_hash] = true,
    [ts_external_token__external_expansion_sym_hash] = true,
    [ts_external_token__external_expansion_sym_bang] = true,
    [ts_external_token__external_expansion_sym_equal] = true,
    [ts_external_token_RBRACE] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_LPAREN] = true,
    [ts_external_token_esac] = true,
    [ts_external_token___error_recovery] = true,
  },
  [2] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LPAREN] = true,
  },
  [3] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LPAREN] = true,
  },
  [4] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
  },
  [5] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_LPAREN] = true,
  },
  [6] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LPAREN] = true,
    [ts_external_token_esac] = true,
  },
  [7] = {
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LPAREN] = true,
  },
  [8] = {
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LPAREN] = true,
  },
  [9] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
  },
  [10] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_LPAREN] = true,
  },
  [11] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
  },
  [12] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_LPAREN] = true,
  },
  [13] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
    [ts_external_token_esac] = true,
  },
  [14] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [15] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [16] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [17] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
    [ts_external_token_esac] = true,
  },
  [18] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [19] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [20] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [21] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [22] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [23] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_LPAREN] = true,
  },
  [24] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [25] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [26] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [27] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_LPAREN] = true,
  },
  [28] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
    [ts_external_token_esac] = true,
  },
  [29] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [30] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [31] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [32] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [33] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [34] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [35] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
  },
  [36] = {
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
  },
  [37] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token_LT_LT] = true,
  },
  [38] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [39] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_LT_LT] = true,
  },
  [40] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
  },
  [41] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [42] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LPAREN] = true,
  },
  [43] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [44] = {
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
  },
  [45] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [46] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
  },
  [47] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [48] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_extglob_pattern] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LPAREN] = true,
  },
  [49] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token__regex_no_space] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LPAREN] = true,
  },
  [50] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_LPAREN] = true,
  },
  [51] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [52] = {
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token_LT_LT] = true,
  },
  [53] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [54] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_extglob_pattern] = true,
    [ts_external_token_LT_LT] = true,
  },
  [55] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_extglob_pattern] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
    [ts_external_token_esac] = true,
  },
  [56] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [57] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [58] = {
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token_extglob_pattern] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
  },
  [59] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [60] = {
    [ts_external_token__concat] = true,
    [ts_external_token_LT_LT] = true,
  },
  [61] = {
    [ts_external_token_LT_LT] = true,
  },
  [62] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_extglob_pattern] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
  },
  [63] = {
    [ts_external_token_LT_LT] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [64] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [65] = {
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
  },
  [66] = {
    [ts_external_token__concat] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
  },
  [67] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [68] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [69] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_extglob_pattern] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LPAREN] = true,
    [ts_external_token_esac] = true,
  },
  [70] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
  },
  [71] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [72] = {
    [ts_external_token__immediate_double_hash] = true,
    [ts_external_token__external_expansion_sym_hash] = true,
    [ts_external_token__external_expansion_sym_bang] = true,
    [ts_external_token__external_expansion_sym_equal] = true,
    [ts_external_token_RBRACE] = true,
  },
  [73] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__expansion_word] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACE] = true,
    [ts_external_token_LPAREN] = true,
  },
  [74] = {
    [ts_external_token__empty_value] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_LPAREN] = true,
  },
  [75] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [76] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token_LPAREN] = true,
  },
  [77] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [78] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
  },
  [79] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_extglob_pattern] = true,
    [ts_external_token__brace_start] = true,
  },
  [80] = {
    [ts_external_token__immediate_double_hash] = true,
    [ts_external_token_RBRACE] = true,
  },
  [81] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [82] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
  },
  [83] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token_regex] = true,
    [ts_external_token__brace_start] = true,
  },
  [84] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_RBRACK] = true,
  },
  [85] = {
    [ts_external_token_test_operator] = true,
    [ts_external_token__bare_dollar] = true,
    [ts_external_token__brace_start] = true,
  },
  [86] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [87] = {
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
  },
  [88] = {
    [ts_external_token__immediate_double_hash] = true,
  },
  [89] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [90] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_esac] = true,
  },
  [91] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [92] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [93] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [94] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [95] = {
    [ts_external_token__concat] = true,
    [ts_external_token__immediate_double_hash] = true,
    [ts_external_token__external_expansion_sym_hash] = true,
    [ts_external_token__external_expansion_sym_bang] = true,
    [ts_external_token__external_expansion_sym_equal] = true,
    [ts_external_token_RBRACE] = true,
  },
  [96] = {
    [ts_external_token_LPAREN] = true,
  },
  [97] = {
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [98] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token__external_expansion_sym_hash] = true,
    [ts_external_token__external_expansion_sym_bang] = true,
    [ts_external_token__external_expansion_sym_equal] = true,
    [ts_external_token_RBRACE] = true,
  },
  [99] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [100] = {
    [ts_external_token__concat] = true,
    [ts_external_token_test_operator] = true,
    [ts_external_token__brace_start] = true,
  },
  [101] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [102] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [103] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_variable_name] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [104] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [105] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token__expansion_word] = true,
    [ts_external_token_RBRACE] = true,
    [ts_external_token_LPAREN] = true,
  },
  [106] = {
    [ts_external_token_RBRACE] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
    [ts_external_token_LPAREN] = true,
  },
  [107] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token__expansion_word] = true,
    [ts_external_token_LPAREN] = true,
  },
  [108] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [109] = {
    [ts_external_token_file_descriptor] = true,
    [ts_external_token__concat] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [110] = {
    [ts_external_token_variable_name] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [111] = {
    [ts_external_token_variable_name] = true,
  },
  [112] = {
    [ts_external_token_LT_LT] = true,
    [ts_external_token_LT_LT_DASH] = true,
  },
  [113] = {
    [ts_external_token_heredoc_content] = true,
    [ts_external_token_heredoc_end] = true,
  },
  [114] = {
    [ts_external_token_RBRACE] = true,
  },
  [115] = {
    [ts_external_token__concat] = true,
  },
  [116] = {
    [ts_external_token__concat] = true,
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [117] = {
    [ts_external_token__regex_no_slash] = true,
    [ts_external_token_RBRACE] = true,
  },
  [118] = {
    [ts_external_token_regex] = true,
    [ts_external_token_RBRACE] = true,
  },
  [119] = {
    [ts_external_token_heredoc_redirect_token1] = true,
  },
  [120] = {
    [ts_external_token__concat] = true,
    [ts_external_token__expansion_word] = true,
    [ts_external_token_RBRACE] = true,
  },
  [121] = {
    [ts_external_token__concat] = true,
    [ts_external_token_RBRACE] = true,
  },
  [122] = {
    [ts_external_token__concat] = true,
    [ts_external_token__external_expansion_sym_hash] = true,
    [ts_external_token__external_expansion_sym_bang] = true,
    [ts_external_token__external_expansion_sym_equal] = true,
    [ts_external_token_RBRACE] = true,
  },
  [123] = {
    [ts_external_token__external_expansion_sym_hash] = true,
    [ts_external_token__external_expansion_sym_bang] = true,
    [ts_external_token__external_expansion_sym_equal] = true,
    [ts_external_token_RBRACE] = true,
  },
  [124] = {
    [ts_external_token_simple_heredoc_body] = true,
    [ts_external_token__heredoc_body_beginning] = true,
  },
  [125] = {
    [ts_external_token_esac] = true,
  },
  [126] = {
    [ts_external_token_extglob_pattern] = true,
  },
  [127] = {
    [ts_external_token__concat] = true,
    [ts_external_token_RBRACK] = true,
  },
  [128] = {
    [ts_external_token_RBRACK] = true,
  },
  [129] = {
    [ts_external_token_heredoc_end] = true,
  },
  [130] = {
    [ts_external_token_heredoc_start] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_bash_external_scanner_create(void);
void tree_sitter_bash_external_scanner_destroy(void *);
bool tree_sitter_bash_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_bash_external_scanner_serialize(void *, char *);
void tree_sitter_bash_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_bash(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .supertype_map_slices = ts_supertype_map_slices,
    .supertype_map_entries = ts_supertype_map_entries,
    .supertype_symbols = ts_supertype_symbols,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_word,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_bash_external_scanner_create,
      tree_sitter_bash_external_scanner_destroy,
      tree_sitter_bash_external_scanner_scan,
      tree_sitter_bash_external_scanner_serialize,
      tree_sitter_bash_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "bash",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 25,
      .patch_version = 1,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
